EnrolledService class

Represents the enrollment of a cloud resource into a specific service.

Constructors

EnrolledService({String? cloudProduct, String? enrollmentLevel})
EnrolledService.fromJson(Map json_)

Properties

cloudProduct ↔ String?
The product for which Access Approval will be enrolled.
getter/setter pair
enrollmentLevel ↔ String?
The enrollment level of the service. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited