AccessLevel class

An AccessLevel is a label that can be applied to requests to Google Cloud services, along with a list of requirements necessary for the label to be applied.

Constructors

AccessLevel({BasicLevel? basic, CustomLevel? custom, String? description, String? name, String? title})
AccessLevel.fromJson(Map json_)

Properties

basic ↔ BasicLevel?
A BasicLevel composed of Conditions.
getter/setter pair
custom ↔ CustomLevel?
A CustomLevel written in the Common Expression Language.
getter/setter pair
description ↔ String?
Description of the AccessLevel and its use.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Human readable title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited