AccessPoliciesResource class

Constructors

AccessPoliciesResource(ApiRequester client)

Properties

accessLevels → AccessPoliciesAccessLevelsResource
no setter
authorizedOrgsDescs → AccessPoliciesAuthorizedOrgsDescsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servicePerimeters → AccessPoliciesServicePerimetersResource
no setter

Methods

create(AccessPolicy request, {String? $fields}) → Future<Operation>
Creates an access policy.
delete(String name, {String? $fields}) → Future<Operation>
Deletes an access policy based on the resource name.
get(String name, {String? $fields}) → Future<AccessPolicy>
Returns an access policy based on the name.
getIamPolicy(GetIamPolicyRequest request, String resource, {String? $fields}) → Future<Policy>
Gets the IAM policy for the specified Access Context Manager access policy.
list({int? pageSize, String? pageToken, String? parent, String? $fields}) → Future<ListAccessPoliciesResponse>
Lists all access policies in an organization.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(AccessPolicy request, String name, {String? updateMask, String? $fields}) → Future<Operation>
Updates an access policy.
setIamPolicy(SetIamPolicyRequest request, String resource, {String? $fields}) → Future<Policy>
Sets the IAM policy for the specified Access Context Manager access policy.
testIamPermissions(TestIamPermissionsRequest request, String resource, {String? $fields}) → Future<TestIamPermissionsResponse>
Returns the IAM permissions that the caller has on the specified Access Context Manager resource.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited