get method

Future<ServicePerimeter> get(
  1. String name, {
  2. String? deletedPrincipalSyntax,
  3. String? $fields,
})

Gets a service perimeter based on the resource name.

Request parameters:

name - Required. Resource name for the Service Perimeter. Format: accessPolicies/{policy_id}/servicePerimeters/{service_perimeters_id} Value must have pattern ^accessPolicies/\[^/\]+/servicePerimeters/\[^/\]+$.

deletedPrincipalSyntax - Optional. If true, the response will contain the deleted principal syntax for identities that support it. Possible string values are:

  • "DELETED_PRINCIPAL_SYNTAX_SUPPORT_UNSPECIFIED" : Deleted principal syntax support was not specified.
  • "DELETED_PRINCIPAL_SYNTAX_SUPPORT_DISABLED" : Deleted principal syntax is disabled and no identities in the request or response will contain deleted principal syntax.
  • "DELETED_PRINCIPAL_SYNTAX_SUPPORT_ENABLED" : The request and response can contain identities with deleted IAM principal syntax.

$fields - Selector specifying which fields to include in a partial response.

Completes with a ServicePerimeter.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<ServicePerimeter> get(
  core.String name, {
  core.String? deletedPrincipalSyntax,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'deletedPrincipalSyntax': ?deletedPrincipalSyntax == null
        ? null
        : [deletedPrincipalSyntax],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return ServicePerimeter.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}