AccessScope class

Access scope represents the client scope, etc.

to which the settings will be applied to.

Constructors

AccessScope({ClientScope? clientScope})
AccessScope.fromJson(Map json_)

Properties

clientScope ↔ ClientScope?
Client scope for this access scope.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited