restrictedProject property
The Google Cloud project that is subject to this binding's scope.
Optional.
Implementation
Project? restrictedProject;
The Google Cloud project that is subject to this binding's scope.
Optional.
Project? restrictedProject;