identities property

List<String>? identities
getter/setter pair

A list of identities that are allowed access through [EgressPolicy].

Identities can be an individual user, service account, Google group, third-party identity, or agent identity. For the list of supported identity types, see https://docs.cloud.google.com/vpc-service-controls/docs/supported-identities.

Implementation

core.List<core.String>? identities;