EgressSource class
The source that EgressPolicy authorizes access from inside the ServicePerimeter to somewhere outside the ServicePerimeter boundaries.
Constructors
- EgressSource({String? accessLevel, PrivateServiceConnectEndpoint? pscEndpoint, String? resource})
- EgressSource.fromJson(Map json_)
Properties
- accessLevel ↔ String?
-
An AccessLevel resource name that allows protected resources inside the
ServicePerimeters to access outside the ServicePerimeter boundaries.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pscEndpoint ↔ PrivateServiceConnectEndpoint?
-
A PrivateServiceConnectEndpoint that is allowed to access data outside the
perimeter.
getter/setter pair
- resource ↔ String?
-
A Google Cloud resource from the service perimeter that you want to allow
to access data outside the perimeter.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited