GcpUserAccessBinding class
Restricts access to Cloud Console and Google Cloud APIs for a set of users using Context-Aware Access.
Constructors
-
GcpUserAccessBinding({List<
String> ? accessLevels, List<String> ? dryRunAccessLevels, String? groupKey, String? name, Principal? principal, List<Application> ? restrictedClientApplications, List<ScopedAccessSettings> ? scopedAccessSettings, SessionSettings? sessionSettings}) - GcpUserAccessBinding.fromJson(Map json_)
Properties
-
accessLevels
↔ List<
String> ? -
Access level that a user must have to be granted access.
getter/setter pair
-
dryRunAccessLevels
↔ List<
String> ? -
Dry run access level that will be evaluated but will not be enforced.
getter/setter pair
- groupKey ↔ String?
-
Google Group id whose users are subject to this binding's restrictions.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Assigned by the server during creation.
getter/setter pair
- principal ↔ Principal?
-
The principal that is subject to the access policies in this policy
binding.
getter/setter pair
-
restrictedClientApplications
↔ List<
Application> ? -
Deprecated: Use
scoped_access_settingsinstead.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopedAccessSettings
↔ List<
ScopedAccessSettings> ? -
A list of scoped access settings that set this binding's restrictions on a
subset of applications.
getter/setter pair
- sessionSettings ↔ SessionSettings?
-
The Google Cloud session length (GCSL) policy for the group key.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited