ListServicePerimetersResponse class

A response to ListServicePerimetersRequest.

Constructors

ListServicePerimetersResponse({String? nextPageToken, List<ServicePerimeter>? servicePerimeters})
ListServicePerimetersResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The pagination token to retrieve the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servicePerimeters ↔ List<ServicePerimeter>?
List of the Service Perimeter instances.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited