ListSupportedPermissionsResponse class
A response to ListSupportedPermissionsRequest.
Constructors
-
ListSupportedPermissionsResponse({String? nextPageToken, List<
String> ? supportedPermissions}) - ListSupportedPermissionsResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
Use this pagination token to retrieve the next page of results.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedPermissions
↔ List<
String> ? -
List of VPC Service Controls supported permissions.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited