nextPageToken property
Use this pagination token to retrieve the next page of results.
An empty value indicates that no further results are available.
Implementation
core.String? nextPageToken;
Use this pagination token to retrieve the next page of results.
An empty value indicates that no further results are available.
core.String? nextPageToken;