Principal class

The comprehensive identity container supporting identities including groups, service accounts, and federated identities.

Only one of them can be set to create an access binding.

Constructors

Principal({String? federatedPrincipal, String? serviceAccount, String? serviceAccountProjectNumber})
Principal.fromJson(Map json_)

Properties

federatedPrincipal ↔ String?
The IAM principal identifier of the federated workforce or workload to assign the policy to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Service account email used to assign policies to a specific service account.
getter/setter pair
serviceAccountProjectNumber ↔ String?
Cloud project number used to assign policies to all service accounts owned by the project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited