serviceAccount property

String? serviceAccount
getter/setter pair

Service account email used to assign policies to a specific service account.

If a service account is subject to multiple policies (e.g., if there is a policy for all service accounts in a project and a policy for the service account), the closest (i.e. the most specific) dry-run policy will be used for the dry-run functionality and the closest enforcement policy will be used for the enforcement.

Immutable.

Implementation

core.String? serviceAccount;