serviceAccountProjectNumber property
Cloud project number used to assign policies to all service accounts owned by the project.
Immutable.
Implementation
core.String? serviceAccountProjectNumber;
Cloud project number used to assign policies to all service accounts owned by the project.
Immutable.
core.String? serviceAccountProjectNumber;