sessionLengthEnabled property

bool? sessionLengthEnabled
getter/setter pair

This field enables or disables Google Cloud session length.

When false, all fields set above will be disregarded and the session length is basically infinite. If session_length is set to zero, this field must be set to false.

Optional.

Implementation

core.bool? sessionLengthEnabled;