allowedServicePatterns property
Specifies which Google services are allowed to be accessed from VPC networks in the service perimeter.
Implementation
core.List<ServicePattern>? allowedServicePatterns;
Specifies which Google services are allowed to be accessed from VPC networks in the service perimeter.
core.List<ServicePattern>? allowedServicePatterns;