GoogleMapsAddressvalidationV1Address class

Details of the post-processed address.

Post-processing includes correcting misspelled parts of the address, replacing incorrect parts, and inferring missing parts.

Constructors

GoogleMapsAddressvalidationV1Address({List<GoogleMapsAddressvalidationV1AddressComponent>? addressComponents, String? formattedAddress, List<String>? missingComponentTypes, GoogleTypePostalAddress? postalAddress, List<String>? unconfirmedComponentTypes, List<String>? unresolvedTokens})
GoogleMapsAddressvalidationV1Address.fromJson(Map json_)

Properties

addressComponents ↔ List<GoogleMapsAddressvalidationV1AddressComponent>?
Unordered list.
getter/setter pair
formattedAddress ↔ String?
The post-processed address, formatted as a single-line address following the address formatting rules of the region where the address is located.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
missingComponentTypes ↔ List<String>?
The types of components that were expected to be present in a correctly formatted mailing address but were not found in the input AND could not be inferred.
getter/setter pair
postalAddress ↔ GoogleTypePostalAddress?
The post-processed address represented as a postal address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unconfirmedComponentTypes ↔ List<String>?
The types of the components that are present in the address_components but could not be confirmed to be correct.
getter/setter pair
unresolvedTokens ↔ List<String>?
Any tokens in the input that could not be resolved.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited