GoogleMapsAddressvalidationV1AddressComponent class

Represents an address component, such as a street, city, or state.

Constructors

GoogleMapsAddressvalidationV1AddressComponent({GoogleMapsAddressvalidationV1ComponentName? componentName, String? componentType, String? confirmationLevel, bool? inferred, bool? replaced, bool? spellCorrected, bool? unexpected})
GoogleMapsAddressvalidationV1AddressComponent.fromJson(Map json_)

Properties

componentName ↔ GoogleMapsAddressvalidationV1ComponentName?
The name for this component.
getter/setter pair
componentType ↔ String?
The type of the address component.
getter/setter pair
confirmationLevel ↔ String?
Indicates the level of certainty that we have that the component is correct. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inferred ↔ bool?
Indicates that the component was not part of the input, but we inferred it for the address location and believe it should be provided for a complete address.
getter/setter pair
replaced ↔ bool?
Indicates the name of the component was replaced with a completely different one, for example a wrong postal code being replaced with one that is correct for the address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spellCorrected ↔ bool?
Indicates a correction to a misspelling in the component name.
getter/setter pair
unexpected ↔ bool?
Indicates an address component that is not expected to be present in a postal address for the given region.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited