Building class

Public API: Resources.buildings

Constructors

Building({BuildingAddress? address, String? buildingId, String? buildingName, BuildingCoordinates? coordinates, String? description, String? etags, List<String>? floorNames, String? kind})
Building.fromJson(Map json_)

Properties

address ↔ BuildingAddress?
The postal address of the building.
getter/setter pair
buildingId ↔ String?
Unique identifier for the building.
getter/setter pair
buildingName ↔ String?
The building name as seen by users in Calendar.
getter/setter pair
coordinates ↔ BuildingCoordinates?
The geographic coordinates of the center of the building, expressed as latitude and longitude in decimal degrees.
getter/setter pair
description ↔ String?
A brief description of the building.
getter/setter pair
etags ↔ String?
ETag of the resource.
getter/setter pair
floorNames ↔ List<String>?
The display names for all floors in this building.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited