Channel class

An notification channel used to watch for resource changes.

Constructors

Channel({String? address, String? expiration, String? id, String? kind, Map<String, String>? params, bool? payload, String? resourceId, String? resourceUri, String? token, String? type})
Channel.fromJson(Map json_)

Properties

address ↔ String?
The address where notifications are delivered for this channel.
getter/setter pair
expiration ↔ String?
Date and time of notification channel expiration, expressed as a Unix timestamp, in milliseconds.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
A UUID or similar unique string that identifies this channel.
getter/setter pair
kind ↔ String?
Identifies this as a notification channel used to watch for changes to a resource, which is api#channel.
getter/setter pair
params ↔ Map<String, String>?
Additional parameters controlling delivery channel behavior.
getter/setter pair
payload ↔ bool?
A Boolean value to indicate whether payload is wanted.
getter/setter pair
resourceId ↔ String?
An opaque ID that identifies the resource being watched on this channel.
getter/setter pair
resourceUri ↔ String?
A version-specific identifier for the watched resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
An arbitrary string delivered to the target address with each notification delivered over this channel.
getter/setter pair
type ↔ String?
The type of delivery mechanism used for this channel.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited