CreatePrintServerRequest class

Request for adding a new print server.

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent ↔ String?
The unique ID of the customer's Google Workspace account.
getter/setter pair
printServer ↔ PrintServer?
A print server to create.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited