DirectoryChromeosdevicesCommandResult class

The result of executing a command.

Constructors

DirectoryChromeosdevicesCommandResult({String? commandResultPayload, String? errorMessage, String? executeTime, String? result})
DirectoryChromeosdevicesCommandResult.fromJson(Map json_)

Properties

commandResultPayload ↔ String?
The payload for the command result.
getter/setter pair
errorMessage ↔ String?
The error message with a short explanation as to why the command failed.
getter/setter pair
executeTime ↔ String?
The time at which the command was executed or failed to execute.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
result ↔ String?
The result of the command. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited