customer property
Immutable ID of the Google Workspace account.
Only required when request is created by a service account. Defaults to the authenticated user's customer ID otherwise.
Optional.
Implementation
core.String? customer;
Immutable ID of the Google Workspace account.
Only required when request is created by a service account. Defaults to the authenticated user's customer ID otherwise.
Optional.
core.String? customer;