Domains class

Constructors

Domains({String? creationTime, List<DomainAlias>? domainAliases, String? domainName, String? etag, bool? isPrimary, String? kind, bool? verified})
Domains.fromJson(Map json_)

Properties

creationTime ↔ String?
Creation time of the domain.
getter/setter pair
domainAliases ↔ List<DomainAlias>?
A list of domain alias objects.
getter/setter pair
domainName ↔ String?
The domain name of the customer.
getter/setter pair
etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPrimary ↔ bool?
Indicates if the domain is a primary domain (Read-only).
getter/setter pair
kind ↔ String?
Kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verified ↔ bool?
Indicates the verification state of a domain.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited