ExternalId class

External identifier used to link and identify this group across external directory systems.

Constructors

ExternalId({String? id, String? namespace})
ExternalId.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier string assigned by the external provider.
getter/setter pair
namespace String?
The system or identity provider managing this ID.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited