ListPrinterModelsResponse class

Response for listing allowed printer models.

Constructors

ListPrinterModelsResponse({String? nextPageToken, List<PrinterModel>? printerModels})
ListPrinterModelsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
printerModels ↔ List<PrinterModel>?
Printer models that are currently allowed to be configured for ChromeOs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited