Privilege class

Constructors

Privilege({List<Privilege>? childPrivileges, String? etag, bool? isOuScopable, String? kind, String? privilegeName, String? serviceId, String? serviceName})
Privilege.fromJson(Map json_)

Properties

childPrivileges ↔ List<Privilege>?
A list of child privileges.
getter/setter pair
etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isOuScopable ↔ bool?
If the privilege can be restricted to an organization unit.
getter/setter pair
kind ↔ String?
The type of the API resource.
getter/setter pair
privilegeName ↔ String?
The name of the privilege.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceId ↔ String?
The obfuscated ID of the service this privilege is for.
getter/setter pair
serviceName ↔ String?
The name of the service this privilege is for.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited