RoleAssignment class

Defines an assignment of a role.

Constructors

RoleAssignment({String? assignedTo, String? assigneeType, String? condition, String? etag, String? kind, String? orgUnitId, String? roleAssignmentId, String? roleId, String? scopeType})
RoleAssignment.fromJson(Map json_)

Properties

assignedTo ↔ String?
The unique ID of the entity this role is assigned to—either the user_id of a user, the group_id of a group, or the uniqueId of a service account as defined in [Identity and Access Management (IAM)](https://cloud.google.com/iam/docs/reference/rest/v1/projects.serviceAccounts).
getter/setter pair
assigneeType ↔ String?
The type of the assignee (USER or GROUP).
getter/setter pair
condition ↔ String?
The condition associated with this role assignment.
getter/setter pair
etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The type of the API resource.
getter/setter pair
orgUnitId ↔ String?
If the role is restricted to an organization unit, this contains the ID for the organization unit the exercise of this role is restricted to.
getter/setter pair
roleAssignmentId ↔ String?
ID of this roleAssignment.
getter/setter pair
roleId ↔ String?
The ID of the role that is assigned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeType ↔ String?
The scope in which this role is assigned.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited