UserPhoto class

Constructors

UserPhoto({String? etag, int? height, String? id, String? kind, String? mimeType, String? photoData, String? primaryEmail, int? width})
UserPhoto.fromJson(Map json_)

Properties

etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
Height of the photo in pixels.
getter/setter pair
id ↔ String?
The ID the API uses to uniquely identify the user.
getter/setter pair
kind ↔ String?
The type of the API resource.
getter/setter pair
mimeType ↔ String?
The MIME type of the photo.
getter/setter pair
photoData ↔ String?
The user photo's upload data in [web-safe Base64](https://en.wikipedia.org/wiki/Base64#URL_applications) format in bytes.
getter/setter pair
photoDataAsBytes ↔ List<int>
getter/setter pair
primaryEmail ↔ String?
The user's primary email address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int?
Width of the photo in pixels.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited