Users class

Constructors

Users({String? etag, String? kind, String? nextPageToken, String? triggerEvent, List<User>? users})
Users.fromJson(Map json_)

Properties

etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Kind of resource this is.
getter/setter pair
nextPageToken ↔ String?
Token used to access next page of this result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerEvent ↔ String?
Event that triggered this response (only used in case of Push Response)
getter/setter pair
users ↔ List<User>?
A list of user objects.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited