Activity class

JSON template for the activity resource.

Constructors

Activity({ActivityActor? actor, String? etag, List<ActivityEvents>? events, ActivityId? id, String? ipAddress, bool? isAgenticAction, String? kind, ActivityNetworkInfo? networkInfo, String? ownerDomain, List<ResourceDetails>? resourceDetails, ActivityUserDeviceInfo? userDeviceInfo})
Activity.fromJson(Map json_)

Properties

actor ↔ ActivityActor?
User doing the action.
getter/setter pair
etag ↔ String?
ETag of the entry.
getter/setter pair
events ↔ List<ActivityEvents>?
Activity events in the report.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ ActivityId?
Unique identifier for each activity record.
getter/setter pair
ipAddress ↔ String?
IP address of the user doing the action.
getter/setter pair
isAgenticAction ↔ bool?
Whether the activity was performed by an agent.
getter/setter pair
kind ↔ String?
The type of API resource.
getter/setter pair
networkInfo ↔ ActivityNetworkInfo?
Network information of the user doing the action.
getter/setter pair
ownerDomain ↔ String?
This is the domain that is affected by the report's event.
getter/setter pair
resourceDetails ↔ List<ResourceDetails>?
Details of the resource on which the action was performed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userDeviceInfo ↔ ActivityUserDeviceInfo?
Device details of the user doing the action.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited