agentAttributionInfo property
Details of the AI agent that was the actor for the activity.
Implementation
AgentAttributionInfo? agentAttributionInfo;
Details of the AI agent that was the actor for the activity.
AgentAttributionInfo? agentAttributionInfo;