ActivityEventsSensitiveParameters class

Properties

boolValue ↔ bool?
Boolean value of the parameter.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intValue ↔ String?
Integer value of the parameter.
getter/setter pair
messageValue ↔ ActivityEventsSensitiveParametersMessageValue?
Nested parameter value pairs associated with this parameter.
getter/setter pair
multiIntValue ↔ List<String>?
Integer values of the parameter.
getter/setter pair
multiMessageValue ↔ List<ActivityEventsSensitiveParametersMultiMessageValue>?
List of messageValue objects.
getter/setter pair
multiValue ↔ List<String>?
String values of the parameter.
getter/setter pair
name ↔ String?
The name of the parameter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
String value of the parameter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited