messageValue property

ActivityEventsSensitiveParametersMessageValue? messageValue
getter/setter pair

Nested parameter value pairs associated with this parameter.

Complex value type for a parameter are returned as a list of parameter values. For example, the address parameter may have a value as [{parameter: [{name: city, value: abc}]}]

Implementation

ActivityEventsSensitiveParametersMessageValue? messageValue;