ActivityEventsStatus class

Status of the event.

Note: Not all events have status.

Constructors

ActivityEventsStatus({String? errorCode, String? errorMessage, String? eventStatus, int? httpStatusCode})
ActivityEventsStatus.fromJson(Map json_)

Properties

errorCode ↔ String?
Error code of the event.
getter/setter pair
errorMessage ↔ String?
Error message of the event.
getter/setter pair
eventStatus ↔ String?
Status of the event.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpStatusCode ↔ int?
Status code of the event.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited