ActivityUserDeviceInfo class

Device details of the user doing the action.

Constructors

ActivityUserDeviceInfo({String? deviceId, String? deviceOsVersion, String? deviceType})
ActivityUserDeviceInfo.fromJson(Map json_)

Properties

deviceId ↔ String?
Device ID of the user's device.
getter/setter pair
deviceOsVersion ↔ String?
Device OS version of the user's device.
getter/setter pair
deviceType ↔ String?
The type of the user's device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited