AgentAttributionInfo class

Details of the AI agent that was the actor for the activity.

Constructors

AgentAttributionInfo({String? agentId, String? agentName, AgentAttributionInfoAgentOwner? agentOwner, String? agentType})
AgentAttributionInfo.fromJson(Map json_)

Properties

agentId String?
The ID of the agent.
getter/setter pair
agentName String?
The user visible name of the agent.
getter/setter pair
agentOwner AgentAttributionInfoAgentOwner?
The owner of the agent.
getter/setter pair
agentType String?
Type of the agent.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited