FieldValueSelectionValue class

Setting a selection value by selecting a single value from a dropdown.

Constructors

FieldValueSelectionValue({bool? badged, String? displayName, String? id})
FieldValueSelectionValue.fromJson(Map json_)

Properties

badged ↔ bool?
Whether the selection is badged.
getter/setter pair
displayName ↔ String?
Display name of the selection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Identifier of the selection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited