OwnerIdentity class

Identity details of the owner of the resource.

Constructors

OwnerIdentity({CustomerIdentity? customerIdentity, GroupIdentity? groupIdentity, SharedDriveIdentity? sharedDriveIdentity, UserIdentity? userIdentity})
OwnerIdentity.fromJson(Map json_)

Properties

customerIdentity CustomerIdentity?
Identity of the Google Workspace customer who owns the resource.
getter/setter pair
groupIdentity GroupIdentity?
Identity of the group who owns the resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharedDriveIdentity SharedDriveIdentity?
Identity of the shared drive who owns the resource.
getter/setter pair
userIdentity UserIdentity?
Identity of the user who owns the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited