ListPublisherAccountsResponse class

Response for the publisher account list request.

Properties

account ↔ List<PublisherAccount>?
Publisher that the client credentials can access.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If not empty, indicates that there might be more accounts for the request; you must pass this value in a new ListPublisherAccountsRequest.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited