NetworkReportSpec class

The specification for generating an AdMob Network report.

For example, the specification to get clicks and estimated earnings for only the 'US' and 'CN' countries can look like the following example: { 'date_range': { 'start_date': {'year': 2021, 'month': 9, 'day': 1}, 'end_date': {'year': 2021, 'month': 9, 'day': 30} }, 'dimensions': ['DATE', 'APP', 'COUNTRY'], 'metrics': ['CLICKS', 'ESTIMATED_EARNINGS'], 'dimension_filters': [ { 'dimension': 'COUNTRY', 'matches_any': {'values': [{'value': 'US', 'value': 'CN'}]} } ], 'sort_conditions': [ {'dimension':'APP', order: 'ASCENDING'}, {'metric':'CLICKS', order: 'DESCENDING'} ], 'localization_settings': { 'currency_code': 'USD', 'language_code': 'en-US' } } For a better understanding, you can treat the preceding specification like the following pseudo SQL: SELECT DATE, APP, COUNTRY, CLICKS, ESTIMATED_EARNINGS FROM NETWORK_REPORT WHERE DATE >= '2021-09-01' AND DATE <= '2021-09-30' AND COUNTRY IN ('US', 'CN') GROUP BY DATE, APP, COUNTRY ORDER BY APP ASC, CLICKS DESC;

Constructors

NetworkReportSpec({DateRange? dateRange, List<NetworkReportSpecDimensionFilter>? dimensionFilters, List<String>? dimensions, LocalizationSettings? localizationSettings, int? maxReportRows, List<String>? metrics, List<NetworkReportSpecSortCondition>? sortConditions, String? timeZone})
NetworkReportSpec.fromJson(Map json_)

Properties

dateRange ↔ DateRange?
The date range for which the report is generated.
getter/setter pair
dimensionFilters ↔ List<NetworkReportSpecDimensionFilter>?
Describes which report rows to match based on their dimension values.
getter/setter pair
dimensions ↔ List<String>?
List of dimensions of the report.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localizationSettings ↔ LocalizationSettings?
Localization settings of the report.
getter/setter pair
maxReportRows ↔ int?
Maximum number of report data rows to return.
getter/setter pair
metrics ↔ List<String>?
List of metrics of the report.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortConditions ↔ List<NetworkReportSpecSortCondition>?
Describes the sorting of report rows.
getter/setter pair
timeZone ↔ String?
A report time zone.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited