PublisherAccount class

A publisher account contains information relevant to the use of this API, such as the time zone used for the reports.

Constructors

PublisherAccount({String? currencyCode, String? name, String? publisherId, String? reportingTimeZone})
PublisherAccount.fromJson(Map json_)

Properties

currencyCode ↔ String?
Currency code of the earning-related metrics, which is the 3-letter code defined in ISO 4217.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of this account.
getter/setter pair
publisherId ↔ String?
The unique ID by which this publisher account can be identified in the API requests (for example, pub-1234567890).
getter/setter pair
reportingTimeZone ↔ String?
The time zone that is used in reports that are generated for this account.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited