ReportRowMetricValue class

Representation of a metric value.

Constructors

ReportRowMetricValue({double? doubleValue, String? integerValue, String? microsValue})
ReportRowMetricValue.fromJson(Map json_)

Properties

doubleValue ↔ double?
Double precision (approximate) decimal values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integerValue ↔ String?
Metric integer value.
getter/setter pair
microsValue ↔ String?
Amount in micros.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited