ReportWarning class

Warnings associated with generation of the report.

Constructors

ReportWarning({String? description, String? type})
ReportWarning.fromJson(Map json_)

Properties

description ↔ String?
Describes the details of the warning message, in English.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of the warning. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited