AdBlockingRecoveryTag class

Representation of an ad blocking recovery tag.

See https://support.google.com/adsense/answer/11575177.

Constructors

AdBlockingRecoveryTag({String? errorProtectionCode, String? tag})
AdBlockingRecoveryTag.fromJson(Map json_)

Properties

errorProtectionCode ↔ String?
Error protection code that can be used in conjunction with the tag.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String?
The ad blocking recovery tag.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited