AdClientAdCode class

Representation of the AdSense code for a given ad client.

For more information, see About the AdSense code.

Constructors

AdClientAdCode({String? adCode, String? ampBody, String? ampHead})
AdClientAdCode.fromJson(Map json_)

Properties

adCode ↔ String?
The AdSense code snippet to add to the head of an HTML page.
getter/setter pair
ampBody ↔ String?
The AdSense code snippet to add to the body of an AMP page.
getter/setter pair
ampHead ↔ String?
The AdSense code snippet to add to the head of an AMP page.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited