AdUnitAdCode class

Representation of the ad unit code for a given ad unit.

For more information, see About the AdSense code and Where to place the ad code in your HTML.

Constructors

AdUnitAdCode({String? adCode})
AdUnitAdCode.fromJson(Map json_)

Properties

adCode ↔ String?
The code snippet to add to the body of an HTML page.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited