Alert class

Representation of an alert.

Constructors

Alert({String? message, String? name, String? severity, String? type})
Alert.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
The localized alert message.
getter/setter pair
name ↔ String?
Resource name of the alert.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Severity of this alert.
getter/setter pair
type ↔ String?
Type of alert.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited