Header class

The header information of the columns requested in the report.

Constructors

Header({String? currencyCode, String? name, String? type})
Header.fromJson(Map json_)

Properties

currencyCode ↔ String?
The [ISO-4217 currency code](https://en.wikipedia.org/wiki/ISO_4217) of this column.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the header.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of the header.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited