ListLinkedCustomChannelsResponse class

Response definition for the custom channels linked to an adunit list rpc.

Properties

customChannels ↔ List<CustomChannel>?
The custom channels returned in this list response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Continuation token used to page through alerts.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited