ReportResult class

Result of a generated report.

Constructors

ReportResult({Row? averages, Date? endDate, List<Header>? headers, List<Row>? rows, Date? startDate, String? totalMatchedRows, Row? totals, List<String>? warnings})
ReportResult.fromJson(Map json_)

Properties

averages ↔ Row?
The averages of the report.
getter/setter pair
endDate ↔ Date?
End date of the range (inclusive).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ List<Header>?
The header information; one for each dimension in the request, followed by one for each metric in the request.
getter/setter pair
rows ↔ List<Row>?
The output rows of the report.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ Date?
Start date of the range (inclusive).
getter/setter pair
totalMatchedRows ↔ String?
The total number of rows matched by the report request.
getter/setter pair
totals ↔ Row?
The totals of the report.
getter/setter pair
warnings ↔ List<String>?
Any warnings associated with generation of the report.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited