Account class

Representation of an Account.

Constructors

Account({String? createTime, String? creationRequestId, String? displayName, String? name, String? regionCode, String? state, TimeZone? timeZone})
Account.fromJson(Map json_)

Properties

createTime ↔ String?
Creation time of the account.
getter/setter pair
creationRequestId ↔ String?
An opaque token that uniquely identifies the account among all the platform's accounts.
getter/setter pair
displayName ↔ String?
Display name of this account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of the account.
getter/setter pair
regionCode ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Approval state of the account.
getter/setter pair
timeZone ↔ TimeZone?
The IANA TZ timezone code of this account.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited