Address class

Address data.

Constructors

Address({String? address1, String? address2, String? city, String? company, String? contact, String? fax, String? phone, String? regionCode, String? state, String? zip})
Address.fromJson(Map json_)

Properties

address1 ↔ String?
First line of address.
getter/setter pair
address2 ↔ String?
Second line of address.
getter/setter pair
city ↔ String?
City.
getter/setter pair
company ↔ String?
Name of the company.
getter/setter pair
contact ↔ String?
Contact name of the company.
getter/setter pair
fax ↔ String?
Fax number with international code (i.e. +441234567890).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
phone ↔ String?
Phone number with international code (i.e. +441234567890).
getter/setter pair
regionCode ↔ String?
Country/Region code.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State.
getter/setter pair
zip ↔ String?
Zip/post code.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited