Event class

A platform sub-account event to record spam signals.

Constructors

Event({EventInfo? eventInfo, String? eventTime, String? eventType})
Event.fromJson(Map json_)

Properties

eventInfo ↔ EventInfo?
Information associated with the event.
getter/setter pair
eventTime ↔ String?
Event timestamp.
getter/setter pair
eventType ↔ String?
Event type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited