EventInfo class

Private information for partner recorded events (PII).

Constructors

EventInfo({Address? billingAddress, String? email})
EventInfo.fromJson(Map json_)

Properties

billingAddress ↔ Address?
The billing address of the publisher associated with this event, if available.
getter/setter pair
email ↔ String?
The email address that is associated with the publisher when performing the event.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited