ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
notifications → ProjectsLocationsNotificationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getSettings(String name, {String? $fields}) → Future<GoogleCloudAdvisorynotificationsV1Settings>
Get notification settings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateSettings(GoogleCloudAdvisorynotificationsV1Settings request, String name, {String? $fields}) → Future<GoogleCloudAdvisorynotificationsV1Settings>
Update notification settings.

Operators

operator ==(Object other) → bool
The equality operator.
inherited