agentidentity/v1 library

Classes

AccessSummary
Message describing AccessSummary object
AgentIdentityApi
ApiKeyParams
Message describing ApiKeyParams object.
AuditConfig
Specifies the audit configuration for a service.
Authorization
Message describing Authorization object
AuthProvider
Message describing AuthProvider object
AuthProviderTypeParams
AuthProvider type specific parameters.
Binding
Associates members, or principals, with a role.
ListAccessSummariesResponse
Message for response to listing AccessSummaries
ListAuthorizationsResponse
Message for response to listing Authorizations
ListAuthProvidersResponse
Message for response to listing AuthProviders
ListLocationsResponse
The response message for Locations.ListLocations.
Policy
An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources.
ProjectsLocationsAccessSummariesResource
ProjectsLocationsAuthProvidersAuthorizationsResource
ProjectsLocationsAuthProvidersResource
ProjectsLocationsResource
ProjectsResource
QueryAuthProvidersResponse
Response message for QueryAuthProviders.
QueryWorkloadsResponse
Response message for QueryWorkloads.
RevokeAuthorizationRequest
Request message for RevokeAuthorization.
SetIamPolicyRequest
Request message for SetIamPolicy method.
ThreeLeggedOAuth
Message describing ThreeLeggedOAuth object.
TwoLeggedOAuth
Message describing TwoLeggedOAuth object.

Typedefs

AuditLogConfig = $AuditLogConfig
Provides the configuration for logging a type of permissions.
DisableAuthProviderRequest = $AuthProviderRequest
Message for disabling an AuthProvider
Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
EnableAuthProviderRequest = $AuthProviderRequest
Message for enabling an AuthProvider
Expr = $Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
GeminiEnterpriseAuthProviderParams = $Empty
Message describing GeminiEnterpriseAuthProviderParams object.
Location = $Location00
A resource that represents a Google Cloud location.
RevokeAuthorizationResponse = $Empty
Response message for RevokeAuthorization.
TestIamPermissionsRequest = $TestIamPermissionsRequest00
Request message for TestIamPermissions method.
TestIamPermissionsResponse = $PermissionsResponse
Response message for TestIamPermissions method.
UndeleteAuthProviderRequest = $AuthProviderRequest
Message for undeleting a AuthProvider

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.