AccessSummary class

Message describing AccessSummary object

Constructors

AccessSummary({String? authProvider, String? authProviderType, String? firstAccessTime, Map<String, String>? labels, String? lastAccessTime, String? name, String? purgeTime, List<String>? scopes, String? tokenUrl, String? userId, String? workloadId})
AccessSummary.fromJson(Map json_)

Properties

authProvider String?
The auth_provider that this access summary is associated with.
getter/setter pair
authProviderType String?
The type of the connector that was used to create this access summary.
getter/setter pair
firstAccessTime String?
The first time this user has interacted with this workload.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
Labels as key value pairs
getter/setter pair
lastAccessTime String?
The most recent time this user has interacted with this workload.
getter/setter pair
name String?
Identifier.
getter/setter pair
purgeTime String?
The time when this access summary is permanently deleted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>?
All scopes that have been used by this user with this workload.
getter/setter pair
tokenUrl String?
The url of the authentication server that was accessed.
getter/setter pair
userId String?
The user_id provided by the workload application for this user.
getter/setter pair
workloadId String?
The identity bound to the workload that this user interacted with to produce this AccessSummary.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited