firstAccessTime property
The first time this user has interacted with this workload.
Rounded to the previous hour.
Output only.
Implementation
core.String? firstAccessTime;
The first time this user has interacted with this workload.
Rounded to the previous hour.
Output only.
core.String? firstAccessTime;