lastAccessTime property
The most recent time this user has interacted with this workload.
Rounded to the previous hour.
Output only.
Implementation
core.String? lastAccessTime;
The most recent time this user has interacted with this workload.
Rounded to the previous hour.
Output only.
core.String? lastAccessTime;