userId property
The user_id provided by the workload application for this user.
Not verified by Google.
Output only.
Implementation
core.String? userId;
The user_id provided by the workload application for this user.
Not verified by Google.
Output only.
core.String? userId;