workloadId property
The identity bound to the workload that this user interacted with to produce this AccessSummary.
Will typically be an agentic spiffe id
Output only.
Implementation
core.String? workloadId;
The identity bound to the workload that this user interacted with to produce this AccessSummary.
Will typically be an agentic spiffe id
Output only.
core.String? workloadId;