AuthProvider class

Message describing AuthProvider object

Constructors

AuthProvider({List<String>? allowedScopes, AuthProviderTypeParams? authProviderTypeParams, List<String>? blockedScopes, String? createTime, bool? deleted, String? description, String? expireTime, Map<String, String>? labels, String? name, String? state, String? updateTime, List<String>? workloadIds})
AuthProvider.fromJson(Map json_)

Properties

allowedScopes List<String>?
List of scopes that are allowed to be requested for this auth_provider.
getter/setter pair
authProviderTypeParams AuthProviderTypeParams?
AuthProvider type specific parameters.
getter/setter pair
blockedScopes List<String>?
List of scopes that are blocked from being requested for this auth_provider.
getter/setter pair
createTime String?
Create time stamp
getter/setter pair
deleted bool?
This is set to true if the auth_provider is deleted.
getter/setter pair
description String?
Description of the resource.
getter/setter pair
expireTime String?
The time when the auth_provider will expire.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
Labels as key value pairs
getter/setter pair
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The state of the auth_provider.
getter/setter pair
updateTime String?
Update time stamp
getter/setter pair
workloadIds List<String>?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited