blockedScopes property
List of scopes that are blocked from being requested for this auth_provider.
If a scope appears in this list, it will not be requested, even if it also
appears in allowed_scopes. blocked_scopes takes precedence over
allowed_scopes. The number of blocked scopes is limited to 200.
Optional.
Implementation
core.List<core.String>? blockedScopes;