Authorization class

Message describing Authorization object

Constructors

Authorization({String? clientUserId, String? createTime, String? name, List<String>? scopes, String? state, String? updateTime})
Authorization.fromJson(Map json_)

Properties

clientUserId String?
The client_user_id provided by the client application for their end user.
getter/setter pair
createTime String?
Create time stamp
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>?
The scopes actually granted by the end user during the consent flow.
getter/setter pair
state String?
The state of the authorization.
getter/setter pair
updateTime String?
Update time stamp
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited