clientUserId property
The client_user_id provided by the client application for their end user.
Not verified by Google.
Output only.
Implementation
core.String? clientUserId;
The client_user_id provided by the client application for their end user.
Not verified by Google.
Output only.
core.String? clientUserId;