ListAuthProvidersResponse class

Message for response to listing AuthProviders

Constructors

ListAuthProvidersResponse({List<AuthProvider>? authProviders, String? nextPageToken, List<String>? unreachable})
ListAuthProvidersResponse.fromJson(Map json_)

Properties

authProviders List<AuthProvider>?
The list of AuthProvider
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextPageToken String?
A token identifying a page of results the server should return.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreachable List<String>?
Unordered list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited