ProjectsLocationsAuthProvidersAuthorizationsResource class
Constructors
- ProjectsLocationsAuthProvidersAuthorizationsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String name, {String? requestId, String? $fields}) → Future< Empty> - Deletes a single Authorization.
-
get(
String name, {String? $fields}) → Future< Authorization> - Gets details of a single Authorization.
-
list(
String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) → Future< ListAuthorizationsResponse> - Lists Authorizations in a given project and location.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited