list method
Lists Authorizations in a given project and location.
Request parameters:
parent - Required. The parent resource where the search is performed.
Format:
projects/{project}/locations/{location}/authProviders/{auth_provider}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/authProviders/\[^/\]+$.
filter - Optional. Filter string to restrict the results. Currently
supports filtering by client_user_id only. Format: client_user_id=""
orderBy - Optional. This field is currently ignored. Defaults to
ordering by authorization_id in ascending order.
pageSize - Optional. Requested page size. Server may return fewer items
than requested. If unspecified, server will pick an appropriate default.
pageToken - Optional. A page token, received from a previous
ListAuthorizations call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListAuthorizations
must match the call that provided the page token.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListAuthorizationsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListAuthorizationsResponse> list(
core.String parent, {
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/authorizations';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListAuthorizationsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}