disable method

Future<AuthProvider> disable(
  1. DisableAuthProviderRequest request,
  2. String name, {
  3. String? $fields,
})

Disables a single AuthProvider.

request - The metadata request object.

Request parameters:

name - Required. Name of the resource Format: projects/{project}/locations/{location}/authProviders/{auth_provider} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/authProviders/\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a AuthProvider.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<AuthProvider> disable(
  DisableAuthProviderRequest request,
  core.String name, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':disable';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return AuthProvider.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}