nextPageToken property

String? nextPageToken
getter/setter pair

A token identifying a page of results the server should return.

If this field is omitted, there are no subsequent pages.

Implementation

core.String? nextPageToken;