authorizationUrl property
The authorization endpoint to send users to for consenting to delegate to the agent.
eg. "https://auth.atlassian.com/authorize"
Optional.
Implementation
core.String? authorizationUrl;
The authorization endpoint to send users to for consenting to delegate to the agent.
eg. "https://auth.atlassian.com/authorize"
Optional.
core.String? authorizationUrl;