defaultContinueUri property
The default continue URI for 3LO flow and it will be used when no continue URI is provided in the RetrieveCredentials request.
Optional.
Implementation
core.String? defaultContinueUri;
The default continue URI for 3LO flow and it will be used when no continue URI is provided in the RetrieveCredentials request.
Optional.
core.String? defaultContinueUri;