TwoLeggedOAuth class
Message describing TwoLeggedOAuth object.
Constructors
- TwoLeggedOAuth({String? clientId, String? clientSecret, String? tokenUrl})
- TwoLeggedOAuth.fromJson(Map json_)
Properties
- clientId ↔ String?
-
The client ID of the OAuth client.
getter/setter pair
- clientSecret ↔ String?
-
Input only.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenUrl ↔ String?
-
The token endpoint of the OAuth client.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited