forceRefreshToken property

String? forceRefreshToken
getter/setter pair

Input only.

Set this field only if the previous token was expired or invalid. This value must be the full, previously returned token string. Setting this field triggers a refresh of the access token with a stored refresh token, if possible, or a new consent flow.

Optional.

Implementation

core.String? forceRefreshToken;