finalize method

Finalizes the credentials after a successful consent flow.

request - The metadata request object.

Request parameters:

authProvider - Required. The resource name of the auth provider. Format: projects/{project}/locations/{location}/authProviders/{auth_provider} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/authProviders/\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsResponse>
finalize(
  GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsRequest request,
  core.String authProvider, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'v1/' + core.Uri.encodeFull('$authProvider') + '/credentials:finalize';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}