A2ASkill class

Represents the skills of an Agent.

Constructors

A2ASkill({String? description, List<String>? examples, String? id, String? name, List<String>? tags})
A2ASkill.fromJson(Map json_)

Properties

description String?
A more detailed description of the skill.
getter/setter pair
examples List<String>?
Example prompts or scenarios this skill can handle.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
A unique identifier for the agent's skill.
getter/setter pair
name String?
A human-readable name for the agent's skill.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>?
Keywords describing the skill.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited