attributes property
Attributes of the Agent.
Valid values: * agentregistry.googleapis.com/system/Framework:
{"framework": "google-adk"} - the agent framework used to develop the
Agent. Example values: "google-adk", "langchain", "custom". *
agentregistry.googleapis.com/system/RuntimeIdentity: {"principal":
"principal://..."} - the runtime identity associated with the Agent. *
agentregistry.googleapis.com/system/RuntimeReference: {"uri": "//..."} -
the URI of the underlying resource hosting the Agent, for example, the
Reasoning Engine URI.
Output only.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Map<core.String, core.Object?>>? attributes;