description property
The description of the Agent, often obtained from the A2A Agent Card.
Empty if Agent Card has no description.
Output only.
Implementation
core.String? description;
The description of the Agent, often obtained from the A2A Agent Card.
Empty if Agent Card has no description.
Output only.
core.String? description;