displayName property
The display name of the agent, often obtained from the A2A Agent Card.
Output only.
Implementation
core.String? displayName;
The display name of the agent, often obtained from the A2A Agent Card.
Output only.
core.String? displayName;