location property
The location where agent is hosted.
The value is defined by the hosting environment (i.e. cloud provider).
Output only.
Implementation
core.String? location;
The location where agent is hosted.
The value is defined by the hosting environment (i.e. cloud provider).
Output only.
core.String? location;