version property

String? version
getter/setter pair

The version of the Agent, often obtained from the A2A Agent Card.

Empty if Agent Card has no version or agent is not an A2A Agent.

Output only.

Implementation

core.String? version;