AgentRegistryApi class

Agent Registry is a centralized, unified catalog that lets you store, discover, and govern Model Context Protocol (MCP) servers, tools, and AI agents within Google Cloud.

Constructors

AgentRegistryApi(Client client, {String rootUrl = 'https://agentregistry.googleapis.com/', String servicePath = ''})

Properties

hashCode int
The hash code for this object.
no setterinherited
projects ProjectsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

agentregistryReadOnlyScope → const String
See your Google Cloud Agent Registry data and the email address of your Google Account
agentregistryReadWriteScope → const String
See, edit, configure, and delete your Google Cloud Agent Registry data and see the email address for your Google Account
cloudPlatformReadOnlyScope → const String
View your data across Google Cloud services and see the email address of your Google Account
cloudPlatformScope → const String
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.