Annotations class

Annotations describing the characteristics and behavior of a tool or operation.

Constructors

Annotations({bool? destructiveHint, bool? idempotentHint, bool? openWorldHint, bool? readOnlyHint, String? title})
Annotations.fromJson(Map json_)

Properties

destructiveHint ↔ bool?
If true, the tool may perform destructive updates to its environment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idempotentHint ↔ bool?
If true, calling the tool repeatedly with the same arguments will have no additional effect on its environment.
getter/setter pair
openWorldHint ↔ bool?
If true, this tool may interact with an "open world" of external entities.
getter/setter pair
readOnlyHint ↔ bool?
If true, the tool does not modify its environment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
A human-readable title for the tool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited