AuthProviderBinding class

The AuthProvider of the Binding.

Constructors

AuthProviderBinding({String? authProvider, String? continueUri, List<String>? scopes})
AuthProviderBinding.fromJson(Map json_)

Properties

authProvider String?
The resource name of the target AuthProvider.
getter/setter pair
continueUri String?
The continue URI of the AuthProvider.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>?
The list of OAuth2 scopes of the AuthProvider.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited