continueUri property
The continue URI of the AuthProvider.
The URI is used to reauthenticate the user and finalize the managed OAuth flow.
Optional.
Implementation
core.String? continueUri;
The continue URI of the AuthProvider.
The URI is used to reauthenticate the user and finalize the managed OAuth flow.
Optional.
core.String? continueUri;