Card class

Full Agent Card payload, often obtained from the A2A Agent Card.

Constructors

Card({Map<String, Object?>? content, String? type})
Card.fromJson(Map json_)

Properties

content ↔ Map<String, Object?>?
The content of the agent card.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of agent card.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited