attributes property

Map<String, Map<String, Object?>>? attributes
getter/setter pair

Attributes of the Endpoint.

Valid values: * agentregistry.googleapis.com/system/RuntimeReference: {"uri": "//..."} - the URI of the underlying resource hosting the Endpoint, for example, the GKE Deployment.

Output only.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Map<core.String, core.Object?>>? attributes;