ListBindingsResponse class
Message for response to listing Bindings
Constructors
-
ListBindingsResponse({List<
Binding> ? bindings, String? nextPageToken}) - ListBindingsResponse.fromJson(Map json_)
Properties
-
bindings
↔ List<
Binding> ? -
The list of Binding resources matching the parent and filter criteria in
the request.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
A token identifying a page of results the server should return.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited