nextPageToken property
A token identifying a page of results the server should return.
Used in page_token.
Implementation
core.String? nextPageToken;
A token identifying a page of results the server should return.
Used in page_token.
core.String? nextPageToken;