ProjectsLocationsAgentsResource class

Constructors

ProjectsLocationsAgentsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) Future<Agent>
Gets details of a single Agent.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListAgentsResponse>
Lists Agents in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
Searches Agents in a given project and location.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited