Protocol class

Represents the protocol of an Agent.

Constructors

Protocol({List<Interface>? interfaces, String? protocolVersion, String? type})
Protocol.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
interfaces List<Interface>?
The connection details for the Agent.
getter/setter pair
protocolVersion String?
The version of the protocol, for example, the A2A Agent Card version.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of the protocol.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited