protocolVersion property
The version of the protocol, for example, the A2A Agent Card version.
Output only.
Implementation
core.String? protocolVersion;
The version of the protocol, for example, the A2A Agent Card version.
Output only.
core.String? protocolVersion;