SearchAgentsResponse class
Message for response to searching Agents
Constructors
-
SearchAgentsResponse({List<
Agent> ? agents, String? nextPageToken}) - SearchAgentsResponse.fromJson(Map json_)
Properties
-
agents
↔ List<
Agent> ? -
A list of Agents that match the
search_string.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
If there are more results than those appearing in this response, then
next_page_tokenis included.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited