Service class

Represents a user-defined Service.

Constructors

Service({AgentSpec? agentSpec, String? createTime, String? description, String? displayName, EndpointSpec? endpointSpec, List<Interface>? interfaces, McpServerSpec? mcpServerSpec, String? name, String? registryResource, String? updateTime})
Service.fromJson(Map json_)

Properties

agentSpec ↔ AgentSpec?
The spec of the Agent.
getter/setter pair
createTime ↔ String?
Create time.
getter/setter pair
description ↔ String?
User-defined description of an Service.
getter/setter pair
displayName ↔ String?
User-defined display name for the Service.
getter/setter pair
endpointSpec ↔ EndpointSpec?
The spec of the Endpoint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interfaces ↔ List<Interface>?
The connection details for the Service.
getter/setter pair
mcpServerSpec ↔ McpServerSpec?
The spec of the MCP Server.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
registryResource ↔ String?
The resource name of the resulting Agent, MCP Server, or Endpoint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Update time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited