agentSpec property
The spec of the Agent.
When agent_spec is set, the type of the service is Agent.
Optional.
Implementation
AgentSpec? agentSpec;
The spec of the Agent.
When agent_spec is set, the type of the service is Agent.
Optional.
AgentSpec? agentSpec;