endpointSpec property
The spec of the Endpoint.
When endpoint_spec is set, the type of the service is Endpoint.
Optional.
Implementation
EndpointSpec? endpointSpec;
The spec of the Endpoint.
When endpoint_spec is set, the type of the service is Endpoint.
Optional.
EndpointSpec? endpointSpec;