mcpServerSpec property
The spec of the MCP Server.
When mcp_server_spec is set, the type of the service is MCP Server.
Optional.
Implementation
McpServerSpec? mcpServerSpec;
The spec of the MCP Server.
When mcp_server_spec is set, the type of the service is MCP Server.
Optional.
McpServerSpec? mcpServerSpec;