Source class

The source of the Binding.

Constructors

Source({String? identifier})
Source.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier ↔ String?
The identifier of the source Agent.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited