Tool class

Represents a single tool provided by an MCP Server.

Constructors

Tool({Annotations? annotations, String? description, String? name})
Tool.fromJson(Map json_)

Properties

annotations Annotations?
Annotations associated with the tool.
getter/setter pair
description String?
Description of what the tool does.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Human-readable name of the tool.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited