GoogleCloudAiplatformV1ActiveLearningConfig class

Parameters that configure the active learning pipeline.

Active learning will label the data incrementally by several iterations. For every iteration, it will select a batch of data based on the sampling strategy.

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxDataItemCount ↔ String?
Max number of human labeled DataItems.
getter/setter pair
maxDataItemPercentage ↔ int?
Max percent of total DataItems for human labeling.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleConfig ↔ GoogleCloudAiplatformV1SampleConfig?
Active learning data sampling config.
getter/setter pair
trainingConfig ↔ GoogleCloudAiplatformV1TrainingConfig?
CMLE training config.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited