stateDelta property

Map<String, Object?>? stateDelta
getter/setter pair

The change in the session state caused by this event.

This is a key-value map of fields that were modified or added by the event.

Optional.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? stateDelta;