GoogleCloudAiplatformV1AggregationOutput class

The aggregation result for the entire dataset and all metrics.

Properties

aggregationResults List<GoogleCloudAiplatformV1AggregationResult>?
One AggregationResult per metric.
getter/setter pair
dataset GoogleCloudAiplatformV1EvaluationDataset?
The dataset used for evaluation & aggregation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited