GoogleCloudAiplatformV1AsyncQueryReasoningEngineRequest class

Request message for ReasoningEngineExecutionService.AsyncQueryReasoningEngine.

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputGcsUri ↔ String?
Input Cloud Storage URI for the Async query.
getter/setter pair
outputGcsUri ↔ String?
Output Cloud Storage URI for the Async query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited