GoogleCloudAiplatformV1BatchReadFeatureValuesRequestEntityTypeSpec class

Selects Features of an EntityType to read values of and specifies read settings.

Properties

entityTypeId ↔ String?
ID of the EntityType to select Features.
getter/setter pair
featureSelector ↔ GoogleCloudAiplatformV1FeatureSelector?
Selectors choosing which Feature values to read from the EntityType.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ List<GoogleCloudAiplatformV1DestinationFeatureSetting>?
Per-Feature settings for the batch read.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited