GoogleCloudAiplatformV1BigQueryRequestSetSamplingConfig class

The sampling config.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplingCount ↔ int?
The total number of logged data to import.
getter/setter pair
samplingDuration ↔ String?
How long to wait before sampling data from the BigQuery table.
getter/setter pair
samplingMethod ↔ String?
The sampling method to use.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited