GoogleCloudAiplatformV1BigQuerySource class

The BigQuery location for the input content.

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputUri ↔ String?
BigQuery URI to a table, up to 2000 characters long.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited