operationName property
The name of the longrunning operation returned from AsyncQueryReasoningEngine.
Format: projects/{project}/locations/{location}/operations/{operation}
Required.
Implementation
core.String? operationName;
The name of the longrunning operation returned from AsyncQueryReasoningEngine.
Format: projects/{project}/locations/{location}/operations/{operation}
Required.
core.String? operationName;