GoogleCloudAiplatformV1CompactionConfigEventEditingConfig class

Configuration for event-history editing-based compaction.

When set, the event history is rewritten in place using deterministic rules (e.g. truncating/masking oversized tool responses, stripping model thoughts).

Properties

hashCode int
The hash code for this object.
no setterinherited
mode String?
The event-editing mode.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited