GoogleCloudAiplatformV1CompactionConfigLlmSummarizationConfig class

Configuration for LLM summarization-based compaction.

When set, the session context is summarized with an LLM once it exceeds the summarizer target threshold.

Properties

hashCode int
The hash code for this object.
no setterinherited
mode String?
The summarization mode.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited