GoogleCloudAiplatformV1Content class

The structured data content of a message.

A Content message contains a role field, which indicates the producer of the content, and a parts field, which contains the multi-part data of the message.

Properties

hashCode int
The hash code for this object.
no setterinherited
parts List<GoogleCloudAiplatformV1Part>?
A list of Part objects that make up a single message.
getter/setter pair
role String?
The producer of the content.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited