GoogleCloudAiplatformV1CopyModelRequest class

Request message for ModelService.CopyModel.

Constructors

GoogleCloudAiplatformV1CopyModelRequest({String? customServiceAccount, GoogleCloudAiplatformV1EncryptionSpec? encryptionSpec, String? modelId, String? parentModel, String? sourceModel})
GoogleCloudAiplatformV1CopyModelRequest.fromJson(Map json_)

Properties

customServiceAccount String?
The user-provided custom service account to use to do the copy model.
getter/setter pair
encryptionSpec GoogleCloudAiplatformV1EncryptionSpec?
Customer-managed encryption key options.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
modelId String?
Copy source_model into a new Model with this ID.
getter/setter pair
parentModel String?
Specify this field to copy source_model into this existing Model as a new version.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceModel String?
The resource name of the Model to copy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited