GoogleCloudAiplatformV1DeleteFeatureValuesRequestSelectEntity class

Message to select entity.

If an entity id is selected, all the feature values corresponding to the entity id will be deleted, including the entityId.

Properties

entityIdSelector ↔ GoogleCloudAiplatformV1EntityIdSelector?
Selectors choosing feature values of which entity id to be deleted from the EntityType.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited