GoogleCloudAiplatformV1ErrorAnalysisAnnotation class

Model error analysis for each annotation.

Properties

attributedItems ↔ List<GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem>?
Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
outlierScore ↔ double?
The outlier score of this annotated item.
getter/setter pair
outlierThreshold ↔ double?
The threshold used to determine if this annotation is an outlier or not.
getter/setter pair
queryType ↔ String?
The query type used for finding the attributed items. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited