GoogleCloudAiplatformV1ErrorAnalysisAnnotationAttributedItem class

Attributed items for a given annotation, typically representing neighbors from the training sets constrained by the query type.

Properties

annotationResourceName ↔ String?
The unique ID for each annotation.
getter/setter pair
distance ↔ double?
The distance of this item to the annotation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited