GoogleCloudAiplatformV1EvaluationInstanceAgentConfig class

Configuration for an Agent.

Properties

agentId String?
Unique identifier of the agent.
getter/setter pair
agentType String?
The type or class of the agent (e.g., "LlmAgent", "RouterAgent", "ToolUseAgent").
getter/setter pair
description String?
A high-level description of the agent's role and responsibilities.
getter/setter pair
developerInstruction GoogleCloudAiplatformV1EvaluationInstanceInstanceData?
Contains instructions from the developer for the agent.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subAgents List<String>?
The list of valid agent IDs (names) that this agent can delegate to.
getter/setter pair
tools GoogleCloudAiplatformV1EvaluationInstanceAgentConfigTools?
List of tools.
getter/setter pair
toolsText String?
A JSON string containing a list of tools available to an agent with info such as name, description, parameters and required parameters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited