GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent class
A single event in the execution trace.
Constructors
-
GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent({List<
GoogleCloudAiplatformV1Tool> ? activeTools, String? author, GoogleCloudAiplatformV1Content? content, String? eventTime, Map<String, Object?> ? stateDelta}) - GoogleCloudAiplatformV1EvaluationInstanceAgentDataAgentEvent.fromJson(Map json_)
Properties
-
activeTools
↔ List<
GoogleCloudAiplatformV1Tool> ? -
The list of tools that were active/available to the agent at the time of
this event.
getter/setter pair
-
The ID of the agent or entity that generated this event.
getter/setter pair
- content ↔ GoogleCloudAiplatformV1Content?
-
The content of the event (e.g., text response, tool call, tool response).
getter/setter pair
- eventTime ↔ String?
-
The timestamp when the event occurred.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stateDelta
↔ Map<
String, Object?> ? -
The change in the session state caused by this event.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited