activeTools property
The list of tools that were active/available to the agent at the time of this event.
This overrides the AgentConfig.tools if set.
Optional.
Implementation
core.List<GoogleCloudAiplatformV1Tool>? activeTools;
The list of tools that were active/available to the agent at the time of this event.
This overrides the AgentConfig.tools if set.
Optional.
core.List<GoogleCloudAiplatformV1Tool>? activeTools;