GoogleCloudAiplatformV1EvaluationInstanceInteractionsDataSource class
Source for populating AgentData from an Interactions API interaction.
Constructors
- GoogleCloudAiplatformV1EvaluationInstanceInteractionsDataSource({GoogleCloudAiplatformV1GeminiAgentConfig? geminiAgentConfig, String? interaction})
- GoogleCloudAiplatformV1EvaluationInstanceInteractionsDataSource.fromJson(Map json_)
Properties
- geminiAgentConfig ↔ GoogleCloudAiplatformV1GeminiAgentConfig?
-
Gemini Agent (Vertex AI Agent resource).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interaction ↔ String?
-
The interaction to evaluate.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited