GoogleCloudAiplatformV1EvaluationParserConfig class

Config for parsing LLM responses.

It can be used to parse the LLM response to be evaluated, or the LLM response from LLM-based metrics/Autoraters.

Properties

customCodeParserConfig GoogleCloudAiplatformV1EvaluationParserConfigCustomCodeParserConfig?
Use custom code to parse the LLM response.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited