GoogleCloudAiplatformV1EvaluationRequest class

A single evaluation request supporting input for both single-turn model generation and multi-turn agent execution traces.

Valid input modes: 1. Inference Mode: prompt is set (containing text or AgentData context). 2. Offline Eval Mode: prompt is unset, and candidate_responses contains agent_data (the completed execution trace). Validation Rule: Either prompt must be set, OR at least one of the candidate_responses must contain agent_data.

Properties

candidateResponses List<GoogleCloudAiplatformV1CandidateResponse>?
Responses from model under test and other baseline models for comparison.
getter/setter pair
goldenResponse GoogleCloudAiplatformV1CandidateResponse?
The Ideal response or ground truth.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
prompt GoogleCloudAiplatformV1EvaluationPrompt?
The request/prompt to evaluate.
getter/setter pair
rubrics Map<String, GoogleCloudAiplatformV1RubricGroup>?
Named groups of rubrics associated with this prompt.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited