GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig class
Configuration for Agent Run.
Constructors
- GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig({String? agentEngine, GoogleCloudAiplatformV1GeminiAgentConfig? geminiAgentConfig, GoogleCloudAiplatformV1EvaluationRunInferenceConfigSessionInput? sessionInput, GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig? userSimulatorConfig})
- GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfig.fromJson(Map json_)
Properties
- agentEngine ↔ String?
-
The resource name of the Agent Engine.
getter/setter pair
- geminiAgentConfig ↔ GoogleCloudAiplatformV1GeminiAgentConfig?
-
Config for scraping a Gemini Agent via the Interactions API.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionInput ↔ GoogleCloudAiplatformV1EvaluationRunInferenceConfigSessionInput?
-
The session input to get agent running results.
getter/setter pair
- userSimulatorConfig ↔ GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig?
-
The configuration for a user simulator that uses an LLM to generate
messages on behalf of the user.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited