maxTurn property

int? maxTurn
getter/setter pair

Maximum number of invocations allowed by the multi-turn agent scraping.

This property allows us to stop a run-off conversation, where the agent and the user simulator get into a never ending loop. The initial fixed prompt is also counted as an invocation.

Implementation

core.int? maxTurn;