GoogleCloudAiplatformV1EvaluationRunInferenceConfigSessionInput class

Session input to run an Agent.

Properties

hashCode int
The hash code for this object.
no setterinherited
parameters Map<String, String>?
Additional parameters for the session, like app_name, etc.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionState Map<String, Object?>?
Session specific memory which stores key conversation points.
getter/setter pair
userId String?
The user id for the agent session.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited