GoogleCloudAiplatformV1EventMetadata class

Metadata relating to a LLM response event.

Constructors

GoogleCloudAiplatformV1EventMetadata({String? branch, Map<String, Object?>? customMetadata, GoogleCloudAiplatformV1GroundingMetadata? groundingMetadata, bool? interrupted, List<String>? longRunningToolIds, bool? partial, bool? turnComplete})
GoogleCloudAiplatformV1EventMetadata.fromJson(Map json_)

Properties

branch String?
The branch of the event.
getter/setter pair
customMetadata Map<String, Object?>?
The custom metadata of the LlmResponse.
getter/setter pair
groundingMetadata GoogleCloudAiplatformV1GroundingMetadata?
Metadata returned to client when grounding is enabled.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interrupted bool?
Flag indicating that LLM was interrupted when generating the content.
getter/setter pair
longRunningToolIds List<String>?
Set of ids of the long running function calls.
getter/setter pair
partial bool?
Indicates whether the text content is part of a unfinished text stream.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turnComplete bool?
Indicates whether the response from the model is complete.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited