GoogleCloudAiplatformV1Examples class

Example-based explainability that returns the nearest neighbors from the provided dataset.

Properties

exampleGcsSource ↔ GoogleCloudAiplatformV1ExamplesExampleGcsSource?
The Cloud Storage input instances.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nearestNeighborSearchConfig ↔ Object?
The full configuration for the generated index, the semantics are the same as metadata and should match NearestNeighborSearchConfig.
getter/setter pair
neighborCount ↔ int?
The number of neighbors to return when querying for examples.
getter/setter pair
presets ↔ GoogleCloudAiplatformV1Presets?
Simplified preset configuration, which automatically sets configuration values based on the desired query speed-precision trade-off and modality.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited