GoogleCloudAiplatformV1ExamplesExampleGcsSource class

The Cloud Storage input instances.

Properties

dataFormat ↔ String?
The format in which instances are given, if not specified, assume it's JSONL format.
getter/setter pair
gcsSource ↔ GoogleCloudAiplatformV1GcsSource?
The Cloud Storage location for the input instances.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited