GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization class

Visualization configurations for image explanation.

Constructors

GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization({double? clipPercentLowerbound, double? clipPercentUpperbound, String? colorMap, String? overlayType, String? polarity, String? type})
GoogleCloudAiplatformV1ExplanationMetadataInputMetadataVisualization.fromJson(Map json_)

Properties

clipPercentLowerbound ↔ double?
Excludes attributions below the specified percentile, from the highlighted areas.
getter/setter pair
clipPercentUpperbound ↔ double?
Excludes attributions above the specified percentile from the highlighted areas.
getter/setter pair
colorMap ↔ String?
The color scheme used for the highlighted areas.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
overlayType ↔ String?
How the original image is displayed in the visualization.
getter/setter pair
polarity ↔ String?
Whether to only highlight pixels with positive contributions, negative or both.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of the image visualization.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited