GoogleCloudAiplatformV1ExportModelRequestOutputConfig class

Output configuration for the Model export.

Properties

artifactDestination ↔ GoogleCloudAiplatformV1GcsDestination?
The Cloud Storage location where the Model artifact is to be written to.
getter/setter pair
exportFormatId ↔ String?
The ID of the format in which the Model must be exported.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageDestination ↔ GoogleCloudAiplatformV1ContainerRegistryDestination?
The Google Container Registry or Artifact Registry uri where the Model container image will be copied to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited