GoogleCloudAiplatformV1FeatureViewDirectWriteResponse class

Response message for FeatureOnlineStoreService.FeatureViewDirectWrite.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ GoogleRpcStatus?
Response status for the keys listed in FeatureViewDirectWriteResponse.write_responses.
getter/setter pair
writeResponses ↔ List<GoogleCloudAiplatformV1FeatureViewDirectWriteResponseWriteResponse>?
Details about write for each key.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited