GoogleCloudAiplatformV1FeatureViewFeatureRegistrySource class

A Feature Registry source for features that need to be synced to Online Store.

Properties

featureGroups ↔ List<GoogleCloudAiplatformV1FeatureViewFeatureRegistrySourceFeatureGroup>?
List of features that need to be synced to Online Store.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
projectNumber ↔ String?
The project number of the parent project of the Feature Groups.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited