GoogleCloudAiplatformV1FeatureViewOptimizedConfig class

Configuration for FeatureViews created in Optimized FeatureOnlineStore.

Properties

automaticResources ↔ GoogleCloudAiplatformV1AutomaticResources?
A description of resources that the FeatureView uses, which to large degree are decided by Vertex AI, and optionally allows only a modest additional configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited