GoogleCloudAiplatformV1FeaturestoreMonitoringConfigImportFeaturesAnalysis class

Configuration of the Featurestore's ImportFeature Analysis Based Monitoring.

This type of analysis generates statistics for values of each Feature imported by every ImportFeatureValues operation.

Properties

anomalyDetectionBaseline ↔ String?
The baseline used to do anomaly detection for the statistics generated by import features analysis. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Whether to enable / disable / inherite default hebavior for import features analysis. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited