GoogleCloudAiplatformV1FetchFeatureValuesResponse class

Response message for FeatureOnlineStoreService.FetchFeatureValues

Properties

dataKey ↔ GoogleCloudAiplatformV1FeatureViewDataKey?
The data key associated with this response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyValues ↔ GoogleCloudAiplatformV1FetchFeatureValuesResponseFeatureNameValuePairList?
Feature values in KeyValue format.
getter/setter pair
protoStruct ↔ Map<String, Object?>?
Feature values in proto Struct format.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited