GoogleCloudAiplatformV1FunctionCallingConfig class

Function calling config.

Constructors

GoogleCloudAiplatformV1FunctionCallingConfig({List<String>? allowedFunctionNames, String? mode, bool? streamFunctionCallArguments})
GoogleCloudAiplatformV1FunctionCallingConfig.fromJson(Map json_)

Properties

allowedFunctionNames ↔ List<String>?
Function names to call.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?
Function calling mode.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamFunctionCallArguments ↔ bool?
When set to true, arguments of a single function call will be streamed out in multiple parts/contents/responses.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited