streamFunctionCallArguments property
When set to true, arguments of a single function call will be streamed out in multiple parts/contents/responses.
Partial parameter results will be returned in the
FunctionCall.partial_args field.
Optional.
Implementation
core.bool? streamFunctionCallArguments;