GoogleCloudAiplatformV1FunctionDeclaration class

Structured representation of a function declaration as defined by the OpenAPI 3.0 specification.

Included in this declaration are the function name, description, parameters and response type. This FunctionDeclaration is a representation of a block of code that can be used as a Tool by the model and executed by the client.

Constructors

GoogleCloudAiplatformV1FunctionDeclaration({String? behavior, String? description, String? name, GoogleCloudAiplatformV1Schema? parameters, Object? parametersJsonSchema, GoogleCloudAiplatformV1Schema? response, Object? responseJsonSchema})
GoogleCloudAiplatformV1FunctionDeclaration.fromJson(Map json_)

Properties

behavior ↔ String?
Specifies the function Behavior.
getter/setter pair
description ↔ String?
Description and purpose of the function.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the function to call.
getter/setter pair
parameters ↔ GoogleCloudAiplatformV1Schema?
Describes the parameters to this function in JSON Schema Object format.
getter/setter pair
parametersJsonSchema ↔ Object?
Describes the parameters to the function in JSON Schema format.
getter/setter pair
response ↔ GoogleCloudAiplatformV1Schema?
Describes the output from this function in JSON Schema format.
getter/setter pair
responseJsonSchema ↔ Object?
Describes the output from this function in JSON Schema format.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited