behavior property

String? behavior
getter/setter pair

Specifies the function Behavior.

If not specified, the system keeps the current function call behavior. This field is currently only supported by the BidiGenerateContent method.

Optional. Possible string values are:

  • "UNSPECIFIED" : This value is unspecified.
  • "BLOCKING" : If set, the system will wait to receive the function response before continuing the conversation.
  • "NON_BLOCKING" : If set, the system will not wait to receive the function response. Instead, it will attempt to handle function responses as they become available while maintaining the conversation between the user and the model.

Implementation

core.String? behavior;