scheduling property
Specifies how the response should be scheduled in the conversation.
Only applicable to NON_BLOCKING function calls, is ignored otherwise. Defaults to WHEN_IDLE.
Optional. Possible string values are:
- "SCHEDULING_UNSPECIFIED" : This value is unused.
- "SILENT" : Only add the result to the conversation context, do not interrupt or trigger generation.
- "WHEN_IDLE" : Add the result to the conversation context, and prompt to generate output without interrupting ongoing generation.
- "INTERRUPT" : Add the result to the conversation context, interrupt ongoing generation and prompt to generate output.
Implementation
core.String? scheduling;