GoogleCloudAiplatformV1FunctionResponsePart class

A datatype containing media that is part of a FunctionResponse message.

A FunctionResponsePart consists of data which has an associated datatype. A FunctionResponsePart can only contain one of the accepted types in FunctionResponsePart.data. A FunctionResponsePart must have a fixed IANA MIME type identifying the type and subtype of the media if the inline_data field is filled with raw bytes.

Properties

fileData ↔ GoogleCloudAiplatformV1FunctionResponseFileData?
URI based data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inlineData ↔ GoogleCloudAiplatformV1FunctionResponseBlob?
Inline media bytes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited