GoogleCloudAiplatformV1GenerateMemoriesRequest class

Request message for MemoryBankService.GenerateMemories.

Maximum size is 8 MB.

Properties

directContentsSource GoogleCloudAiplatformV1GenerateMemoriesRequestDirectContentsSource?
Defines a direct source of content as the source content from which to generate memories.
getter/setter pair
directMemoriesSource GoogleCloudAiplatformV1GenerateMemoriesRequestDirectMemoriesSource?
Defines a direct source of memories that should be uploaded to Memory Bank.
getter/setter pair
disableConsolidation bool?
If true, generated memories will not be consolidated with existing memories; all generated memories will be added as new memories regardless of whether they are duplicates of or contradictory to existing memories.
getter/setter pair
disableMemoryRevisions bool?
If true, no revisions will be created for this request.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, GoogleCloudAiplatformV1MemoryMetadataValue>?
User-provided metadata for the generated memories.
getter/setter pair
metadataMergeStrategy String?
The strategy to use when applying metadata to existing memories.
getter/setter pair
revisionExpireTime String?
Timestamp of when the revision is considered expired.
getter/setter pair
revisionLabels Map<String, String>?
Labels to be applied to the generated memory revisions.
getter/setter pair
revisionTtl String?
The TTL for the revision.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope Map<String, String>?
The scope of the memories that should be generated.
getter/setter pair
vertexSessionSource GoogleCloudAiplatformV1GenerateMemoriesRequestVertexSessionSource?
Defines a Vertex Session as the source content from which to generate memories.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited