GoogleCloudAiplatformV1GenerateMemoriesRequestDirectMemoriesSourceDirectMemory class

A direct memory to upload to Memory Bank.

Properties

fact String?
The fact to consolidate with existing memories.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topics List<GoogleCloudAiplatformV1MemoryTopicId>?
The topics that the consolidated memories should be associated with.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited