GoogleCloudAiplatformV1GenerationConfig class

Configuration for content generation.

This message contains all the parameters that control how the model generates content. It allows you to influence the randomness, length, and structure of the output.

Constructors

GoogleCloudAiplatformV1GenerationConfig({bool? audioTimestamp, int? candidateCount, bool? enableAffectiveDialog, double? frequencyPenalty, GoogleCloudAiplatformV1ImageConfig? imageConfig, int? logprobs, int? maxOutputTokens, String? mediaResolution, double? presencePenalty, Object? responseJsonSchema, bool? responseLogprobs, String? responseMimeType, List<String>? responseModalities, GoogleCloudAiplatformV1Schema? responseSchema, GoogleCloudAiplatformV1GenerationConfigRoutingConfig? routingConfig, int? seed, GoogleCloudAiplatformV1SpeechConfig? speechConfig, List<String>? stopSequences, double? temperature, GoogleCloudAiplatformV1GenerationConfigThinkingConfig? thinkingConfig, double? topK, double? topP})
GoogleCloudAiplatformV1GenerationConfig.fromJson(Map json_)

Properties

audioTimestamp bool?
If enabled, audio timestamps will be included in the request to the model.
getter/setter pair
candidateCount int?
The number of candidate responses to generate.
getter/setter pair
enableAffectiveDialog bool?
If enabled, the model will detect emotions and adapt its responses accordingly.
getter/setter pair
frequencyPenalty double?
Penalizes tokens based on their frequency in the generated text.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageConfig GoogleCloudAiplatformV1ImageConfig?
Config for image generation features.
getter/setter pair
logprobs int?
The number of top log probabilities to return for each token.
getter/setter pair
maxOutputTokens int?
The maximum number of tokens to generate in the response.
getter/setter pair
mediaResolution String?
The token resolution at which input media content is sampled.
getter/setter pair
presencePenalty double?
Penalizes tokens that have already appeared in the generated text.
getter/setter pair
responseJsonSchema Object?
When this field is set, response_schema must be omitted and response_mime_type must be set to application/json.
getter/setter pair
responseLogprobs bool?
If set to true, the log probabilities of the output tokens are returned.
getter/setter pair
responseMimeType String?
The IANA standard MIME type of the response.
getter/setter pair
responseModalities List<String>?
The modalities of the response.
getter/setter pair
responseSchema GoogleCloudAiplatformV1Schema?
Lets you to specify a schema for the model's response, ensuring that the output conforms to a particular structure.
getter/setter pair
routingConfig GoogleCloudAiplatformV1GenerationConfigRoutingConfig?
Routing configuration.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seed int?
A seed for the random number generator.
getter/setter pair
speechConfig GoogleCloudAiplatformV1SpeechConfig?
The speech generation config.
getter/setter pair
stopSequences List<String>?
A list of character sequences that will stop the model from generating further tokens.
getter/setter pair
temperature double?
Controls the randomness of the output.
getter/setter pair
thinkingConfig GoogleCloudAiplatformV1GenerationConfigThinkingConfig?
Configuration for thinking features.
getter/setter pair
topK double?
Specifies the top-k sampling threshold.
getter/setter pair
topP double?
Specifies the nucleus sampling threshold.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited