responseFormat property
New response format field for the model to configure output formatting and delivery.
Optional.
Implementation
core.List<GoogleCloudAiplatformV1ResponseFormat>? responseFormat;
New response format field for the model to configure output formatting and delivery.
Optional.
core.List<GoogleCloudAiplatformV1ResponseFormat>? responseFormat;