GoogleCloudAiplatformV1GroundingChunk class

A piece of evidence that supports a claim made by the model.

This is used to show a citation for a claim made by the model. When grounding is enabled, the model returns a GroundingChunk that contains a reference to the source of the information.

Properties

hashCode int
The hash code for this object.
no setterinherited
maps GoogleCloudAiplatformV1GroundingChunkMaps?
A grounding chunk from Google Maps.
getter/setter pair
retrievedContext GoogleCloudAiplatformV1GroundingChunkRetrievedContext?
A grounding chunk from a data source retrieved by a retrieval tool, such as Vertex AI Search.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
web GoogleCloudAiplatformV1GroundingChunkWeb?
A grounding chunk from a web page, typically from Google Search.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited