GoogleCloudAiplatformV1GroundingChunkRetrievedContext class

Context retrieved from a data source to ground the model's response.

This is used when a retrieval tool fetches information from a user-provided corpus or a public dataset.

Properties

documentName String?
The full resource name of the referenced Vertex AI Search document.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ragChunk GoogleCloudAiplatformV1RagChunk?
Additional context for a Retrieval-Augmented Generation (RAG) retrieval result.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The content of the retrieved data source.
getter/setter pair
title String?
The title of the retrieved data source.
getter/setter pair
uri String?
The URI of the retrieved data source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited