GoogleCloudAiplatformV1GroundingChunkWeb class

A Web chunk is a piece of evidence that comes from a web page.

It contains the URI of the web page, the title of the page, and the domain of the page. This is used to provide the user with a link to the source of the information.

Properties

domain String?
The domain of the web page that contains the evidence.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
The title of the web page that contains the evidence.
getter/setter pair
uri String?
The URI of the web page that contains the evidence.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited