GoogleCloudAiplatformV1ImageConfigImageOutputOptions class

The image output format for generated images.

Properties

compressionQuality ↔ int?
The compression quality of the output image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mimeType ↔ String?
The image format that the output should be saved as.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited