GoogleCloudAiplatformV1ImportFeatureValuesRequest class

Request message for FeaturestoreService.ImportFeatureValues.

Constructors

GoogleCloudAiplatformV1ImportFeatureValuesRequest({GoogleCloudAiplatformV1AvroSource? avroSource, GoogleCloudAiplatformV1BigQuerySource? bigquerySource, GoogleCloudAiplatformV1CsvSource? csvSource, bool? disableIngestionAnalysis, bool? disableOnlineServing, String? entityIdField, List<GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec>? featureSpecs, String? featureTime, String? featureTimeField, int? workerCount})
GoogleCloudAiplatformV1ImportFeatureValuesRequest.fromJson(Map json_)

Properties

avroSource ↔ GoogleCloudAiplatformV1AvroSource?
getter/setter pair
bigquerySource ↔ GoogleCloudAiplatformV1BigQuerySource?
getter/setter pair
csvSource ↔ GoogleCloudAiplatformV1CsvSource?
getter/setter pair
disableIngestionAnalysis ↔ bool?
If true, API doesn't start ingestion analysis pipeline.
getter/setter pair
disableOnlineServing ↔ bool?
If set, data will not be imported for online serving.
getter/setter pair
entityIdField ↔ String?
Source column that holds entity IDs.
getter/setter pair
featureSpecs ↔ List<GoogleCloudAiplatformV1ImportFeatureValuesRequestFeatureSpec>?
Specifications defining which Feature values to import from the entity.
getter/setter pair
featureTime ↔ String?
Single Feature timestamp for all entities being imported.
getter/setter pair
featureTimeField ↔ String?
Source column that holds the Feature timestamp for all Feature values in each entity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workerCount ↔ int?
Specifies the number of workers that are used to write data to the Featurestore.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited