GoogleCloudAiplatformV1IngestEventsRequest class

Request message for MemoryBankService.IngestEvents.

Constructors

GoogleCloudAiplatformV1IngestEventsRequest({GoogleCloudAiplatformV1IngestionDirectContentsSource? directContentsSource, bool? disableMemoryRevisions, bool? forceFlush, GoogleCloudAiplatformV1MemoryGenerationTriggerConfig? generationTriggerConfig, Map<String, GoogleCloudAiplatformV1MemoryMetadataValue>? metadata, String? metadataMergeStrategy, String? revisionExpireTime, Map<String, String>? revisionLabels, String? revisionTtl, Map<String, String>? scope, String? streamId})
GoogleCloudAiplatformV1IngestEventsRequest.fromJson(Map json_)

Properties

directContentsSource GoogleCloudAiplatformV1IngestionDirectContentsSource?
Ingest events directly from the request.
getter/setter pair
disableMemoryRevisions bool?
If true, no revisions will be created for this request.
getter/setter pair
forceFlush bool?
Forces a flush of all pending events in the stream and triggers memory generation immediately bypassing any conditions configured in the generation_trigger_config.
getter/setter pair
generationTriggerConfig GoogleCloudAiplatformV1MemoryGenerationTriggerConfig?
Configuration for triggering memory generation from this ingestion.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, GoogleCloudAiplatformV1MemoryMetadataValue>?
User-provided metadata for the generated memories.
getter/setter pair
metadataMergeStrategy String?
The strategy to use when applying metadata to existing memories.
getter/setter pair
revisionExpireTime String?
Timestamp of when the revision is considered expired.
getter/setter pair
revisionLabels Map<String, String>?
Labels to be applied to the generated memory revisions.
getter/setter pair
revisionTtl String?
The TTL for the revision.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope Map<String, String>?
The scope of the memories that should be generated from the stream.
getter/setter pair
streamId String?
The ID of the stream to ingest events into.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited