GoogleCloudAiplatformV1IngestionDirectContentsSourceEvent class

A single event to ingest.

Properties

content GoogleCloudAiplatformV1Content?
The content of the event.
getter/setter pair
eventId String?
A unique identifier for the event.
getter/setter pair
eventTime String?
The time at which the event occurred.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited