GoogleCloudAiplatformV1KeepAliveProbe class

Represents the configuration for keep-alive probe.

Contains configuration on a specified endpoint that a deployment host should use to keep the container alive based on the probe settings.

Properties

hashCode int
The hash code for this object.
no setterinherited
httpGet GoogleCloudAiplatformV1KeepAliveProbeHttpGet?
Specifies the HTTP GET configuration for the probe.
getter/setter pair
maxSeconds int?
Specifies the maximum duration (in seconds) to keep the instance alive via this probe.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited