GoogleCloudAiplatformV1KeepAliveProbeHttpGet class

Specifies the HTTP GET configuration for the probe.

Properties

hashCode int
The hash code for this object.
no setterinherited
path String?
Specifies the path of the HTTP GET request (e.g., "/is_busy").
getter/setter pair
port int?
Specifies the port number on the container to which the request is sent.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited