GoogleCloudAiplatformV1ListMemoryRevisionsResponse class
Response message for MemoryBankService.ListMemoryRevisions.
Constructors
-
GoogleCloudAiplatformV1ListMemoryRevisionsResponse({List<
GoogleCloudAiplatformV1MemoryRevision> ? memoryRevisions, String? nextPageToken}) - GoogleCloudAiplatformV1ListMemoryRevisionsResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
memoryRevisions
↔ List<
GoogleCloudAiplatformV1MemoryRevision> ? -
The list of Memory Revisions in the request page.
getter/setter pair
- nextPageToken ↔ String?
-
A token, which can be sent as
page_tokento retrieve the next page.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited