GoogleCloudAiplatformV1Memory class

A memory.

Constructors

GoogleCloudAiplatformV1Memory({String? createTime, String? description, bool? disableMemoryRevisions, String? displayName, String? expireTime, String? fact, Map<String, GoogleCloudAiplatformV1MemoryMetadataValue>? metadata, String? name, String? revisionExpireTime, Map<String, String>? revisionLabels, String? revisionTtl, Map<String, String>? scope, List<GoogleCloudAiplatformV1MemoryTopicId>? topics, String? ttl, String? updateTime})
GoogleCloudAiplatformV1Memory.fromJson(Map json_)

Properties

createTime String?
Timestamp when this Memory was created.
getter/setter pair
description String?
Description of the Memory.
getter/setter pair
disableMemoryRevisions bool?
Input only.
getter/setter pair
displayName String?
Display name of the Memory.
getter/setter pair
expireTime String?
Timestamp of when this resource is considered expired.
getter/setter pair
fact String?
Semantic knowledge extracted from the source content.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, GoogleCloudAiplatformV1MemoryMetadataValue>?
User-provided metadata for the Memory.
getter/setter pair
name String?
Identifier.
getter/setter pair
revisionExpireTime String?
Input only.
getter/setter pair
revisionLabels Map<String, String>?
Input only.
getter/setter pair
revisionTtl String?
Input only.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope Map<String, String>?
The scope of the Memory.
getter/setter pair
topics List<GoogleCloudAiplatformV1MemoryTopicId>?
The Topics of the Memory.
getter/setter pair
ttl String?
Input only.
getter/setter pair
updateTime String?
Timestamp when this Memory was most recently updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited