GoogleCloudAiplatformV1MemoryBankCustomizationConfig class

Represents configuration for organizing natural language memories for a particular scope.

Properties

consolidationConfig GoogleCloudAiplatformV1MemoryBankCustomizationConfigConsolidationConfig?
Represents configuration for customizing how memories are consolidated together.
getter/setter pair
disableNaturalLanguageMemories bool?
Indicates whether natural language memory generation should be disabled for all requests.
getter/setter pair
enableThirdPersonMemories bool?
Indicates whether the memories will be generated in the third person (i.e. "The user generates memories with Memory Bank.").
getter/setter pair
generateMemoriesExamples List<GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample>?
Provides examples of how to generate memories for a particular scope.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
memoryTopics List<GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopic>?
Represents topics of information that should be extracted from conversations and stored as memories.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopeKeys List<String>?
Represents the scope keys (i.e. 'user_id') for which to use this config.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited