revisionsPerCandidateCount property

int? revisionsPerCandidateCount
getter/setter pair

Represents the maximum number of revisions to consider for each candidate memory.

If not set, then the default value (1) will be used, which means that only the latest revision will be considered.

Optional.

Implementation

core.int? revisionsPerCandidateCount;