GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExample class

An example of how to generate memories for a particular scope.

Properties

conversationSource ↔ GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleConversationSource?
A conversation source for the example.
getter/setter pair
generatedMemories ↔ List<GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory>?
Represents the memories that are expected to be generated from the input conversation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited