generatedMemories property

Represents the memories that are expected to be generated from the input conversation.

An empty list indicates that no memories are expected to be generated for the input conversation.

Optional.

Implementation

core.List<
  GoogleCloudAiplatformV1MemoryBankCustomizationConfigGenerateMemoriesExampleGeneratedMemory
>?
generatedMemories;