GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopic class

A topic of information that should be extracted from conversations and stored as memories.

Properties

customMemoryTopic ↔ GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopicCustomMemoryTopic?
A custom memory topic defined by the developer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
managedMemoryTopic ↔ GoogleCloudAiplatformV1MemoryBankCustomizationConfigMemoryTopicManagedMemoryTopic?
A managed memory topic defined by Memory Bank.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited