description property
Represents the description of the memory topic.
This should explain what information should be extracted for this topic.
Required.
Implementation
core.String? description;
Represents the description of the memory topic.
This should explain what information should be extracted for this topic.
Required.
core.String? description;