generationRule property

Represents the active rule that determines when to flush the buffer.

If not set, then the stream will be force flushed immediately.

Optional.

Implementation

GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule?
generationRule;