idleDuration property
Specifies to trigger generation if the stream is inactive for the specified duration after the most recent event.
The duration must have a minute-level granularity.
Optional.
Implementation
core.String? idleDuration;
Specifies to trigger generation if the stream is inactive for the specified duration after the most recent event.
The duration must have a minute-level granularity.
Optional.
core.String? idleDuration;