timestampValue property
Timestamp value.
When filtering on timestamp values, only the seconds field will be compared.
Implementation
core.String? timestampValue;
Timestamp value.
When filtering on timestamp values, only the seconds field will be compared.
core.String? timestampValue;