GoogleCloudAiplatformV1MemoryRevision class

A revision of a Memory.

Properties

createTime String?
Timestamp when this Memory Revision was created.
getter/setter pair
expireTime String?
Timestamp of when this resource is considered expired.
getter/setter pair
extractedMemories List<GoogleCloudAiplatformV1IntermediateExtractedMemory>?
The extracted memories from the source content before consolidation when the memory was updated via GenerateMemories.
getter/setter pair
fact String?
The fact of the Memory Revision.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
The labels of the Memory Revision.
getter/setter pair
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited