structuredData property

Map<String, Object?>? structuredData
getter/setter pair

Represents the structured value of the memory at the time of revision creation.

Output only.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? structuredData;