GoogleCloudAiplatformV1Metadata class
Metadata for a chunk.
Constructors
-
GoogleCloudAiplatformV1Metadata({Map<
String, String> ? attributes}) - GoogleCloudAiplatformV1Metadata.fromJson(Map json_)
Properties
-
attributes
↔ Map<
String, String> ? -
Attributes attached to the data.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited