GoogleCloudAiplatformV1ModelMonitoringObjectiveConfig class

The objective configuration for model monitoring, including the information needed to detect anomalies for one particular model.

Properties

explanationConfig ↔ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigExplanationConfig?
The config for integrating with Vertex Explainable AI.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
predictionDriftDetectionConfig ↔ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigPredictionDriftDetectionConfig?
The config for drift of prediction data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingDataset ↔ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingDataset?
Training dataset for models.
getter/setter pair
trainingPredictionSkewDetectionConfig ↔ GoogleCloudAiplatformV1ModelMonitoringObjectiveConfigTrainingPredictionSkewDetectionConfig?
The config for skew between training data and prediction data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited