GoogleCloudAiplatformV1ModelVersionCheckpoint class

Describes the machine learning model version checkpoint.

Properties

checkpointId ↔ String?
The ID of the checkpoint.
getter/setter pair
epoch ↔ String?
The epoch of the checkpoint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
step ↔ String?
The step of the checkpoint.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited