GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpec class

The spec of multi-trial Neural Architecture Search (NAS).

Properties

hashCode → int
The hash code for this object.
no setterinherited
metric ↔ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecMetricSpec?
Metric specs for the NAS job.
getter/setter pair
multiTrialAlgorithm ↔ String?
The multi-trial Neural Architecture Search (NAS) algorithm type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchTrialSpec ↔ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecSearchTrialSpec?
Spec for search trials.
getter/setter pair
trainTrialSpec ↔ GoogleCloudAiplatformV1NasJobSpecMultiTrialAlgorithmSpecTrainTrialSpec?
Spec for train trials.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited