GoogleCloudAiplatformV1NearestNeighborQuery class

A query to find a number of similar entities.

Properties

embedding ↔ GoogleCloudAiplatformV1NearestNeighborQueryEmbedding?
The embedding vector that be used for similar search.
getter/setter pair
entityId ↔ String?
The entity id whose similar entities should be searched for.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
neighborCount ↔ int?
The number of similar entities to be retrieved from feature view for each query.
getter/setter pair
numericFilters ↔ List<GoogleCloudAiplatformV1NearestNeighborQueryNumericFilter>?
The list of numeric filters.
getter/setter pair
parameters ↔ GoogleCloudAiplatformV1NearestNeighborQueryParameters?
Parameters that can be set to tune query on the fly.
getter/setter pair
perCrowdingAttributeNeighborCount ↔ int?
Crowding is a constraint on a neighbor list produced by nearest neighbor search requiring that no more than sper_crowding_attribute_neighbor_count of the k neighbors returned have the same value of crowding_attribute.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringFilters ↔ List<GoogleCloudAiplatformV1NearestNeighborQueryStringFilter>?
The list of string filters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited