GoogleCloudAiplatformV1NearestNeighborQueryParameters class

Parameters that can be overrided in each query to tune query latency and recall.

Constructors

GoogleCloudAiplatformV1NearestNeighborQueryParameters({int? approximateNeighborCandidates, double? leafNodesSearchFraction})
GoogleCloudAiplatformV1NearestNeighborQueryParameters.fromJson(Map json_)

Properties

approximateNeighborCandidates ↔ int?
The number of neighbors to find via approximate search before exact reordering is performed; if set, this value must be > neighbor_count.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
leafNodesSearchFraction ↔ double?
The fraction of the number of leaves to search, set at query time allows user to tune search performance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited