GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpec class

Compute configuration to use for an execution job.

Properties

hashCode → int
The hash code for this object.
no setterinherited
machineSpec ↔ GoogleCloudAiplatformV1MachineSpec?
The specification of a single machine for the execution job.
getter/setter pair
networkSpec ↔ GoogleCloudAiplatformV1NetworkSpec?
The network configuration to use for the execution job.
getter/setter pair
persistentDiskSpec ↔ GoogleCloudAiplatformV1PersistentDiskSpec?
The specification of a persistent disk to attach for the execution job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shieldedInstanceConfig ↔ GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpecShieldedInstanceConfig?
Shielded VM configuration (for example, Secure Boot) for the execution VM.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited