GoogleCloudAiplatformV1NotebookExecutionJobCustomEnvironmentSpecShieldedInstanceConfig class

A set of Shielded VM options for the execution VM.

Mirrors google.cloud.notebooks.v2.ShieldedInstanceConfig. See https://cloud.google.com/compute/docs/instances/modifying-shielded-vm.

Properties

enableIntegrityMonitoring bool?
Whether the VM instance has integrity monitoring enabled.
getter/setter pair
enableSecureBoot bool?
Whether the VM instance has Secure Boot enabled.
getter/setter pair
enableVtpm bool?
Whether the VM instance has vTPM enabled.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited