GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntimeContainerImage class

The definition of a user-provided container image to run the notebook execution in.

Mirrors google.cloud.notebooks.v2.ContainerImage.

Properties

hashCode int
The hash code for this object.
no setterinherited
repository String?
The path to the container image repository.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
The tag of the container image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited