GoogleCloudAiplatformV1NotebookSoftwareConfig class

Notebook Software Config.

This is passed to the backend when user makes software configurations in UI.

Properties

colabImage ↔ GoogleCloudAiplatformV1ColabImage?
Google-managed NotebookRuntime colab image.
getter/setter pair
env ↔ List<GoogleCloudAiplatformV1EnvVar>?
Environment variables to be passed to the container.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postStartupScriptConfig ↔ GoogleCloudAiplatformV1PostStartupScriptConfig?
Post startup script config.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited