GoogleCloudAiplatformV1Part class

A datatype containing media that is part of a multi-part Content message.

A Part consists of data which has an associated datatype. A Part can only contain one of the accepted types in Part.data. For media types that are not text, Part must have a fixed IANA MIME type identifying the type and subtype of the media if inline_data or file_data field is filled with raw bytes.

Properties

codeExecutionResult GoogleCloudAiplatformV1CodeExecutionResult?
The result of executing the ExecutableCode.
getter/setter pair
executableCode GoogleCloudAiplatformV1ExecutableCode?
Code generated by the model that is intended to be executed.
getter/setter pair
fileData GoogleCloudAiplatformV1FileData?
The URI-based data of the part.
getter/setter pair
functionCall GoogleCloudAiplatformV1FunctionCall?
A predicted function call returned from the model.
getter/setter pair
functionResponse GoogleCloudAiplatformV1FunctionResponse?
The result of a function call.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inlineData GoogleCloudAiplatformV1Blob?
The inline data content of the part.
getter/setter pair
mediaResolution GoogleCloudAiplatformV1PartMediaResolution?
per part media resolution.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The text content of the part.
getter/setter pair
thought bool?
Indicates whether the part represents the model's thought process or reasoning.
getter/setter pair
thoughtSignature String?
An opaque signature for the thought so it can be reused in subsequent requests.
getter/setter pair
thoughtSignatureAsBytes List<int>
getter/setter pair
videoMetadata GoogleCloudAiplatformV1VideoMetadata?
Video metadata.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited