executableCode property
Code generated by the model that is intended to be executed.
Optional.
Implementation
GoogleCloudAiplatformV1ExecutableCode? executableCode;
Code generated by the model that is intended to be executed.
Optional.
GoogleCloudAiplatformV1ExecutableCode? executableCode;