GoogleCloudAiplatformV1PreTunedModel class

A pre-tuned model for continuous tuning.

Constructors

GoogleCloudAiplatformV1PreTunedModel({String? baseModel, String? checkpointId, String? tunedModelName})
GoogleCloudAiplatformV1PreTunedModel.fromJson(Map json_)

Properties

baseModel String?
The name of the base model this PreTunedModel was tuned from.
getter/setter pair
checkpointId String?
The source checkpoint id.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tunedModelName String?
The resource name of the Model.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited