GoogleCloudAiplatformV1PythonPackageSpec class

The spec of a Python packaged code.

Properties

args ↔ List<String>?
Command line arguments to be passed to the Python task.
getter/setter pair
env ↔ List<GoogleCloudAiplatformV1EnvVar>?
Environment variables to be passed to the python module.
getter/setter pair
executorImageUri ↔ String?
The URI of a container image in Artifact Registry that will run the provided Python package.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
packageUris ↔ List<String>?
The Google Cloud Storage location of the Python package files which are the training program and its dependent packages.
getter/setter pair
pythonModule ↔ String?
The Python module name to run after installing the packages.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited