GoogleCloudAiplatformV1QueryDeployedModelsResponse class

Response message for QueryDeployedModels method.

Properties

deployedModelRefs ↔ List<GoogleCloudAiplatformV1DeployedModelRef>?
References to the DeployedModels that share the specified deploymentResourcePool.
getter/setter pair
deployedModels ↔ List<GoogleCloudAiplatformV1DeployedModel>?
DEPRECATED Use deployed_model_refs instead.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalDeployedModelCount ↔ int?
The total number of DeployedModels on this DeploymentResourcePool.
getter/setter pair
totalEndpointCount ↔ int?
The total number of Endpoints that have DeployedModels on this DeploymentResourcePool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited