GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityView class

Entity view with Feature values.

Properties

data ↔ List<GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData>?
Each piece of data holds the k requested values for one requested Feature.
getter/setter pair
entityId ↔ String?
ID of the requested entity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited