GoogleCloudAiplatformV1ReadFeatureValuesResponseEntityViewData class

Container to hold value(s), successive in time, for one Feature from the request.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ GoogleCloudAiplatformV1FeatureValue?
Feature value if a single value is requested.
getter/setter pair
values ↔ GoogleCloudAiplatformV1FeatureValueList?
Feature values list if values, successive in time, are requested.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited