GoogleCloudAiplatformV1ReadFeatureValuesResponseHeader class

Response header with metadata for the requested ReadFeatureValuesRequest.entity_type and Features.

Properties

entityType ↔ String?
The resource name of the EntityType from the ReadFeatureValuesRequest.
getter/setter pair
featureDescriptors ↔ List<GoogleCloudAiplatformV1ReadFeatureValuesResponseFeatureDescriptor>?
List of Feature metadata corresponding to each piece of ReadFeatureValuesResponse.EntityView.data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited