GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigGenerationConfig class

Configuration for how to generate memories.

Properties

generationTriggerConfig ↔ GoogleCloudAiplatformV1MemoryGenerationTriggerConfig?
Specifies the default trigger configuration for generating memories using IngestEvents.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
model ↔ String?
The model used to generate memories.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited