defaultTtl property

String? defaultTtl
getter/setter pair

The default TTL duration of the memories in the Memory Bank.

This applies to all operations that create or update a memory.

Optional.

Implementation

core.String? defaultTtl;