memoryRevisionDefaultTtl property

String? memoryRevisionDefaultTtl
getter/setter pair

The default TTL duration of the memory revisions in the Memory Bank.

This applies to all operations that create a memory revision. If not set, a default TTL of 365 days will be used.

Optional.

Implementation

core.String? memoryRevisionDefaultTtl;