containerSpec property
Deploy from a container image with a defined entrypoint and commands.
Implementation
GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec? containerSpec;
Deploy from a container image with a defined entrypoint and commands.
GoogleCloudAiplatformV1ReasoningEngineSpecContainerSpec? containerSpec;