serviceAccount property

String? serviceAccount
getter/setter pair

The service account that Cloud Build uses to run the build.

This field is only applicable when worker_pool is specified (i.e., for custom worker pools). If worker_pool is not specified, this field is ignored and the build runs using the Google-managed service agent. Format: projects/{project}/serviceAccounts/{service_account} or {service_account}@{project}.iam.gserviceaccount.com

Optional.

Implementation

core.String? serviceAccount;