GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpecAgentGatewayConfig class

Agent Gateway configuration for a Reasoning Engine deployment.

Properties

agentToAnywhereConfig GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpecAgentGatewayConfigAgentToAnywhereConfig?
Configuration for traffic originating from the Reasoning Engine.
getter/setter pair
clientToAgentConfig GoogleCloudAiplatformV1ReasoningEngineSpecDeploymentSpecAgentGatewayConfigClientToAgentConfig?
Configuration for traffic targeting the Reasoning Engine.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited