GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec class

Specification for running a Python application from source.

Properties

entrypointModule ↔ String?
The Python module to load as the entrypoint, specified as a fully qualified module name.
getter/setter pair
entrypointObject ↔ String?
The name of the callable object within the entrypoint_module to use as the application If not specified, defaults to "root_agent".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requirementsFile ↔ String?
The path to the requirements file, relative to the source root.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
The version of Python to use.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited