GoogleCloudAiplatformV1RebaseTunedModelRequest class

Request message for GenAiTuningService.RebaseTunedModel.

Properties

artifactDestination GoogleCloudAiplatformV1GcsDestination?
The Google Cloud Storage location to write the artifacts to.
getter/setter pair
deployToSameEndpoint bool?
By default, rebasing a model creates a new endpoint for the new model.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tunedModelRef GoogleCloudAiplatformV1TunedModelRef?
A reference to the tuned model to rebase.
getter/setter pair
tuningJob GoogleCloudAiplatformV1TuningJob?
The tuning job to be updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited