GoogleCloudAiplatformV1ResponseFormat class

Configuration for the model to configure output formatting and delivery.

Properties

audio GoogleCloudAiplatformV1AudioResponseFormat?
Audio output format.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image GoogleCloudAiplatformV1ImageResponseFormat?
Image output format.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text GoogleCloudAiplatformV1TextResponseFormat?
Text output format.
getter/setter pair
video GoogleCloudAiplatformV1VideoResponseFormat?
Video output format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited