GoogleCloudAiplatformV1RollbackMemoryRequest class
Request message for MemoryBankService.RollbackMemory.
Constructors
- GoogleCloudAiplatformV1RollbackMemoryRequest({String? targetRevisionId})
- GoogleCloudAiplatformV1RollbackMemoryRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetRevisionId ↔ String?
-
The ID of the revision to rollback to.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited