method property

String? method
getter/setter pair

The method for blocking content.

If not specified, the default behavior is to use the probability score.

Optional. Possible string values are:

  • "HARM_BLOCK_METHOD_UNSPECIFIED" : The harm block method is unspecified.
  • "SEVERITY" : The harm block method uses both probability and severity scores.
  • "PROBABILITY" : The harm block method uses the probability score.

Implementation

core.String? method;