GoogleCloudAiplatformV1SandboxEnvironmentSpecCodeExecutionEnvironment class

The code execution environment with customized settings.

Properties

codeLanguage ↔ String?
The coding language supported in this environment. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
machineConfig ↔ String?
The machine config of the code execution environment. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited