GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfig class

Configuration for egress control of sandbox instances.

Properties

customerVpcNetwork String?
The customer VPC network that sandbox egress is routed into.
getter/setter pair
dnsPeeringConfigs List<GoogleCloudAiplatformV1SandboxEnvironmentTemplateEgressControlConfigDnsPeeringConfig>?
DNS peering configurations that allow sandbox egress to resolve customer-internal domains via the customer VPC.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internetAccess bool?
Whether to allow internet access.
getter/setter pair
networkAttachment String?
The name of the customer VPC NetworkAttachment used to draw a PSC interface IP into the customer VPC for sandbox egress.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited