maxConcurrentActiveRunCount property
Specifies the maximum number of active runs that can be executed concurrently for this Schedule.
This limits the number of runs that can be in a non-terminal state at the same time. Currently, this field is only supported for requests of type CreatePipelineJobRequest.
Optional.
Implementation
core.String? maxConcurrentActiveRunCount;