GoogleCloudAiplatformV1Segment class
A segment of the content.
Constructors
- GoogleCloudAiplatformV1Segment({int? endIndex, int? partIndex, int? startIndex, String? text})
- GoogleCloudAiplatformV1Segment.fromJson(Map json_)
Properties
- endIndex ↔ int?
-
The end index of the segment in the
Part, measured in bytes.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- partIndex ↔ int?
-
The index of the
Partobject that this segment belongs to.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startIndex ↔ int?
-
The start index of the segment in the
Part, measured in bytes.getter/setter pair - text ↔ String?
-
The text of the segment.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited