invocationId property
The invocation id of the event, multiple events can have the same invocation id.
Required.
Implementation
core.String? invocationId;
The invocation id of the event, multiple events can have the same invocation id.
Required.
core.String? invocationId;