GoogleCloudAiplatformV1SyntheticExample class
A single instance of generated synthetic data.
Each example is made up of one or more named fields, as defined in
OutputFieldSpec. These examples are used as few-shot examples to show the
model what you want (in GenerateSyntheticDataRequest.examples) and to
return generated examples in the response (in
GenerateSyntheticDataResponse.synthetic_examples).
Constructors
Properties
-
fields
↔ List<
GoogleCloudAiplatformV1SyntheticField> ? -
A list of fields that constitute an example.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited