taskDescription property
A general description of the type of synthetic data you want to generate.
For example, "Generate customer reviews for a new smartphone."
Required.
Implementation
core.String? taskDescription;
A general description of the type of synthetic data you want to generate.
For example, "Generate customer reviews for a new smartphone."
Required.
core.String? taskDescription;