GoogleCloudAiplatformV1TextResponseFormat class
Configuration for text-specific output formatting.
Constructors
- GoogleCloudAiplatformV1TextResponseFormat({String? mimeType, Object? schema})
- GoogleCloudAiplatformV1TextResponseFormat.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType ↔ String?
-
The IANA standard MIME type of the response.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema ↔ Object?
-
The JSON schema that the output should conform to.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited