GoogleCloudAiplatformV1ToolCodeExecution typedef

GoogleCloudAiplatformV1ToolCodeExecution = $Empty

Tool that executes code generated by the model, and automatically returns the result to the model.

See also ExecutableCode and CodeExecutionResult, which are input and output to this tool.

Implementation

typedef GoogleCloudAiplatformV1ToolCodeExecution = $Empty;