GoogleCloudAiplatformV1ToolComputerUse class

Tool to support computer use.

Constructors

GoogleCloudAiplatformV1ToolComputerUse({bool? enablePromptInjectionDetection, String? environment, List<String>? excludedPredefinedFunctions})
GoogleCloudAiplatformV1ToolComputerUse.fromJson(Map json_)

Properties

enablePromptInjectionDetection ↔ bool?
Enables the prompt injection detection check on computer-use request.
getter/setter pair
environment ↔ String?
The environment being operated.
getter/setter pair
excludedPredefinedFunctions ↔ List<String>?
By default, predefined functions are included in the final model call.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited