GoogleCloudAiplatformV1ToolGoogleSearch class
GoogleSearch tool type.
Tool to support Google Search in Model. Powered by Google.
Constructors
-
GoogleCloudAiplatformV1ToolGoogleSearch({String? blockingConfidence, List<
String> ? excludeDomains}) - GoogleCloudAiplatformV1ToolGoogleSearch.fromJson(Map json_)
Properties
- blockingConfidence ↔ String?
-
Sites with confidence level chosen & above this value will be blocked from
the search results.
getter/setter pair
-
excludeDomains
↔ List<
String> ? -
List of domains to be excluded from the search results.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited