GoogleCloudAiplatformV1UrlMetadata class

The metadata for a single URL retrieval.

Constructors

GoogleCloudAiplatformV1UrlMetadata({String? retrievedUrl, String? urlRetrievalStatus})
GoogleCloudAiplatformV1UrlMetadata.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
retrievedUrl String?
The URL retrieved by the tool.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlRetrievalStatus String?
The status of the URL retrieval. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited