GoogleCloudAiplatformV1UserScenarioGenerationConfig class
User scenario generation configuration.
Constructors
- GoogleCloudAiplatformV1UserScenarioGenerationConfig({String? environmentData, String? modelName, String? simulationInstruction, String? userScenarioCount})
- GoogleCloudAiplatformV1UserScenarioGenerationConfig.fromJson(Map json_)
Properties
- environmentData ↔ String?
-
Environment data in string type.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- modelName ↔ String?
-
The model name to use for generation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simulationInstruction ↔ String?
-
Simulation instruction to guide the user scenario generation.
getter/setter pair
- userScenarioCount ↔ String?
-
The number of user scenarios to generate.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited