GoogleCloudAiplatformV1VoiceConfig class

Configuration for a voice.

Properties

hashCode int
The hash code for this object.
no setterinherited
prebuiltVoiceConfig GoogleCloudAiplatformV1PrebuiltVoiceConfig?
The configuration for a prebuilt voice.
getter/setter pair
replicatedVoiceConfig GoogleCloudAiplatformV1ReplicatedVoiceConfig?
The configuration for a replicated voice.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited