MediaResource class

Constructors

MediaResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upload(GoogleCloudAiplatformV1UploadRagFileRequest request, String parent, {String? $fields, Media? uploadMedia}) → Future<GoogleCloudAiplatformV1UploadRagFileResponse>
Upload a file into a RagCorpus.

Operators

operator ==(Object other) → bool
The equality operator.
inherited