ProjectsLocationsDataLabelingJobsResource class

Constructors

ProjectsLocationsDataLabelingJobsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → ProjectsLocationsDataLabelingJobsOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(GoogleCloudAiplatformV1CancelDataLabelingJobRequest request, String name, {String? $fields}) → Future<GoogleProtobufEmpty>
Cancels a DataLabelingJob.
create(GoogleCloudAiplatformV1DataLabelingJob request, String parent, {String? $fields}) → Future<GoogleCloudAiplatformV1DataLabelingJob>
Creates a DataLabelingJob.
delete(String name, {String? $fields}) → Future<GoogleLongrunningOperation>
Deletes a DataLabelingJob.
get(String name, {String? $fields}) → Future<GoogleCloudAiplatformV1DataLabelingJob>
Gets a DataLabelingJob.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? readMask, String? $fields}) → Future<GoogleCloudAiplatformV1ListDataLabelingJobsResponse>
Lists DataLabelingJobs in a Location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited