ProjectsLocationsDatasetsSavedQueriesResource class

Constructors

ProjectsLocationsDatasetsSavedQueriesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → ProjectsLocationsDatasetsSavedQueriesOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String name, {String? $fields}) → Future<GoogleLongrunningOperation>
Deletes a SavedQuery.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? readMask, String? $fields}) → Future<GoogleCloudAiplatformV1ListSavedQueriesResponse>
Lists SavedQueries in a Dataset.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited