ProjectsLocationsFeaturestoresEntityTypesFeaturesResource class

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → ProjectsLocationsFeaturestoresEntityTypesFeaturesOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchCreate(GoogleCloudAiplatformV1BatchCreateFeaturesRequest request, String parent, {String? $fields}) → Future<GoogleLongrunningOperation>
Creates a batch of Features in a given EntityType.
create(GoogleCloudAiplatformV1Feature request, String parent, {String? featureId, String? $fields}) → Future<GoogleLongrunningOperation>
Creates a new Feature in a given EntityType.
delete(String name, {String? $fields}) → Future<GoogleLongrunningOperation>
Deletes a single Feature.
get(String name, {String? $fields}) → Future<GoogleCloudAiplatformV1Feature>
Gets details of a single Feature.
list(String parent, {String? filter, int? latestStatsCount, String? orderBy, int? pageSize, String? pageToken, String? readMask, String? $fields}) → Future<GoogleCloudAiplatformV1ListFeaturesResponse>
Lists Features in a given EntityType.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleCloudAiplatformV1Feature request, String name, {String? updateMask, String? $fields}) → Future<GoogleCloudAiplatformV1Feature>
Updates the parameters of a single Feature.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited