ProjectsLocationsHyperparameterTuningJobsResource class

Constructors

ProjectsLocationsHyperparameterTuningJobsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → ProjectsLocationsHyperparameterTuningJobsOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(GoogleCloudAiplatformV1CancelHyperparameterTuningJobRequest request, String name, {String? $fields}) → Future<GoogleProtobufEmpty>
Cancels a HyperparameterTuningJob.
create(GoogleCloudAiplatformV1HyperparameterTuningJob request, String parent, {String? $fields}) → Future<GoogleCloudAiplatformV1HyperparameterTuningJob>
Creates a HyperparameterTuningJob
delete(String name, {String? $fields}) → Future<GoogleLongrunningOperation>
Deletes a HyperparameterTuningJob.
get(String name, {String? $fields}) → Future<GoogleCloudAiplatformV1HyperparameterTuningJob>
Gets a HyperparameterTuningJob
list(String parent, {String? filter, int? pageSize, String? pageToken, String? readMask, String? $fields}) → Future<GoogleCloudAiplatformV1ListHyperparameterTuningJobsResponse>
Lists HyperparameterTuningJobs in a Location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited