ProjectsLocationsMemoryBanksResource class

Constructors

ProjectsLocationsMemoryBanksResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
memories → ProjectsLocationsMemoryBanksMemoriesResource
no setter
operations → ProjectsLocationsMemoryBanksOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

ingestEvents(GoogleCloudAiplatformV1IngestEventsRequest request, String parent, {String? $fields}) → Future<GoogleLongrunningOperation>
Ingests events for a Memory Bank.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited