compact method
- GoogleCloudAiplatformV1CompactSessionRequest request,
- String name, {
- String? $fields,
Compacts the event history of a given Session, which may run an LLM summarization call and rewrite the full event history.
Compaction is a storage-side rewrite that can apply a stackable pipeline of rules (event-horizon preservation, tool-response truncation, thought stripping, and LLM summarization etc.)
request - The metadata request object.
Request parameters:
name - Required. The resource name of the session to compact. Format:
projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine}/sessions/{session}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/reasoningEngines/\[^/\]+/sessions/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleLongrunningOperation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleLongrunningOperation> compact(
GoogleCloudAiplatformV1CompactSessionRequest request,
core.String name, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':compact';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleLongrunningOperation.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}