create method

Future<GoogleLongrunningOperation> create(
  1. GoogleCloudAiplatformV1Session request,
  2. String parent, {
  3. String? sessionId,
  4. String? $fields,
})

Creates a new Session.

request - The metadata request object.

Request parameters:

parent - Required. The resource name of the location to create the session in. Format: projects/{project}/locations/{location}/reasoningEngines/{reasoning_engine} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/reasoningEngines/\[^/\]+$.

sessionId - Optional. The user defined ID to use for session, which will become the final component of the session resource name. If not provided, Vertex AI will generate a value for this ID. This value may be up to 63 characters, and valid characters are [a-z0-9-]. The first and last characters must be a letter or number.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleLongrunningOperation.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleLongrunningOperation> create(
  GoogleCloudAiplatformV1Session request,
  core.String parent, {
  core.String? sessionId,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'sessionId': ?sessionId == null ? null : [sessionId],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/sessions';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return GoogleLongrunningOperation.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}