updateSemanticGovernancePolicyEngine method

Future<GoogleLongrunningOperation> updateSemanticGovernancePolicyEngine(
  1. GoogleCloudAiplatformV1SemanticGovernancePolicyEngine request,
  2. String name, {
  3. String? updateMask,
  4. String? $fields,
})

Updates a SemanticGovernancePolicyEngine.

This method performs an upsert operation. If the SemanticGovernancePolicyEngine resource does not exist, it will be created. Otherwise, it will be updated.

request - The metadata request object.

Request parameters:

name - Identifier. The resource name of the SemanticGovernancePolicyEngine. Format: projects/{project}/locations/{location}/semanticGovernancePolicyEngine Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/semanticGovernancePolicyEngine$.

updateMask - Optional. Specifies the fields to be overwritten in the SemanticGovernancePolicyEngine resource by the update. The fields specified in the update_mask are relative to the resource itself. If no update_mask is provided, all fields are overwritten.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleLongrunningOperation.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleLongrunningOperation> updateSemanticGovernancePolicyEngine(
  GoogleCloudAiplatformV1SemanticGovernancePolicyEngine request,
  core.String name, {
  core.String? updateMask,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'updateMask': ?updateMask == null ? null : [updateMask],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'PATCH',
    body: body_,
    queryParams: queryParams_,
  );
  return GoogleLongrunningOperation.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}