deprovision method
- GoogleCloudAiplatformV1DeprovisionSemanticGovernancePolicyEngineRequest request,
- String name, {
- String? $fields,
Deprovisions the SemanticGovernancePolicyEngine, tearing down the associated tenant project, GKE cluster, and PSC service attachments.
This operation is irreversible. Returns a long-running operation; poll for completion. The response contains the SemanticGovernancePolicyEngine in DEPROVISIONING state.
request - The metadata request object.
Request parameters:
name - Required. The resource name of the SemanticGovernancePolicyEngine
to deprovision. Format:
projects/{project}/locations/{location}/semanticGovernancePolicyEngine
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/semanticGovernancePolicyEngine$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleLongrunningOperation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleLongrunningOperation> deprovision(
GoogleCloudAiplatformV1DeprovisionSemanticGovernancePolicyEngineRequest
request,
core.String name, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':deprovision';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleLongrunningOperation.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}