ProjectsLocationsTuningJobsResource class

Constructors

ProjectsLocationsTuningJobsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → ProjectsLocationsTuningJobsOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(GoogleCloudAiplatformV1CancelTuningJobRequest request, String name, {String? $fields}) → Future<GoogleProtobufEmpty>
Cancels a tuning job.
create(GoogleCloudAiplatformV1TuningJob request, String parent, {String? $fields}) → Future<GoogleCloudAiplatformV1TuningJob>
Creates a tuning job.
get(String name, {String? $fields}) → Future<GoogleCloudAiplatformV1TuningJob>
Gets a tuning job.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<GoogleCloudAiplatformV1ListTuningJobsResponse>
Lists tuning jobs in a location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebaseTunedModel(GoogleCloudAiplatformV1RebaseTunedModelRequest request, String parent, {String? $fields}) → Future<GoogleLongrunningOperation>
Rebase a tuned model.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited