LookupCurrentConditionsResponse class

Constructors

LookupCurrentConditionsResponse({String? dateTime, HealthRecommendations? healthRecommendations, List<AirQualityIndex>? indexes, List<Pollutant>? pollutants, String? regionCode})
LookupCurrentConditionsResponse.fromJson(Map json_)

Properties

dateTime ↔ String?
A rounded down timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthRecommendations ↔ HealthRecommendations?
Health advice and recommended actions related to the reported air quality conditions.
getter/setter pair
indexes ↔ List<AirQualityIndex>?
Based on the request parameters, this list will include (up to) two air quality indexes: - Universal AQI.
getter/setter pair
pollutants ↔ List<Pollutant>?
A list of pollutants affecting the location specified in the request.
getter/setter pair
regionCode ↔ String?
The ISO_3166-1 alpha-2 code of the country/region corresponding to the location provided in the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited