Cluster class

A cluster is a collection of regional AlloyDB resources.

It can include a primary instance and one or more read pool instances. All cluster resources share a storage layer, which scales as needed.

Constructors

Cluster({Map<String, String>? annotations, AutomatedBackupPolicy? automatedBackupPolicy, BackupSource? backupSource, BackupDrBackupSource? backupdrBackupSource, BackupDrInfo? backupdrInfo, CloudSQLBackupRunSource? cloudsqlBackupRunSource, String? clusterType, ContinuousBackupConfig? continuousBackupConfig, ContinuousBackupInfo? continuousBackupInfo, String? createTime, String? databaseVersion, DataplexConfig? dataplexConfig, String? deleteTime, String? displayName, EncryptionConfig? encryptionConfig, EncryptionInfo? encryptionInfo, String? etag, UserPassword? initialUser, Map<String, String>? labels, MaintenanceSchedule? maintenanceSchedule, MaintenanceUpdatePolicy? maintenanceUpdatePolicy, String? maintenanceVersionSelectionPolicy, MigrationSource? migrationSource, String? name, String? network, NetworkConfig? networkConfig, PrimaryConfig? primaryConfig, PscConfig? pscConfig, bool? reconciling, bool? satisfiesPzs, SecondaryConfig? secondaryConfig, SslConfig? sslConfig, String? state, String? subscriptionType, Map<String, String>? tags, TrialMetadata? trialMetadata, String? uid, String? updateTime})
Cluster.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Annotations to allow client tools to store small amount of arbitrary data.
getter/setter pair
automatedBackupPolicy ↔ AutomatedBackupPolicy?
The automated backup policy for this cluster.
getter/setter pair
backupdrBackupSource ↔ BackupDrBackupSource?
Cluster created from a BackupDR backup.
getter/setter pair
backupdrInfo ↔ BackupDrInfo?
Output only information about BackupDR protection for this cluster.
getter/setter pair
backupSource ↔ BackupSource?
Cluster created from backup.
getter/setter pair
cloudsqlBackupRunSource ↔ CloudSQLBackupRunSource?
Cluster created from CloudSQL snapshot.
getter/setter pair
clusterType ↔ String?
The type of the cluster.
getter/setter pair
continuousBackupConfig ↔ ContinuousBackupConfig?
Continuous backup configuration for this cluster.
getter/setter pair
continuousBackupInfo ↔ ContinuousBackupInfo?
Continuous backup properties for this cluster.
getter/setter pair
createTime ↔ String?
Create time stamp
getter/setter pair
databaseVersion ↔ String?
The database engine major version.
getter/setter pair
dataplexConfig ↔ DataplexConfig?
Configuration for Dataplex integration.
getter/setter pair
deleteTime ↔ String?
Delete time stamp
getter/setter pair
displayName ↔ String?
User-settable and human-readable display name for the Cluster.
getter/setter pair
encryptionConfig ↔ EncryptionConfig?
The encryption config can be specified to encrypt the data disks and other persistent data resources of a cluster with a customer-managed encryption key (CMEK).
getter/setter pair
encryptionInfo ↔ EncryptionInfo?
The encryption information for the cluster.
getter/setter pair
etag ↔ String?
For Resource freshness validation (https://google.aip.dev/154)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialUser ↔ UserPassword?
Input only.
getter/setter pair
labels ↔ Map<String, String>?
Labels as key value pairs
getter/setter pair
maintenanceSchedule ↔ MaintenanceSchedule?
The maintenance schedule for the cluster, generated for a specific rollout if a maintenance window is set.
getter/setter pair
maintenanceUpdatePolicy ↔ MaintenanceUpdatePolicy?
The maintenance update policy determines when to allow or deny updates.
getter/setter pair
maintenanceVersionSelectionPolicy ↔ String?
Input only.
getter/setter pair
migrationSource ↔ MigrationSource?
Cluster created via DMS migration.
getter/setter pair
name ↔ String?
The name of the cluster resource with the format: * projects/{project}/locations/{region}/clusters/{cluster_id} where the cluster ID segment should satisfy the regex expression [a-z0-9-]+.
getter/setter pair
network ↔ String?
The resource link for the VPC network in which cluster resources are created and from which they are accessible via Private IP.
getter/setter pair
networkConfig ↔ NetworkConfig?
getter/setter pair
primaryConfig ↔ PrimaryConfig?
Cross Region replication config specific to PRIMARY cluster.
getter/setter pair
pscConfig ↔ PscConfig?
The configuration for Private Service Connect (PSC) for the cluster.
getter/setter pair
reconciling ↔ bool?
Reconciling (https://google.aip.dev/128#reconciliation).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
secondaryConfig ↔ SecondaryConfig?
Cross Region replication config specific to SECONDARY cluster.
getter/setter pair
sslConfig ↔ SslConfig?
SSL configuration for this AlloyDB cluster.
getter/setter pair
state ↔ String?
The current serving state of the cluster.
getter/setter pair
subscriptionType ↔ String?
Subscription type of the cluster.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
trialMetadata ↔ TrialMetadata?
Metadata for free trial clusters
getter/setter pair
uid ↔ String?
The system-generated UID of the resource.
getter/setter pair
updateTime ↔ String?
Update time stamp
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited