CsvImportOptions class

Options for importing data in CSV format.

Constructors

CsvImportOptions({List<String>? columns, String? escapeCharacter, String? fieldDelimiter, String? quoteCharacter, String? table})
CsvImportOptions.fromJson(Map json_)

Properties

columns ↔ List<String>?
The columns to which CSV data is imported.
getter/setter pair
escapeCharacter ↔ String?
Specifies the character that should appear before a data character that needs to be escaped.
getter/setter pair
fieldDelimiter ↔ String?
Specifies the character that separates columns within each row (line) of the file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
quoteCharacter ↔ String?
Specifies the quoting character to be used when a data value is quoted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table ↔ String?
The database table to import CSV file into.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited