ExportClusterRequest class

Export cluster request.

Constructors

ExportClusterRequest({CsvExportOptions? csvExportOptions, String? database, GcsDestination? gcsDestination, SqlExportOptions? sqlExportOptions})
ExportClusterRequest.fromJson(Map json_)

Properties

csvExportOptions ↔ CsvExportOptions?
Options for exporting data in CSV format.
getter/setter pair
database ↔ String?
Name of the database where the export command will be executed.
getter/setter pair
gcsDestination ↔ GcsDestination?
Option to export data to cloud storage.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlExportOptions ↔ SqlExportOptions?
Options for exporting data in SQL format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited