ImportClusterRequest class

Import cluster request.

Constructors

ImportClusterRequest({CsvImportOptions? csvImportOptions, String? database, String? gcsUri, SqlImportOptions? sqlImportOptions, String? user})
ImportClusterRequest.fromJson(Map json_)

Properties

csvImportOptions ↔ CsvImportOptions?
Options for importing data in CSV format.
getter/setter pair
database ↔ String?
Name of the database to which the import will be done.
getter/setter pair
gcsUri ↔ String?
The path to the file in Google Cloud Storage where the source file for import will be stored.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlImportOptions ↔ SqlImportOptions?
Options for importing data in SQL format.
getter/setter pair
user ↔ String?
Database user to be used for importing the data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited