InjectFaultRequest class

Message for triggering fault injection on an instance

Constructors

InjectFaultRequest({String? faultType, String? requestId, bool? validateOnly})
InjectFaultRequest.fromJson(Map json_)

Properties

faultType ↔ String?
The type of fault to be injected in an instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
An optional request ID to identify requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited