Instance class

An Instance is a computing unit that an end customer can connect to.

It's the main unit of computing resources in AlloyDB.

Constructors

Instance({String? activationPolicy, Map<String, String>? annotations, String? availabilityType, ClientConnectionConfig? clientConnectionConfig, ConnectionPoolConfig? connectionPoolConfig, String? createTime, String? dataApiAccess, Map<String, String>? databaseFlags, String? deleteTime, String? displayName, String? etag, String? gceZone, String? instanceType, String? ipAddress, Map<String, String>? labels, MachineConfig? machineConfig, String? maintenanceVersionName, String? name, InstanceNetworkConfig? networkConfig, List<Node>? nodes, ObservabilityInstanceConfig? observabilityConfig, List<String>? outboundPublicIpAddresses, PscInstanceConfig? pscInstanceConfig, String? publicIpAddress, QueryInsightsInstanceConfig? queryInsightsConfig, ReadPoolConfig? readPoolConfig, bool? reconciling, bool? satisfiesPzs, String? state, String? uid, String? updateTime, Node? writableNode})
Instance.fromJson(Map json_)

Properties

activationPolicy ↔ String?
Specifies whether an instance needs to spin up.
getter/setter pair
annotations ↔ Map<String, String>?
Annotations to allow client tools to store small amount of arbitrary data.
getter/setter pair
availabilityType ↔ String?
Availability type of an Instance.
getter/setter pair
clientConnectionConfig ↔ ClientConnectionConfig?
Client connection specific configurations
getter/setter pair
connectionPoolConfig ↔ ConnectionPoolConfig?
The configuration for Managed Connection Pool (MCP).
getter/setter pair
createTime ↔ String?
Create time stamp
getter/setter pair
dataApiAccess ↔ String?
Controls whether the Data API is enabled for this instance.
getter/setter pair
databaseFlags ↔ Map<String, String>?
Database flags.
getter/setter pair
deleteTime ↔ String?
Delete time stamp
getter/setter pair
displayName ↔ String?
User-settable and human-readable display name for the Instance.
getter/setter pair
etag ↔ String?
For Resource freshness validation (https://google.aip.dev/154)
getter/setter pair
gceZone ↔ String?
The Compute Engine zone that the instance should serve from, per https://cloud.google.com/compute/docs/regions-zones This can ONLY be specified for ZONAL instances.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceType ↔ String?
The type of the instance.
getter/setter pair
ipAddress ↔ String?
The IP address for the Instance.
getter/setter pair
labels ↔ Map<String, String>?
Labels as key value pairs
getter/setter pair
machineConfig ↔ MachineConfig?
Configurations for the machines that host the underlying database engine.
getter/setter pair
maintenanceVersionName ↔ String?
Maintenance version of the instance, for example: POSTGRES_15.2025_07_15.04_00.
getter/setter pair
name ↔ String?
The name of the instance resource with the format: * projects/{project}/locations/{region}/clusters/{cluster_id}/instances/{instance_id} where the cluster and instance ID segments should satisfy the regex expression [a-z]([a-z0-9-]{0,61}[a-z0-9])?, e.g. 1-63 characters of lowercase letters, numbers, and dashes, starting with a letter, and ending with a letter or number.
getter/setter pair
networkConfig ↔ InstanceNetworkConfig?
Instance-level network configuration.
getter/setter pair
nodes ↔ List<Node>?
List of available read-only VMs in this instance, including the standby for a PRIMARY instance.
getter/setter pair
observabilityConfig ↔ ObservabilityInstanceConfig?
Configuration for observability.
getter/setter pair
outboundPublicIpAddresses ↔ List<String>?
All outbound public IP addresses configured for the instance.
getter/setter pair
pscInstanceConfig ↔ PscInstanceConfig?
The configuration for Private Service Connect (PSC) for the instance.
getter/setter pair
publicIpAddress ↔ String?
The public IP addresses for the Instance.
getter/setter pair
queryInsightsConfig ↔ QueryInsightsInstanceConfig?
Configuration for query insights.
getter/setter pair
readPoolConfig ↔ ReadPoolConfig?
Read pool instance configuration.
getter/setter pair
reconciling ↔ bool?
Reconciling (https://google.aip.dev/128#reconciliation).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
state ↔ String?
The current serving state of the instance.
getter/setter pair
uid ↔ String?
The system-generated UID of the resource.
getter/setter pair
updateTime ↔ String?
Update time stamp
getter/setter pair
writableNode ↔ Node?
This is set for the read-write VM of the PRIMARY instance only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited