MaintenanceUpdatePolicy class

MaintenanceUpdatePolicy defines the policy for system updates.

Constructors

MaintenanceUpdatePolicy({List<DenyMaintenancePeriod>? denyMaintenancePeriods, List<MaintenanceWindow>? maintenanceWindows})
MaintenanceUpdatePolicy.fromJson(Map json_)

Properties

denyMaintenancePeriods ↔ List<DenyMaintenancePeriod>?
Periods to deny maintenance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maintenanceWindows ↔ List<MaintenanceWindow>?
Preferred windows to perform maintenance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited