MaintenanceWindow class

MaintenanceWindow specifies a preferred day and time for maintenance.

Properties

day ↔ String?
Preferred day of the week for maintenance, e.g. MONDAY, TUESDAY, etc. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ GoogleTypeTimeOfDay?
Preferred time to start the maintenance operation on the specified day.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited