NetworkConfig class

Metadata related to network configuration.

Constructors

NetworkConfig({String? allocatedIpRange, String? network})
NetworkConfig.fromJson(Map json_)

Properties

allocatedIpRange ↔ String?
Name of the allocated IP range for the private IP AlloyDB cluster, for example: "google-managed-services-default".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
network ↔ String?
The resource link for the VPC network in which cluster resources are created and from which they are accessible via Private IP.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited