Node class

Details of a single node in the instance.

Nodes in an AlloyDB instance are ephemeral, they can change during update, failover, autohealing and resize operations.

Constructors

Node({String? id, String? ip, bool? isHotStandby, String? state, String? zoneId})
Node.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The identifier of the VM e.g. "test-read-0601-407e52be-ms3l".
getter/setter pair
ip ↔ String?
The private IP address of the VM e.g. "10.57.0.34".
getter/setter pair
isHotStandby ↔ bool?
Indicates whether the node set up to be configured as a hot standby.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Determined by state of the compute VM and postgres-service health.
getter/setter pair
zoneId ↔ String?
The Compute Engine zone of the VM e.g. "us-central1-b".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited