isHotStandby property
Indicates whether the node set up to be configured as a hot standby.
Output only.
Implementation
core.bool? isHotStandby;
Indicates whether the node set up to be configured as a hot standby.
Output only.
core.bool? isHotStandby;