ObservabilityInstanceConfig class

Observability Instance specific configuration.

Constructors

ObservabilityInstanceConfig({bool? enabled, int? maxQueryStringLength, bool? preserveComments, int? queryPlansPerMinute, bool? recordApplicationTags, bool? trackActiveQueries, bool? trackWaitEventTypes, bool? trackWaitEvents})
ObservabilityInstanceConfig.fromJson(Map json_)

Properties

enabled ↔ bool?
Observability feature status for an instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxQueryStringLength ↔ int?
Query string length.
getter/setter pair
preserveComments ↔ bool?
Preserve comments in query string for an instance.
getter/setter pair
queryPlansPerMinute ↔ int?
Number of query execution plans captured by Insights per minute for all queries combined.
getter/setter pair
recordApplicationTags ↔ bool?
Record application tags for an instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackActiveQueries ↔ bool?
Track actively running queries on the instance.
getter/setter pair
trackWaitEvents ↔ bool?
Track wait events during query execution for an instance.
getter/setter pair
trackWaitEventTypes ↔ bool?
Track wait event types during query execution for an instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited