PscInstanceConfig class

PscInstanceConfig contains PSC related configuration at an instance level.

Constructors

PscInstanceConfig({List<String>? allowedConsumerProjects, List<PscAutoConnectionConfig>? pscAutoConnections, String? pscDnsName, List<PscInterfaceConfig>? pscInterfaceConfigs, String? serviceAttachmentLink})
PscInstanceConfig.fromJson(Map json_)

Properties

allowedConsumerProjects ↔ List<String>?
List of consumer projects that are allowed to create PSC endpoints to service-attachments to this instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pscAutoConnections ↔ List<PscAutoConnectionConfig>?
Configurations for setting up PSC service automation.
getter/setter pair
pscDnsName ↔ String?
The DNS name of the instance for PSC connectivity.
getter/setter pair
pscInterfaceConfigs ↔ List<PscInterfaceConfig>?
Configurations for setting up PSC interfaces attached to the instance which are used for outbound connectivity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The service attachment created when Private Service Connect (PSC) is enabled for the instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited