RestoreClusterRequest class

Message for restoring a Cluster from a backup or another cluster at a given point in time.

NEXT_ID: 11

Constructors

RestoreClusterRequest({BackupSource? backupSource, BackupDrBackupSource? backupdrBackupSource, BackupDrPitrSource? backupdrPitrSource, Cluster? cluster, String? clusterId, ContinuousBackupSource? continuousBackupSource, String? requestId, bool? validateOnly})
RestoreClusterRequest.fromJson(Map json_)

Properties

backupdrBackupSource ↔ BackupDrBackupSource?
BackupDR backup source.
getter/setter pair
backupdrPitrSource ↔ BackupDrPitrSource?
BackupDR source used for point in time recovery.
getter/setter pair
backupSource ↔ BackupSource?
Backup source.
getter/setter pair
cluster ↔ Cluster?
The resource being created
getter/setter pair
clusterId ↔ String?
ID of the requesting object.
getter/setter pair
continuousBackupSource ↔ ContinuousBackupSource?
ContinuousBackup source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
An optional request ID to identify requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
If set, performs request validation, for example, permission checks and any other type of validation, but does not actually execute the create request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited