RestoreFromCloudSQLRequest class

Message for registering Restoring from CloudSQL resource.

Constructors

RestoreFromCloudSQLRequest({CloudSQLBackupRunSource? cloudsqlBackupRunSource, Cluster? cluster, String? clusterId})
RestoreFromCloudSQLRequest.fromJson(Map json_)

Properties

cloudsqlBackupRunSource ↔ CloudSQLBackupRunSource?
Cluster created from CloudSQL backup run.
getter/setter pair
cluster ↔ Cluster?
The resource being created
getter/setter pair
clusterId ↔ String?
ID of the requesting object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited