SecondaryConfig class

Configuration information for the secondary cluster.

This should be set if and only if the cluster is of type SECONDARY.

Constructors

SecondaryConfig({String? primaryClusterName})
SecondaryConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
primaryClusterName ↔ String?
The name of the primary cluster name with the format: * projects/{project}/locations/{region}/clusters/{cluster_id}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited