SupportedDatabaseFlag class

SupportedDatabaseFlag gives general information about a database flag, like type and allowed values.

This is a static value that is defined on the server side, and it cannot be modified by callers. To set the Database flags on a particular Instance, a caller should modify the Instance.database_flags field.

Constructors

SupportedDatabaseFlag({bool? acceptsMultipleValues, String? flagName, IntegerRestrictions? integerRestrictions, String? name, String? recommendedIntegerValue, String? recommendedStringValue, bool? requiresDbRestart, String? scope, StringRestrictions? stringRestrictions, List<String>? supportedDbVersions, String? valueType})
SupportedDatabaseFlag.fromJson(Map json_)

Properties

acceptsMultipleValues ↔ bool?
Whether the database flag accepts multiple values.
getter/setter pair
flagName ↔ String?
The name of the database flag, e.g. "max_allowed_packets".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integerRestrictions ↔ IntegerRestrictions?
Restriction on INTEGER type value.
getter/setter pair
name ↔ String?
The name of the flag resource, following Google Cloud conventions, e.g.: * projects/{project}/locations/{location}/flags/{flag} This field currently has no semantic meaning.
getter/setter pair
recommendedIntegerValue ↔ String?
The recommended value for an INTEGER flag.
getter/setter pair
recommendedStringValue ↔ String?
The recommended value for a STRING flag.
getter/setter pair
requiresDbRestart ↔ bool?
Whether setting or updating this flag on an Instance requires a database restart.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
The scope of the flag. Possible string values are:
getter/setter pair
stringRestrictions ↔ StringRestrictions?
Restriction on STRING type value.
getter/setter pair
supportedDbVersions ↔ List<String>?
Major database engine versions for which this flag is supported.
getter/setter pair
valueType ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited