AccountTicket class

JSON template for an Analytics account ticket.

The account ticket consists of the ticket ID and the basic information for the account, property and profile.

Constructors

AccountTicket({Account? account, String? id, String? kind, Profile? profile, String? redirectUri, Webproperty? webproperty})
AccountTicket.fromJson(Map json_)

Properties

account ↔ Account?
Account for this ticket.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Account ticket ID used to access the account ticket.
getter/setter pair
kind ↔ String?
Resource type for account ticket.
getter/setter pair
profile ↔ Profile?
View (Profile) for the account.
getter/setter pair
redirectUri ↔ String?
Redirect URI where the user will be sent after accepting Terms of Service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webproperty ↔ Webproperty?
Web property for the account.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited