Columns class

Lists columns (dimensions and metrics) for a particular report type.

Constructors

Columns({List<String>? attributeNames, String? etag, List<Column>? items, String? kind, int? totalResults})
Columns.fromJson(Map json_)

Properties

attributeNames ↔ List<String>?
List of attributes names returned by columns.
getter/setter pair
etag ↔ String?
Etag of collection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Column>?
List of columns for a report type.
getter/setter pair
kind ↔ String?
Collection type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalResults ↔ int?
Total number of columns returned in the response.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited