CustomDimension class

JSON template for Analytics Custom Dimension.

Constructors

CustomDimension({String? accountId, bool? active, DateTime? created, String? id, int? index, String? kind, String? name, CustomDimensionParentLink? parentLink, String? scope, String? selfLink, DateTime? updated, String? webPropertyId})
CustomDimension.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID.
getter/setter pair
active ↔ bool?
Boolean indicating whether the custom dimension is active.
getter/setter pair
created ↔ DateTime?
Time the custom dimension was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Custom dimension ID.
getter/setter pair
index ↔ int?
Index of the custom dimension.
getter/setter pair
kind ↔ String?
Kind value for a custom dimension.
getter/setter pair
name ↔ String?
Name of the custom dimension.
getter/setter pair
Parent link for the custom dimension.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
Scope of the custom dimension: HIT, SESSION, USER or PRODUCT.
getter/setter pair
Link for the custom dimension
getter/setter pair
updated ↔ DateTime?
Time the custom dimension was last modified.
getter/setter pair
webPropertyId ↔ String?
Property ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited