CustomDimensions class

A custom dimension collection lists Analytics custom dimensions to which the user has access.

Each resource in the collection corresponds to a single Analytics custom dimension.

Constructors

CustomDimensions({List<CustomDimension>? items, int? itemsPerPage, String? kind, String? nextLink, String? previousLink, int? startIndex, int? totalResults, String? username})
CustomDimensions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<CustomDimension>?
Collection of custom dimensions.
getter/setter pair
itemsPerPage ↔ int?
The maximum number of resources the response can contain, regardless of the actual number of resources returned.
getter/setter pair
kind ↔ String?
Collection type.
getter/setter pair
Link to next page for this custom dimension collection.
getter/setter pair
Link to previous page for this custom dimension collection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex ↔ int?
The starting index of the resources, which is 1 by default or otherwise specified by the start-index query parameter.
getter/setter pair
totalResults ↔ int?
The total number of results for the query, regardless of the number of results in the response.
getter/setter pair
username ↔ String?
Email ID of the authenticated user
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited