CustomMetric class

JSON template for Analytics Custom Metric.

Constructors

CustomMetric({String? accountId, bool? active, DateTime? created, String? id, int? index, String? kind, String? maxValue, String? minValue, String? name, CustomMetricParentLink? parentLink, String? scope, String? selfLink, String? type, DateTime? updated, String? webPropertyId})
CustomMetric.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID.
getter/setter pair
active ↔ bool?
Boolean indicating whether the custom metric is active.
getter/setter pair
created ↔ DateTime?
Time the custom metric was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Custom metric ID.
getter/setter pair
index ↔ int?
Index of the custom metric.
getter/setter pair
kind ↔ String?
Kind value for a custom metric.
getter/setter pair
maxValue ↔ String?
Max value of custom metric.
getter/setter pair
minValue ↔ String?
Min value of custom metric.
getter/setter pair
name ↔ String?
Name of the custom metric.
getter/setter pair
Parent link for the custom metric.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
Scope of the custom metric: HIT or PRODUCT.
getter/setter pair
Link for the custom metric
getter/setter pair
type ↔ String?
Data type of custom metric.
getter/setter pair
updated ↔ DateTime?
Time the custom metric was last modified.
getter/setter pair
webPropertyId ↔ String?
Property ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited