EntityUserLinkEntity class

Entity for this link.

It can be an account, a web property, or a view (profile).

Constructors

EntityUserLinkEntity({AccountRef? accountRef, ProfileRef? profileRef, WebPropertyRef? webPropertyRef})
EntityUserLinkEntity.fromJson(Map json_)

Properties

accountRef ↔ AccountRef?
Account for this link.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
profileRef ↔ ProfileRef?
View (Profile) for this link.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webPropertyRef ↔ WebPropertyRef?
Web property for this link.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited