EntityUserLinkPermissions class

Permissions the user has for this entity.

Properties

effective ↔ List<String>?
Effective permissions represent all the permissions that a user has for this entity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
local ↔ List<String>?
Permissions that a user has been assigned at this very level.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited