Experiment class

JSON template for Analytics experiment resource.

Constructors

Experiment({String? accountId, DateTime? created, String? description, bool? editableInGaUi, DateTime? endTime, bool? equalWeighting, String? id, String? internalWebPropertyId, String? kind, int? minimumExperimentLengthInDays, String? name, String? objectiveMetric, String? optimizationType, ExperimentParentLink? parentLink, String? profileId, String? reasonExperimentEnded, bool? rewriteVariationUrlsAsOriginal, String? selfLink, String? servingFramework, String? snippet, DateTime? startTime, String? status, double? trafficCoverage, DateTime? updated, List<ExperimentVariations>? variations, String? webPropertyId, double? winnerConfidenceLevel, bool? winnerFound})
Experiment.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID to which this experiment belongs.
getter/setter pair
created ↔ DateTime?
Time the experiment was created.
getter/setter pair
description ↔ String?
Notes about this experiment.
getter/setter pair
editableInGaUi ↔ bool?
If true, the end user will be able to edit the experiment via the Google Analytics user interface.
getter/setter pair
endTime ↔ DateTime?
The ending time of the experiment (the time the status changed from RUNNING to ENDED).
getter/setter pair
equalWeighting ↔ bool?
Boolean specifying whether to distribute traffic evenly across all variations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Experiment ID.
getter/setter pair
internalWebPropertyId ↔ String?
Internal ID for the web property to which this experiment belongs.
getter/setter pair
kind ↔ String?
Resource type for an Analytics experiment.
getter/setter pair
minimumExperimentLengthInDays ↔ int?
An integer number in [3, 90].
getter/setter pair
name ↔ String?
Experiment name.
getter/setter pair
objectiveMetric ↔ String?
The metric that the experiment is optimizing.
getter/setter pair
optimizationType ↔ String?
Whether the objectiveMetric should be minimized or maximized.
getter/setter pair
Parent link for an experiment.
getter/setter pair
profileId ↔ String?
View (Profile) ID to which this experiment belongs.
getter/setter pair
reasonExperimentEnded ↔ String?
Why the experiment ended.
getter/setter pair
rewriteVariationUrlsAsOriginal ↔ bool?
Boolean specifying whether variations URLS are rewritten to match those of the original.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Link for this experiment.
getter/setter pair
servingFramework ↔ String?
The framework used to serve the experiment variations and evaluate the results.
getter/setter pair
snippet ↔ String?
The snippet of code to include on the control page(s).
getter/setter pair
startTime ↔ DateTime?
The starting time of the experiment (the time the status changed from READY_TO_RUN to RUNNING).
getter/setter pair
status ↔ String?
Experiment status.
getter/setter pair
trafficCoverage ↔ double?
A floating-point number in (0, 1].
getter/setter pair
updated ↔ DateTime?
Time the experiment was last modified.
getter/setter pair
variations ↔ List<ExperimentVariations>?
Array of variations.
getter/setter pair
webPropertyId ↔ String?
Web property ID to which this experiment belongs.
getter/setter pair
winnerConfidenceLevel ↔ double?
A floating-point number in (0, 1).
getter/setter pair
winnerFound ↔ bool?
Boolean specifying whether a winner has been found for this experiment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited