FilterAdvancedDetails class

Details for the filter of the type ADVANCED.

Constructors

FilterAdvancedDetails({bool? caseSensitive, String? extractA, String? extractB, String? fieldA, int? fieldAIndex, bool? fieldARequired, String? fieldB, int? fieldBIndex, bool? fieldBRequired, String? outputConstructor, String? outputToField, int? outputToFieldIndex, bool? overrideOutputField})
FilterAdvancedDetails.fromJson(Map json_)

Properties

caseSensitive ↔ bool?
Indicates if the filter expressions are case sensitive.
getter/setter pair
extractA ↔ String?
Expression to extract from field A.
getter/setter pair
extractB ↔ String?
Expression to extract from field B.
getter/setter pair
fieldA ↔ String?
Field A.
getter/setter pair
fieldAIndex ↔ int?
The Index of the custom dimension.
getter/setter pair
fieldARequired ↔ bool?
Indicates if field A is required to match.
getter/setter pair
fieldB ↔ String?
Field B.
getter/setter pair
fieldBIndex ↔ int?
The Index of the custom dimension.
getter/setter pair
fieldBRequired ↔ bool?
Indicates if field B is required to match.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
outputConstructor ↔ String?
Expression used to construct the output value.
getter/setter pair
outputToField ↔ String?
Output field.
getter/setter pair
outputToFieldIndex ↔ int?
The Index of the custom dimension.
getter/setter pair
overrideOutputField ↔ bool?
Indicates if the existing value of the output field, if any, should be overridden by the output expression.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited