FilterExpression class

JSON template for an Analytics filter expression.

Constructors

FilterExpression({bool? caseSensitive, String? expressionValue, String? field, int? fieldIndex, String? kind, String? matchType})
FilterExpression.fromJson(Map json_)

Properties

caseSensitive ↔ bool?
Determines if the filter is case sensitive.
getter/setter pair
expressionValue ↔ String?
Filter expression value
getter/setter pair
field ↔ String?
Field to filter.
getter/setter pair
fieldIndex ↔ int?
The Index of the custom dimension.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Kind value for filter expression
getter/setter pair
matchType ↔ String?
Match type for this filter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited