FilterLowercaseDetails class

Details for the filter of the type LOWER.

Constructors

FilterLowercaseDetails({String? field, int? fieldIndex})
FilterLowercaseDetails.fromJson(Map json_)

Properties

field ↔ String?
Field to use in the filter.
getter/setter pair
fieldIndex ↔ int?
The Index of the custom dimension.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited