FilterParentLink class

Parent link for this filter.

Points to the account to which this filter belongs.

Constructors

FilterParentLink({String? href, String? type})
FilterParentLink.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
href ↔ String?
Link to the account to which this filter belongs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Value is "analytics#account".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited