GaDataProfileInfo class

Information for the view (profile), for which the Analytics data was requested.

Constructors

GaDataProfileInfo({String? accountId, String? internalWebPropertyId, String? profileId, String? profileName, String? tableId, String? webPropertyId})
GaDataProfileInfo.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID to which this view (profile) belongs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalWebPropertyId ↔ String?
Internal ID for the web property to which this view (profile) belongs.
getter/setter pair
profileId ↔ String?
View (Profile) ID.
getter/setter pair
profileName ↔ String?
View (Profile) name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId ↔ String?
Table ID for view (profile).
getter/setter pair
webPropertyId ↔ String?
Web Property ID to which this view (profile) belongs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited