Goal class

JSON template for Analytics goal resource.

Constructors

Goal({String? accountId, bool? active, DateTime? created, GoalEventDetails? eventDetails, String? id, String? internalWebPropertyId, String? kind, String? name, GoalParentLink? parentLink, String? profileId, String? selfLink, String? type, DateTime? updated, GoalUrlDestinationDetails? urlDestinationDetails, double? value, GoalVisitNumPagesDetails? visitNumPagesDetails, GoalVisitTimeOnSiteDetails? visitTimeOnSiteDetails, String? webPropertyId})
Goal.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID to which this goal belongs.
getter/setter pair
active ↔ bool?
Determines whether this goal is active.
getter/setter pair
created ↔ DateTime?
Time this goal was created.
getter/setter pair
eventDetails ↔ GoalEventDetails?
Details for the goal of the type EVENT.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Goal ID.
getter/setter pair
internalWebPropertyId ↔ String?
Internal ID for the web property to which this goal belongs.
getter/setter pair
kind ↔ String?
Resource type for an Analytics goal.
getter/setter pair
name ↔ String?
Goal name.
getter/setter pair
Parent link for a goal.
getter/setter pair
profileId ↔ String?
View (Profile) ID to which this goal belongs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Link for this goal.
getter/setter pair
type ↔ String?
Goal type.
getter/setter pair
updated ↔ DateTime?
Time this goal was last modified.
getter/setter pair
urlDestinationDetails ↔ GoalUrlDestinationDetails?
Details for the goal of the type URL_DESTINATION.
getter/setter pair
value ↔ double?
Goal value.
getter/setter pair
visitNumPagesDetails ↔ GoalVisitNumPagesDetails?
Details for the goal of the type VISIT_NUM_PAGES.
getter/setter pair
visitTimeOnSiteDetails ↔ GoalVisitTimeOnSiteDetails?
Details for the goal of the type VISIT_TIME_ON_SITE.
getter/setter pair
webPropertyId ↔ String?
Web property ID to which this goal belongs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited