GoalEventDetails class

Details for the goal of the type EVENT.

Constructors

GoalEventDetails({List<GoalEventDetailsEventConditions>? eventConditions, bool? useEventValue})
GoalEventDetails.fromJson(Map json_)

Properties

eventConditions ↔ List<GoalEventDetailsEventConditions>?
List of event conditions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useEventValue ↔ bool?
Determines if the event value should be used as the value for this goal.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited