GoalEventDetailsEventConditions class

Constructors

GoalEventDetailsEventConditions({String? comparisonType, String? comparisonValue, String? expression, String? matchType, String? type})
GoalEventDetailsEventConditions.fromJson(Map json_)

Properties

comparisonType ↔ String?
Type of comparison.
getter/setter pair
comparisonValue ↔ String?
Value used for this comparison.
getter/setter pair
expression ↔ String?
Expression used for this match.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchType ↔ String?
Type of the match to be performed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of this event condition.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited