GoalUrlDestinationDetails class

Details for the goal of the type URL_DESTINATION.

Constructors

GoalUrlDestinationDetails({bool? caseSensitive, bool? firstStepRequired, String? matchType, List<GoalUrlDestinationDetailsSteps>? steps, String? url})
GoalUrlDestinationDetails.fromJson(Map json_)

Properties

caseSensitive ↔ bool?
Determines if the goal URL must exactly match the capitalization of visited URLs.
getter/setter pair
firstStepRequired ↔ bool?
Determines if the first step in this goal is required.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchType ↔ String?
Match type for the goal URL.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
steps ↔ List<GoalUrlDestinationDetailsSteps>?
List of steps configured for this goal funnel.
getter/setter pair
url ↔ String?
URL for this goal.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited