GoalVisitNumPagesDetails class

Details for the goal of the type VISIT_NUM_PAGES.

Constructors

GoalVisitNumPagesDetails({String? comparisonType, String? comparisonValue})
GoalVisitNumPagesDetails.fromJson(Map json_)

Properties

comparisonType ↔ String?
Type of comparison.
getter/setter pair
comparisonValue ↔ String?
Value used for this comparison.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited