LinkedForeignAccount class

JSON template for an Analytics Remarketing Audience Foreign Link.

Constructors

LinkedForeignAccount({String? accountId, bool? eligibleForSearch, String? id, String? internalWebPropertyId, String? kind, String? linkedAccountId, String? remarketingAudienceId, String? status, String? type, String? webPropertyId})
LinkedForeignAccount.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID to which this linked foreign account belongs.
getter/setter pair
eligibleForSearch ↔ bool?
Boolean indicating whether this is eligible for search.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Entity ad account link ID.
getter/setter pair
internalWebPropertyId ↔ String?
Internal ID for the web property to which this linked foreign account belongs.
getter/setter pair
kind ↔ String?
Resource type for linked foreign account.
getter/setter pair
linkedAccountId ↔ String?
The foreign account ID.
getter/setter pair
remarketingAudienceId ↔ String?
Remarketing audience ID to which this linked foreign account belongs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status of this foreign account link.
getter/setter pair
type ↔ String?
The type of the foreign account.
getter/setter pair
webPropertyId ↔ String?
Web property ID of the form UA-XXXXX-YY to which this linked foreign account belongs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited