ManagementCustomMetricsResource class

Constructors

ManagementCustomMetricsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String accountId, String webPropertyId, String customMetricId, {String? $fields}) → Future<CustomMetric>
Get a custom metric to which the user has access.
insert(CustomMetric request, String accountId, String webPropertyId, {String? $fields}) → Future<CustomMetric>
Create a new custom metric.
list(String accountId, String webPropertyId, {int? maxResults, int? startIndex, String? $fields}) → Future<CustomMetrics>
Lists custom metrics to which the user has access.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(CustomMetric request, String accountId, String webPropertyId, String customMetricId, {bool? ignoreCustomDataSourceLinks, String? $fields}) → Future<CustomMetric>
Updates an existing custom metric.
toString() → String
A string representation of this object.
inherited
update(CustomMetric request, String accountId, String webPropertyId, String customMetricId, {bool? ignoreCustomDataSourceLinks, String? $fields}) → Future<CustomMetric>
Updates an existing custom metric.

Operators

operator ==(Object other) → bool
The equality operator.
inherited