Profile class

JSON template for an Analytics view (profile).

Constructors

Profile({String? accountId, bool? botFilteringEnabled, ProfileChildLink? childLink, DateTime? created, String? currency, String? defaultPage, bool? eCommerceTracking, bool? enhancedECommerceTracking, String? excludeQueryParameters, String? id, String? internalWebPropertyId, String? kind, String? name, ProfileParentLink? parentLink, ProfilePermissions? permissions, String? selfLink, String? siteSearchCategoryParameters, String? siteSearchQueryParameters, bool? starred, bool? stripSiteSearchCategoryParameters, bool? stripSiteSearchQueryParameters, String? timezone, String? type, DateTime? updated, String? webPropertyId, String? websiteUrl})
Profile.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID to which this view (profile) belongs.
getter/setter pair
botFilteringEnabled ↔ bool?
Indicates whether bot filtering is enabled for this view (profile).
getter/setter pair
Child link for this view (profile).
getter/setter pair
created ↔ DateTime?
Time this view (profile) was created.
getter/setter pair
currency ↔ String?
The currency type associated with this view (profile), defaults to USD.
getter/setter pair
defaultPage ↔ String?
Default page for this view (profile).
getter/setter pair
eCommerceTracking ↔ bool?
Indicates whether ecommerce tracking is enabled for this view (profile).
getter/setter pair
enhancedECommerceTracking ↔ bool?
Indicates whether enhanced ecommerce tracking is enabled for this view (profile).
getter/setter pair
excludeQueryParameters ↔ String?
The query parameters that are excluded from this view (profile).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
View (Profile) ID.
getter/setter pair
internalWebPropertyId ↔ String?
Internal ID for the web property to which this view (profile) belongs.
getter/setter pair
kind ↔ String?
Resource type for Analytics view (profile).
getter/setter pair
name ↔ String?
Name of this view (profile).
getter/setter pair
Parent link for this view (profile).
getter/setter pair
permissions ↔ ProfilePermissions?
Permissions the user has for this view (profile).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Link for this view (profile).
getter/setter pair
siteSearchCategoryParameters ↔ String?
Site search category parameters for this view (profile).
getter/setter pair
siteSearchQueryParameters ↔ String?
The site search query parameters for this view (profile).
getter/setter pair
starred ↔ bool?
Indicates whether this view (profile) is starred or not.
getter/setter pair
stripSiteSearchCategoryParameters ↔ bool?
Whether or not Analytics will strip search category parameters from the URLs in your reports.
getter/setter pair
stripSiteSearchQueryParameters ↔ bool?
Whether or not Analytics will strip search query parameters from the URLs in your reports.
getter/setter pair
timezone ↔ String?
Time zone for which this view (profile) has been configured.
getter/setter pair
type ↔ String?
View (Profile) type.
getter/setter pair
updated ↔ DateTime?
Time this view (profile) was last modified.
getter/setter pair
webPropertyId ↔ String?
Web property ID of the form UA-XXXXX-YY to which this view (profile) belongs.
getter/setter pair
websiteUrl ↔ String?
Website URL for this view (profile).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited