ProfileChildLink class

Child link for this view (profile).

Points to the list of goals for this view (profile).

Constructors

ProfileChildLink({String? href, String? type})
ProfileChildLink.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
href ↔ String?
Link to the list of goals for this view (profile).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Value is "analytics#goals".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited