ProfileRef class

JSON template for a linked view (profile).

Constructors

ProfileRef({String? accountId, String? href, String? id, String? internalWebPropertyId, String? kind, String? name, String? webPropertyId})
ProfileRef.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID to which this view (profile) belongs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
href ↔ String?
Link for this view (profile).
getter/setter pair
id ↔ String?
View (Profile) ID.
getter/setter pair
internalWebPropertyId ↔ String?
Internal ID for the web property to which this view (profile) belongs.
getter/setter pair
kind ↔ String?
Analytics view (profile) reference.
getter/setter pair
name ↔ String?
Name of this view (profile).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webPropertyId ↔ String?
Web property ID of the form UA-XXXXX-YY to which this view (profile) belongs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited