RealtimeDataColumnHeaders class

Constructors

RealtimeDataColumnHeaders({String? columnType, String? dataType, String? name})
RealtimeDataColumnHeaders.fromJson(Map json_)

Properties

columnType ↔ String?
Column Type.
getter/setter pair
dataType ↔ String?
Data type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Column name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited