RealtimeDataQuery class

Real time data request query parameters.

Constructors

RealtimeDataQuery({String? dimensions, String? filters, String? ids, int? maxResults, List<String>? metrics, List<String>? sort})
RealtimeDataQuery.fromJson(Map json_)

Properties

dimensions ↔ String?
List of real time dimensions.
getter/setter pair
filters ↔ String?
Comma-separated list of dimension or metric filters.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ids ↔ String?
Unique table ID.
getter/setter pair
maxResults ↔ int?
Maximum results per page.
getter/setter pair
metrics ↔ List<String>?
List of real time metrics.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sort ↔ List<String>?
List of dimensions or metrics based on which real time data is sorted.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited