Segment class

JSON template for an Analytics segment.

Constructors

Segment({DateTime? created, String? definition, String? id, String? kind, String? name, String? segmentId, String? selfLink, String? type, DateTime? updated})
Segment.fromJson(Map json_)

Properties

created ↔ DateTime?
Time the segment was created.
getter/setter pair
definition ↔ String?
Segment definition.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Segment ID.
getter/setter pair
kind ↔ String?
Resource type for Analytics segment.
getter/setter pair
name ↔ String?
Segment name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentId ↔ String?
Segment ID.
getter/setter pair
Link for this segment.
getter/setter pair
type ↔ String?
Type for a segment.
getter/setter pair
updated ↔ DateTime?
Time the segment was last modified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited