UnsampledReport class

JSON template for Analytics unsampled report resource.

Constructors

UnsampledReport({String? accountId, UnsampledReportCloudStorageDownloadDetails? cloudStorageDownloadDetails, DateTime? created, String? dimensions, String? downloadType, UnsampledReportDriveDownloadDetails? driveDownloadDetails, String? endDate, String? filters, String? id, String? kind, String? metrics, String? profileId, String? segment, String? selfLink, String? startDate, String? status, String? title, DateTime? updated, String? webPropertyId})
UnsampledReport.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID to which this unsampled report belongs.
getter/setter pair
cloudStorageDownloadDetails ↔ UnsampledReportCloudStorageDownloadDetails?
Download details for a file stored in Google Cloud Storage.
getter/setter pair
created ↔ DateTime?
Time this unsampled report was created.
getter/setter pair
dimensions ↔ String?
The dimensions for the unsampled report.
getter/setter pair
downloadType ↔ String?
The type of download you need to use for the report data file.
getter/setter pair
driveDownloadDetails ↔ UnsampledReportDriveDownloadDetails?
Download details for a file stored in Google Drive.
getter/setter pair
endDate ↔ String?
The end date for the unsampled report.
getter/setter pair
filters ↔ String?
The filters for the unsampled report.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unsampled report ID.
getter/setter pair
kind ↔ String?
Resource type for an Analytics unsampled report.
getter/setter pair
metrics ↔ String?
The metrics for the unsampled report.
getter/setter pair
profileId ↔ String?
View (Profile) ID to which this unsampled report belongs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segment ↔ String?
The segment for the unsampled report.
getter/setter pair
Link for this unsampled report.
getter/setter pair
startDate ↔ String?
The start date for the unsampled report.
getter/setter pair
status ↔ String?
Status of this unsampled report.
getter/setter pair
title ↔ String?
Title of the unsampled report.
getter/setter pair
updated ↔ DateTime?
Time this unsampled report was last modified.
getter/setter pair
webPropertyId ↔ String?
Web property ID to which this unsampled report belongs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited