Upload class

Metadata returned for an upload operation.

Constructors

Upload({String? accountId, String? customDataSourceId, List<String>? errors, String? id, String? kind, String? status, DateTime? uploadTime})
Upload.fromJson(Map json_)

Properties

accountId ↔ String?
Account Id to which this upload belongs.
getter/setter pair
customDataSourceId ↔ String?
Custom data source Id to which this data import belongs.
getter/setter pair
errors ↔ List<String>?
Data import errors collection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
A unique ID for this upload.
getter/setter pair
kind ↔ String?
Resource type for Analytics upload.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Upload status.
getter/setter pair
uploadTime ↔ DateTime?
Time this file is uploaded.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited