WebPropertySummary class

JSON template for an Analytics WebPropertySummary.

WebPropertySummary returns basic information (i.e., summary) for a web property.

Constructors

WebPropertySummary({String? id, String? internalWebPropertyId, String? kind, String? level, String? name, List<ProfileSummary>? profiles, bool? starred, String? websiteUrl})
WebPropertySummary.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Web property ID of the form UA-XXXXX-YY.
getter/setter pair
internalWebPropertyId ↔ String?
Internal ID for this web property.
getter/setter pair
kind ↔ String?
Resource type for Analytics WebPropertySummary.
getter/setter pair
level ↔ String?
Level for this web property.
getter/setter pair
name ↔ String?
Web property name.
getter/setter pair
profiles ↔ List<ProfileSummary>?
List of profiles under this web property.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starred ↔ bool?
Indicates whether this web property is starred or not.
getter/setter pair
websiteUrl ↔ String?
Website url for this web property.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited