Webproperty class

JSON template for an Analytics web property.

Constructors

Webproperty({String? accountId, WebpropertyChildLink? childLink, DateTime? created, bool? dataRetentionResetOnNewActivity, String? dataRetentionTtl, String? defaultProfileId, String? id, String? industryVertical, String? internalWebPropertyId, String? kind, String? level, String? name, WebpropertyParentLink? parentLink, WebpropertyPermissions? permissions, int? profileCount, String? selfLink, bool? starred, DateTime? updated, String? websiteUrl})
Webproperty.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID to which this web property belongs.
getter/setter pair
Child link for this web property.
getter/setter pair
created ↔ DateTime?
Time this web property was created.
getter/setter pair
dataRetentionResetOnNewActivity ↔ bool?
Set to true to reset the retention period of the user identifier with each new event from that user (thus setting the expiration date to current time plus retention period). Set to false to delete data associated with the user identifier automatically after the rentention period. This property cannot be set on insert.
getter/setter pair
dataRetentionTtl ↔ String?
The length of time for which user and event data is retained. This property cannot be set on insert.
getter/setter pair
defaultProfileId ↔ String?
Default view (profile) ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Web property ID of the form UA-XXXXX-YY.
getter/setter pair
industryVertical ↔ String?
The industry vertical/category selected for this web property.
getter/setter pair
internalWebPropertyId ↔ String?
Internal ID for this web property.
getter/setter pair
kind ↔ String?
Resource type for Analytics WebProperty.
getter/setter pair
level ↔ String?
Level for this web property.
getter/setter pair
name ↔ String?
Name of this web property.
getter/setter pair
Parent link for this web property.
getter/setter pair
permissions ↔ WebpropertyPermissions?
Permissions the user has for this web property.
getter/setter pair
profileCount ↔ int?
View (Profile) count for this web property.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Link for this web property.
getter/setter pair
starred ↔ bool?
Indicates whether this web property is starred or not.
getter/setter pair
updated ↔ DateTime?
Time this web property was last modified.
getter/setter pair
websiteUrl ↔ String?
Website url for this web property.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited