BigQueryDatasetSource class

A reference to a shared dataset.

It is an existing BigQuery dataset with a collection of objects such as tables and views that you want to share with subscribers. When subscriber's subscribe to a listing, Analytics Hub creates a linked dataset in the subscriber's project. A Linked dataset is an opaque, read-only BigQuery dataset that serves as a symbolic link to a shared dataset.

Constructors

BigQueryDatasetSource({String? dataset, List<Replica>? effectiveReplicas, List<String>? replicaLocations, RestrictedExportPolicy? restrictedExportPolicy, List<SelectedResource>? selectedResources})
BigQueryDatasetSource.fromJson(Map json_)

Properties

dataset ↔ String?
Resource name of the dataset source for this listing.
getter/setter pair
effectiveReplicas ↔ List<Replica>?
Server-owned effective state of replicas.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
replicaLocations ↔ List<String>?
A list of regions where the publisher has created shared dataset replicas.
getter/setter pair
restrictedExportPolicy ↔ RestrictedExportPolicy?
If set, restricted export policy will be propagated and enforced on the linked dataset.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedResources ↔ List<SelectedResource>?
Resource in this dataset that is selectively shared.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited