serviceAccountEmail property

String? serviceAccountEmail
getter/setter pair

The service account to use to write to Bigtable.

The subscription creator or updater that specifies this field must have iam.serviceAccounts.actAs permission on the service account. If not specified, the Pub/Sub [service agent]({$universe.dns_names.final_documentation_domain}/iam/docs/service-agents), service-{project_number}@gcp-sa-pubsub.iam.gserviceaccount.com, is used.

Optional.

Implementation

core.String? serviceAccountEmail;