table property
The unique name of the table to write messages to.
Values are of the form projects//instances//tables/.
Optional.
Implementation
core.String? table;
The unique name of the table to write messages to.
Values are of the form projects//instances//tables/.
Optional.
core.String? table;