DcrExchangeConfig class

Data Clean Room (DCR), used for privacy-safe and secured data sharing.

Constructors

DcrExchangeConfig({bool? singleLinkedDatasetPerCleanroom, bool? singleSelectedResourceSharingRestriction})
DcrExchangeConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleLinkedDatasetPerCleanroom ↔ bool?
If True, when subscribing to this DCR, it will create only one linked dataset containing all resources shared within the cleanroom.
getter/setter pair
singleSelectedResourceSharingRestriction ↔ bool?
If True, this DCR restricts the contributors to sharing only a single resource in a Listing.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited