DestinationDataset class

Defines the destination bigquery dataset.

Constructors

DestinationDataset({DestinationDatasetReference? datasetReference, String? description, String? friendlyName, Map<String, String>? labels, String? location, List<String>? replicaLocations})
DestinationDataset.fromJson(Map json_)

Properties

datasetReference ↔ DestinationDatasetReference?
A reference that identifies the destination dataset.
getter/setter pair
description ↔ String?
A user-friendly description of the dataset.
getter/setter pair
friendlyName ↔ String?
A descriptive name for the dataset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels associated with this dataset.
getter/setter pair
location ↔ String?
The geographic location where the dataset should reside.
getter/setter pair
replicaLocations ↔ List<String>?
The geographic locations where the dataset should be replicated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited