bigtableConfig property
If delivery to Bigtable is used with this subscription, this field is used to configure it.
Optional.
Implementation
BigtableConfig? bigtableConfig;
If delivery to Bigtable is used with this subscription, this field is used to configure it.
Optional.
BigtableConfig? bigtableConfig;