JavaScriptUDF class

User-defined JavaScript function that can transform or filter a Pub/Sub message.

Constructors

JavaScriptUDF({String? code, String? functionName})
JavaScriptUDF.fromJson(Map json_)

Properties

code ↔ String?
JavaScript code that contains a function function_name with the below signature: ``` / * * * Transforms a Pub/Sub message.
getter/setter pair
functionName ↔ String?
Name of the JavasScript function that should applied to Pub/Sub messages.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited