ListQueryTemplatesResponse class

Message for response to the list of QueryTemplates.

Constructors

ListQueryTemplatesResponse({String? nextPageToken, List<QueryTemplate>? queryTemplates})
ListQueryTemplatesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to request the next page of results.
getter/setter pair
queryTemplates ↔ List<QueryTemplate>?
The list of QueryTemplates.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited