PushConfig class

Configuration for a push delivery endpoint.

Constructors

PushConfig({Map<String, String>? attributes, NoWrapper? noWrapper, OidcToken? oidcToken, PubsubWrapper? pubsubWrapper, String? pushEndpoint})
PushConfig.fromJson(Map json_)

Properties

attributes ↔ Map<String, String>?
Endpoint configuration attributes that can be used to control different aspects of the message delivery.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
noWrapper ↔ NoWrapper?
When set, the payload to the push endpoint is not wrapped.
getter/setter pair
oidcToken ↔ OidcToken?
If specified, Pub/Sub will generate and attach an OIDC JWT token as an Authorization header in the HTTP request for every pushed message.
getter/setter pair
pubsubWrapper ↔ TextConfig?
When set, the payload to the push endpoint is in the form of the JSON representation of a PubsubMessage (https://cloud.google.com/pubsub/docs/reference/rpc/google.pubsub.v1#pubsubmessage).
getter/setter pair
pushEndpoint ↔ String?
A URL locating the endpoint to which messages should be pushed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited