SharingEnvironmentConfig class

Sharing environment is a behavior model for sharing data within a data exchange.

This option is configurable for a data exchange.

Constructors

SharingEnvironmentConfig({DcrExchangeConfig? dcrExchangeConfig, DefaultExchangeConfig? defaultExchangeConfig})
SharingEnvironmentConfig.fromJson(Map json_)

Properties

dcrExchangeConfig ↔ DcrExchangeConfig?
Data Clean Room (DCR), used for privacy-safe and secured data sharing.
getter/setter pair
defaultExchangeConfig ↔ TextConfig?
Default Analytics Hub data exchange, used for secured data sharing.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited