Subscription class

A subscription represents a subscribers' access to a particular set of published data.

It contains references to associated listings, data exchanges, and linked datasets.

Constructors

Subscription({GoogleCloudBigqueryAnalyticshubV1SubscriptionCommercialInfo? commercialInfo, String? creationTime, String? dataExchange, DestinationDataset? destinationDataset, String? lastModifyTime, Map<String, LinkedResource>? linkedDatasetMap, List<LinkedResource>? linkedResources, String? listing, bool? logLinkedDatasetQueryUserEmail, String? name, String? organizationDisplayName, String? organizationId, String? resourceType, String? state, String? subscriberContact})
Subscription.fromJson(Map json_)

Properties

commercialInfo ↔ GoogleCloudBigqueryAnalyticshubV1SubscriptionCommercialInfo?
This is set if this is a commercial subscription i.e. if this subscription was created from subscribing to a commercial listing.
getter/setter pair
creationTime ↔ String?
Timestamp when the subscription was created.
getter/setter pair
dataExchange ↔ String?
Resource name of the source Data Exchange.
getter/setter pair
destinationDataset ↔ DestinationDataset?
BigQuery destination dataset to create for the subscriber.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModifyTime ↔ String?
Timestamp when the subscription was last modified.
getter/setter pair
linkedDatasetMap ↔ Map<String, LinkedResource>?
Map of listing resource names to associated linked resource, e.g. projects/123/locations/us/dataExchanges/456/listings/789 -> projects/123/datasets/my_dataset For listing-level subscriptions, this is a map of size 1.
getter/setter pair
linkedResources ↔ List<LinkedResource>?
Linked resources created in the subscription.
getter/setter pair
listing ↔ String?
Resource name of the source Listing.
getter/setter pair
logLinkedDatasetQueryUserEmail ↔ bool?
By default, false.
getter/setter pair
name ↔ String?
The resource name of the subscription.
getter/setter pair
organizationDisplayName ↔ String?
Display name of the project of this subscription.
getter/setter pair
organizationId ↔ String?
Organization of the project this subscription belongs to.
getter/setter pair
resourceType ↔ String?
Listing shared asset type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Current state of the subscription.
getter/setter pair
subscriberContact ↔ String?
Email of the subscriber.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited