check method

Future<PackageRegistrationStatus> check(
  1. String name, {
  2. String? certificateFingerprint,
  3. String? $fields,
})

Retrieves the Android Developer ID registration status for a given package.

Request parameters:

name - Required. The name of the package registration status resource. Format: packages/{package}/packageRegistrationStatus {package} must follow the specific format: The fully-qualified Android package name with dots ('.') replaced by hyphens ('-') (e.g., com-example-app instead of com.example.app). Value must have pattern ^packages/\[^/\]+/packageRegistrationStatus$.

certificateFingerprint - Optional. The SHA-256 fingerprint of the public certificate represented as a 64-character lowercase hexadecimal string without any colons or separators (e.g., d6ac89ed1d0a805aad4b087d06d5f41645b814480b133fbc867ef7498d069e06).

$fields - Selector specifying which fields to include in a partial response.

Completes with a PackageRegistrationStatus.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<PackageRegistrationStatus> check(
  core.String name, {
  core.String? certificateFingerprint,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'certificateFingerprint': ?certificateFingerprint == null
        ? null
        : [certificateFingerprint],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':check';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return PackageRegistrationStatus.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}