AndroidProvisioningPartnerApi class

Automates Android zero-touch enrollment for device resellers, customers, and EMMs.

Constructors

AndroidProvisioningPartnerApi(Client client, {String rootUrl = 'https://androiddeviceprovisioning.googleapis.com/', String servicePath = ''})

Properties

customers → CustomersResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
operations → OperationsResource
no setter
partners → PartnersResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited