ClaimDeviceRequest class

Request message to claim a device on behalf of a customer.

Constructors

ClaimDeviceRequest({String? configurationId, String? customerId, DeviceIdentifier? deviceIdentifier, DeviceMetadata? deviceMetadata, String? googleWorkspaceCustomerId, String? preProvisioningToken, String? sectionType, String? simlockProfileId})
ClaimDeviceRequest.fromJson(Map json_)

Properties

configurationId ↔ String?
The ID of the configuration applied to the device section.
getter/setter pair
customerId ↔ String?
The ID of the customer for whom the device is being claimed.
getter/setter pair
deviceIdentifier ↔ DeviceIdentifier?
The device identifier of the device to claim.
getter/setter pair
deviceMetadata ↔ DeviceMetadata?
The metadata to attach to the device.
getter/setter pair
googleWorkspaceCustomerId ↔ String?
The Google Workspace customer ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
preProvisioningToken ↔ String?
Must and can only be set for Chrome OS devices.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionType ↔ String?
The section type of the device's provisioning record.
getter/setter pair
simlockProfileId ↔ String?
Must and can only be set when DeviceProvisioningSectionType is SECTION_TYPE_SIM_LOCK.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited