ClaimDeviceResponse class

Response message containing device id of the claim.

Constructors

ClaimDeviceResponse({String? deviceId, String? deviceName})
ClaimDeviceResponse.fromJson(Map json_)

Properties

deviceId ↔ String?
The device ID of the claimed device.
getter/setter pair
deviceName ↔ String?
The resource name of the device in the format partners/[PARTNER_ID]/devices/[DEVICE_ID].
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited