Configuration class

A configuration collects the provisioning options for Android devices.

Each configuration combines the following: * The EMM device policy controller (DPC) installed on the devices. * EMM policies enforced on the devices. * Metadata displayed on the device to help users during setup. Customers can add as many configurations as they need. However, zero-touch enrollment works best when a customer sets a default configuration that's applied to any new devices the organization purchases.

Constructors

Configuration({String? companyName, String? configurationId, String? configurationName, String? contactEmail, String? contactPhone, String? customMessage, String? dpcExtras, String? dpcResourcePath, String? forcedResetTime, bool? isDefault, String? name})
Configuration.fromJson(Map json_)

Properties

companyName ↔ String?
The name of the organization.
getter/setter pair
configurationId ↔ String?
The ID of the configuration.
getter/setter pair
configurationName ↔ String?
A short name that describes the configuration's purpose.
getter/setter pair
contactEmail ↔ String?
The email address that device users can contact to get help.
getter/setter pair
contactPhone ↔ String?
The telephone number that device users can call, using another device, to get help.
getter/setter pair
customMessage ↔ String?
A message, containing one or two sentences, to help device users get help or give them more details about what’s happening to their device.
getter/setter pair
dpcExtras ↔ String?
The JSON-formatted EMM provisioning extras that are passed to the DPC.
getter/setter pair
dpcResourcePath ↔ String?
The resource name of the selected DPC (device policy controller) in the format customers/[CUSTOMER_ID]/dpcs / * .
getter/setter pair
forcedResetTime ↔ String?
The timeout before forcing factory reset the device if the device doesn't go through provisioning in the setup wizard, usually due to lack of network connectivity during setup wizard.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDefault ↔ bool?
Whether this is the default configuration that zero-touch enrollment applies to any new devices the organization purchases in the future.
getter/setter pair
name ↔ String?
The API resource name in the format customers/[CUSTOMER_ID]/configurations/[CONFIGURATION_ID].
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited