CustomerApplyConfigurationRequest class

Request message for customer to assign a configuration to device.

Properties

configuration ↔ String?
The configuration applied to the device in the format customers/[CUSTOMER_ID]/configurations/[CONFIGURATION_ID].
getter/setter pair
device ↔ DeviceReference?
The device the configuration is applied to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited