Device class

An Android or Chrome OS device registered for zero-touch enrollment.

Constructors

Device({List<DeviceClaim>? claims, String? configuration, String? deviceId, DeviceIdentifier? deviceIdentifier, DeviceMetadata? deviceMetadata, String? name})
Device.fromJson(Map json_)

Properties

claims ↔ List<DeviceClaim>?
The provisioning claims for a device.
getter/setter pair
configuration ↔ String?
Not available to resellers.
getter/setter pair
deviceId ↔ String?
The ID of the device.
getter/setter pair
deviceIdentifier ↔ DeviceIdentifier?
The hardware IDs that identify a manufactured device.
getter/setter pair
deviceMetadata ↔ DeviceMetadata?
The metadata attached to the device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The API resource name in the format partners/[PARTNER_ID]/devices/[DEVICE_ID].
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited