DeviceMetadata class

Metadata entries that can be attached to a Device.

To learn more, read Device metadata.

Constructors

DeviceMetadata({Map<String, String>? entries})
DeviceMetadata.fromJson(Map json_)

Properties

entries ↔ Map<String, String>?
Metadata entries recorded as key-value pairs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited