FindDevicesByDeviceIdentifierRequest class

Request to find devices.

Properties

deviceIdentifier ↔ DeviceIdentifier?
The device identifier to search for.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ String?
The maximum number of devices to show in a page of results.
getter/setter pair
pageToken ↔ String?
A token specifying which result page to return.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited