Operation class

This resource represents a long-running operation that is the result of a network API call.

Constructors

Operation({bool? done, Status? error, Map<String, Object?>? metadata, String? name, Map<String, Object?>? response})
Operation.fromJson(Map json_)

Properties

done ↔ bool?
If the value is false, it means the operation is still in progress.
getter/setter pair
error ↔ Status?
This field will always be not set if the operation is created by claimAsync, unclaimAsync, or updateMetadataAsync.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, Object?>?
This field will contain a DevicesLongRunningOperationMetadata object if the operation is created by claimAsync, unclaimAsync, or updateMetadataAsync.
getter/setter pair
name ↔ String?
The server-assigned name, which is only unique within the same service that originally returns it.
getter/setter pair
response ↔ Map<String, Object?>?
This field will contain a DevicesLongRunningOperationResponse object if the operation is created by claimAsync, unclaimAsync, or updateMetadataAsync.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited