UpdateMetadataArguments class

Identifies metadata updates to one device.

Constructors

UpdateMetadataArguments({String? deviceId, DeviceIdentifier? deviceIdentifier, DeviceMetadata? deviceMetadata})
UpdateMetadataArguments.fromJson(Map json_)

Properties

deviceId ↔ String?
Device ID of the device.
getter/setter pair
deviceIdentifier ↔ DeviceIdentifier?
Device identifier.
getter/setter pair
deviceMetadata ↔ DeviceMetadata?
The metadata to update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited