AdministratorWebTokenSpec class

Specification for a token used to generate iframes.

The token specifies what data the admin is allowed to modify and the URI the iframe is allowed to communiate with.

Properties

hashCode → int
The hash code for this object.
no setterinherited
managedConfigurations ↔ AdministratorWebTokenSpecManagedConfigurations?
Options for displaying the Managed Configuration page.
getter/setter pair
parent ↔ String?
The URI of the parent frame hosting the iframe.
getter/setter pair
permission ↔ List<String>?
Use PlaySearch.approveApps.
getter/setter pair
playSearch ↔ AdministratorWebTokenSpecPlaySearch?
Options for displaying the managed Play Search apps page.
getter/setter pair
privateApps ↔ AdministratorWebTokenSpecPrivateApps?
Options for displaying the Private Apps page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeBuilder ↔ AdministratorWebTokenSpecStoreBuilder?
Options for displaying the Organize apps page.
getter/setter pair
webApps ↔ AdministratorWebTokenSpecWebApps?
Options for displaying the Web Apps page.
getter/setter pair
zeroTouch ↔ AdministratorWebTokenSpecZeroTouch?
Options for displaying the Zero Touch page.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited