AutoInstallConstraint class

The auto-install constraint.

Defines a set of restrictions for installation. At least one of the fields must be set.

Constructors

AutoInstallConstraint({String? chargingStateConstraint, String? deviceIdleStateConstraint, String? networkTypeConstraint})
AutoInstallConstraint.fromJson(Map json_)

Properties

chargingStateConstraint ↔ String?
Charging state constraint. Possible string values are:
getter/setter pair
deviceIdleStateConstraint ↔ String?
Device idle state constraint. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
networkTypeConstraint ↔ String?
Network type constraint. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited