AutoInstallPolicy class

Constructors

AutoInstallPolicy({List<AutoInstallConstraint>? autoInstallConstraint, String? autoInstallMode, int? autoInstallPriority, int? minimumVersionCode})
AutoInstallPolicy.fromJson(Map json_)

Properties

autoInstallConstraint ↔ List<AutoInstallConstraint>?
The constraints for auto-installing the app.
getter/setter pair
autoInstallMode ↔ String?
The auto-install mode.
getter/setter pair
autoInstallPriority ↔ int?
The priority of the install, as an unsigned integer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minimumVersionCode ↔ int?
The minimum version of the app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited