Device class

A Devices resource represents a mobile device managed by the EMM and belonging to a specific enterprise user.

Constructors

Device({String? androidId, String? device, String? latestBuildFingerprint, String? maker, String? managementType, String? model, Policy? policy, String? product, DeviceReport? report, String? retailBrand, int? sdkVersion})
Device.fromJson(Map json_)

Properties

androidId ↔ String?
The Google Play Services Android ID for the device encoded as a lowercase hex string.
getter/setter pair
device ↔ String?
The internal hardware codename of the device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latestBuildFingerprint ↔ String?
The build fingerprint of the device if known.
getter/setter pair
maker ↔ String?
The manufacturer of the device.
getter/setter pair
managementType ↔ String?
Identifies the extent to which the device is controlled by a managed Google Play EMM in various deployment configurations.
getter/setter pair
model ↔ String?
The model name of the device.
getter/setter pair
policy ↔ Policy?
The policy enforced on the device.
getter/setter pair
product ↔ String?
The product name of the device.
getter/setter pair
report ↔ DeviceReport?
The device report updated with the latest app states.
getter/setter pair
retailBrand ↔ String?
Retail brand for the device, if set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkVersion ↔ int?
API compatibility version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited