DeviceState class

The state of a user's device, as accessed by the getState and setState methods on device resources.

Constructors

DeviceState({String? accountState})
DeviceState.fromJson(Map json_)

Properties

accountState ↔ String?
The state of the Google account on the device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited