getState method

Future<DeviceState> getState(
  1. String enterpriseId,
  2. String userId,
  3. String deviceId, {
  4. String? $fields,
})

Checks if a device can access Google apps and services for a user.

Returns whether access is "enabled" or "disabled". A "disabled" state prevents the user's Managed Google Account on the device from successfully authenticating with Google. This blocks access to most Google applications and services, including Google Play, as the device cannot prove its entitlement to access them. New devices default to "disabled". Important: Enforcement of this state depends on the following conditions: * The user must be a managed google account. * The enterprise must be a managed google domain. * Third-party Android mobile management must be active in the Google Admin Console for the user's Organizational Unit. If these conditions aren't met, access may still be possible even in a "disabled" state.

Request parameters:

enterpriseId - The ID of the enterprise.

userId - The ID of the user.

deviceId - The ID of the device.

$fields - Selector specifying which fields to include in a partial response.

Completes with a DeviceState.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<DeviceState> getState(
  core.String enterpriseId,
  core.String userId,
  core.String deviceId, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'androidenterprise/v1/enterprises/' +
      commons.escapeVariable('$enterpriseId') +
      '/users/' +
      commons.escapeVariable('$userId') +
      '/devices/' +
      commons.escapeVariable('$deviceId') +
      '/state';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return DeviceState.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}