EnrollmentTokenGoogleAuthenticationOptions class

Options for Google authentication during the enrollment.

Constructors

EnrollmentTokenGoogleAuthenticationOptions({String? authenticationRequirement, String? requiredAccountEmail})
EnrollmentTokenGoogleAuthenticationOptions.fromJson(Map json_)

Properties

authenticationRequirement ↔ String?
Specifies whether user should authenticate with Google during enrollment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requiredAccountEmail ↔ String?
Specifies the managed Google account that the user must use during enrollment.AuthenticationRequirement must be set toREQUIRED if this field is set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited