MaintenanceWindow class

Maintenance window for managed Google Play Accounts.

This allows Play store to update the apps on the foreground in the designated window.

Constructors

MaintenanceWindow({String? durationMs, String? startTimeAfterMidnightMs})
MaintenanceWindow.fromJson(Map json_)

Properties

durationMs ↔ String?
Duration of the maintenance window, in milliseconds.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimeAfterMidnightMs ↔ String?
Start time of the maintenance window, in milliseconds after midnight on the device.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited