ManagedConfiguration class

Deprecated: New integrations cannot use this method and can refer to our new recommendations

Constructors

ManagedConfiguration({ConfigurationVariables? configurationVariables, String? kind, List<ManagedProperty>? managedProperty, String? productId})
ManagedConfiguration.fromJson(Map json_)

Properties

configurationVariables ↔ ConfigurationVariables?
Contains the ID of the managed configuration profile and the set of configuration variables (if any) defined for the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Deprecated.
getter/setter pair
managedProperty ↔ List<ManagedProperty>?
The set of managed properties for this configuration.
getter/setter pair
productId ↔ String?
The ID of the product that the managed configuration is for, e.g. "app:com.google.android.gm".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited