NewDeviceEvent class

An event generated when a new device is ready to be managed.

Constructors

NewDeviceEvent({String? deviceId, String? dpcPackageName, String? managementType, String? userId})
NewDeviceEvent.fromJson(Map json_)

Properties

deviceId ↔ String?
The Android ID of the device.
getter/setter pair
dpcPackageName ↔ String?
Policy app on the device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
managementType ↔ String?
Identifies the extent to which the device is controlled by an Android EMM in various deployment configurations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String?
The ID of the user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited