Notification class

A notification of one event relating to an enterprise.

Constructors

Notification({AppRestrictionsSchemaChangeEvent? appRestrictionsSchemaChangeEvent, AppUpdateEvent? appUpdateEvent, DeviceReportUpdateEvent? deviceReportUpdateEvent, String? enterpriseId, EnterpriseUpgradeEvent? enterpriseUpgradeEvent, InstallFailureEvent? installFailureEvent, NewDeviceEvent? newDeviceEvent, NewPermissionsEvent? newPermissionsEvent, String? notificationType, ProductApprovalEvent? productApprovalEvent, ProductAvailabilityChangeEvent? productAvailabilityChangeEvent, String? timestampMillis})
Notification.fromJson(Map json_)

Properties

appRestrictionsSchemaChangeEvent ↔ AppRestrictionsSchemaChangeEvent?
Notifications about new app restrictions schema changes.
getter/setter pair
appUpdateEvent ↔ AppUpdateEvent?
Notifications about app updates.
getter/setter pair
deviceReportUpdateEvent ↔ DeviceReportUpdateEvent?
Notifications about device report updates.
getter/setter pair
enterpriseId ↔ String?
The ID of the enterprise for which the notification is sent.
getter/setter pair
enterpriseUpgradeEvent ↔ EnterpriseUpgradeEvent?
Notifications about enterprise upgrade.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installFailureEvent ↔ InstallFailureEvent?
Notifications about an app installation failure.
getter/setter pair
newDeviceEvent ↔ NewDeviceEvent?
Notifications about new devices.
getter/setter pair
newPermissionsEvent ↔ NewPermissionsEvent?
Notifications about new app permissions.
getter/setter pair
notificationType ↔ String?
Type of the notification. Possible string values are:
getter/setter pair
productApprovalEvent ↔ ProductApprovalEvent?
Notifications about changes to a product's approval status.
getter/setter pair
productAvailabilityChangeEvent ↔ ProductAvailabilityChangeEvent?
Notifications about product availability changes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampMillis ↔ String?
The time when the notification was published in milliseconds since 1970-01-01T00:00:00Z.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited