Policy class

The device policy for a given managed device.

Constructors

Policy({String? autoUpdatePolicy, String? deviceReportPolicy, MaintenanceWindow? maintenanceWindow, String? policyId, String? productAvailabilityPolicy, List<ProductPolicy>? productPolicy})
Policy.fromJson(Map json_)

Properties

autoUpdatePolicy ↔ String?
Controls when automatic app updates on the device can be applied.
getter/setter pair
deviceReportPolicy ↔ String?
Whether the device reports app states to the EMM.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maintenanceWindow ↔ MaintenanceWindow?
The maintenance window defining when apps running in the foreground should be updated.
getter/setter pair
policyId ↔ String?
An identifier for the policy that will be passed with the app install feedback sent from the Play Store.
getter/setter pair
productAvailabilityPolicy ↔ String?
The availability granted to the device for the specified products.
getter/setter pair
productPolicy ↔ List<ProductPolicy>?
The list of product policies.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited