ServiceAccount class

A service account identity, including the name and credentials that can be used to authenticate as the service account.

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ ServiceAccountKey?
Credentials that can be used to authenticate as this ServiceAccount.
getter/setter pair
name ↔ String?
The account name of the service account, in the form of an email address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited