ServiceAccountKey class

Deprecated: New integrations cannot use this method and can refer to our new recommendations

Constructors

ServiceAccountKey({String? data, String? id, String? publicData, String? type})
ServiceAccountKey.fromJson(Map json_)

Properties

data ↔ String?
The body of the private key credentials file, in string format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
An opaque, unique identifier for this ServiceAccountKey.
getter/setter pair
publicData ↔ String?
Public key data for the credentials file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The file format of the generated key data. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited