data property

String? data
getter/setter pair

The body of the private key credentials file, in string format.

This is only populated when the ServiceAccountKey is created, and is not stored by Google. When type is "pkcs12", the contents of the data field is base64 encoded and has the password "notasecret".

Implementation

core.String? data;