UsersResource class

Constructors

UsersResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String enterpriseId, String userId, {String? $fields}) → Future<void>
Deleted an EMM-managed user.
generateAuthenticationToken(String enterpriseId, String userId, {String? $fields}) → Future<AuthenticationToken>
Generates an authentication token which the device policy client can use to provision the given EMM-managed user account on a device.
get(String enterpriseId, String userId, {String? $fields}) → Future<User>
Retrieves a user's details.
getAvailableProductSet(String enterpriseId, String userId, {String? $fields}) → Future<ProductSet>
Retrieves the set of products a user is entitled to access.
insert(User request, String enterpriseId, {String? $fields}) → Future<User>
Creates a new EMM-managed user.
list(String enterpriseId, String email, {String? $fields}) → Future<UsersListResponse>
Looks up a user by primary email address.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revokeDeviceAccess(String enterpriseId, String userId, {String? $fields}) → Future<void>
Revokes access to all devices currently provisioned to the user.
setAvailableProductSet(ProductSet request, String enterpriseId, String userId, {String? $fields}) → Future<ProductSet>
Modifies the set of products that a user is entitled to access (referred to as whitelisted products).
toString() → String
A string representation of this object.
inherited
update(User request, String enterpriseId, String userId, {String? $fields}) → Future<User>
Updates the details of an EMM-managed user.

Operators

operator ==(Object other) → bool
The equality operator.
inherited