VariableSet class

A variable set is a key-value pair of EMM-provided placeholders and its corresponding value, which is attributed to a user.

For example, $FIRSTNAME could be a placeholder, and its value could be Alice. Placeholders should start with a '$' sign and should be alphanumeric only.

Constructors

VariableSet({String? placeholder, String? userValue})
VariableSet.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
placeholder ↔ String?
The placeholder string; defined by EMM.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userValue ↔ String?
The value of the placeholder, specific to the user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited