WebApp class

A WebApps resource represents a web app created for an enterprise.

Web apps are published to managed Google Play and can be distributed like other Android apps. On a user's device, a web app opens its specified URL.

Constructors

WebApp({String? displayMode, List<WebAppIcon>? icons, bool? isPublished, String? startUrl, String? title, String? versionCode, String? webAppId})
WebApp.fromJson(Map json_)

Properties

displayMode ↔ String?
The display mode of the web app.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icons ↔ List<WebAppIcon>?
A list of icons representing this website.
getter/setter pair
isPublished ↔ bool?
A flag whether the app has been published to the Play store yet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startUrl ↔ String?
The start URL, i.e. the URL that should load when the user opens the application.
getter/setter pair
title ↔ String?
The title of the web app as displayed to the user (e.g., amongst a list of other applications, or as a label for an icon).
getter/setter pair
versionCode ↔ String?
The current version of the app.
getter/setter pair
webAppId ↔ String?
The ID of the application.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited