AddEsimParams class

Parameters associated with the ADD_ESIM command to add an eSIM profile to the device.

Constructors

AddEsimParams({String? activationCode, String? activationState})
AddEsimParams.fromJson(Map json_)

Properties

activationCode ↔ String?
The activation code for the eSIM profile.
getter/setter pair
activationState ↔ String?
The activation state of the eSIM profile once it is downloaded.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited