ApiLevelCondition class

A compliance rule condition which is satisfied if the Android Framework API level on the device doesn't meet a minimum requirement.

There can only be one rule with this type of condition per policy.

Constructors

ApiLevelCondition({int? minApiLevel})
ApiLevelCondition.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
minApiLevel ↔ int?
The minimum desired Android Framework API level.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited