Application class

Information about an app.

Constructors

Application({String? appPricing, List<AppTrackInfo>? appTracks, List<AppVersion>? appVersions, String? author, List<String>? availableCountries, String? category, String? contentRating, String? description, String? distributionChannel, List<String>? features, String? fullDescription, String? iconUrl, List<ManagedProperty>? managedProperties, int? minAndroidSdkVersion, String? name, List<ApplicationPermission>? permissions, String? playStoreUrl, String? recentChanges, List<String>? screenshotUrls, String? smallIconUrl, String? title, String? updateTime})
Application.fromJson(Map json_)

Properties

appPricing ↔ String?
Whether this app is free, free with in-app purchases, or paid.
getter/setter pair
appTracks ↔ List<AppTrackInfo>?
Application tracks visible to the enterprise.
getter/setter pair
appVersions ↔ List<AppVersion>?
Versions currently available for this app.
getter/setter pair
author ↔ String?
The name of the author of the apps (for example, the app developer).
getter/setter pair
availableCountries ↔ List<String>?
The countries which this app is available in as per ISO 3166-1 alpha-2.
getter/setter pair
category ↔ String?
The app category (e.g. RACING, SOCIAL, etc.)
getter/setter pair
contentRating ↔ String?
The content rating for this app. Possible string values are:
getter/setter pair
description ↔ String?
The localized promotional description, if available.
getter/setter pair
distributionChannel ↔ String?
How and to whom the package is made available. Possible string values are:
getter/setter pair
features ↔ List<String>?
Noteworthy features (if any) of this app.
getter/setter pair
fullDescription ↔ String?
Full app description, if available.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconUrl ↔ String?
A link to an image that can be used as an icon for the app.
getter/setter pair
managedProperties ↔ List<ManagedProperty>?
The set of managed properties available to be pre-configured for the app.
getter/setter pair
minAndroidSdkVersion ↔ int?
The minimum Android SDK necessary to run the app.
getter/setter pair
name ↔ String?
The name of the app in the form enterprises/{enterprise}/applications/{package_name}.
getter/setter pair
permissions ↔ List<ApplicationPermission>?
The permissions required by the app.
getter/setter pair
playStoreUrl ↔ String?
A link to the (consumer) Google Play details page for the app.
getter/setter pair
recentChanges ↔ String?
A localised description of the recent changes made to the app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenshotUrls ↔ List<String>?
A list of screenshot links representing the app.
getter/setter pair
smallIconUrl ↔ String?
A link to a smaller image that can be used as an icon for the app.
getter/setter pair
title ↔ String?
The title of the app.
getter/setter pair
updateTime ↔ String?
The approximate time (within 7 days) the app was last published.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited