ApplicationEvent class

An app-related event.

Constructors

ApplicationEvent({String? createTime, String? eventType})
ApplicationEvent.fromJson(Map json_)

Properties

createTime ↔ String?
The creation time of the event.
getter/setter pair
eventType ↔ String?
App event type. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited