ApplicationReport class

Information reported about an installed app.

Constructors

ApplicationReport({String? applicationSource, String? displayName, List<ApplicationEvent>? events, String? installerPackageName, List<KeyedAppState>? keyedAppStates, String? packageName, String? packageSha256Hash, List<String>? signingKeyCertFingerprints, List<ApplicationSigningKeyCert>? signingKeyCerts, String? state, String? userFacingType, int? versionCode, String? versionName})
ApplicationReport.fromJson(Map json_)

Properties

applicationSource ↔ String?
The source of the package. Possible string values are:
getter/setter pair
displayName ↔ String?
The display name of the app.
getter/setter pair
events ↔ List<ApplicationEvent>?
The list of app events which have occurred in the last 30 hours.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installerPackageName ↔ String?
The package name of the app that installed this app.
getter/setter pair
keyedAppStates ↔ List<KeyedAppState>?
List of keyed app states reported by the app.
getter/setter pair
packageName ↔ String?
Package name of the app.
getter/setter pair
packageSha256Hash ↔ String?
The SHA-256 hash of the app's APK file, which can be used to verify the app hasn't been modified.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signingKeyCertFingerprints ↔ List<String>?
Use signingKeyCerts instead.
getter/setter pair
signingKeyCerts ↔ List<ApplicationSigningKeyCert>?
Signing key certificates of the app.
getter/setter pair
state ↔ String?
Application state. Possible string values are:
getter/setter pair
userFacingType ↔ String?
Whether the app is user facing. Possible string values are:
getter/setter pair
versionCode ↔ int?
The app version code, which can be used to determine whether one version is more recent than another.
getter/setter pair
versionName ↔ String?
The app version as displayed to the user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited