ApplicationReportingSettings class

Settings controlling the behavior of application reports.

Constructors

ApplicationReportingSettings({bool? includeRemovedApps})
ApplicationReportingSettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeRemovedApps ↔ bool?
Whether removed apps are included in application reports.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited