BlockAction class

An action to block access to apps and data on a fully managed device or in a work profile.

This action also triggers a device or work profile to displays a user-facing notification with information (where possible) on how to correct the compliance issue. Note: wipeAction must also be specified.

Constructors

BlockAction({int? blockAfterDays, String? blockScope})
BlockAction.fromJson(Map json_)

Properties

blockAfterDays ↔ int?
Number of days the policy is non-compliant before the device or work profile is blocked.
getter/setter pair
blockScope ↔ String?
Specifies the scope of this BlockAction.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited