ClearAppsDataStatus class

Status of the CLEAR_APP_DATA command to clear the data of specified apps from the device.

Properties

hashCode → int
The hash code for this object.
no setterinherited
results ↔ Map<String, PerAppResult>?
The per-app results, a mapping from package names to the respective clearing result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited