ContentProviderEndpoint class

This feature is not generally available.

Constructors

ContentProviderEndpoint({String? packageName, List<String>? signingCertsSha256, String? uri})
ContentProviderEndpoint.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
packageName ↔ String?
This feature is not generally available.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signingCertsSha256 ↔ List<String>?
This feature is not generally available.
getter/setter pair
uri ↔ String?
This feature is not generally available.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited