CrossDevicePolicies class

Policies controlling cross-device communication.

Constructors

CrossDevicePolicies({String? nearbyAppStreaming, String? nearbyNotificationStreaming})
CrossDevicePolicies.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
nearbyAppStreaming String?
Manages video streaming of apps on the device for fully managed devices or in the work profile for devices with work profiles to nearby devices.
getter/setter pair
nearbyNotificationStreaming String?
Manages streaming of notifications from apps on the device for fully managed devices or in the work profile for devices with work profiles to nearby devices.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited