nearbyNotificationStreaming property

String? nearbyNotificationStreaming
getter/setter pair

Manages streaming of notifications from apps on the device for fully managed devices or in the work profile for devices with work profiles to nearby devices.

This is supported on Android 13 and above.

Optional. Possible string values are:

  • "NEARBY_NOTIFICATION_STREAMING_UNSPECIFIED" : Unspecified. Defaults to NEARBY_NOTIFICATION_STREAMING_USER_CHOICE_SAME_MANAGED_ACCOUNT.
  • "NEARBY_NOTIFICATION_STREAMING_USER_CHOICE" : The user is allowed to choose whether to stream notifications to nearby devices.
  • "NEARBY_NOTIFICATION_STREAMING_DISABLED" : Disables notification streaming to nearby devices.
  • "NEARBY_NOTIFICATION_STREAMING_USER_CHOICE_SAME_MANAGED_ACCOUNT" : The user is allowed to choose whether to stream notifications to other nearby devices which are signed in with the same authenticated managed account.

Implementation

core.String? nearbyNotificationStreaming;