DefaultApplicationSetting class

The default application setting for a DefaultApplicationType.

Constructors

DefaultApplicationSetting({List<String>? defaultApplicationScopes, String? defaultApplicationType, List<DefaultApplication>? defaultApplications})
DefaultApplicationSetting.fromJson(Map json_)

Properties

defaultApplications ↔ List<DefaultApplication>?
The list of applications that can be set as the default app for a given type.
getter/setter pair
defaultApplicationScopes ↔ List<String>?
The scopes to which the policy should be applied.
getter/setter pair
defaultApplicationType ↔ String?
The app type to set the default application.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited