Device class

A device owned by an enterprise.

Unless otherwise noted, all fields are read-only and can't be modified by enterprises.devices.patch.

Constructors

Device({int? apiLevel, List<ApplicationReport>? applicationReports, List<PasswordRequirements>? appliedPasswordPolicies, String? appliedPolicyName, String? appliedPolicyVersion, String? appliedState, CommonCriteriaModeInfo? commonCriteriaModeInfo, List<DefaultApplicationInfo>? defaultApplicationInfo, DeviceSettings? deviceSettings, UserFacingMessage? disabledReason, List<Display>? displays, DpcMigrationInfo? dpcMigrationInfo, String? enrollmentTime, String? enrollmentTokenData, String? enrollmentTokenName, HardwareInfo? hardwareInfo, List<HardwareStatus>? hardwareStatusSamples, String? lastPolicyComplianceReportTime, String? lastPolicySyncTime, String? lastStatusReportTime, String? managementMode, List<MemoryEvent>? memoryEvents, MemoryInfo? memoryInfo, String? name, NetworkInfo? networkInfo, List<NonComplianceDetail>? nonComplianceDetails, String? ownership, bool? policyCompliant, String? policyName, List<PowerManagementEvent>? powerManagementEvents, List<String>? previousDeviceNames, SecurityPosture? securityPosture, SoftwareInfo? softwareInfo, String? state, Map<String, String>? systemProperties, User? user, String? userName})
Device.fromJson(Map json_)

Properties

apiLevel ↔ int?
The API level of the Android platform version running on the device.
getter/setter pair
applicationReports ↔ List<ApplicationReport>?
Reports for apps installed on the device.
getter/setter pair
appliedPasswordPolicies ↔ List<PasswordRequirements>?
The password requirements currently applied to the device.
getter/setter pair
appliedPolicyName ↔ String?
The name of the policy currently applied to the device.
getter/setter pair
appliedPolicyVersion ↔ String?
The version of the policy currently applied to the device.
getter/setter pair
appliedState ↔ String?
The state currently applied to the device. Possible string values are:
getter/setter pair
commonCriteriaModeInfo ↔ CommonCriteriaModeInfo?
Information about Common Criteria Mode—security standards defined in the Common Criteria for Information Technology Security Evaluation (https://www.commoncriteriaportal.org/) (CC).This information is only available if statusReportingSettings.commonCriteriaModeEnabled is true in the device's policy the device is company-owned.
getter/setter pair
defaultApplicationInfo ↔ List<DefaultApplicationInfo>?
The default application information for the DefaultApplicationType.
getter/setter pair
deviceSettings ↔ DeviceSettings?
Device settings information.
getter/setter pair
disabledReason ↔ UserFacingMessage?
If the device state is DISABLED, an optional message that is displayed on the device indicating the reason the device is disabled.
getter/setter pair
displays ↔ List<Display>?
Detailed information about displays on the device.
getter/setter pair
dpcMigrationInfo ↔ DpcMigrationInfo?
Information related to whether this device was migrated from being managed by another Device Policy Controller (DPC).
getter/setter pair
enrollmentTime ↔ String?
The time of device enrollment.
getter/setter pair
enrollmentTokenData ↔ String?
If the device was enrolled with an enrollment token with additional data provided, this field contains that data.
getter/setter pair
enrollmentTokenName ↔ String?
If the device was enrolled with an enrollment token, this field contains the name of the token.
getter/setter pair
hardwareInfo ↔ HardwareInfo?
Detailed information about the device hardware.
getter/setter pair
hardwareStatusSamples ↔ List<HardwareStatus>?
Hardware status samples in chronological order.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastPolicyComplianceReportTime ↔ String?
Deprecated.
getter/setter pair
lastPolicySyncTime ↔ String?
The last time the device fetched its policy.
getter/setter pair
lastStatusReportTime ↔ String?
The last time the device sent a status report.
getter/setter pair
managementMode ↔ String?
The type of management mode Android Device Policy takes on the device.
getter/setter pair
memoryEvents ↔ List<MemoryEvent>?
Events related to memory and storage measurements in chronological order.
getter/setter pair
memoryInfo ↔ MemoryInfo?
Memory information: contains information about device memory and storage.
getter/setter pair
name ↔ String?
The name of the device in the form enterprises/{enterpriseId}/devices/{deviceId}.
getter/setter pair
networkInfo ↔ NetworkInfo?
Device network information.
getter/setter pair
nonComplianceDetails ↔ List<NonComplianceDetail>?
Details about policy settings that the device is not compliant with.
getter/setter pair
ownership ↔ String?
Ownership of the managed device. Possible string values are:
getter/setter pair
policyCompliant ↔ bool?
Whether the device is compliant with its policy.
getter/setter pair
policyName ↔ String?
The name of the policy applied to the device, in the form enterprises/{enterpriseId}/policies/{policyId}.
getter/setter pair
powerManagementEvents ↔ List<PowerManagementEvent>?
Power management events on the device in chronological order.
getter/setter pair
previousDeviceNames ↔ List<String>?
If the same physical device has been enrolled multiple times, this field contains its previous device names.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityPosture ↔ SecurityPosture?
Device's security posture value that reflects how secure the device is.
getter/setter pair
softwareInfo ↔ SoftwareInfo?
Detailed information about the device software.
getter/setter pair
state ↔ String?
The state to be applied to the device.
getter/setter pair
systemProperties ↔ Map<String, String>?
Map of selected system properties name and value related to the device.
getter/setter pair
user ↔ User?
The user who owns the device.
getter/setter pair
userName ↔ String?
The resource name of the user that owns this device in the form enterprises/{enterpriseId}/users/{userId}.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited