DeviceRadioState class

Controls for device radio settings.

Constructors

DeviceRadioState({String? airplaneModeState, String? cellularTwoGState, String? minimumWifiSecurityLevel, String? ultraWidebandState, String? userInitiatedAddEsimSettings, String? wifiState})
DeviceRadioState.fromJson(Map json_)

Properties

airplaneModeState ↔ String?
Controls whether airplane mode can be toggled by the user or not. Possible string values are:
getter/setter pair
cellularTwoGState ↔ String?
Controls whether cellular 2G setting can be toggled by the user or not. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minimumWifiSecurityLevel ↔ String?
The minimum required security level of Wi-Fi networks that the device can connect to. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ultraWidebandState ↔ String?
Controls the state of the ultra wideband setting and whether the user can toggle it on or off. Possible string values are:
getter/setter pair
userInitiatedAddEsimSettings ↔ String?
Controls whether the user is allowed to add eSIM profiles.
getter/setter pair
wifiState ↔ String?
Controls current state of Wi-Fi and if user can change its state. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited