EnterprisesDevicesResource class

Constructors

EnterprisesDevicesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → EnterprisesDevicesOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String name, {List<String>? wipeDataFlags, String? wipeReasonMessage, String? $fields}) → Future<Empty>
Deletes a device.
get(String name, {String? $fields}) → Future<Device>
Gets a device.
issueCommand(Command request, String name, {String? $fields}) → Future<Operation>
Issues a command to a device.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) → Future<ListDevicesResponse>
Lists devices for a given enterprise.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Device request, String name, {String? updateMask, String? $fields}) → Future<Device>
Updates a device.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited