EnterprisesResource class

Constructors

EnterprisesResource(ApiRequester client)

Properties

applications → EnterprisesApplicationsResource
no setter
devices → EnterprisesDevicesResource
no setter
enrollmentTokens → EnterprisesEnrollmentTokensResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
migrationTokens → EnterprisesMigrationTokensResource
no setter
policies → EnterprisesPoliciesResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webApps → EnterprisesWebAppsResource
no setter
webTokens → EnterprisesWebTokensResource
no setter

Methods

create(Enterprise request, {bool? agreementAccepted, String? enterpriseToken, String? projectId, String? signupUrlName, String? $fields}) → Future<Enterprise>
Creates an enterprise.
delete(String name, {String? $fields}) → Future<Empty>
Permanently deletes an enterprise and all accounts and data associated with it.
generateEnterpriseUpgradeUrl(GenerateEnterpriseUpgradeUrlRequest request, String name, {String? $fields}) → Future<GenerateEnterpriseUpgradeUrlResponse>
Generates an enterprise upgrade URL to upgrade an existing managed Google Play Accounts enterprise to a managed Google domain.
get(String name, {String? $fields}) → Future<Enterprise>
Gets an enterprise.
list({int? pageSize, String? pageToken, String? projectId, String? view, String? $fields}) → Future<ListEnterprisesResponse>
Lists EMM-managed enterprises.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Enterprise request, String name, {String? updateMask, String? $fields}) → Future<Enterprise>
Updates an enterprise.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited