EsimCommandStatus class

Status and error details (if present) of an ADD_ESIM or REMOVE_ESIM command.

Constructors

EsimCommandStatus({EsimInfo? esimInfo, InternalErrorDetails? internalErrorDetails, String? status})
EsimCommandStatus.fromJson(Map json_)

Properties

esimInfo ↔ EsimInfo?
Information about the eSIM added or removed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalErrorDetails ↔ InternalErrorDetails?
Details of the error if the status is set to INTERNAL_ERROR.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Status of an ADD_ESIM or REMOVE_ESIM command.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited