ExternalData class

Data hosted at an external location.

The data is to be downloaded by Android Device Policy and verified against the hash.

Constructors

ExternalData({String? sha256Hash, String? url})
ExternalData.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256Hash ↔ String?
The base-64 encoded SHA-256 hash of the content hosted at url.
getter/setter pair
url ↔ String?
The absolute URL to the data, which must use either the http or https scheme.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited