GoogleAuthenticationOptions class

Options for Google authentication during the enrollment.When triggering the enrollment with a SigninDetail, these options are enforced after the user completes third-party sign-in and an EnrollmentToken is created.

If this token's authentication_requirement is set to REQUIRED, these options interact with the SigninDetail.googleAuthenticationOptions that initiated the flow in the following ways: - If the user skipped Google sign-in earlier (permitted by SigninDetail.googleAuthenticationOptions), an error will occur and the user will be prompted to sign in again. - If required_account_email is set on this token and the user signed in with a different email earlier, an error will occur and the user will be asked to sign in again with the correct account.

Constructors

GoogleAuthenticationOptions({String? authenticationRequirement, String? requiredAccountEmail})
GoogleAuthenticationOptions.fromJson(Map json_)

Properties

authenticationRequirement String?
Specifies whether user should authenticate with Google during enrollment.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
requiredAccountEmail String?
Specifies the managed Google account that the user must use during enrollment.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited