requiredAccountEmail property
Specifies the managed Google account that the user must use during enrollment.
This field can only be set if AuthenticationRequirement is set to REQUIRED.
Optional.
Implementation
core.String? requiredAccountEmail;
Specifies the managed Google account that the user must use during enrollment.
This field can only be set if AuthenticationRequirement is set to REQUIRED.
Optional.
core.String? requiredAccountEmail;