HardwareStatus class

Hardware status.

Temperatures may be compared to the temperature thresholds available in hardwareInfo to determine hardware health.

Constructors

HardwareStatus({List<double>? batteryTemperatures, List<double>? cpuTemperatures, List<double>? cpuUsages, String? createTime, List<double>? fanSpeeds, List<double>? gpuTemperatures, List<double>? skinTemperatures})
HardwareStatus.fromJson(Map json_)

Properties

batteryTemperatures ↔ List<double>?
Current battery temperatures in Celsius for each battery on the device.
getter/setter pair
cpuTemperatures ↔ List<double>?
Current CPU temperatures in Celsius for each CPU on the device.
getter/setter pair
cpuUsages ↔ List<double>?
CPU usages in percentage for each core available on the device.
getter/setter pair
createTime ↔ String?
The time the measurements were taken.
getter/setter pair
fanSpeeds ↔ List<double>?
Fan speeds in RPM for each fan on the device.
getter/setter pair
gpuTemperatures ↔ List<double>?
Current GPU temperatures in Celsius for each GPU on the device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skinTemperatures ↔ List<double>?
Current device skin temperatures in Celsius.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited