InternalErrorDetails class

Internal error details if present for the ADD_ESIM or REMOVE_ESIM command.

Constructors

InternalErrorDetails({String? errorCode, String? errorCodeDetail, String? operationCode, String? operationCodeDetail})
InternalErrorDetails.fromJson(Map json_)

Properties

errorCode ↔ String?
Integer representation of the error code as specified here (https://developer.android.com/reference/android/telephony/euicc/EuiccManager#EXTRA_EMBEDDED_SUBSCRIPTION_DETAILED_CODE).
getter/setter pair
errorCodeDetail ↔ String?
The error code detail corresponding to the error_code.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
operationCode ↔ String?
Integer representation of the operation code as specified here (https://developer.android.com/reference/android/telephony/euicc/EuiccManager#EXTRA_EMBEDDED_SUBSCRIPTION_DETAILED_CODE).
getter/setter pair
operationCodeDetail ↔ String?
The operation code detail corresponding to the operation_code.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited