KeyedAppState class

Keyed app state reported by the app.

Constructors

KeyedAppState({String? createTime, String? data, String? key, String? lastUpdateTime, String? message, String? severity})
KeyedAppState.fromJson(Map json_)

Properties

createTime ↔ String?
The creation time of the app state on the device.
getter/setter pair
data ↔ String?
Optionally, a machine-readable value to be read by the EMM.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The key for the app state.
getter/setter pair
lastUpdateTime ↔ String?
The time the app state was most recently updated.
getter/setter pair
message ↔ String?
Optionally, a free-form message string to explain the app state.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of the app state. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited