ListEnterprisesResponse class

Response to a request to list enterprises.

Constructors

ListEnterprisesResponse({List<Enterprise>? enterprises, String? nextPageToken})
ListEnterprisesResponse.fromJson(Map json_)

Properties

enterprises ↔ List<Enterprise>?
The list of enterprises.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If there are more results, a token to retrieve next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited