ManagedConfigurationTemplate class

The managed configurations template for the app, saved from the managed configurations iframe.

Constructors

ManagedConfigurationTemplate({Map<String, String>? configurationVariables, String? templateId})
ManagedConfigurationTemplate.fromJson(Map json_)

Properties

configurationVariables ↔ Map<String, String>?
Optional, a map containing configuration variables defined for the configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateId ↔ String?
The ID of the managed configurations template.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited