templateId property
The ID of the managed configurations template.
This value must be a numeric string containing exactly one or more digits (for example, "123456").
Implementation
core.String? templateId;
The ID of the managed configurations template.
This value must be a numeric string containing exactly one or more digits (for example, "123456").
core.String? templateId;