MemoryEvent class

An event related to memory and storage measurements.To distinguish between new and old events, we recommend using the createTime field.

Constructors

MemoryEvent({String? byteCount, String? createTime, String? eventType})
MemoryEvent.fromJson(Map json_)

Properties

byteCount ↔ String?
The number of free bytes in the medium, or for EXTERNAL_STORAGE_DETECTED, the total capacity in bytes of the storage medium.
getter/setter pair
createTime ↔ String?
The creation time of the event.
getter/setter pair
eventType ↔ String?
Event type. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited