NetworkInfo class

Device network info.

Constructors

NetworkInfo({String? imei, String? meid, String? networkOperatorName, List<TelephonyInfo>? telephonyInfos, String? wifiMacAddress})
NetworkInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
imei ↔ String?
IMEI number of the GSM device.
getter/setter pair
meid ↔ String?
MEID number of the CDMA device.
getter/setter pair
networkOperatorName ↔ String?
Alphabetic name of current registered operator.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
telephonyInfos ↔ List<TelephonyInfo>?
Provides telephony information associated with each SIM card on the device.
getter/setter pair
wifiMacAddress ↔ String?
Wi-Fi MAC address of the device.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited