PasswordRequirements class

Requirements for the password used to unlock a device.

Constructors

PasswordRequirements({int? maximumFailedPasswordsForWipe, String? passwordExpirationTimeout, int? passwordHistoryLength, int? passwordMinimumLength, int? passwordMinimumLetters, int? passwordMinimumLowerCase, int? passwordMinimumNonLetter, int? passwordMinimumNumeric, int? passwordMinimumSymbols, int? passwordMinimumUpperCase, String? passwordQuality, String? passwordScope, String? requirePasswordUnlock, String? unifiedLockSettings})
PasswordRequirements.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumFailedPasswordsForWipe ↔ int?
Number of incorrect device-unlock passwords that can be entered before a device is wiped.
getter/setter pair
passwordExpirationTimeout ↔ String?
Password expiration timeout.
getter/setter pair
passwordHistoryLength ↔ int?
The length of the password history.
getter/setter pair
passwordMinimumLength ↔ int?
The minimum allowed password length.
getter/setter pair
passwordMinimumLetters ↔ int?
Minimum number of letters required in the password.
getter/setter pair
passwordMinimumLowerCase ↔ int?
Minimum number of lower case letters required in the password.
getter/setter pair
passwordMinimumNonLetter ↔ int?
Minimum number of non-letter characters (numerical digits or symbols) required in the password.
getter/setter pair
passwordMinimumNumeric ↔ int?
Minimum number of numerical digits required in the password.
getter/setter pair
passwordMinimumSymbols ↔ int?
Minimum number of symbols required in the password.
getter/setter pair
passwordMinimumUpperCase ↔ int?
Minimum number of upper case letters required in the password.
getter/setter pair
passwordQuality ↔ String?
The required password quality. Possible string values are:
getter/setter pair
passwordScope ↔ String?
The scope that the password requirement applies to. Possible string values are:
getter/setter pair
requirePasswordUnlock ↔ String?
The length of time after a device or work profile is unlocked using a strong form of authentication (password, PIN, pattern) that it can be unlocked using any other authentication method (e.g. fingerprint, trust agents, face).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unifiedLockSettings ↔ String?
Controls whether a unified lock is allowed for the device and the work profile, on devices running Android 9 and above with a work profile.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited