screenCaptureDisabled property
If true, screen capture is disabled for all users.
This also blocks Circle to Search (https://support.google.com/android/answer/14508957).
Implementation
core.bool? screenCaptureDisabled;
If true, screen capture is disabled for all users.
This also blocks Circle to Search (https://support.google.com/android/answer/14508957).
core.bool? screenCaptureDisabled;