autofillPolicy property

String? autofillPolicy
getter/setter pair

The policy for the autofill service.

Optional. Possible string values are:

  • "AUTOFILL_POLICY_UNSPECIFIED" : Defaults to AUTOFILL_USER_CHOICE.
  • "AUTOFILL_USER_CHOICE" : The user can choose and use an autofill service.
  • "AUTOFILL_DISABLED" : Autofill is disabled and the user is not allowed to change this setting. This is supported only on Android 8 and above.

Implementation

core.String? autofillPolicy;