PreferentialNetworkServiceConfig class

Individual preferential network service configuration.

Constructors

PreferentialNetworkServiceConfig({String? fallbackToDefaultConnection, String? nonMatchingNetworks, String? preferentialNetworkId})
PreferentialNetworkServiceConfig.fromJson(Map json_)

Properties

fallbackToDefaultConnection ↔ String?
Whether fallback to the device-wide default network is allowed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nonMatchingNetworks ↔ String?
Whether apps this configuration applies to are blocked from using networks other than the preferential service.
getter/setter pair
preferentialNetworkId ↔ String?
Preferential network identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited