PrivateDnsSettings class
Controls the device's private DNS settings.
Constructors
- PrivateDnsSettings({String? privateDnsHost, String? privateDnsMode})
- PrivateDnsSettings.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- privateDnsHost ↔ String?
-
The hostname of the DNS server.
getter/setter pair
- privateDnsMode ↔ String?
-
The configuration mode for device's global private DNS settings.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited