SigninDetailGoogleAuthenticationOptions class

Options for Google authentication during the enrollment.These options control whether the Google authentication screen is shown, and whether it can be skipped, at the start of the sign-in flow.

More requirements can be enforced by EnrollmentToken.googleAuthenticationOptions on the EnrollmentToken that is created later.

Properties

authenticationRequirement String?
Specifies whether user should authenticate with Google during enrollment.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited