authenticationRequirement property

String? authenticationRequirement
getter/setter pair

Specifies whether user should authenticate with Google during enrollment.

If this is set to any value other than AUTHENTICATION_REQUIREMENT_UNSPECIFIED, the enterprise-level setting googleAuthenticationSettings is ignored for devices enrolled with this sign-in detail.

Optional. Possible string values are:

  • "AUTHENTICATION_REQUIREMENT_UNSPECIFIED" : The setting googleAuthenticationSettings for the enterprise that this sign-in detail belongs to is used to determine whether the user needs to authenticate with Google during enrollment.
  • "OPTIONAL" : Google authentication is optional for the user. This means the user can choose to skip Google authentication during enrollment.
  • "REQUIRED" : Google authentication is required for the user. This means the user must authenticate with a Google account to proceed.

Implementation

core.String? authenticationRequirement;