TelephonyInfo class

Telephony information associated with a given SIM card on the device.

Only supported on fully managed devices starting from Android API level 23.

Constructors

TelephonyInfo({String? activationState, String? carrierName, String? configMode, String? iccId, String? phoneNumber})
TelephonyInfo.fromJson(Map json_)

Properties

activationState ↔ String?
Activation state of the SIM card on the device.
getter/setter pair
carrierName ↔ String?
The carrier name associated with this SIM card.
getter/setter pair
configMode ↔ String?
The configuration mode of the SIM card on the device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iccId ↔ String?
The ICCID associated with this SIM card.
getter/setter pair
phoneNumber ↔ String?
The phone number associated with this SIM card.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited