WebApp class

A web app.

Constructors

WebApp({String? displayMode, List<WebAppIcon>? icons, String? name, String? startUrl, String? title, String? versionCode})
WebApp.fromJson(Map json_)

Properties

displayMode ↔ String?
The display mode of the web app. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icons ↔ List<WebAppIcon>?
A list of icons for the web app.
getter/setter pair
name ↔ String?
The name of the web app, which is generated by the server during creation in the form enterprises/{enterpriseId}/webApps/{packageName}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startUrl ↔ String?
The start URL, i.e. the URL that should load when the user opens the application.
getter/setter pair
title ↔ String?
The title of the web app as displayed to the user (e.g., amongst a list of other applications, or as a label for an icon).
getter/setter pair
versionCode ↔ String?
The current version of the app.Note that the version can automatically increase during the lifetime of the web app, while Google does internal housekeeping to keep the web app up-to-date.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited