WebToken class

A web token used to access the managed Google Play iframe.

Constructors

WebToken({List<String>? enabledFeatures, String? name, String? parentFrameUrl, List<String>? permissions, String? value})
WebToken.fromJson(Map json_)

Properties

enabledFeatures ↔ List<String>?
The features to enable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the web token, which is generated by the server during creation in the form enterprises/{enterpriseId}/webTokens/{webTokenId}.
getter/setter pair
parentFrameUrl ↔ String?
The URL of the parent frame hosting the iframe with the embedded UI.
getter/setter pair
permissions ↔ List<String>?
Permissions available to an admin in the embedded UI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The token value which is used in the hosting page to generate the iframe with the embedded UI.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited