ActivateBasePlanRequest class

Request message for ActivateBasePlan.

Constructors

ActivateBasePlanRequest({String? basePlanId, String? latencyTolerance, String? packageName, String? productId})
ActivateBasePlanRequest.fromJson(Map json_)

Properties

basePlanId ↔ String?
The unique base plan ID of the base plan to activate.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latencyTolerance ↔ String?
The latency tolerance for the propagation of this product update.
getter/setter pair
packageName ↔ String?
The parent app (package name) of the base plan to activate.
getter/setter pair
productId ↔ String?
The parent subscription (ID) of the base plan to activate.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited