AddTargetingRequest class

Request message for AddTargeting.

Constructors

AddTargetingRequest({TargetingUpdate? targetingUpdate})
AddTargetingRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetingUpdate ↔ TargetingUpdate?
Specifies targeting updates such as regions, android sdk versions etc.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited