AndroidPublisherApi class

Lets Android application developers access their Google Play accounts.

At a high level, the expected workflow is to "insert" an Edit, make changes as necessary, and then "commit" it.

Constructors

AndroidPublisherApi(Client client, {String rootUrl = 'https://androidpublisher.googleapis.com/', String servicePath = ''})

Properties

applications → ApplicationsResource
no setter
apprecovery → ApprecoveryResource
no setter
appsigning → AppsigningResource
no setter
appstoreappsreview → AppstoreappsreviewResource
no setter
appstorecatalog → AppstorecatalogResource
no setter
edits → EditsResource
no setter
externaltransactions → ExternaltransactionsResource
no setter
generatedapks → GeneratedapksResource
no setter
grants → GrantsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
inappproducts → InappproductsResource
no setter
internalappsharingartifacts → InternalappsharingartifactsResource
no setter
monetization → MonetizationResource
no setter
orders → OrdersResource
no setter
purchases → PurchasesResource
no setter
reviews → ReviewsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemapks → SystemapksResource
no setter
users → UsersResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

androidpublisherScope → const String
View and manage your Google Play Developer account