AndroidSdks class

Android api level targeting data for app recovery action targeting.

Constructors

AndroidSdks({List<String>? sdkLevels})
AndroidSdks.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkLevels ↔ List<String>?
Android api levels of devices targeted by recovery action.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited