ApkSet class

A set of apks representing a module.

Constructors

ApkSet({List<ApkDescription>? apkDescription, ModuleMetadata? moduleMetadata})
ApkSet.fromJson(Map json_)

Properties

apkDescription ↔ List<ApkDescription>?
Description of the generated apks.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
moduleMetadata ↔ ModuleMetadata?
Metadata about the module represented by this ApkSet
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited