AppRecoveryAction class

Information about an app recovery action.

Constructors

AppRecoveryAction({String? appRecoveryId, String? cancelTime, String? createTime, String? deployTime, String? lastUpdateTime, RemoteInAppUpdateData? remoteInAppUpdateData, String? status, Targeting? targeting})
AppRecoveryAction.fromJson(Map json_)

Properties

appRecoveryId ↔ String?
ID corresponding to the app recovery action.
getter/setter pair
cancelTime ↔ String?
Timestamp of when the app recovery action is canceled by the developer.
getter/setter pair
createTime ↔ String?
Timestamp of when the app recovery action is created by the developer.
getter/setter pair
deployTime ↔ String?
Timestamp of when the app recovery action is deployed to the users.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateTime ↔ String?
Timestamp of when the developer last updated recovery action.
getter/setter pair
remoteInAppUpdateData ↔ RemoteInAppUpdateData?
Data about the remote in-app update action such as such as recovered user base, recoverable user base etc.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status of the recovery action. Possible string values are:
getter/setter pair
targeting ↔ Targeting?
Specifies targeting criteria for the recovery action such as regions, android sdk versions, app versions etc.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited