AppStoreAppDetails class

Details about the app.

Constructors

AppStoreAppDetails({String? contactEmail, String? developerName, String? developerWebsite})
AppStoreAppDetails.fromJson(Map json_)

Properties

contactEmail ↔ String?
The app developer's contact email address.
getter/setter pair
developerName ↔ String?
The app developer's name.
getter/setter pair
developerWebsite ↔ String?
Website link for the developer or app.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited