AppVersionRange class

Data format for a continuous range of app versions.

Constructors

AppVersionRange({String? versionCodeEnd, String? versionCodeStart})
AppVersionRange.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionCodeEnd ↔ String?
Highest app version in the range, inclusive.
getter/setter pair
versionCodeStart ↔ String?
Lowest app version in the range, inclusive.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited