ApplicationsResource class

Constructors

ApplicationsResource(ApiRequester client)

Properties

deviceTierConfigs → ApplicationsDeviceTierConfigsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracks → ApplicationsTracksResource
no setter

Methods

dataSafety(SafetyLabelsUpdateRequest request, String packageName, {String? $fields}) → Future<SafetyLabelsUpdateResponse>
Writes the Safety Labels declaration of an app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited