AppsigningResource class

Constructors

AppsigningResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enrollApp(EnrollAppRequest request, String name, {String? $fields}) Future<EnrollAppResponse>
Enrolls an app in Play App Signing using a self-hosted Google Cloud KMS key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotateAppSigningKey(RotateAppSigningKeyRequest request, String name, {String? $fields}) Future<RotateAppSigningKeyResponse>
Rotates an app's signing key to a new self-hosted Google Cloud KMS key.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited