AppstoreappsreviewResource class

Constructors

AppstoreappsreviewResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createappstorehostedapp(CreateAppStoreHostedAppRequest request, String appStorePackageName, {String? $fields}) Future<SafetyLabelsUpdateResponse>
Creates an app store hosted app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateappstorehostedapp(UpdateAppStoreHostedAppRequest request, String appStorePackageName, {String? $fields}) Future<SafetyLabelsUpdateResponse>
Updates details for an app hosted on an app store.
updateappstorehostedapppublishstatus(UpdateAppStoreHostedAppPublishStatusRequest request, String appStorePackageName, String packageName, {String? $fields}) Future<SafetyLabelsUpdateResponse>
Updates the publish status of an app store hosted app.
uploadapk(UploadApkRequest request, String appStorePackageName, String packageName, {String? $fields, UploadOptions uploadOptions = commons.UploadOptions.defaultOptions, Media? uploadMedia}) Future<UploadApkResponse>
Upload an APK file for the hosted app.
uploadappstoreapppolicydeclarationfile(UploadAppStoreAppPolicyDeclarationFileRequest request, String appStorePackageName, String packageName, {String? $fields, UploadOptions uploadOptions = commons.UploadOptions.defaultOptions, Media? uploadMedia}) Future<UploadAppStoreAppPolicyDeclarationFileResponse>
Upload a policy declaration file for the hosted app.
uploadimage(UploadImageRequest request, String appStorePackageName, String packageName, {String? $fields, UploadOptions uploadOptions = commons.UploadOptions.defaultOptions, Media? uploadMedia}) Future<UploadImageResponse>
Upload a screenshot or app icon for the hosted app.

Operators

operator ==(Object other) bool
The equality operator.
inherited