updateappstorehostedapppublishstatus method
Future<SafetyLabelsUpdateResponse>
updateappstorehostedapppublishstatus(
- UpdateAppStoreHostedAppPublishStatusRequest request,
- String appStorePackageName,
- String packageName, {
- String? $fields,
Updates the publish status of an app store hosted app.
The default state after calling UpdateAppStoreHostedApp is PUBLISHED. It is not necessary to call this RPC explicitly to set an app to PUBLISHED.
request - The metadata request object.
Request parameters:
appStorePackageName - Required. Package name of the third-party app
store.
packageName - Required. Package name of the app.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a UpdateAppStoreHostedAppPublishStatusResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<UpdateAppStoreHostedAppPublishStatusResponse>
updateappstorehostedapppublishstatus(
UpdateAppStoreHostedAppPublishStatusRequest request,
core.String appStorePackageName,
core.String packageName, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'androidpublisher/v3/appstore/' +
commons.escapeVariable('$appStorePackageName') +
'/apps/' +
commons.escapeVariable('$packageName') +
':updateAppStoreHostedAppPublishStatus';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return UpdateAppStoreHostedAppPublishStatusResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}