get method

Future<RecentAppView> get(
  1. String appStorePackageName,
  2. String playAppPackageName, {
  3. String? $fields,
})

Returns metadata about a recently updated app.

Request parameters:

appStorePackageName - Required. The package name of the app store on behalf of which the request is made.

playAppPackageName - Required. The package name of the requested Play app.

$fields - Selector specifying which fields to include in a partial response.

Completes with a RecentAppView.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<RecentAppView> get(
  core.String appStorePackageName,
  core.String playAppPackageName, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'androidpublisher/v3/appstorecatalog/' +
      commons.escapeVariable('$appStorePackageName') +
      '/recentAppViews/' +
      commons.escapeVariable('$playAppPackageName');

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return RecentAppView.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}