AppstorecatalogRecentupdateeventsResource class

Constructors

AppstorecatalogRecentupdateeventsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

list(String appStorePackageName, {String? endTime, int? pageSize, String? pageToken, String? startTime, String? $fields}) Future<ListRecentUpdateEventsResponse>
Lists update events for eligible apps in the given time range.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited