list method

Future<ListRecentUpdateEventsResponse> list(
  1. String appStorePackageName, {
  2. String? endTime,
  3. int? pageSize,
  4. String? pageToken,
  5. String? startTime,
  6. String? $fields,
})

Lists update events for eligible apps in the given time range.

Request parameters:

appStorePackageName - Required. The package name of the app store on behalf of which the request is made.

endTime - Required. The end time of the range (exclusive).

pageSize - Optional. The maximum number of update events to return. The service may return fewer than this value. If unspecified, at most 100 update events will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

pageToken - Optional. A page token, received from a previous ListRecentUpdateEvents call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListRecentUpdateEvents must match the call that provided the page token.

startTime - Required. The start time of the range (inclusive).

$fields - Selector specifying which fields to include in a partial response.

Completes with a ListRecentUpdateEventsResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<ListRecentUpdateEventsResponse> list(
  core.String appStorePackageName, {
  core.String? endTime,
  core.int? pageSize,
  core.String? pageToken,
  core.String? startTime,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'endTime': ?endTime == null ? null : [endTime],
    'pageSize': ?pageSize == null ? null : ['${pageSize}'],
    'pageToken': ?pageToken == null ? null : [pageToken],
    'startTime': ?startTime == null ? null : [startTime],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'androidpublisher/v3/appstorecatalog/' +
      commons.escapeVariable('$appStorePackageName') +
      '/recentUpdateEvents';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return ListRecentUpdateEventsResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}