AssetModuleMetadata class

Metadata of an asset module.

Constructors

AssetModuleMetadata({String? deliveryType, String? name})
AssetModuleMetadata.fromJson(Map json_)

Properties

deliveryType ↔ String?
Indicates the delivery type for persistent install. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Module name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited