AssetSliceSet class

Set of asset slices belonging to a single asset module.

Constructors

AssetSliceSet({List<ApkDescription>? apkDescription, AssetModuleMetadata? assetModuleMetadata})
AssetSliceSet.fromJson(Map json_)

Properties

apkDescription ↔ List<ApkDescription>?
Asset slices.
getter/setter pair
assetModuleMetadata ↔ AssetModuleMetadata?
Module level metadata.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited