AutoRenewingPlan class

Information related to an auto renewing plan.

Constructors

AutoRenewingPlan({bool? autoRenewEnabled, InstallmentPlan? installmentDetails, SubscriptionItemPriceChangeDetails? priceChangeDetails, PriceStepUpConsentDetails? priceStepUpConsentDetails, Money? recurringPrice})
AutoRenewingPlan.fromJson(Map json_)

Properties

autoRenewEnabled ↔ bool?
If the subscription is currently set to auto-renew, e.g. the user has not canceled the subscription
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installmentDetails ↔ InstallmentPlan?
The installment plan commitment and state related info for the auto renewing plan.
getter/setter pair
priceChangeDetails ↔ SubscriptionItemPriceChangeDetails?
The information of the last price change for the item since subscription signup.
getter/setter pair
priceStepUpConsentDetails ↔ PriceStepUpConsentDetails?
The information of the latest price step-up consent.
getter/setter pair
recurringPrice ↔ Money?
The current recurring price of the auto renewing plan.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited