BasePlan class

A single base plan for a subscription.

Constructors

BasePlan({AutoRenewingBasePlanType? autoRenewingBasePlanType, String? basePlanId, InstallmentsBasePlanType? installmentsBasePlanType, List<OfferTag>? offerTags, OtherRegionsBasePlanConfig? otherRegionsConfig, PrepaidBasePlanType? prepaidBasePlanType, List<RegionalBasePlanConfig>? regionalConfigs, String? state})
BasePlan.fromJson(Map json_)

Properties

autoRenewingBasePlanType ↔ AutoRenewingBasePlanType?
Set when the base plan automatically renews at a regular interval.
getter/setter pair
basePlanId ↔ String?
The unique identifier of this base plan.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installmentsBasePlanType ↔ InstallmentsBasePlanType?
Set for installments base plans where a user is committed to a specified number of payments.
getter/setter pair
offerTags ↔ List<OfferTag>?
List of up to 20 custom tags specified for this base plan, and returned to the app through the billing library.
getter/setter pair
otherRegionsConfig ↔ OtherRegionsBasePlanConfig?
Pricing information for any new locations Play may launch in the future.
getter/setter pair
prepaidBasePlanType ↔ PrepaidBasePlanType?
Set when the base plan does not automatically renew at the end of the billing period.
getter/setter pair
regionalConfigs ↔ List<RegionalBasePlanConfig>?
Region-specific information for this base plan.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the base plan, i.e. whether it's active.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited