deliveryToken property
The token used for delivery of the app with the Google Play Inline Install API.
Implementation
core.String? deliveryToken;
The token used for delivery of the app with the Google Play Inline Install API.
core.String? deliveryToken;