CatalogDeviceSelector class

Defines a device selector for a device.

A device is considered matched if it matches any of given the selectors.

Constructors

CatalogDeviceSelector({String? deviceTypeSelector, RamSelector? ramSelector, List<SocSelector>? socSelectors})
CatalogDeviceSelector.fromJson(Map json_)

Properties

deviceTypeSelector String?
The device type selector. Possible string values are:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ramSelector RamSelector?
Defines a RAM selector for a device.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socSelectors List<SocSelector>?
The SOC selectors.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited