socSelectors property
The SOC selectors.
A device matches the device selector if it matches any of the SOC selectors.
Implementation
core.List<SocSelector>? socSelectors;
The SOC selectors.
A device matches the device selector if it matches any of the SOC selectors.
core.List<SocSelector>? socSelectors;