CatalogPermission class
A permission declared by an app.
Constructors
- CatalogPermission({int? maxSdkVersion, String? name})
- CatalogPermission.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxSdkVersion ↔ int?
-
The
maxSdkVersionattribute indicating up to which Android SDK version the permission is requested.getter/setter pair - name ↔ String?
-
The
nameattribute indicating the permission name.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited