CatalogSdkVersion class

Defines a range of SDK versions.

A device is considered compatible uf its\ SDK version falls within the min_sdk_version and max_sdk_version range.

Constructors

CatalogSdkVersion({String? maxSdkVersion, String? minSdkVersion, String? targetSdkVersion})
CatalogSdkVersion.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
maxSdkVersion String?
The maximum SDK version required for the app (inclusive).
getter/setter pair
minSdkVersion String?
The minimum SDK version required for the app (inclusive).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetSdkVersion String?
The target SDK version for the app.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited