CertificateHashes class

Hash digests of a certificate.

Constructors

CertificateHashes({String? certificateHashMd5, String? certificateHashSha1, String? certificateHashSha256})
CertificateHashes.fromJson(Map json_)

Properties

certificateHashMd5 String?
Hex-encoded MD5 hash of the certificate.
getter/setter pair
certificateHashSha1 String?
Hex-encoded SHA1 hash of the certificate.
getter/setter pair
certificateHashSha256 String?
Hex-encoded SHA256 hash of the certificate.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited