CloudKmsKey class

Reference to a private key hosted in developer-managed Google Cloud KMS.

Constructors

CloudKmsKey({String? cryptoKeyVersionResource})
CloudKmsKey.fromJson(Map json_)

Properties

cryptoKeyVersionResource String?
Resource identifier of the private key hosted in Google Cloud KMS.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited