CloudKmsKeyAndCert class
Cloud KMS key and the certificate associated with the key.
Constructors
- CloudKmsKeyAndCert({CloudKmsKey? cloudKmsKey, String? pemCertificate})
- CloudKmsKeyAndCert.fromJson(Map json_)
Properties
- cloudKmsKey ↔ CloudKmsKey?
-
Cloud KMS key.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pemCertificate ↔ String?
-
Certificate associated with the key.
getter/setter pair
-
pemCertificateAsBytes
↔ List<
int> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited