CoarseLocation class
Coarse Geographic location details for where the consumption happened.
Constructors
- CoarseLocation({String? administrativeArea, String? locality, String? regionCode, String? sublocality})
- CoarseLocation.fromJson(Map json_)
Properties
- administrativeArea ↔ String?
-
Highest administrative subdivision which is used for postal addresses of a
country or region.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- locality ↔ String?
-
Generally refers to the city or town portion of the address.
getter/setter pair
- regionCode ↔ String?
-
CLDR region code of the country/region of the
address.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sublocality ↔ String?
-
Sublocality of the address.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited