regionCode property
CLDR region code of the country/region of the address.
This value is never inferred and you must ensure the value is correct. Example: "CH" for Switzerland.
Required.
Implementation
core.String? regionCode;
CLDR region code of the country/region of the address.
This value is never inferred and you must ensure the value is correct. Example: "CH" for Switzerland.
Required.
core.String? regionCode;