sublocality property
Sublocality of the address.
For example, this can be a neighborhood, borough, or district. For most addresses, you can omit this.
Optional.
Implementation
core.String? sublocality;
Sublocality of the address.
For example, this can be a neighborhood, borough, or district. For most addresses, you can omit this.
Optional.
core.String? sublocality;