ConsumptionUsageEvent class

List of events, each representing an instance where the user consumed or used the purchased item or service.

Constructors

ConsumptionUsageEvent({String? consumptionItemDescription, String? consumptionTime, String? ipAddress, CoarseLocation? location, String? obfuscatedAccountId, String? obfuscatedProfileId})
ConsumptionUsageEvent.fromJson(Map json_)

Properties

consumptionItemDescription ↔ String?
Free form text that allows developers to provide more info on the item consumed.
getter/setter pair
consumptionTime ↔ String?
Time when the user consumed, used, downloaded, opened, or streamed the content.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String?
The IP address from which the consumption occurred.
getter/setter pair
location ↔ CoarseLocation?
Geographic location where the consumption occurred.
getter/setter pair
obfuscatedAccountId ↔ String?
Obfuscated string that is uniquely associated with the purchaser's user account in the app.
getter/setter pair
obfuscatedProfileId ↔ String?
Obfuscated string that is uniquely associated with the purchaser's user profile in the app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited