consumptionItemDescription property
Free form text that allows developers to provide more info on the item consumed.
Maximum length is 5000 characters.
Optional.
Implementation
core.String? consumptionItemDescription;
Free form text that allows developers to provide more info on the item consumed.
Maximum length is 5000 characters.
Optional.
core.String? consumptionItemDescription;