consumptionTime property
Time when the user consumed, used, downloaded, opened, or streamed the content.
Optional.
Implementation
core.String? consumptionTime;
Time when the user consumed, used, downloaded, opened, or streamed the content.
Optional.
core.String? consumptionTime;