obfuscatedAccountId property
Obfuscated string that is uniquely associated with the purchaser's user account in the app.
Optional.
Implementation
core.String? obfuscatedAccountId;
Obfuscated string that is uniquely associated with the purchaser's user account in the app.
Optional.
core.String? obfuscatedAccountId;