obfuscatedProfileId property
Obfuscated string that is uniquely associated with the purchaser's user profile in the app.
Optional.
Implementation
core.String? obfuscatedProfileId;
Obfuscated string that is uniquely associated with the purchaser's user profile in the app.
Optional.
core.String? obfuscatedProfileId;