ConvertRegionPricesResponse class

Response message for ConvertRegionPrices.

Constructors

ConvertRegionPricesResponse({ConvertedOtherRegionsPrice? convertedOtherRegionsPrice, Map<String, ConvertedRegionPrice>? convertedRegionPrices, RegionsVersion? regionVersion})
ConvertRegionPricesResponse.fromJson(Map json_)

Properties

convertedOtherRegionsPrice ↔ ConvertedOtherRegionsPrice?
Converted other regions prices in USD and EUR, to use for countries where Play doesn't support a country's local currency.
getter/setter pair
convertedRegionPrices ↔ Map<String, ConvertedRegionPrice>?
Map from region code to converted region price.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
regionVersion ↔ RegionsVersion?
The region version at which the prices were generated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited