CountryTargeting class

Country targeting specification.

Constructors

CountryTargeting({List<String>? countries, bool? includeRestOfWorld})
CountryTargeting.fromJson(Map json_)

Properties

countries ↔ List<String>?
Countries to target, specified as two letter CLDR codes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeRestOfWorld ↔ bool?
Include "rest of world" as well as explicitly targeted countries.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited