CreateAppStoreHostedAppResponse typedef
CreateAppStoreHostedAppResponse = $Empty
Response for creating a new app record for an app store hosted app.
Implementation
typedef CreateAppStoreHostedAppResponse = $Empty;
Response for creating a new app record for an app store hosted app.
typedef CreateAppStoreHostedAppResponse = $Empty;