DeactivatePurchaseOptionRequest class

Request message for UpdatePurchaseOptionState.

Constructors

DeactivatePurchaseOptionRequest({String? latencyTolerance, String? packageName, String? productId, String? purchaseOptionId})
DeactivatePurchaseOptionRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
latencyTolerance ↔ String?
The latency tolerance for the propagation of this product update.
getter/setter pair
packageName ↔ String?
The parent app (package name) of the purchase option to deactivate.
getter/setter pair
productId ↔ String?
The parent one-time product (ID) of the purchase option to deactivate.
getter/setter pair
purchaseOptionId ↔ String?
The purchase option ID of the purchase option to deactivate.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited