DeleteOneTimeProductRequest class

Request message for deleting a one-time product.

Constructors

DeleteOneTimeProductRequest({String? latencyTolerance, String? packageName, String? productId})
DeleteOneTimeProductRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
latencyTolerance ↔ String?
The latency tolerance for the propagation of this product update.
getter/setter pair
packageName ↔ String?
The parent app (package name) of the one-time product to delete.
getter/setter pair
productId ↔ String?
The one-time product ID of the one-time product to delete.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited