DeveloperComment class

Developer entry from conversation between user and developer.

Constructors

DeveloperComment({Timestamp? lastModified, String? text})
DeveloperComment.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastModified ↔ Timestamp?
The last time at which this comment was updated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The content of the comment, i.e. reply body.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited