DeveloperDetails class

The developer details of a Google Play app.

Constructors

DeveloperDetails({String? address, String? contactEmail, String? developerName, String? phoneNumber, String? website})
DeveloperDetails.fromJson(Map json_)

Properties

address ↔ String?
The physical address of the developer.
getter/setter pair
contactEmail ↔ String?
The contact email of the developer.
getter/setter pair
developerName ↔ String?
The developer name of the app.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber ↔ String?
The phone number of the developer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
website ↔ String?
The website of the developer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited