usesConfigurations property

List<UsesConfiguration>? usesConfigurations
getter/setter pair

Lists all configurations marked as required by use of the uses-configuration manifest tag.

Each instance of this proto represents a single uses-configuration entry. See http://developer.android.com/guide/topics/manifest/uses-configuration-element.html

Implementation

core.List<UsesConfiguration>? usesConfigurations;