DeviceFeature class

Represents a device feature.

Constructors

DeviceFeature({String? featureName, int? featureVersion})
DeviceFeature.fromJson(Map json_)

Properties

featureName ↔ String?
Name of the feature.
getter/setter pair
featureVersion ↔ int?
The feature version specified by android:glEsVersion or android:version in in the AndroidManifest.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited