DeviceId class

Identifier of a device.

Constructors

DeviceId({String? buildBrand, String? buildDevice})
DeviceId.fromJson(Map json_)

Properties

buildBrand ↔ String?
Value of Build.BRAND.
getter/setter pair
buildDevice ↔ String?
Value of Build.DEVICE.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited