DeviceRam class

Conditions about a device's RAM capabilities.

Constructors

DeviceRam({String? maxBytes, String? minBytes})
DeviceRam.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxBytes ↔ String?
Maximum RAM in bytes (bound excluded).
getter/setter pair
minBytes ↔ String?
Minimum RAM in bytes (bound included).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited