DeviceTierConfig class

Configuration describing device targeting criteria for the content of an app.

Constructors

DeviceTierConfig({List<DeviceGroup>? deviceGroups, String? deviceTierConfigId, DeviceTierSet? deviceTierSet, List<UserCountrySet>? userCountrySets})
DeviceTierConfig.fromJson(Map json_)

Properties

deviceGroups ↔ List<DeviceGroup>?
Definition of device groups for the app.
getter/setter pair
deviceTierConfigId ↔ String?
The device tier config ID.
getter/setter pair
deviceTierSet ↔ DeviceTierSet?
Definition of the set of device tiers for the app.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userCountrySets ↔ List<UserCountrySet>?
Definition of user country sets for the app.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited