EditsImagesResource class

Constructors

EditsImagesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String packageName, String editId, String language, String imageType, String imageId, {String? $fields}) → Future<void>
Deletes the image (specified by id) from the edit.
deleteall(String packageName, String editId, String language, String imageType, {String? $fields}) → Future<ImagesDeleteAllResponse>
Deletes all images for the specified language and image type.
list(String packageName, String editId, String language, String imageType, {String? $fields}) → Future<ImagesListResponse>
Lists all images.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upload(String packageName, String editId, String language, String imageType, {String? aiGeneratedState, String? $fields, UploadOptions uploadOptions = commons.UploadOptions.defaultOptions, Media? uploadMedia}) → Future<ImagesUploadResponse>
Uploads an image of the specified language and image type, and adds to the edit.

Operators

operator ==(Object other) → bool
The equality operator.
inherited