EditsResource class

Constructors

EditsResource(ApiRequester client)

Properties

apks → EditsApksResource
no setter
bundles → EditsBundlesResource
no setter
countryavailability → EditsCountryavailabilityResource
no setter
deobfuscationfiles → EditsDeobfuscationfilesResource
no setter
details → EditsDetailsResource
no setter
expansionfiles → EditsExpansionfilesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
images → EditsImagesResource
no setter
listings → EditsListingsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testers → EditsTestersResource
no setter
tracks → EditsTracksResource
no setter

Methods

commit(String packageName, String editId, {String? changesInReviewBehavior, bool? changesNotSentForReview, String? $fields}) → Future<AppEdit>
Commits an app edit.
delete(String packageName, String editId, {String? $fields}) → Future<void>
Deletes an app edit.
get(String packageName, String editId, {String? $fields}) → Future<AppEdit>
Gets an app edit.
insert(AppEdit request, String packageName, {String? $fields}) → Future<AppEdit>
Creates a new edit for an app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validate(String packageName, String editId, {String? $fields}) → Future<AppEdit>
Validates an app edit.

Operators

operator ==(Object other) → bool
The equality operator.
inherited