EnrollAppRequest class

Request to enroll an app into Play App Signing using a self-hosted Cloud KMS key.

Constructors

EnrollAppRequest({EnrollExistingApp? enrollExistingApp, EnrollNewApp? enrollNewApp, String? pemUploadCertificate})
EnrollAppRequest.fromJson(Map json_)

Properties

enrollExistingApp ↔ EnrollExistingApp?
Enrolls an existing app into Play signing using an external Cloud KMS key.
getter/setter pair
enrollNewApp ↔ EnrollNewApp?
Changes the signing key of a new app to an external Cloud KMS key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pemUploadCertificate ↔ String?
The certificate associated with the upload key, in PEM format.
getter/setter pair
pemUploadCertificateAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited