enrollNewApp property

EnrollNewApp? enrollNewApp
getter/setter pair

Changes the signing key of a new app to an external Cloud KMS key.

The app must not have published to Open testing or Production tracks.

Implementation

EnrollNewApp? enrollNewApp;