EnrollAppResponse class
Response to enroll an app into Play signing.
Constructors
- EnrollAppResponse({CertificateHashes? signingCertificate, CertificateHashes? uploadCertificate})
- EnrollAppResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signingCertificate ↔ CertificateHashes?
-
The signing certificate hashes for the app.
getter/setter pair
- uploadCertificate ↔ CertificateHashes?
-
The upload certificate hashes for the app.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited