cloudKmsKeyAndCert property
Self-hosted key.
Once enrolled, this key will be used to sign your app.
Required.
Implementation
CloudKmsKeyAndCert? cloudKmsKeyAndCert;
Self-hosted key.
Once enrolled, this key will be used to sign your app.
Required.
CloudKmsKeyAndCert? cloudKmsKeyAndCert;