ExpansionFile class

An expansion file.

The resource for ExpansionFilesService.

Constructors

ExpansionFile({String? fileSize, int? referencesVersion})
ExpansionFile.fromJson(Map json_)

Properties

fileSize ↔ String?
If set, this field indicates that this APK has an expansion file uploaded to it: this APK does not reference another APK's expansion file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
referencesVersion ↔ int?
If set, this APK's expansion file references another APK's expansion file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited