ExternalAccountIdentifiers class

User account identifier in the third-party service.

Constructors

ExternalAccountIdentifiers({String? externalAccountId, String? obfuscatedExternalAccountId, String? obfuscatedExternalProfileId})
ExternalAccountIdentifiers.fromJson(Map json_)

Properties

externalAccountId ↔ String?
User account identifier in the third-party service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
obfuscatedExternalAccountId ↔ String?
An obfuscated version of the id that is uniquely associated with the user's account in your app.
getter/setter pair
obfuscatedExternalProfileId ↔ String?
An obfuscated version of the id that is uniquely associated with the user's profile in your app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited