ExternallyHostedApk class

Defines an APK available for this application that is hosted externally and not uploaded to Google Play.

This function is only available to organizations using Managed Play whose application is configured to restrict distribution to the organizations.

Constructors

ExternallyHostedApk({String? applicationLabel, List<String>? certificateBase64s, String? externallyHostedUrl, String? fileSha1Base64, String? fileSha256Base64, String? fileSize, String? iconBase64, int? maximumSdk, int? minimumSdk, List<String>? nativeCodes, String? packageName, List<String>? usesFeatures, List<UsesPermission>? usesPermissions, int? versionCode, String? versionName})
ExternallyHostedApk.fromJson(Map json_)

Properties

applicationLabel ↔ String?
The application label.
getter/setter pair
certificateBase64s ↔ List<String>?
A certificate (or array of certificates if a certificate-chain is used) used to sign this APK, represented as a base64 encoded byte array.
getter/setter pair
externallyHostedUrl ↔ String?
The URL at which the APK is hosted.
getter/setter pair
fileSha1Base64 ↔ String?
The sha1 checksum of this APK, represented as a base64 encoded byte array.
getter/setter pair
fileSha256Base64 ↔ String?
The sha256 checksum of this APK, represented as a base64 encoded byte array.
getter/setter pair
fileSize ↔ String?
The file size in bytes of this APK.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconBase64 ↔ String?
The icon image from the APK, as a base64 encoded byte array.
getter/setter pair
maximumSdk ↔ int?
The maximum SDK supported by this APK (optional).
getter/setter pair
minimumSdk ↔ int?
The minimum SDK targeted by this APK.
getter/setter pair
nativeCodes ↔ List<String>?
The native code environments supported by this APK (optional).
getter/setter pair
packageName ↔ String?
The package name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usesFeatures ↔ List<String>?
The features required by this APK (optional).
getter/setter pair
usesPermissions ↔ List<UsesPermission>?
The permissions requested by this APK.
getter/setter pair
versionCode ↔ int?
The version code of this APK.
getter/setter pair
versionName ↔ String?
The version name of this APK.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited