unprotectedGeneratedSplitApks property

List<GeneratedSplitApk>? unprotectedGeneratedSplitApks
getter/setter pair

List of generated split APKs without automatic protection, signed with a key corresponding to certificate_sha256_hash.

This field is only present if the app uses automatic protection. In this case, generated_split_apks contains APKs with automatic protection enabled, whereas this field contains APKs without automatic protection.

Implementation

core.List<GeneratedSplitApk>? unprotectedGeneratedSplitApks;