GeneratedSplitApk class

Download metadata for a split APK.

Constructors

GeneratedSplitApk({String? downloadId, String? moduleName, String? splitId, int? variantId})
GeneratedSplitApk.fromJson(Map json_)

Properties

downloadId ↔ String?
Download ID, which uniquely identifies the APK to download.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
moduleName ↔ String?
Name of the module that this APK belongs to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splitId ↔ String?
Split ID.
getter/setter pair
variantId ↔ int?
ID of the generated variant.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited