GetOneTimeProductOfferRequest class

Request message for GetOneTimeProductOffers.

Constructors

GetOneTimeProductOfferRequest({String? offerId, String? packageName, String? productId, String? purchaseOptionId})
GetOneTimeProductOfferRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
offerId ↔ String?
The unique offer ID of the offer to get.
getter/setter pair
packageName ↔ String?
The parent app (package name) of the offer to get.
getter/setter pair
productId ↔ String?
The parent one-time product (ID) of the offer to get.
getter/setter pair
purchaseOptionId ↔ String?
The parent purchase option (ID) of the offer to get.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited