InAppProduct class

An in-app product.

The resource for InappproductsService.

Constructors

InAppProduct({String? defaultLanguage, Price? defaultPrice, String? gracePeriod, Map<String, InAppProductListing>? listings, ManagedProductTaxAndComplianceSettings? managedProductTaxesAndComplianceSettings, String? packageName, Map<String, Price>? prices, String? purchaseType, String? sku, String? status, String? subscriptionPeriod, SubscriptionTaxAndComplianceSettings? subscriptionTaxesAndComplianceSettings, String? trialPeriod})
InAppProduct.fromJson(Map json_)

Properties

defaultLanguage ↔ String?
Default language of the localized data, as defined by BCP-47.
getter/setter pair
defaultPrice ↔ Price?
Default price.
getter/setter pair
gracePeriod ↔ String?
Grace period of the subscription, specified in ISO 8601 format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listings ↔ Map<String, InAppProductListing>?
List of localized title and description data.
getter/setter pair
managedProductTaxesAndComplianceSettings ↔ ManagedProductTaxAndComplianceSettings?
Details about taxes and legal compliance.
getter/setter pair
packageName ↔ String?
Package name of the parent app.
getter/setter pair
prices ↔ Map<String, Price>?
Prices per buyer region.
getter/setter pair
purchaseType ↔ String?
The type of the product, e.g. a recurring subscription. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String?
Stock-keeping-unit (SKU) of the product, unique within an app.
getter/setter pair
status ↔ String?
The status of the product, e.g. whether it's active. Possible string values are:
getter/setter pair
subscriptionPeriod ↔ String?
Subscription period, specified in ISO 8601 format.
getter/setter pair
subscriptionTaxesAndComplianceSettings ↔ SubscriptionTaxAndComplianceSettings?
Details about taxes and legal compliance.
getter/setter pair
trialPeriod ↔ String?
Trial period, specified in ISO 8601 format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited