InGracePeriodStateContext class
Additional context around subscriptions in IN_GRACE_PERIOD state.
Constructors
- InGracePeriodStateContext({RenewalDeclinedContext? renewalDeclined})
- InGracePeriodStateContext.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- renewalDeclined ↔ RenewalDeclinedContext?
-
The payment for the renewal was declined.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited