InappproductsDeleteRequest class

Request to delete an in-app product.

Constructors

InappproductsDeleteRequest({String? latencyTolerance, String? packageName, String? sku})
InappproductsDeleteRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
latencyTolerance ↔ String?
The latency tolerance for the propagation of this product update.
getter/setter pair
packageName ↔ String?
Package name of the app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String?
Unique identifier for the in-app product.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited