InappproductsUpdateRequest class

Request to update an in-app product.

Constructors

InappproductsUpdateRequest({bool? allowMissing, bool? autoConvertMissingPrices, InAppProduct? inappproduct, String? latencyTolerance, String? packageName, String? sku})
InappproductsUpdateRequest.fromJson(Map json_)

Properties

allowMissing ↔ bool?
If set to true, and the in-app product with the given package_name and sku doesn't exist, the in-app product will be created.
getter/setter pair
autoConvertMissingPrices ↔ bool?
If true the prices for all regions targeted by the parent app that don't have a price specified for this in-app product will be auto converted to the target currency based on the default price.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inappproduct ↔ InAppProduct?
The new in-app product.
getter/setter pair
latencyTolerance ↔ String?
The latency tolerance for the propagation of this product update.
getter/setter pair
packageName ↔ String?
Package name of the app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String?
Unique identifier for the in-app product.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited