InstallmentPlan class

Information to a installment plan.

Constructors

InstallmentPlan({int? initialCommittedPaymentsCount, PendingCancellation? pendingCancellation, int? remainingCommittedPaymentsCount, int? subsequentCommittedPaymentsCount})
InstallmentPlan.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialCommittedPaymentsCount ↔ int?
Total number of payments the user is initially committed for.
getter/setter pair
pendingCancellation ↔ DeveloperInitiatedCancellation?
If present, this installment plan is pending to be canceled.
getter/setter pair
remainingCommittedPaymentsCount ↔ int?
Total number of committed payments remaining to be paid for in this renewal cycle.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subsequentCommittedPaymentsCount ↔ int?
Total number of payments the user will be committed for after each commitment period.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited