InstallmentsBasePlanType class

Represents an installments base plan where a user commits to a specified number of payments.

Constructors

InstallmentsBasePlanType({String? accountHoldDuration, String? billingPeriodDuration, int? committedPaymentsCount, String? gracePeriodDuration, String? prorationMode, String? renewalType, String? resubscribeState})
InstallmentsBasePlanType.fromJson(Map json_)

Properties

accountHoldDuration ↔ String?
Custom account hold period of the subscription, specified in ISO 8601 format.
getter/setter pair
billingPeriodDuration ↔ String?
Subscription period, specified in ISO 8601 format.
getter/setter pair
committedPaymentsCount ↔ int?
The number of payments the user is committed to.
getter/setter pair
gracePeriodDuration ↔ String?
Grace period of the subscription, specified in ISO 8601 format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
prorationMode ↔ String?
The proration mode for the base plan determines what happens when a user switches to this plan from another base plan.
getter/setter pair
renewalType ↔ String?
Installments base plan renewal type.
getter/setter pair
resubscribeState ↔ String?
Whether users should be able to resubscribe to this base plan in Google Play surfaces.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited