InternalappsharingartifactsResource class

Constructors

InternalappsharingartifactsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
uploadapk(String packageName, {String? $fields, UploadOptions uploadOptions = commons.UploadOptions.defaultOptions, Media? uploadMedia}) → Future<InternalAppSharingArtifact>
Uploads an APK to internal app sharing.
uploadbundle(String packageName, {String? $fields, UploadOptions uploadOptions = commons.UploadOptions.defaultOptions, Media? uploadMedia}) → Future<InternalAppSharingArtifact>
Uploads an app bundle to internal app sharing.

Operators

operator ==(Object other) → bool
The equality operator.
inherited