ItemReplacement class

Details about a subscription line item that is being replaced.

Constructors

ItemReplacement({String? basePlanId, String? offerId, String? productId, String? replacementMode})
ItemReplacement.fromJson(Map json_)

Properties

basePlanId ↔ String?
The base plan ID of the subscription line item being replaced.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offerId ↔ String?
The offer ID of the subscription line item being replaced, if applicable.
getter/setter pair
productId ↔ String?
The product ID of the subscription line item being replaced.
getter/setter pair
replacementMode ↔ String?
The replacement mode applied during the purchase. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited