LineItem class

Details of a line item.

Constructors

LineItem({Money? listingPrice, OneTimePurchaseDetails? oneTimePurchaseDetails, PaidAppDetails? paidAppDetails, String? productId, String? productTitle, SubscriptionDetails? subscriptionDetails, Money? tax, Money? total})
LineItem.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
listingPrice ↔ Money?
Item's listed price on Play Store, this may or may not include tax.
getter/setter pair
oneTimePurchaseDetails ↔ OneTimePurchaseDetails?
Details of a one-time purchase.
getter/setter pair
paidAppDetails ↔ DeveloperInitiatedCancellation?
Details of a paid app purchase.
getter/setter pair
productId ↔ String?
The purchased product ID or in-app SKU (for example, 'monthly001' or 'com.some.thing.inapp1').
getter/setter pair
productTitle ↔ String?
Developer-specified name of the product.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionDetails ↔ SubscriptionDetails?
Details of a subscription purchase.
getter/setter pair
tax ↔ Money?
The tax paid for this line item.
getter/setter pair
total ↔ Money?
The total amount paid by the user for this line item, taking into account discounts and tax.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited