ListReleaseSummariesResponse class

Response listing all releases for a given track that are either ready to be sent for review, in review, approved, not approved or available.

Properties

hashCode int
The hash code for this object.
no setterinherited
releases List<ReleaseSummary>?
List of releases for this track.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited