Listing class

A localized store listing.

The resource for ListingsService.

Constructors

Listing({String? fullDescription, String? language, String? shortDescription, String? title, String? video})
Listing.fromJson(Map json_)

Properties

fullDescription ↔ String?
Full description of the app.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
language ↔ String?
Language localization code (a BCP-47 language tag; for example, "de-AT" for Austrian German).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortDescription ↔ String?
Short description of the app.
getter/setter pair
title ↔ String?
Localized title of the app.
getter/setter pair
video ↔ String?
URL of a promotional YouTube video for the app.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited