LocalizedStoreListings class

The localized store listings of an app.

Constructors

LocalizedStoreListings({String? defaultLanguageCode, List<LocalizedStoreListing>? localizedStoreListings})
LocalizedStoreListings.fromJson(Map json_)

Properties

defaultLanguageCode String?
The default language code of the app.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
localizedStoreListings List<LocalizedStoreListing>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited