ModuleTargeting class

Targeting on the module level.

Constructors

ModuleTargeting({List<DeviceFeatureTargeting>? deviceFeatureTargeting, SdkVersionTargeting? sdkVersionTargeting, UserCountriesTargeting? userCountriesTargeting})
ModuleTargeting.fromJson(Map json_)

Properties

deviceFeatureTargeting ↔ List<DeviceFeatureTargeting>?
Targeting for device features.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdkVersionTargeting ↔ SdkVersionTargeting?
The sdk version that the variant targets
getter/setter pair
userCountriesTargeting ↔ UserCountriesTargeting?
Countries-level targeting
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited