MonetizationResource class

Constructors

MonetizationResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onetimeproducts → MonetizationOnetimeproductsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptions → MonetizationSubscriptionsResource
no setter

Methods

convertRegionPrices(ConvertRegionPricesRequest request, String packageName, {String? $fields}) → Future<ConvertRegionPricesResponse>
Calculates the region prices, using today's exchange rate and country-specific pricing patterns, based on the price in the request for a set of regions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited