MultiAbi class

Represents a list of ABIs.

Constructors

MultiAbi({List<Abi>? abi})
MultiAbi.fromJson(Map json_)

Properties

abi ↔ List<Abi>?
A list of targeted ABIs, as represented by the Android Platform
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited