NestedPolicyResponse class

An individual nested response to a policy question about an app.

Nested responses are like regular responses but without groups.

Constructors

NestedPolicyResponse({PolicyBooleanResponse? booleanResponse, PolicyDocumentResponse? documentResponse, PolicyMultipleChoiceResponse? multipleChoiceResponse, String? questionId, PolicySingleChoiceResponse? singleChoiceResponse, PolicyStringResponse? stringResponse})
NestedPolicyResponse.fromJson(Map json_)

Properties

booleanResponse ↔ PolicyBooleanResponse?
A boolean response.
getter/setter pair
documentResponse ↔ PolicyDocumentResponse?
A document response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
multipleChoiceResponse ↔ PolicyMultipleChoiceResponse?
A multiple choice response.
getter/setter pair
questionId ↔ String?
ID of the question being answered.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleChoiceResponse ↔ PolicySingleChoiceResponse?
A single choice response.
getter/setter pair
stringResponse ↔ PolicyStringResponse?
A string response.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited