OfferPhase class

Offer phase details.

Constructors

OfferPhase({BasePriceOfferPhase? basePrice, FreeTrialOfferPhase? freeTrial, IntroductoryPriceOfferPhase? introductoryPrice, ProrationPeriodOfferPhase? prorationPeriod})
OfferPhase.fromJson(Map json_)

Properties

basePrice ↔ DeveloperInitiatedCancellation?
Set when the offer phase is a base plan pricing phase.
getter/setter pair
freeTrial ↔ DeveloperInitiatedCancellation?
Set when the offer phase is a free trial.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
introductoryPrice ↔ DeveloperInitiatedCancellation?
Set when the offer phase is an introductory price offer phase.
getter/setter pair
prorationPeriod ↔ ProrationPeriodOfferPhase?
Set when the offer phase is a proration period.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited