OneTimeProductOffer class

A single offer for a one-time product.

Constructors

OneTimeProductOffer({OneTimeProductDiscountedOffer? discountedOffer, String? offerId, List<OfferTag>? offerTags, String? packageName, OneTimeProductPreOrderOffer? preOrderOffer, String? productId, String? purchaseOptionId, List<OneTimeProductOfferRegionalPricingAndAvailabilityConfig>? regionalPricingAndAvailabilityConfigs, RegionsVersion? regionsVersion, String? state})
OneTimeProductOffer.fromJson(Map json_)

Properties

discountedOffer ↔ OneTimeProductDiscountedOffer?
A discounted offer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offerId ↔ String?
The ID of this product offer.
getter/setter pair
offerTags ↔ List<OfferTag>?
List of up to 20 custom tags specified for this offer, and returned to the app through the billing library.
getter/setter pair
packageName ↔ String?
The package name of the app the parent product belongs to.
getter/setter pair
preOrderOffer ↔ OneTimeProductPreOrderOffer?
A pre-order offer.
getter/setter pair
productId ↔ String?
The ID of the parent product this offer belongs to.
getter/setter pair
purchaseOptionId ↔ String?
The ID of the purchase option to which this offer is an extension.
getter/setter pair
regionalPricingAndAvailabilityConfigs ↔ List<OneTimeProductOfferRegionalPricingAndAvailabilityConfig>?
Set of regional pricing and availability information for this offer.
getter/setter pair
regionsVersion ↔ RegionsVersion?
The version of the regions configuration that was used to generate the one-time product offer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of this offer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited