OneTimeProductPurchaseOption class

A single purchase option for a one-time product.

Properties

buyOption ↔ OneTimeProductBuyPurchaseOption?
A purchase option that can be bought.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newRegionsConfig ↔ OneTimeProductPurchaseOptionNewRegionsConfig?
Pricing information for any new locations Play may launch in the future.
getter/setter pair
offerTags ↔ List<OfferTag>?
List of up to 20 custom tags specified for this purchase option, and returned to the app through the billing library.
getter/setter pair
purchaseOptionId ↔ String?
The unique identifier of this purchase option.
getter/setter pair
regionalPricingAndAvailabilityConfigs ↔ List<OneTimeProductPurchaseOptionRegionalPricingAndAvailabilityConfig>?
Regional pricing and availability information for this purchase option.
getter/setter pair
rentOption ↔ OneTimeProductRentPurchaseOption?
A purchase option that can be rented.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the purchase option, i.e., whether it's active.
getter/setter pair
taxAndComplianceSettings ↔ PurchaseOptionTaxAndComplianceSettings?
Details about taxes and legal compliance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited