preorderDetails property
The details of a pre-order purchase.
Only set if it is a pre-order purchase. Note that this field will be set even after pre-order is fulfilled.
Implementation
PreorderDetails? preorderDetails;
The details of a pre-order purchase.
Only set if it is a pre-order purchase. Note that this field will be set even after pre-order is fulfilled.
PreorderDetails? preorderDetails;