OrderHistory class

Details about events which modified the order.

Constructors

OrderHistory({CancellationEvent? cancellationEvent, List<PartialRefundEvent>? partialRefundEvents, ProcessedEvent? processedEvent, RefundEvent? refundEvent})
OrderHistory.fromJson(Map json_)

Properties

cancellationEvent ↔ CancellationEvent?
Details of when the order was canceled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partialRefundEvents ↔ List<PartialRefundEvent>?
Details of the partial refund events for this order.
getter/setter pair
processedEvent ↔ ProcessedEvent?
Details of when the order was processed.
getter/setter pair
refundEvent ↔ RefundEvent?
Details of when the order was fully refunded.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited