OrdersReviewRefundRequest class

Request for the orders.reviewrefund API.

Constructors

OrdersReviewRefundRequest({int? consumptionPercentageMilliunits, List<ConsumptionUsageEvent>? consumptionUsageEvents, String? pendingRefundToken, String? refundPreference, bool? sampleContentProvided})
OrdersReviewRefundRequest.fromJson(Map json_)

Properties

consumptionPercentageMilliunits int?
Percentage of the In-App purchase the customer consumed, in milliunits.
getter/setter pair
consumptionUsageEvents List<ConsumptionUsageEvent>?
List of events, each representing an instance where the user consumed or used the purchased item or service.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pendingRefundToken String?
The pending refund token included in the pending refund review notification.
getter/setter pair
refundPreference String?
Indicates your preference, based on your operational logic, as to whether the Play Store should grant the refund.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleContentProvided bool?
Indicates whether you provided a free sample, trial, or information about the functionality prior to the purchase.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited