pendingRefundToken property
The pending refund token included in the pending refund review notification.
Required.
Implementation
core.String? pendingRefundToken;
The pending refund token included in the pending refund review notification.
Required.
core.String? pendingRefundToken;