OtherRegionsBasePlanConfig class

Pricing information for any new locations Play may launch in.

Constructors

OtherRegionsBasePlanConfig({Money? eurPrice, bool? newSubscriberAvailability, Money? usdPrice})
OtherRegionsBasePlanConfig.fromJson(Map json_)

Properties

eurPrice ↔ Money?
Price in EUR to use for any new locations Play may launch in.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newSubscriberAvailability ↔ bool?
Whether the base plan is available for new subscribers in any new locations Play may launch in.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usdPrice ↔ Money?
Price in USD to use for any new locations Play may launch in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited