PartialRefund class

A partial refund of a transaction.

Constructors

PartialRefund({String? refundId, Price? refundPreTaxAmount})
PartialRefund.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
refundId ↔ String?
A unique id distinguishing this partial refund.
getter/setter pair
refundPreTaxAmount ↔ Price?
The pre-tax amount of the partial refund.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited