Price class

Definition of a price, i.e. currency and units.

Constructors

Price({String? currency, String? priceMicros})
Price.fromJson(Map json_)

Properties

currency ↔ String?
3 letter Currency code, as defined by ISO 4217.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
priceMicros ↔ String?
Price in 1/million of the currency base unit, represented as a string.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited