ProductPurchase class

A ProductPurchase resource indicates the status of a user's inapp product purchase.

Constructors

ProductPurchase({int? acknowledgementState, int? consumptionState, String? developerPayload, String? kind, String? obfuscatedExternalAccountId, String? obfuscatedExternalProfileId, String? orderId, String? productId, int? purchaseState, String? purchaseTimeMillis, String? purchaseToken, int? purchaseType, int? quantity, int? refundableQuantity, String? regionCode})
ProductPurchase.fromJson(Map json_)

Properties

acknowledgementState ↔ int?
The acknowledgement state of the inapp product.
getter/setter pair
consumptionState ↔ int?
The consumption state of the inapp product.
getter/setter pair
developerPayload ↔ String?
A developer-specified string that contains supplemental information about an order.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
This kind represents an inappPurchase object in the androidpublisher service.
getter/setter pair
obfuscatedExternalAccountId ↔ String?
An obfuscated version of the id that is uniquely associated with the user's account in your app.
getter/setter pair
obfuscatedExternalProfileId ↔ String?
An obfuscated version of the id that is uniquely associated with the user's profile in your app.
getter/setter pair
orderId ↔ String?
The order id associated with the purchase of the inapp product.
getter/setter pair
productId ↔ String?
The inapp product SKU.
getter/setter pair
purchaseState ↔ int?
The purchase state of the order.
getter/setter pair
purchaseTimeMillis ↔ String?
The time the product was purchased, in milliseconds since the epoch (Jan 1, 1970).
getter/setter pair
purchaseToken ↔ String?
The purchase token generated to identify this purchase.
getter/setter pair
purchaseType ↔ int?
The type of purchase of the inapp product.
getter/setter pair
quantity ↔ int?
The quantity associated with the purchase of the inapp product.
getter/setter pair
refundableQuantity ↔ int?
The quantity eligible for refund, i.e. quantity that hasn't been refunded.
getter/setter pair
regionCode ↔ String?
ISO 3166-1 alpha-2 billing region code of the user at the time the product was granted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited