PurchasesSubscriptionsResource class

Constructors

PurchasesSubscriptionsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acknowledge(SubscriptionPurchasesAcknowledgeRequest request, String packageName, String subscriptionId, String token, {String? $fields}) Future<void>
Acknowledges a subscription purchase.
cancel(String packageName, String subscriptionId, String token, {String? $fields}) Future<void>
Deprecated: Use purchases.subscriptionsv2.cancel instead.
defer(SubscriptionPurchasesDeferRequest request, String packageName, String subscriptionId, String token, {String? $fields}) Future<SubscriptionPurchasesDeferResponse>
Deprecated: Use purchases.subscriptionsv2.defer instead.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited