RamSelector class
Defines a RAM selector for a device.
Constructors
- RamSelector({String? ramMbLessThanOrEqual})
- RamSelector.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ramMbLessThanOrEqual ↔ String?
-
This will match any device that has less than or equal
ram_mb_less_than_or_equal mb of RAM.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited