RecentUpdateEvent class
A recent update event.
Constructors
- RecentUpdateEvent({String? eventTime, String? playAppPackageName, String? updateType})
- RecentUpdateEvent.fromJson(Map json_)
Properties
- eventTime ↔ String?
-
The timestamp of the update.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- playAppPackageName ↔ String?
-
The package name of the app.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateType ↔ String?
-
The type of the update event.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited