RegionalSubscriptionOfferPhaseConfig class

Configuration for a single phase of a subscription offer in a single region.

Properties

absoluteDiscount ↔ Money?
The absolute amount of money subtracted from the base plan price prorated over the phase duration that the user pays for this offer phase.
getter/setter pair
free ↔ DeveloperInitiatedCancellation?
Set to specify this offer is free to obtain.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
price ↔ Money?
The absolute price the user pays for this offer phase.
getter/setter pair
regionCode ↔ String?
The region to which this config applies.
getter/setter pair
relativeDiscount ↔ double?
The fraction of the base plan price prorated over the phase duration that the user pays for this offer phase.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited