ReleaseSummary class
Summary of a release.
Constructors
-
ReleaseSummary({List<
ArtifactSummary> ? activeArtifacts, String? releaseLifecycleState, String? releaseName, String? track}) - ReleaseSummary.fromJson(Map json_)
Properties
-
activeArtifacts
↔ List<
ArtifactSummary> ? -
List of active artifacts on this release
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- releaseLifecycleState ↔ String?
-
The lifecycle state of a release.
Possible string values are:
getter/setter pair
- releaseName ↔ String?
-
Name of the release.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- track ↔ String?
-
Identifier for the track.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited