RemoteInAppUpdate class

Object representation for Remote in-app update action type.

Constructors

RemoteInAppUpdate({bool? isRemoteInAppUpdateRequested})
RemoteInAppUpdate.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRemoteInAppUpdateRequested ↔ bool?
Set to true if Remote In-App Update action type is needed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited