RemoteInAppUpdateDataPerBundle class

Data related to the recovery action at bundle level.

Constructors

RemoteInAppUpdateDataPerBundle({String? recoveredDeviceCount, String? totalDeviceCount, String? versionCode})
RemoteInAppUpdateDataPerBundle.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
recoveredDeviceCount ↔ String?
Total number of devices which have been rescued.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalDeviceCount ↔ String?
Total number of devices affected by this recovery action associated with bundle of the app.
getter/setter pair
versionCode ↔ String?
Version Code corresponding to the target bundle.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited