Review class

An Android app review.

Constructors

Review({String? authorName, List<Comment>? comments, String? reviewId})
Review.fromJson(Map json_)

Properties

authorName ↔ String?
The name of the user who wrote the review.
getter/setter pair
comments ↔ List<Comment>?
A repeated field containing comments for the review.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reviewId ↔ String?
Unique identifier for this review.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited