ReviewsReplyRequest class

Request to reply to review or update existing reply.

Constructors

ReviewsReplyRequest({String? replyText})
ReviewsReplyRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
replyText ↔ String?
The text to set as the reply.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited