RotateAppSigningKeyRequest class
Request to rotate an app's signing key.
Constructors
- RotateAppSigningKeyRequest({String? keyRotationReason, RotatedCloudKmsKey? rotatedCloudKmsKey})
- RotateAppSigningKeyRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyRotationReason ↔ String?
-
Reason for rotating the app key.
getter/setter pair
- rotatedCloudKmsKey ↔ RotatedCloudKmsKey?
-
Self-hosted Cloud KMS key.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited