cloudKmsKeyAndCert property
Cloud KMS key and the certificate associated with the key.
Required.
Implementation
CloudKmsKeyAndCert? cloudKmsKeyAndCert;
Cloud KMS key and the certificate associated with the key.
Required.
CloudKmsKeyAndCert? cloudKmsKeyAndCert;