ScreenDensity class

Represents a screen density.

Constructors

ScreenDensity({String? densityAlias, int? densityDpi})
ScreenDensity.fromJson(Map json_)

Properties

densityAlias ↔ String?
Alias for a screen density. Possible string values are:
getter/setter pair
densityDpi ↔ int?
Value for density dpi.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited