ScreenshotSet class

A set of screenshots.

Constructors

ScreenshotSet({List<ImageAsset>? screenshots})
ScreenshotSet.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenshots List<ImageAsset>?
The image assets of the screenshots.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited