SdkVersionTargeting class

Targeting based on sdk version.

Constructors

SdkVersionTargeting({List<SdkVersion>? alternatives, List<SdkVersion>? value})
SdkVersionTargeting.fromJson(Map json_)

Properties

alternatives ↔ List<SdkVersion>?
Targeting of other sibling directories that were in the Bundle.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ List<SdkVersion>?
Value of an sdk version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited