SignupPromotion class

The promotion applied on this item when purchased.

Constructors

SignupPromotion({OneTimeCode? oneTimeCode, VanityCode? vanityCode})
SignupPromotion.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
oneTimeCode ↔ DeveloperInitiatedCancellation?
A one-time code was applied.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vanityCode ↔ VanityCode?
A vanity code was applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited