SocSelector class

Defines a SOC selector for a device.

This will match any device whose SoC (System on Chip) matches all fields in the selector.

Constructors

SocSelector({String? socMake, String? socModel})
SocSelector.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socMake ↔ String?
The manufacturer of the SoC.
getter/setter pair
socModel ↔ String?
The model of the SoC.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited