SplitApkMetadata class

Holds data specific to Split APKs.

Constructors

SplitApkMetadata({bool? isMasterSplit, String? splitId})
SplitApkMetadata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMasterSplit ↔ bool?
Indicates whether this APK is the main split of the module.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splitId ↔ String?
Id of the split.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited