Subscription class

A single subscription for an app.

Constructors

Subscription({bool? archived, List<BasePlan>? basePlans, List<SubscriptionListing>? listings, String? packageName, String? productId, RestrictedPaymentCountries? restrictedPaymentCountries, SubscriptionTaxAndComplianceSettings? taxAndComplianceSettings})
Subscription.fromJson(Map json_)

Properties

archived ↔ bool?
Deprecated: subscription archiving is not supported.
getter/setter pair
basePlans ↔ List<BasePlan>?
The set of base plans for this subscription.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listings ↔ List<SubscriptionListing>?
List of localized listings for this subscription.
getter/setter pair
packageName ↔ String?
Package name of the parent app.
getter/setter pair
productId ↔ String?
Unique product ID of the product.
getter/setter pair
restrictedPaymentCountries ↔ RestrictedPaymentCountries?
Countries where the purchase of this subscription is restricted to payment methods registered in the same country.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxAndComplianceSettings ↔ SubscriptionTaxAndComplianceSettings?
Details about taxes and legal compliance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited