offerPhaseDetails property
The pricing phase details for the entitlement period funded by this order.
Implementation
OfferPhaseDetails? offerPhaseDetails;
The pricing phase details for the entitlement period funded by this order.
OfferPhaseDetails? offerPhaseDetails;