SubscriptionListing class

The consumer-visible metadata of a subscription.

Constructors

SubscriptionListing({List<String>? benefits, String? description, String? languageCode, String? title})
SubscriptionListing.fromJson(Map json_)

Properties

benefits ↔ List<String>?
A list of benefits shown to the user on platforms such as the Play Store and in restoration flows in the language of this listing.
getter/setter pair
description ↔ String?
The description of this subscription in the language of this listing.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The language of this listing, as defined by BCP-47, e.g. "en-US".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The title of this subscription in the language of this listing.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited