SubscriptionOfferTargeting class

Defines the rule a user needs to satisfy to receive this offer.

Properties

acquisitionRule ↔ AcquisitionTargetingRule?
Offer targeting rule for new user acquisition.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upgradeRule ↔ UpgradeTargetingRule?
Offer targeting rule for upgrading users' existing plans.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited