SubscriptionPurchaseLineItem class

Item-level info for a subscription purchase.

Constructors

SubscriptionPurchaseLineItem({AutoRenewingPlan? autoRenewingPlan, DeferredItemRemoval? deferredItemRemoval, DeferredItemReplacement? deferredItemReplacement, String? expiryTime, ItemReplacement? itemReplacement, String? latestSuccessfulOrderId, OfferDetails? offerDetails, OfferPhase? offerPhase, PrepaidPlan? prepaidPlan, String? productId, SignupPromotion? signupPromotion})
SubscriptionPurchaseLineItem.fromJson(Map json_)

Properties

autoRenewingPlan ↔ AutoRenewingPlan?
The item is auto renewing.
getter/setter pair
deferredItemRemoval ↔ DeveloperInitiatedCancellation?
Information for deferred item removal.
getter/setter pair
deferredItemReplacement ↔ DeferredItemReplacement?
Information for deferred item replacement.
getter/setter pair
expiryTime ↔ String?
Time at which the subscription expired or will expire unless the access is extended (ex.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemReplacement ↔ ItemReplacement?
Details of the item being replaced.
getter/setter pair
latestSuccessfulOrderId ↔ String?
The order id of the latest successful order associated with this item.
getter/setter pair
offerDetails ↔ OfferDetails?
The offer details for this item.
getter/setter pair
offerPhase ↔ OfferPhase?
Current offer phase details for this item.
getter/setter pair
prepaidPlan ↔ PrepaidPlan?
The item is prepaid.
getter/setter pair
productId ↔ String?
The purchased product ID (for example, 'monthly001').
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signupPromotion ↔ SignupPromotion?
Promotion details about this item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited