etag property

String? etag
getter/setter pair

Entity tag representing the current state of the subscription.

The developer will provide this etag for subscription actions. This etag is always present for auto-renewing and prepaid subscriptions.

Implementation

core.String? etag;