outOfAppPurchaseContext property

OutOfAppPurchaseContext? outOfAppPurchaseContext
getter/setter pair

Additional context for out of app purchases.

This information is only present for re-subscription purchases (subscription purchases made after the previous subscription of the same product has expired) made through the Google Play subscriptions center. This field will be removed after you acknowledge the subscription.

Implementation

OutOfAppPurchaseContext? outOfAppPurchaseContext;