Targeting class

Targeting details for a recovery action such as regions, android sdk levels, app versions etc.

Constructors

Targeting({AllUsers? allUsers, AndroidSdks? androidSdks, Regions? regions, AppVersionList? versionList, AppVersionRange? versionRange})
Targeting.fromJson(Map json_)

Properties

allUsers ↔ AllUsers?
All users are targeted.
getter/setter pair
androidSdks ↔ AndroidSdks?
Targeting is based on android api levels of devices.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
regions ↔ Regions?
Targeting is based on the user account region.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionList ↔ AppVersionList?
Target version codes as a list.
getter/setter pair
versionRange ↔ AppVersionRange?
Target version codes as a range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited