TargetingInfo class

Targeting information about the generated apks.

Constructors

TargetingInfo({List<AssetSliceSet>? assetSliceSet, String? packageName, List<SplitApkVariant>? variant})
TargetingInfo.fromJson(Map json_)

Properties

assetSliceSet ↔ List<AssetSliceSet>?
List of created asset slices.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
packageName ↔ String?
The package name of this app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variant ↔ List<SplitApkVariant>?
List of the created variants.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited