TargetingRuleScope class

Defines the scope of subscriptions which a targeting rule can match to target offers to users based on past or current entitlement.

Constructors

TargetingRuleScope({TargetingRuleScopeAnySubscriptionInApp? anySubscriptionInApp, String? specificSubscriptionInApp, TargetingRuleScopeThisSubscription? thisSubscription})
TargetingRuleScope.fromJson(Map json_)

Properties

anySubscriptionInApp ↔ DeveloperInitiatedCancellation?
The scope of the current targeting rule is any subscription in the parent app.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specificSubscriptionInApp ↔ String?
The scope of the current targeting rule is the subscription with the specified subscription ID.
getter/setter pair
thisSubscription ↔ DeveloperInitiatedCancellation?
The scope of the current targeting rule is the subscription in which this offer is defined.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited