Track class

A track configuration.

The resource for TracksService.

Constructors

Track({List<TrackRelease>? releases, String? track})
Track.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
releases ↔ List<TrackRelease>?
In a read request, represents all active releases in the track.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
track ↔ String?
Identifier of the track.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited