TrackConfig class

Configurations of the new track.

Constructors

TrackConfig({String? formFactor, String? track, String? type})
TrackConfig.fromJson(Map json_)

Properties

formFactor ↔ String?
Form factor of the new track.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
track ↔ String?
Identifier of the new track.
getter/setter pair
type ↔ String?
Type of the new track.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited