TrackTargetedCountry class

Representation of a single country where the contents of a track can be made available.

Constructors

TrackTargetedCountry({String? countryCode})
TrackTargetedCountry.fromJson(Map json_)

Properties

countryCode ↔ String?
The country that can be targeted, as a two-letter CLDR code.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited