UpdateAppStoreHostedAppPublishStatusRequest class

Request to update the publish status of an app store hosted app.

The default state for any app with an update is PUBLISHED. It is not necessary to call this RPC explicitly to set an app to PUBLISHED.

Properties

hashCode int
The hash code for this object.
no setterinherited
publishState String?
The new publish state for the hosted app.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited