UpdateBasePlanStateRequest class

Request message to update the state of a subscription base plan.

Constructors

UpdateBasePlanStateRequest({ActivateBasePlanRequest? activateBasePlanRequest, DeactivateBasePlanRequest? deactivateBasePlanRequest})
UpdateBasePlanStateRequest.fromJson(Map json_)

Properties

activateBasePlanRequest ↔ ActivateBasePlanRequest?
Activates a base plan.
getter/setter pair
deactivateBasePlanRequest ↔ DeactivateBasePlanRequest?
Deactivates a base plan.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited