UpdateOneTimeProductOfferStateRequest class

Request message to update the state of a one-time product offer.

Constructors

UpdateOneTimeProductOfferStateRequest({ActivateOneTimeProductOfferRequest? activateOneTimeProductOfferRequest, CancelOneTimeProductOfferRequest? cancelOneTimeProductOfferRequest, DeactivateOneTimeProductOfferRequest? deactivateOneTimeProductOfferRequest})
UpdateOneTimeProductOfferStateRequest.fromJson(Map json_)

Properties

activateOneTimeProductOfferRequest ↔ ActivateOneTimeProductOfferRequest?
Activates an offer.
getter/setter pair
cancelOneTimeProductOfferRequest ↔ CancelOneTimeProductOfferRequest?
Cancels an offer.
getter/setter pair
deactivateOneTimeProductOfferRequest ↔ DeactivateOneTimeProductOfferRequest?
Deactivates an offer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited