User class

A user resource.

Constructors

User({String? accessState, List<String>? developerAccountPermissions, String? email, String? expirationTime, List<Grant>? grants, String? name, bool? partial})
User.fromJson(Map json_)

Properties

accessState ↔ String?
The state of the user's access to the Play Console.
getter/setter pair
developerAccountPermissions ↔ List<String>?
Permissions for the user which apply across the developer account.
getter/setter pair
email ↔ String?
The user's email address.
getter/setter pair
expirationTime ↔ String?
The time at which the user's access expires, if set.
getter/setter pair
grants ↔ List<Grant>?
Per-app permissions for the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name for this user, following the pattern "developers/{developer}/users/{email}".
getter/setter pair
partial ↔ bool?
Whether there are more permissions for the user that are not represented here.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited