UserComment class

User entry from conversation between user and developer.

Constructors

UserComment({int? androidOsVersion, int? appVersionCode, String? appVersionName, String? device, DeviceMetadata? deviceMetadata, Timestamp? lastModified, String? originalText, String? reviewerLanguage, int? starRating, String? text, int? thumbsDownCount, int? thumbsUpCount})
UserComment.fromJson(Map json_)

Properties

androidOsVersion ↔ int?
Integer Android SDK version of the user's device at the time the review was written, e.g. 23 is Marshmallow.
getter/setter pair
appVersionCode ↔ int?
Integer version code of the app as installed at the time the review was written.
getter/setter pair
appVersionName ↔ String?
String version name of the app as installed at the time the review was written.
getter/setter pair
device ↔ String?
Codename for the reviewer's device, e.g. klte, flounder.
getter/setter pair
deviceMetadata ↔ DeviceMetadata?
Information about the characteristics of the user's device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModified ↔ Timestamp?
The last time at which this comment was updated.
getter/setter pair
originalText ↔ String?
Untranslated text of the review, where the review was translated.
getter/setter pair
reviewerLanguage ↔ String?
Language code for the reviewer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starRating ↔ int?
The star rating associated with the review, from 1 to 5.
getter/setter pair
text ↔ String?
The content of the comment, i.e. review body.
getter/setter pair
thumbsDownCount ↔ int?
Number of users who have given this review a thumbs down.
getter/setter pair
thumbsUpCount ↔ int?
Number of users who have given this review a thumbs up.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited