UserCountriesTargeting class

Describes an inclusive/exclusive list of country codes that module targets.

Constructors

UserCountriesTargeting({List<String>? countryCodes, bool? exclude})
UserCountriesTargeting.fromJson(Map json_)

Properties

countryCodes ↔ List<String>?
List of country codes in the two-letter CLDR territory format.
getter/setter pair
exclude ↔ bool?
Indicates if the list above is exclusive.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited