Variant class

APK that is suitable for inclusion in a system image.

The resource of SystemApksService.

Constructors

Variant({DeviceSpec? deviceSpec, SystemApkOptions? options, int? variantId})
Variant.fromJson(Map json_)

Properties

deviceSpec ↔ DeviceSpec?
The device spec used to generate the APK.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
options ↔ SystemApkOptions?
Options applied to the generated APK.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variantId ↔ int?
The ID of a previously created system APK variant.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited