GoogleCloudApigeeV1AsyncQuery class

Constructors

GoogleCloudApigeeV1AsyncQuery({String? created, String? envgroupHostname, String? error, String? executionTime, String? name, GoogleCloudApigeeV1QueryMetadata? queryParams, String? reportDefinitionId, GoogleCloudApigeeV1AsyncQueryResult? result, String? resultFileSize, String? resultRows, String? self, String? state, String? updated})
GoogleCloudApigeeV1AsyncQuery.fromJson(Map json_)

Properties

created ↔ String?
Creation time of the query.
getter/setter pair
envgroupHostname ↔ String?
Hostname is available only when query is executed at host level.
getter/setter pair
error ↔ String?
Error is set when query fails.
getter/setter pair
executionTime ↔ String?
ExecutionTime is available only after the query is completed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Asynchronous Query Name.
getter/setter pair
queryParams ↔ GoogleCloudApigeeV1QueryMetadata?
Contains information like metrics, dimenstions etc of the AsyncQuery.
getter/setter pair
reportDefinitionId ↔ String?
Asynchronous Report ID.
getter/setter pair
result ↔ GoogleCloudApigeeV1AsyncQueryResult?
Result is available only after the query is completed.
getter/setter pair
resultFileSize ↔ String?
ResultFileSize is available only after the query is completed.
getter/setter pair
resultRows ↔ String?
ResultRows is available only after the query is completed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
self ↔ String?
Self link of the query.
getter/setter pair
state ↔ String?
Query state could be "enqueued", "running", "completed", "failed".
getter/setter pair
updated ↔ String?
Last updated timestamp for the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited