GoogleCloudApigeeV1DebugMask class

Constructors

GoogleCloudApigeeV1DebugMask({List<String>? faultJSONPaths, List<String>? faultXPaths, String? name, Map<String, String>? namespaces, List<String>? requestJSONPaths, List<String>? requestXPaths, List<String>? responseJSONPaths, List<String>? responseXPaths, List<String>? variables})
GoogleCloudApigeeV1DebugMask.fromJson(Map json_)

Properties

faultJSONPaths ↔ List<String>?
List of JSON paths that specify the JSON elements to be filtered from JSON payloads in error flows.
getter/setter pair
faultXPaths ↔ List<String>?
List of XPaths that specify the XML elements to be filtered from XML payloads in error flows.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the debug mask.
getter/setter pair
namespaces ↔ Map<String, String>?
Map of namespaces to URIs.
getter/setter pair
requestJSONPaths ↔ List<String>?
List of JSON paths that specify the JSON elements to be filtered from JSON request message payloads.
getter/setter pair
requestXPaths ↔ List<String>?
List of XPaths that specify the XML elements to be filtered from XML request message payloads.
getter/setter pair
responseJSONPaths ↔ List<String>?
List of JSON paths that specify the JSON elements to be filtered from JSON response message payloads.
getter/setter pair
responseXPaths ↔ List<String>?
List of XPaths that specify the XML elements to be filtered from XML response message payloads.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variables ↔ List<String>?
List of variables that should be masked from the debug output.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited