GoogleCloudApigeeV1DeveloperAppKey class

Constructors

GoogleCloudApigeeV1DeveloperAppKey({List<Object?>? apiProducts, List<GoogleCloudApigeeV1Attribute>? attributes, String? consumerKey, String? consumerSecret, String? expiresAt, String? expiresInSeconds, String? issuedAt, List<String>? scopes, String? status})
GoogleCloudApigeeV1DeveloperAppKey.fromJson(Map json_)

Properties

apiProducts ↔ List<Object?>?
List of API products for which the credential can be used.
getter/setter pair
attributes ↔ List<GoogleCloudApigeeV1Attribute>?
List of attributes associated with the credential.
getter/setter pair
consumerKey ↔ String?
Consumer key.
getter/setter pair
consumerSecret ↔ String?
Secret key.
getter/setter pair
expiresAt ↔ String?
Time the developer app expires in milliseconds since epoch.
getter/setter pair
expiresInSeconds ↔ String?
Input only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuedAt ↔ String?
Time the developer app was created in milliseconds since epoch.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>?
Scopes to apply to the app.
getter/setter pair
status ↔ String?
Status of the credential.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited