GoogleCloudApigeeV1DeveloperSubscription class

Structure of a DeveloperSubscription.

Constructors

GoogleCloudApigeeV1DeveloperSubscription({String? apiproduct, String? createdAt, String? endTime, String? lastModifiedAt, String? name, String? startTime})
GoogleCloudApigeeV1DeveloperSubscription.fromJson(Map json_)

Properties

apiproduct ↔ String?
Name of the API product for which the developer is purchasing a subscription.
getter/setter pair
createdAt ↔ String?
Time when the API product subscription was created in milliseconds since epoch.
getter/setter pair
endTime ↔ String?
Time when the API product subscription ends in milliseconds since epoch.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedAt ↔ String?
Time when the API product subscription was last modified in milliseconds since epoch.
getter/setter pair
name ↔ String?
Name of the API product subscription.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Time when the API product subscription starts in milliseconds since epoch.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited