GoogleCloudApigeeV1KeyAliasReference class

Properties

aliasId ↔ String?
Alias ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reference ↔ String?
Reference name in the following format: organizations/{org}/environments/{env}/references/{reference}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited