GoogleCloudApigeeV1PayloadOperationConfig class

Binds the payload operations in an API proxy with the associated quota enforcement.

Properties

apiSource String?
Name of the API proxy with which the payload operations and quota are associated.
getter/setter pair
attributes List<GoogleCloudApigeeV1Attribute>?
Custom attributes associated with the operation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
operations List<GoogleCloudApigeeV1PayloadOperation>?
List of payload operations for the API proxy to which quota will be applied.
getter/setter pair
quota GoogleCloudApigeeV1Quota?
Quota parameters to be enforced for the operations and API source combination.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited