apiSource property
Name of the API proxy with which the payload operations and quota are associated.
Required.
Implementation
core.String? apiSource;
Name of the API proxy with which the payload operations and quota are associated.
Required.
core.String? apiSource;