GoogleCloudApigeeV1QueryMetadata class

Constructors

GoogleCloudApigeeV1QueryMetadata({List<String>? dimensions, String? endTimestamp, List<String>? metrics, String? outputFormat, String? startTimestamp, String? timeUnit})
GoogleCloudApigeeV1QueryMetadata.fromJson(Map json_)

Properties

dimensions ↔ List<String>?
Dimensions of the AsyncQuery.
getter/setter pair
endTimestamp ↔ String?
End timestamp of the query range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ List<String>?
Metrics of the AsyncQuery.
getter/setter pair
outputFormat ↔ String?
Output format.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp ↔ String?
Start timestamp of the query range.
getter/setter pair
timeUnit ↔ String?
Query GroupBy time unit.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited