GoogleCloudApigeeV1QueryTimeSeriesStatsRequest class

QueryTimeSeriesStatsRequest represents a query that returns a collection of time series sequences grouped by their values.

Constructors

GoogleCloudApigeeV1QueryTimeSeriesStatsRequest({List<String>? dimensions, String? filter, List<GoogleCloudApigeeV1MetricAggregation>? metrics, int? pageSize, String? pageToken, GoogleTypeInterval? timeRange, String? timestampOrder, String? windowSize})
GoogleCloudApigeeV1QueryTimeSeriesStatsRequest.fromJson(Map json_)

Properties

dimensions ↔ List<String>?
List of dimension names to group the aggregations by.
getter/setter pair
filter ↔ String?
Filter further on specific dimension values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ List<GoogleCloudApigeeV1MetricAggregation>?
List of metrics and their aggregations.
getter/setter pair
pageSize ↔ int?
Page size represents the number of time series sequences, one per unique set of dimensions and their values.
getter/setter pair
pageToken ↔ String?
Page token stands for a specific collection of time series sequences.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeRange ↔ GoogleTypeInterval?
Time range for the stats.
getter/setter pair
timestampOrder ↔ String?
Order the sequences in increasing or decreasing order of timestamps.
getter/setter pair
windowSize ↔ String?
Time buckets to group the stats by. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited