apiObservationsPubsubTopic property

String? apiObservationsPubsubTopic
getter/setter pair

Full Pub/Sub topic path in the Apigee Runtime Tenant Project where the Schema Inferring Engine publishes inferred ApiObservation messages.

Format: projects/{project}/topics/{topic}. Same sentinel semantics as raw_observations_pubsub_topic. Default: empty string.

Implementation

core.String? apiObservationsPubsubTopic;