GoogleCloudApigeeV1SecurityReportQuery class

Body structure when user makes a request to create a security report.

Constructors

GoogleCloudApigeeV1SecurityReportQuery({String? csvDelimiter, List<String>? dimensions, String? displayName, String? envgroupHostname, String? filter, String? groupByTimeUnit, int? limit, List<GoogleCloudApigeeV1SecurityReportQueryMetric>? metrics, String? mimeType, String? reportDefinitionId, Object? timeRange})
GoogleCloudApigeeV1SecurityReportQuery.fromJson(Map json_)

Properties

csvDelimiter ↔ String?
Delimiter used in the CSV file, if outputFormat is set to csv.
getter/setter pair
dimensions ↔ List<String>?
A list of dimensions.
getter/setter pair
displayName ↔ String?
Security Report display name which users can specify.
getter/setter pair
envgroupHostname ↔ String?
Hostname needs to be specified if query intends to run at host level.
getter/setter pair
filter ↔ String?
Boolean expression that can be used to filter data.
getter/setter pair
groupByTimeUnit ↔ String?
Time unit used to group the result set.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int?
Maximum number of rows that can be returned in the result.
getter/setter pair
metrics ↔ List<GoogleCloudApigeeV1SecurityReportQueryMetric>?
A list of Metrics.
getter/setter pair
mimeType ↔ String?
Valid values include: csv or json.
getter/setter pair
reportDefinitionId ↔ String?
Report Definition ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeRange ↔ Object?
Time range for the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited