OrganizationsEnvironmentsAddonsConfigResource class

Constructors

OrganizationsEnvironmentsAddonsConfigResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAddonEnablement(GoogleCloudApigeeV1SetAddonEnablementRequest request, String name, {String? $fields}) → Future<GoogleLongrunningOperation>
Updates an add-on enablement status of an environment.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited