list method
List security monitoring conditions.
Request parameters:
parent - Required. For a specific organization, list all the security
monitoring conditions. Format: organizations/{org}
Value must have pattern ^organizations/\[^/\]+$.
filter - Optional. Filter for the monitoring conditions. When
RiskAssessmentType is APIGEE, monitoring conditions can be filtered by
profile and scope. For example: profile=profile1 AND scope=env1 When
RiskAssessmentType is API_HUB, monitoring conditions can be filtered by
profile and api_hub_gateway. For example: profile=profile1 AND api_hub_gateway=gateway1
pageSize - Optional. The maximum number of monitoring conditions to
return.
pageToken - Optional. A page token, received from a previous
ListSecurityMonitoringConditions call. Provide this to retrieve the
subsequent page.
riskAssessmentType - Optional. The risk assessment type of the security
monitoring condition. Defaults to ADVANCED_API_SECURITY.
Possible string values are:
- "RISK_ASSESSMENT_TYPE_UNSPECIFIED" : Risk assessment type is not specified.
- "APIGEE" : Risk assessment type is Apigee.
- "API_HUB" : Risk assessment type is API Hub.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudApigeeV1ListSecurityMonitoringConditionsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleCloudApigeeV1ListSecurityMonitoringConditionsResponse>
list(
core.String parent, {
core.String? filter,
core.int? pageSize,
core.String? pageToken,
core.String? riskAssessmentType,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'riskAssessmentType': ?riskAssessmentType == null
? null
: [riskAssessmentType],
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v1/' +
core.Uri.encodeFull('$parent') +
'/securityMonitoringConditions';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleCloudApigeeV1ListSecurityMonitoringConditionsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}