apihubReadwriteScope constant

String const apihubReadwriteScope

See, edit, configure, and delete your Google Cloud API hub data and see the email address for your Google Account

Implementation

static const apihubReadwriteScope =
    'https://www.googleapis.com/auth/apihub.readwrite';