GoogleCloudApihubV1HttpOperationConfig class

Identifies a single API Hub operation by spec resource name + HTTP path + HTTP method.

Properties

hashCode int
The hash code for this object.
no setterinherited
method String?
HTTP method of the operation within the referenced spec.
getter/setter pair
path String?
HTTP path of the operation within the referenced spec.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spec String?
Spec resource name: projects/{project}/locations/{location}/apis/{api}/versions/{version}/specs/{spec}
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited