ProjectsLocationsApisResource class

Constructors

ProjectsLocationsApisResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versions → ProjectsLocationsApisVersionsResource
no setter

Methods

create(GoogleCloudApihubV1Api request, String parent, {String? apiId, String? $fields}) → Future<GoogleCloudApihubV1Api>
Create an API resource in the API hub.
delete(String name, {bool? force, String? $fields}) → Future<Empty>
Delete an API resource in the API hub.
get(String name, {String? $fields}) → Future<GoogleCloudApihubV1Api>
Get API resource details including the API versions contained in it.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<GoogleCloudApihubV1ListApisResponse>
List API resources in the API hub.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleCloudApihubV1Api request, String name, {String? updateMask, String? $fields}) → Future<GoogleCloudApihubV1Api>
Update an API resource in the API hub.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited