retrieveApiViews method
Retrieve API views.
Request parameters:
parent - Required. The parent resource name. Format:
projects/{project}/locations/{location}.
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
filter - Optional. The filter expression.
pageSize - Optional. The maximum number of results to return. Default to
100.
pageToken - Optional. A page token, received from a previous
RetrieveApiViews call. Provide this to retrieve the subsequent page.
view - Required. The view type to return.
Possible string values are:
- "API_VIEW_TYPE_UNSPECIFIED" : The default view type.
- "MCP_SERVER" : The MCP server view in API hub.
- "MCP_TOOL" : The MCP tool view in API hub.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudApihubV1RetrieveApiViewsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleCloudApihubV1RetrieveApiViewsResponse> retrieveApiViews(
core.String parent, {
core.String? filter,
core.int? pageSize,
core.String? pageToken,
core.String? view,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'view': ?view == null ? null : [view],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + ':retrieveApiViews';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleCloudApihubV1RetrieveApiViewsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}