V2AndroidKeyRestrictions class

The Android apps that are allowed to use the key.

Properties

allowedApplications ↔ List<V2AndroidApplication>?
A list of Android applications that are allowed to make API calls with this key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited