AppsFirewallIngressRulesResource class

Constructors

AppsFirewallIngressRulesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchUpdate(BatchUpdateIngressRulesRequest request, String appsId, {String? $fields}) → Future<BatchUpdateIngressRulesResponse>
Replaces the entire firewall ruleset in one bulk operation.
create(FirewallRule request, String appsId, {String? $fields}) → Future<FirewallRule>
Creates a firewall rule for the application.
delete(String appsId, String ingressRulesId, {String? $fields}) → Future<Empty>
Deletes the specified firewall rule.
get(String appsId, String ingressRulesId, {String? $fields}) → Future<FirewallRule>
Gets the specified firewall rule.
list(String appsId, {String? matchingAddress, int? pageSize, String? pageToken, String? $fields}) → Future<ListIngressRulesResponse>
Lists the firewall rules of an application.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(FirewallRule request, String appsId, String ingressRulesId, {String? updateMask, String? $fields}) → Future<FirewallRule>
Updates the specified firewall rule.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited