AppsLocationsResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(String appsId, String locationsId, {String? $fields})
→ Future<Location>
-
Gets information about a location.
-
list(String appsId, {String? filter, int? pageSize, String? pageToken, String? $fields})
→ Future<ListLocationsResponse>
-
Lists information about the supported locations for this service.This
method lists locations based on the resource scope provided in the
ListLocationsRequest.name field: Global locations: If name is empty, the
method lists the public locations available to all projects.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited