CertificateRawData class

An SSL certificate obtained from a certificate authority.

Constructors

CertificateRawData({String? privateKey, String? publicCertificate})
CertificateRawData.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
privateKey ↔ String?
Unencrypted PEM encoded RSA private key.
getter/setter pair
publicCertificate ↔ String?
PEM encoded x.509 public key certificate.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited