FlexibleRuntimeSettings class

Runtime settings for the App Engine flexible environment.

Constructors

FlexibleRuntimeSettings({String? operatingSystem, String? runtimeVersion})
FlexibleRuntimeSettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operatingSystem ↔ String?
The operating system of the application runtime.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeVersion ↔ String?
The runtime version of an App Engine flexible application.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited