StandardSchedulerSettings class

Scheduler settings for standard environment.

Constructors

StandardSchedulerSettings({int? maxInstances, int? minInstances, double? targetCpuUtilization, double? targetThroughputUtilization})
StandardSchedulerSettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxInstances ↔ int?
Maximum number of instances to run for this version.
getter/setter pair
minInstances ↔ int?
Minimum number of instances to run for this version.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetCpuUtilization ↔ double?
Target CPU utilization ratio to maintain when scaling.
getter/setter pair
targetThroughputUtilization ↔ double?
Target throughput utilization ratio to maintain when scaling
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited