Attributes class

Consumer provided attributes.

Constructors

Attributes({List<ContactInfo>? businessOwners, Criticality? criticality, List<ContactInfo>? developerOwners, Environment? environment, List<ContactInfo>? operatorOwners})
Attributes.fromJson(Map json_)

Properties

businessOwners ↔ List<ContactInfo>?
Business team that ensures user needs are met and value is delivered
getter/setter pair
criticality ↔ Criticality?
User-defined criticality information.
getter/setter pair
developerOwners ↔ List<ContactInfo>?
Developer team that owns development and coding.
getter/setter pair
environment ↔ Environment?
User-defined environment information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
operatorOwners ↔ List<ContactInfo>?
Operator team that ensures runtime and operations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited