ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

applications → ProjectsLocationsApplicationsResource
no setter
discoveredServices → ProjectsLocationsDiscoveredServicesResource
no setter
discoveredWorkloads → ProjectsLocationsDiscoveredWorkloadsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
operations → ProjectsLocationsOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceProjectAttachments → ProjectsLocationsServiceProjectAttachmentsResource
no setter

Methods

detachServiceProjectAttachment(DetachServiceProjectAttachmentRequest request, String name, {String? $fields}) → Future<DetachServiceProjectAttachmentResponse>
Detaches a service project from a host project.
get(String name, {String? $fields}) → Future<Location>
Gets information about a location.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
lookupServiceProjectAttachment(String name, {String? $fields}) → Future<LookupServiceProjectAttachmentResponse>
Lists a service project attachment for a given service project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited