WorkloadProperties class

Properties of an underlying compute resource represented by the Workload.

Constructors

WorkloadProperties({Map<String, ExtendedMetadata>? extendedMetadata, FunctionalType? functionalType, String? gcpProject, Identity? identity, String? location, String? zone})
WorkloadProperties.fromJson(Map json_)

Properties

extendedMetadata ↔ Map<String, ExtendedMetadata>?
Additional metadata specific to the resource type.
getter/setter pair
functionalType ↔ FunctionalType?
The type of the workload.
getter/setter pair
gcpProject ↔ String?
The service project identifier that the underlying cloud resource resides in.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identity ↔ Identity?
The identity associated with the workload.
getter/setter pair
location ↔ String?
The location that the underlying compute resource resides in (for example, us-west1).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zone ↔ String?
The location that the underlying compute resource resides in if it is zonal (for example, us-west1-a).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited