UserLicense class

Constructors

UserLicense({String? applicationId, String? customerId, String? editionId, bool? enabled, String? id, String? kind, String? state, String? userId})
UserLicense.fromJson(Map json_)

Properties

applicationId ↔ String?
The ID of the application corresponding to the license query.
getter/setter pair
customerId ↔ String?
The domain name of the user.
getter/setter pair
editionId ↔ String?
(Deprecated)
getter/setter pair
enabled ↔ bool?
The domain administrator has activated the application for this domain.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the user license.
getter/setter pair
kind ↔ String?
The type of API resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The user's licensing status.
getter/setter pair
userId ↔ String?
The email address of the user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited