ComputeInsightsResponse class

Response for the ComputeInsights RPC.

Constructors

ComputeInsightsResponse({String? count, List<PlaceInsight>? placeInsights})
ComputeInsightsResponse.fromJson(Map json_)

Properties

count ↔ String?
Result for Insights.INSIGHT_COUNT.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
placeInsights ↔ List<PlaceInsight>?
Result for Insights.INSIGHT_PLACES.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited