CleanupPolicyMostRecentVersions class

CleanupPolicyMostRecentVersions is an alternate condition of a CleanupPolicy for retaining a minimum number of versions.

Constructors

CleanupPolicyMostRecentVersions({int? keepCount, List<String>? packageNamePrefixes})
CleanupPolicyMostRecentVersions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keepCount ↔ int?
Minimum number of versions to keep.
getter/setter pair
packageNamePrefixes ↔ List<String>?
List of package name prefixes that will apply this rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited