DockerImage class

DockerImage represents a docker artifact.

The following fields are returned as untyped metadata in the Version resource, using camelcase keys (i.e. metadata.imageSizeBytes): * imageSizeBytes * mediaType * buildTime

Constructors

DockerImage({String? artifactType, String? buildTime, List<ImageManifest>? imageManifests, String? imageSizeBytes, String? mediaType, String? name, List<String>? tags, String? updateTime, String? uploadTime, String? uri})
DockerImage.fromJson(Map json_)

Properties

artifactType ↔ String?
ArtifactType of this image, e.g. "application/vnd.example+type".
getter/setter pair
buildTime ↔ String?
The time this image was built.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageManifests ↔ List<ImageManifest>?
For multi-arch images (manifest lists), this field contains the list of image manifests.
getter/setter pair
imageSizeBytes ↔ String?
Calculated size of the image.
getter/setter pair
mediaType ↔ String?
Media type of this image, e.g. "application/vnd.docker.distribution.manifest.v2+json".
getter/setter pair
name ↔ String?
registry_location, project_id, repository_name and image id forms a unique image name:projects//locations//repositories//dockerImages/.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<String>?
Tags attached to this image.
getter/setter pair
updateTime ↔ String?
The time when the docker image was last updated.
getter/setter pair
uploadTime ↔ String?
Time the image was uploaded.
getter/setter pair
uri ↔ String?
URL to access the image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited