GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigYumRepositoryPublicRepository class

Publicly available Yum repositories constructed from a common repository base and a custom repository path.

Properties

hashCode → int
The hash code for this object.
no setterinherited
repositoryBase ↔ String?
A common public repository base for Yum. Possible string values are:
getter/setter pair
repositoryPath ↔ String?
A custom field to define a path to a specific repository from the base.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited