Package class

Packages are named collections of versions.

Constructors

Package({Map<String, String>? annotations, String? createTime, String? displayName, String? name, String? updateTime})
Package.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Client specified annotations.
getter/setter pair
createTime ↔ String?
The time when the package was created.
getter/setter pair
displayName ↔ String?
The display name of the package.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the package, for example: projects/p1/locations/us-central1/repositories/repo1/packages/pkg1.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The time when the package was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited