PlatformLogsConfig class

The platform logs config for a project or a repository.

Constructors

PlatformLogsConfig({String? loggingState, String? severityLevel})
PlatformLogsConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
loggingState ↔ String?
The state of the platform logs: enabled or disabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityLevel ↔ String?
The severity level for the logs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited