PrewarmedArtifact class

PrewarmedArtifact represents a streamed artifact.

This is not a request message, so field_behavior annotations are not required.

Constructors

PrewarmedArtifact({String? expirationTime, String? location, String? uri})
PrewarmedArtifact.fromJson(Map json_)

Properties

expirationTime String?
The expiration time of the prewarmed artifact.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location String?
The location of the prewarmed artifact.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
URL to access the image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited