ProjectSettings class

The Artifact Registry settings that apply to a Project.

Constructors

ProjectSettings({String? legacyRedirectionState, String? name, int? pullPercent})
ProjectSettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
legacyRedirectionState ↔ String?
The redirection state of the legacy repositories in this project. Possible string values are:
getter/setter pair
name ↔ String?
The name of the project's settings.
getter/setter pair
pullPercent ↔ int?
The percentage of pull traffic to redirect from GCR to AR when using partial redirection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited