ProjectsLocationsResource class
Methods
-
get(String name, {String? $fields})
→ Future<Location>
-
Gets information about a location.
-
getProjectConfig(String name, {String? $fields})
→ Future<ProjectConfig>
-
Retrieves the project configuration.
-
getVpcscConfig(String name, {String? $fields})
→ Future<VPCSCConfig>
-
Retrieves the VPCSC Config for the Project.
-
list(String name, {String? filter, int? pageSize, String? pageToken, String? $fields})
→ Future<ListLocationsResponse>
-
Lists information about the supported locations for this service.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateProjectConfig(ProjectConfig request, String name, {String? updateMask, String? $fields})
→ Future<ProjectConfig>
-
Updates the project configuration.
-
updateVpcscConfig(VPCSCConfig request, String name, {String? updateMask, String? $fields})
→ Future<VPCSCConfig>
-
Updates the VPCSC Config for the Project.