ProjectsResource class

Constructors

ProjectsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
locations → ProjectsLocationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProjectSettings(String name, {String? $fields}) → Future<ProjectSettings>
Retrieves the Settings for the Project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateProjectSettings(ProjectSettings request, String name, {String? updateMask, String? $fields}) → Future<ProjectSettings>
Updates the Settings for the Project.

Operators

operator ==(Object other) → bool
The equality operator.
inherited