PythonPackage class

PythonPackage represents a python artifact.

Constructors

PythonPackage({String? createTime, String? name, String? packageName, String? updateTime, String? uri, String? version})
PythonPackage.fromJson(Map json_)

Properties

createTime ↔ String?
Time the package was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
registry_location, project_id, repository_name and python_package forms a unique package name:projects//locations//repository//pythonPackages/.
getter/setter pair
packageName ↔ String?
Package for the artifact.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Time the package was updated.
getter/setter pair
uri ↔ String?
URL to access the package.
getter/setter pair
version ↔ String?
Version of this package.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited