PythonRepository class

Configuration for a Python remote repository.

Properties

customRepository ↔ GoogleDevtoolsArtifactregistryV1RemoteRepositoryConfigPythonRepositoryCustomRepository?
Customer-specified remote repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
publicRepository ↔ String?
One of the publicly available Python repositories supported by Artifact Registry. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited