RemoteRepositoryConfig class

Remote repository configuration.

Constructors

RemoteRepositoryConfig({AptRepository? aptRepository, CommonRemoteRepository? commonRepository, String? description, bool? disableUpstreamValidation, DockerRepository? dockerRepository, MavenRepository? mavenRepository, NpmRepository? npmRepository, PythonRepository? pythonRepository, UpstreamCredentials? upstreamCredentials, YumRepository? yumRepository})
RemoteRepositoryConfig.fromJson(Map json_)

Properties

aptRepository ↔ AptRepository?
Specific settings for an Apt remote repository.
getter/setter pair
commonRepository ↔ CommonRemoteRepository?
Common remote repository settings.
getter/setter pair
description ↔ String?
The description of the remote source.
getter/setter pair
disableUpstreamValidation ↔ bool?
Input only.
getter/setter pair
dockerRepository ↔ DockerRepository?
Specific settings for a Docker remote repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mavenRepository ↔ MavenRepository?
Specific settings for a Maven remote repository.
getter/setter pair
npmRepository ↔ NpmRepository?
Specific settings for an Npm remote repository.
getter/setter pair
pythonRepository ↔ PythonRepository?
Specific settings for a Python remote repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upstreamCredentials ↔ UpstreamCredentials?
The credentials used to access the remote repository.
getter/setter pair
yumRepository ↔ YumRepository?
Specific settings for a Yum remote repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited