Repository class

A Repository for storing artifacts with a specific format.

Constructors

Repository({Map<String, CleanupPolicy>? cleanupPolicies, bool? cleanupPolicyDryRun, String? createTime, String? description, bool? disallowUnspecifiedMode, DockerRepositoryConfig? dockerConfig, String? format, String? kmsKeyName, Map<String, String>? labels, MavenRepositoryConfig? mavenConfig, String? mode, String? name, PlatformLogsConfig? platformLogsConfig, String? registryUri, RemoteRepositoryConfig? remoteRepositoryConfig, bool? satisfiesPzi, bool? satisfiesPzs, String? sizeBytes, String? updateTime, VirtualRepositoryConfig? virtualRepositoryConfig, VulnerabilityScanningConfig? vulnerabilityScanningConfig})
Repository.fromJson(Map json_)

Properties

cleanupPolicies ↔ Map<String, CleanupPolicy>?
Cleanup policies for this repository.
getter/setter pair
cleanupPolicyDryRun ↔ bool?
If true, the cleanup pipeline is prevented from deleting versions in this repository.
getter/setter pair
createTime ↔ String?
The time when the repository was created.
getter/setter pair
description ↔ String?
The user-provided description of the repository.
getter/setter pair
disallowUnspecifiedMode ↔ bool?
If this is true, an unspecified repo type will be treated as error rather than defaulting to standard.
getter/setter pair
dockerConfig ↔ DockerRepositoryConfig?
Docker repository config contains repository level configuration for the repositories of docker type.
getter/setter pair
format ↔ String?
The format of packages that are stored in the repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
The Cloud KMS resource name of the customer managed encryption key that's used to encrypt the contents of the Repository.
getter/setter pair
labels ↔ Map<String, String>?
Labels with user-defined metadata.
getter/setter pair
mavenConfig ↔ MavenRepositoryConfig?
Maven repository config contains repository level configuration for the repositories of maven type.
getter/setter pair
mode ↔ String?
The mode of the repository.
getter/setter pair
name ↔ String?
The name of the repository, for example: projects/p1/locations/us-central1/repositories/repo1.
getter/setter pair
platformLogsConfig ↔ PlatformLogsConfig?
Configuration for platform logs.
getter/setter pair
registryUri ↔ String?
The repository endpoint, for example: us-docker.pkg.dev/my-proj/my-repo.
getter/setter pair
remoteRepositoryConfig ↔ RemoteRepositoryConfig?
Configuration specific for a Remote Repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Whether or not this repository satisfies PZI.
getter/setter pair
satisfiesPzs ↔ bool?
Whether or not this repository satisfies PZS.
getter/setter pair
sizeBytes ↔ String?
The size, in bytes, of all artifact storage in this repository.
getter/setter pair
updateTime ↔ String?
The time when the repository was last updated.
getter/setter pair
virtualRepositoryConfig ↔ VirtualRepositoryConfig?
Configuration specific for a Virtual Repository.
getter/setter pair
vulnerabilityScanningConfig ↔ VulnerabilityScanningConfig?
Config and state for vulnerability scanning of resources within this Repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited