UsernamePasswordCredentials class

Username and password credentials.

Constructors

UsernamePasswordCredentials({String? passwordSecretVersion, String? username})
UsernamePasswordCredentials.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
passwordSecretVersion ↔ String?
The Secret Manager key version that holds the password to access the remote repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String?
The username to access the remote repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited