VPCSCConfig class

The Artifact Registry VPC SC config that apply to a Project.

Constructors

VPCSCConfig({String? name, String? vpcscPolicy})
VPCSCConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the project's VPC SC Config.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vpcscPolicy ↔ String?
The project per location VPC SC policy that defines the VPC SC behavior for the Remote Repository (Allow/Deny). Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited