fingerprints property

List<Hash>? fingerprints
getter/setter pair

Immutable reference for the version, calculated based on the version's content.

Currently we only support dirsum_sha256 hash algorithm. Additional hash algorithms may be added in the future.

Output only.

Implementation

core.List<Hash>? fingerprints;