assuredworkloads/v1 library

Classes

AssuredworkloadsApi
AssuredworkloadsResource
FoldersLocationsDbFindingSummariesResource
FoldersLocationsDbFrameworkComplianceReportsDbControlComplianceSummariesResource
FoldersLocationsDbFrameworkComplianceReportsResource
FoldersLocationsDbFrameworkComplianceSummariesResource
FoldersLocationsResource
FoldersResource
GoogleCloudAssuredworkloadsV1AcknowledgeViolationRequest
Request for acknowledging the violation
GoogleCloudAssuredworkloadsV1AggregateDbFrameworkComplianceReportResponse
The response message for AggregateDbFrameworkComplianceReport.
GoogleCloudAssuredworkloadsV1AggregatedComplianceReport
The aggregated compliance report.
GoogleCloudAssuredworkloadsV1AnalyzeWorkloadMoveResponse
Response containing the analysis results for the hypothetical resource move.
GoogleCloudAssuredworkloadsV1ApplyWorkloadUpdateRequest
Request to apply update to a workload.
GoogleCloudAssuredworkloadsV1ArchiveResourceEventsRequest
Request for archiving resource events.
GoogleCloudAssuredworkloadsV1ArchiveResourceEventsResponse
Response for archiving resource events.
GoogleCloudAssuredworkloadsV1AssetMoveAnalysis
Represents move analysis results for an asset.
GoogleCloudAssuredworkloadsV1CELExpression
A Common Expression Language (CEL) expression that's used to create a rule.
GoogleCloudAssuredworkloadsV1CloudControlAssessmentDetails
The cloud control assessment details for non-manual cloud controls.
GoogleCloudAssuredworkloadsV1CloudControlReport
The cloud control report.
GoogleCloudAssuredworkloadsV1ControlAssessmentDetails
The details for a control assessment.
GoogleCloudAssuredworkloadsV1DbControlComplianceSummary
The details for control compliance.
GoogleCloudAssuredworkloadsV1DbFindingSummary
The details for a finding.
GoogleCloudAssuredworkloadsV1DbFrameworkComplianceSummary
The details for a framework compliance summary.
GoogleCloudAssuredworkloadsV1FetchDbFrameworkComplianceReportResponse
The response message for FetchDbFrameworkComplianceReport.
GoogleCloudAssuredworkloadsV1ListDbControlComplianceSummariesResponse
The response message for ListDBControlComplianceSummaries.
GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse
The response message for ListDbFindingSummaries.
GoogleCloudAssuredworkloadsV1ListDbFrameworkComplianceSummariesResponse
The response message for ListDbFrameworkComplianceSummariesResponse.
GoogleCloudAssuredworkloadsV1ListViolationsResponse
Response of ListViolations endpoint.
GoogleCloudAssuredworkloadsV1ListWorkloadsResponse
Response of ListWorkloads endpoint.
GoogleCloudAssuredworkloadsV1ListWorkloadUpdatesResponse
Response of listing the compliance updates per workload with pagination.
GoogleCloudAssuredworkloadsV1ManualCloudControlAssessmentDetails
The details for a manual cloud control assessment.
GoogleCloudAssuredworkloadsV1MoveAnalysisGroup
Represents a logical group of checks performed for an asset.
GoogleCloudAssuredworkloadsV1MoveAnalysisResult
Represents the successful move analysis results for a group.
GoogleCloudAssuredworkloadsV1MoveImpact
Represents the impact of moving the asset to the target.
GoogleCloudAssuredworkloadsV1MutatePartnerPermissionsRequest
Request for updating permission settings for a partner workload.
GoogleCloudAssuredworkloadsV1OrgPolicy
This assured workload service object is used to represent the org policy attached to a resource.
GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRule
A rule used to express this policy.
GoogleCloudAssuredworkloadsV1OrgPolicyUpdate
Represents an update for an org policy control applied on an Assured Workload resource.
GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesRequest
Request for restricting list of available resources in Workload environment.
GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest
Request for reverting archived resource events.
GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse
Response for reverting archived resource events.
GoogleCloudAssuredworkloadsV1Rule
A rule in the cloud control.
GoogleCloudAssuredworkloadsV1SimilarControls
The similar controls.
GoogleCloudAssuredworkloadsV1StringList
A list of strings for the parameter value.
GoogleCloudAssuredworkloadsV1TargetResourceDetails
The details for a target resource.
GoogleCloudAssuredworkloadsV1Trend
The trend of a compliance metric.
GoogleCloudAssuredworkloadsV1UpdateDetails
The details of the update.
GoogleCloudAssuredworkloadsV1Violation
Workload monitoring Violation.
GoogleCloudAssuredworkloadsV1ViolationExceptionContext
Violation exception detail.
GoogleCloudAssuredworkloadsV1ViolationRemediation
Represents remediation guidance to resolve compliance violation for AssuredWorkload
GoogleCloudAssuredworkloadsV1ViolationRemediationInstructions
Instructions to remediate violation
GoogleCloudAssuredworkloadsV1Workload
A Workload object for managing highly regulated workloads of cloud customers.
GoogleCloudAssuredworkloadsV1WorkloadComplianceStatus
Represents the Compliance Status of this workload
GoogleCloudAssuredworkloadsV1WorkloadEkmProvisioningResponse
External key management systems(EKM) Provisioning response
GoogleCloudAssuredworkloadsV1WorkloadKMSSettings
Settings specific to the Key Management Service.
GoogleCloudAssuredworkloadsV1WorkloadPartnerPermissions
Permissions granted to the AW Partner SA account for the customer workload
GoogleCloudAssuredworkloadsV1WorkloadResourceInfo
Represent the resources that are children of this Workload.
GoogleCloudAssuredworkloadsV1WorkloadResourceSettings
Represent the custom settings for the resources to be created.
GoogleCloudAssuredworkloadsV1WorkloadSaaEnrollmentResponse
Signed Access Approvals (SAA) enrollment response.
GoogleCloudAssuredworkloadsV1WorkloadUpdate
A workload update is a change to the workload's compliance configuration.
GoogleCloudAssuredworkloadsV1WorkloadWorkloadOptions
Options to be set for the given created workload.
GoogleLongrunningListOperationsResponse
The response message for Operations.ListOperations.
GoogleLongrunningOperation
This resource represents a long-running operation that is the result of a network API call.
OrganizationsLocationsDbFindingSummariesResource
OrganizationsLocationsDbFrameworkComplianceReportsDbControlComplianceSummariesResource
OrganizationsLocationsDbFrameworkComplianceReportsResource
OrganizationsLocationsDbFrameworkComplianceSummariesResource
OrganizationsLocationsOperationsResource
OrganizationsLocationsResource
OrganizationsLocationsWorkloadsResource
OrganizationsLocationsWorkloadsUpdatesResource
OrganizationsLocationsWorkloadsViolationsResource
OrganizationsResource
ProjectsLocationsDbFindingSummariesResource
ProjectsLocationsDbFrameworkComplianceReportsDbControlComplianceSummariesResource
ProjectsLocationsDbFrameworkComplianceReportsResource
ProjectsLocationsDbFrameworkComplianceSummariesResource
ProjectsLocationsResource
ProjectsResource

Typedefs

GoogleCloudAssuredworkloadsV1AcknowledgeViolationResponse = $Empty
Response for violation acknowledgement
GoogleCloudAssuredworkloadsV1EnableComplianceUpdatesResponse = $Empty
Response for EnableComplianceUpdates endpoint.
GoogleCloudAssuredworkloadsV1EnableResourceMonitoringResponse = $Empty
Response for EnableResourceMonitoring endpoint.
GoogleCloudAssuredworkloadsV1OrgPolicyPolicyRuleStringValues = $StringValues
The values allowed for a ListPolicy.
GoogleCloudAssuredworkloadsV1RestrictAllowedResourcesResponse = $Empty
Response for restricting the list of allowed resources.
GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsConsole = $Console
Remediation instructions to resolve violation via cloud console
GoogleCloudAssuredworkloadsV1ViolationRemediationInstructionsGcloud = $Gcloud
Remediation instructions to resolve violation via gcloud cli
GoogleProtobufEmpty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
GoogleRpcStatus = $Status00
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.