AssuredworkloadsResource class

Constructors

AssuredworkloadsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

archiveResourceEvents(GoogleCloudAssuredworkloadsV1ArchiveResourceEventsRequest request, {String? $fields}) Future<GoogleCloudAssuredworkloadsV1ArchiveResourceEventsResponse>
Finds orphan ResourceEvents matching the criteria and moves them to the ArchivedResourceEvents table.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revertArchivedResourceEvents(GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest request, {String? $fields}) Future<GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse>
Finds matching ArchivedResourceEvents and moves them back to the ResourceEvents table.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited