revertArchivedResourceEvents method
Future<GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse>
revertArchivedResourceEvents(
- GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest request, {
- String? $fields,
Finds matching ArchivedResourceEvents and moves them back to the ResourceEvents table.
request - The metadata request object.
Request parameters:
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<
GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse
>
revertArchivedResourceEvents(
GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsRequest request, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
const url_ = 'v1/assuredworkloads:revertArchivedResourceEvents';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleCloudAssuredworkloadsV1RevertArchivedResourceEventsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}