GoogleCloudAssuredworkloadsV1ArchiveResourceEventsResponse class
Response for archiving resource events.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- movedEventsCount ↔ int?
-
The total number of events successfully moved to the archive table.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited