GoogleCloudAssuredworkloadsV1CELExpression class

A Common Expression Language (CEL) expression that's used to create a rule.

Properties

expression String?
The logical expression in CEL.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
resourceTypesValues GoogleCloudAssuredworkloadsV1StringList?
The resource instance types on which this expression is defined.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited