GoogleCloudAssuredworkloadsV1TargetResourceDetails class

The details for a target resource.

Constructors

GoogleCloudAssuredworkloadsV1TargetResourceDetails({String? createTime, String? frameworkDeployment, String? majorRevisionId, String? minorRevisionId, String? targetResource, String? targetResourceDisplayName, String? updateTime})
GoogleCloudAssuredworkloadsV1TargetResourceDetails.fromJson(Map json_)

Properties

createTime String?
The create time of the target resource.
getter/setter pair
frameworkDeployment String?
The framework deployment name for the target resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
majorRevisionId String?
The major revision ID of the framework for the target resource.
getter/setter pair
minorRevisionId String?
The minor revision ID of the framework for the target resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetResource String?
The target resource.
getter/setter pair
targetResourceDisplayName String?
The display name of the target resource.
getter/setter pair
updateTime String?
The update time of the target resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited