ProjectsLocationsDbFrameworkComplianceReportsResource class

Constructors

ProjectsLocationsDbFrameworkComplianceReportsResource(ApiRequester client)

Properties

dbControlComplianceSummaries ProjectsLocationsDbFrameworkComplianceReportsDbControlComplianceSummariesResource
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregate(String name, {String? filter, String? interval_endTime, String? interval_startTime, String? $fields}) Future<GoogleCloudAssuredworkloadsV1AggregateDbFrameworkComplianceReportResponse>
Gets the aggregated compliance report over time for a given scope.
fetch(String name, {String? endTime, String? filter, String? $fields}) Future<GoogleCloudAssuredworkloadsV1FetchDbFrameworkComplianceReportResponse>
Fetches the framework compliance report for a given scope.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited