aggregate method
Gets the aggregated compliance report over time for a given scope.
Request parameters:
name - Required. The name of the aggregated compliance report over time
to retrieve. Format:
organizations/{organization_id}/locations/{location}/dbFrameworkComplianceReports/{db_framework_compliance_report}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/dbFrameworkComplianceReports/\[^/\]+$.
filter - Optional. The filtering results.
interval_endTime - Optional. Exclusive end of the interval. If
specified, a Timestamp matching this interval will have to be before the
end.
interval_startTime - Optional. Inclusive start of the interval. If
specified, a Timestamp matching this interval will have to be the same or
after the start.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudAssuredworkloadsV1AggregateDbFrameworkComplianceReportResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<
GoogleCloudAssuredworkloadsV1AggregateDbFrameworkComplianceReportResponse
>
aggregate(
core.String name, {
core.String? filter,
core.String? interval_endTime,
core.String? interval_startTime,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'interval.endTime': ?interval_endTime == null ? null : [interval_endTime],
'interval.startTime': ?interval_startTime == null
? null
: [interval_startTime],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':aggregate';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleCloudAssuredworkloadsV1AggregateDbFrameworkComplianceReportResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}