AccessConfig class

An access configuration attached to an instance's network interface.

Only one access config per instance is supported.

Constructors

AccessConfig({String? externalIpv6, int? externalIpv6PrefixLength, String? name, String? natIP, String? networkTier, String? publicPtrDomainName, bool? setPublicPtr, String? type})
AccessConfig.fromJson(Map json_)

Properties

externalIpv6 ↔ String?
The external IPv6 address of this access configuration.
getter/setter pair
externalIpv6PrefixLength ↔ int?
The prefix length of the external IPv6 range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of this access configuration.
getter/setter pair
natIP ↔ String?
The external IP address of this access configuration.
getter/setter pair
networkTier ↔ String?
This signifies the networking tier used for configuring this access
getter/setter pair
publicPtrDomainName ↔ String?
The DNS domain name for the public PTR record.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setPublicPtr ↔ bool?
Specifies whether a public DNS 'PTR' record should be created to map the external IP address of the instance to a DNS domain name.
getter/setter pair
type ↔ String?
In accessConfigs (IPv4), the default and only option is ONE_TO_ONE_NAT.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited