BackupConfigInfo class

BackupConfigInfo has information about how the resource is configured for Backup and about the most recent backup to this vault.

Constructors

BackupConfigInfo({BackupApplianceBackupConfig? backupApplianceBackupConfig, GcpBackupConfig? gcpBackupConfig, Status? lastBackupError, String? lastBackupState, String? lastSuccessfulBackupConsistencyTime})
BackupConfigInfo.fromJson(Map json_)

Properties

backupApplianceBackupConfig ↔ BackupApplianceBackupConfig?
Configuration for an application backed up by a Backup Appliance.
getter/setter pair
gcpBackupConfig ↔ GcpBackupConfig?
Configuration for a Google Cloud resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastBackupError ↔ Status?
If the last backup failed, this field has the error message.
getter/setter pair
lastBackupState ↔ String?
The status of the last backup to this BackupVault
getter/setter pair
lastSuccessfulBackupConsistencyTime ↔ String?
If the last backup were successful, this field has the consistency date.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited