BackupLock class

BackupLock represents a single lock on a Backup resource.

An unexpired lock on a Backup prevents the Backup from being deleted.

Constructors

BackupLock({BackupApplianceLockInfo? backupApplianceLockInfo, String? lockUntilTime, ServiceLockInfo? serviceLockInfo})
BackupLock.fromJson(Map json_)

Properties

backupApplianceLockInfo ↔ BackupApplianceLockInfo?
If the client is a backup and recovery appliance, this contains metadata about why the lock exists.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lockUntilTime ↔ String?
The time after which this lock is not considered valid and will no longer protect the Backup from deletion.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceLockInfo ↔ ServiceLockInfo?
Contains metadata about the lock exist for Google Cloud native backups.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited