BackupPlan class

A BackupPlan specifies some common fields, such as description as well as one or more BackupRule messages.

Each BackupRule has a retention policy and defines a schedule by which the system is to perform backup workloads.

Constructors

BackupPlan({List<BackupRule>? backupRules, String? backupVault, String? backupVaultServiceAccount, ComputeInstanceBackupPlanProperties? computeInstanceBackupPlanProperties, String? createTime, String? description, DiskBackupPlanProperties? diskBackupPlanProperties, String? etag, Map<String, String>? labels, String? logRetentionDays, int? maxCustomOnDemandRetentionDays, String? name, String? resourceType, String? revisionId, String? revisionName, String? state, List<String>? supportedResourceTypes, String? updateTime})
BackupPlan.fromJson(Map json_)

Properties

backupRules ↔ List<BackupRule>?
The backup rules for this BackupPlan.
getter/setter pair
backupVault ↔ String?
Resource name of backup vault which will be used as storage location for backups.
getter/setter pair
backupVaultServiceAccount ↔ String?
The Google Cloud service account to be used by the BackupVault for taking backups.
getter/setter pair
computeInstanceBackupPlanProperties ↔ ComputeInstanceBackupPlanProperties?
Defines optional properties specific to backups of compute instance-based resources, such as Compute Engine.
getter/setter pair
createTime ↔ String?
When the BackupPlan was created.
getter/setter pair
description ↔ String?
The description of the BackupPlan resource.
getter/setter pair
diskBackupPlanProperties ↔ DiskBackupPlanProperties?
Defines optional properties specific to backups of disk-based resources, such as Compute Engine Persistent Disks.
getter/setter pair
etag ↔ String?
etag is returned from the service in the response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
This collection of key/value pairs allows for custom labels to be supplied by the user.
getter/setter pair
logRetentionDays ↔ String?
Applicable only for Cloud SQL resource_type.
getter/setter pair
maxCustomOnDemandRetentionDays ↔ int?
Optional field to configure the maximum number of days for which a backup can be retained.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
resourceType ↔ String?
The resource type to which the BackupPlan will be applied.
getter/setter pair
revisionId ↔ String?
The user friendly revision ID of the BackupPlanRevision.
getter/setter pair
revisionName ↔ String?
The resource id of the BackupPlanRevision.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The State for the BackupPlan.
getter/setter pair
supportedResourceTypes ↔ List<String>?
All resource types to which backupPlan can be applied.
getter/setter pair
updateTime ↔ String?
When the BackupPlan was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited