computeInstanceBackupPlanProperties property
Defines optional properties specific to backups of compute instance-based resources, such as Compute Engine.
This includes settings like whether to perform a guest flush.
Optional.
Implementation
ComputeInstanceBackupPlanProperties? computeInstanceBackupPlanProperties;