BackupVault class

Message describing a BackupVault object.

Constructors

BackupVault({String? accessRestriction, Map<String, String>? annotations, String? backupCount, String? backupMinimumEnforcedRetentionDuration, String? backupRetentionInheritance, String? createTime, bool? deletable, String? description, String? effectiveTime, EncryptionConfig? encryptionConfig, String? etag, Map<String, String>? labels, String? name, String? serviceAccount, String? state, String? totalStoredBytes, String? uid, String? updateTime})
BackupVault.fromJson(Map json_)

Properties

accessRestriction ↔ String?
Restricts access to certain sources and destinations for data being sent into, or restored from, the backup vault.
getter/setter pair
annotations ↔ Map<String, String>?
User annotations.
getter/setter pair
backupCount ↔ String?
The number of backups in this backup vault.
getter/setter pair
backupMinimumEnforcedRetentionDuration ↔ String?
The default and minimum enforced retention for each backup within the backup vault.
getter/setter pair
backupRetentionInheritance ↔ String?
Setting for how a backup's enforced retention end time is inherited.
getter/setter pair
createTime ↔ String?
The time when the instance was created.
getter/setter pair
deletable ↔ bool?
Set to true when there are no backups nested under this resource.
getter/setter pair
description ↔ String?
The description of the BackupVault instance (2048 characters or less).
getter/setter pair
effectiveTime ↔ String?
Time after which the BackupVault resource is locked.
getter/setter pair
encryptionConfig ↔ EncryptionConfig?
The encryption config of the backup vault.
getter/setter pair
etag ↔ String?
Server specified ETag for the backup vault resource to prevent simultaneous updates from overwiting each other.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Service account used by the BackupVault Service for this BackupVault.
getter/setter pair
state ↔ String?
The BackupVault resource instance state.
getter/setter pair
totalStoredBytes ↔ String?
Total size of the storage used by all backup resources.
getter/setter pair
uid ↔ String?
Immutable after resource creation until resource deletion.
getter/setter pair
updateTime ↔ String?
The time when the instance was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited