accessRestriction property
Restricts access to certain sources and destinations for data being sent into, or restored from, the backup vault.
Defaults to WITHIN_ORGANIZATION if not provided during creation.
Optional. Possible string values are:
- "ACCESS_RESTRICTION_UNSPECIFIED" : Access restriction not set. If user does not provide any value or pass this value, it will be changed to WITHIN_ORGANIZATION.
- "WITHIN_PROJECT" : Access to or from resources outside your current project will be denied.
- "WITHIN_ORGANIZATION" : Access to or from resources outside your current organization will be denied.
- "UNRESTRICTED" : No access restriction.
- "WITHIN_ORG_BUT_UNRESTRICTED_FOR_BA" : Access to or from resources outside your current organization will be denied except for backup appliance.
Implementation
core.String? accessRestriction;