BackupWindow class

BackupWindow defines a window of the day during which backup jobs will run.

Constructors

BackupWindow({int? endHourOfDay, int? startHourOfDay})
BackupWindow.fromJson(Map json_)

Properties

endHourOfDay ↔ int?
The hour of day (1-24) when the window end for example if value of end hour of day is 10 that mean backup window end time is 10:00.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startHourOfDay ↔ int?
The hour of day (0-23) when the window starts for example if value of start hour of day is 6 that mean backup window start at 6:00.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited