diskExclusionLabels property
Labels used to identify disks for exclusion from the backup.
If a disk carries any of these labels, it will be excluded (OR logic).
Optional.
Implementation
DiskExclusionLabels? diskExclusionLabels;
Labels used to identify disks for exclusion from the backup.
If a disk carries any of these labels, it will be excluded (OR logic).
Optional.
DiskExclusionLabels? diskExclusionLabels;