ComputeInstanceBackupProperties class

ComputeInstanceBackupProperties represents Compute Engine instance backup properties.

Constructors

ComputeInstanceBackupProperties({bool? canIpForward, String? description, List<AttachedDisk>? disk, List<String>? excludedDisks, List<AcceleratorConfig>? guestAccelerator, bool? guestFlush, List<String>? includedDisks, String? keyRevocationActionType, Map<String, String>? labels, String? machineType, Metadata? metadata, String? minCpuPlatform, List<NetworkInterface>? networkInterface, Scheduling? scheduling, List<ServiceAccount>? serviceAccount, String? sourceInstance, Tags? tags})
ComputeInstanceBackupProperties.fromJson(Map json_)

Properties

canIpForward ↔ bool?
Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
getter/setter pair
description ↔ String?
An optional text description for the instances that are created from these properties.
getter/setter pair
disk ↔ List<AttachedDisk>?
An array of disks that are associated with the instances that are created from these properties.
getter/setter pair
excludedDisks ↔ List<String>?
List of disks excluded from the backup.
getter/setter pair
guestAccelerator ↔ List<AcceleratorConfig>?
A list of guest accelerator cards' type and count to use for instances created from these properties.
getter/setter pair
guestFlush ↔ bool?
Indicates whether to perform a guest flush operation before taking a compute backup.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includedDisks ↔ List<String>?
List of disks included in the backup.
getter/setter pair
keyRevocationActionType ↔ String?
KeyRevocationActionType of the instance.
getter/setter pair
labels ↔ Map<String, String>?
Labels to apply to instances that are created from these properties.
getter/setter pair
machineType ↔ String?
The machine type to use for instances that are created from these properties.
getter/setter pair
metadata ↔ Metadata?
The metadata key/value pairs to assign to instances that are created from these properties.
getter/setter pair
minCpuPlatform ↔ String?
Minimum cpu/platform to be used by instances.
getter/setter pair
networkInterface ↔ List<NetworkInterface>?
An array of network access configurations for this interface.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduling ↔ Scheduling?
Specifies the scheduling options for the instances that are created from these properties.
getter/setter pair
serviceAccount ↔ List<ServiceAccount>?
A list of service accounts with specified scopes.
getter/setter pair
sourceInstance ↔ String?
The source instance used to create this backup.
getter/setter pair
tags ↔ Tags?
A list of tags to apply to the instances that are created from these properties.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited