ComputeInstanceRestoreProperties class

ComputeInstanceRestoreProperties represents Compute Engine instance properties to be overridden during restore.

Constructors

ComputeInstanceRestoreProperties({AdvancedMachineFeatures? advancedMachineFeatures, bool? canIpForward, ConfidentialInstanceConfig? confidentialInstanceConfig, bool? deletionProtection, String? description, List<AttachedDisk>? disks, DisplayDevice? displayDevice, List<AcceleratorConfig>? guestAccelerators, String? hostname, CustomerEncryptionKey? instanceEncryptionKey, String? keyRevocationActionType, Map<String, String>? labels, String? machineType, Metadata? metadata, String? minCpuPlatform, String? name, List<NetworkInterface>? networkInterfaces, NetworkPerformanceConfig? networkPerformanceConfig, InstanceParams? params, String? privateIpv6GoogleAccess, AllocationAffinity? reservationAffinity, List<String>? resourcePolicies, Scheduling? scheduling, List<ServiceAccount>? serviceAccounts, Tags? tags})
ComputeInstanceRestoreProperties.fromJson(Map json_)

Properties

advancedMachineFeatures ↔ AdvancedMachineFeatures?
Controls for advanced machine-related behavior features.
getter/setter pair
canIpForward ↔ bool?
Allows this instance to send and receive packets with non-matching destination or source IPs.
getter/setter pair
confidentialInstanceConfig ↔ ConfidentialInstanceConfig?
Controls Confidential compute options on the instance
getter/setter pair
deletionProtection ↔ bool?
Whether the resource should be protected against deletion.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
disks ↔ List<AttachedDisk>?
Array of disks associated with this instance.
getter/setter pair
displayDevice ↔ DisplayDevice?
Enables display device for the instance.
getter/setter pair
guestAccelerators ↔ List<AcceleratorConfig>?
A list of the type and count of accelerator cards attached to the instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
Specifies the hostname of the instance.
getter/setter pair
instanceEncryptionKey ↔ CustomerEncryptionKey?
Encrypts suspended data for an instance with a customer-managed encryption key.
getter/setter pair
keyRevocationActionType ↔ String?
KeyRevocationActionType of the instance.
getter/setter pair
labels ↔ Map<String, String>?
Labels to apply to this instance.
getter/setter pair
machineType ↔ String?
Full or partial URL of the machine type resource to use for this instance.
getter/setter pair
metadata ↔ Metadata?
This includes custom metadata and predefined keys.
getter/setter pair
minCpuPlatform ↔ String?
Minimum CPU platform to use for this instance.
getter/setter pair
name ↔ String?
Name of the compute instance.
getter/setter pair
networkInterfaces ↔ List<NetworkInterface>?
An array of network configurations for this instance.
getter/setter pair
networkPerformanceConfig ↔ NetworkPerformanceConfig?
Configure network performance such as egress bandwidth tier.
getter/setter pair
params ↔ InstanceParams?
Input only.
getter/setter pair
privateIpv6GoogleAccess ↔ String?
The private IPv6 google access type for the VM.
getter/setter pair
reservationAffinity ↔ AllocationAffinity?
Specifies the reservations that this instance can consume from.
getter/setter pair
resourcePolicies ↔ List<String>?
Resource policies applied to this instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduling ↔ Scheduling?
Sets the scheduling options for this instance.
getter/setter pair
serviceAccounts ↔ List<ServiceAccount>?
A list of service accounts, with their specified scopes, authorized for this instance.
getter/setter pair
tags ↔ Tags?
Tags to apply to this instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited