ComputeInstanceTargetEnvironment class

ComputeInstanceTargetEnvironment represents Compute Engine target environment to be used during restore.

Constructors

ComputeInstanceTargetEnvironment({String? project, bool? useProjectServiceAccount, String? zone})
ComputeInstanceTargetEnvironment.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
project ↔ String?
Target project for the Compute Engine instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useProjectServiceAccount ↔ bool?
Whether to use the project service account for the Compute Engine instance restore.
getter/setter pair
zone ↔ String?
The zone of the Compute Engine instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited