useProjectServiceAccount property
Whether to use the project service account for the Compute Engine instance restore.
Optional.
Implementation
core.bool? useProjectServiceAccount;
Whether to use the project service account for the Compute Engine instance restore.
Optional.
core.bool? useProjectServiceAccount;