DataSource class

Message describing a DataSource object.

Datasource object used to represent Datasource details for both admin and basic view.

Constructors

DataSource({bool? backupBlockedByVaultAccessRestriction, BackupConfigInfo? backupConfigInfo, String? backupCount, String? configState, String? createTime, DataSourceBackupApplianceApplication? dataSourceBackupApplianceApplication, DataSourceGcpResource? dataSourceGcpResource, String? etag, Map<String, String>? labels, String? name, String? state, String? totalStoredBytes, String? updateTime})
DataSource.fromJson(Map json_)

Properties

backupBlockedByVaultAccessRestriction ↔ bool?
This field is set to true if the backup is blocked by vault access restriction.
getter/setter pair
backupConfigInfo ↔ BackupConfigInfo?
Details of how the resource is configured for backup.
getter/setter pair
backupCount ↔ String?
Number of backups in the data source.
getter/setter pair
configState ↔ String?
The backup configuration state.
getter/setter pair
createTime ↔ String?
The time when the instance was created.
getter/setter pair
dataSourceBackupApplianceApplication ↔ DataSourceBackupApplianceApplication?
The backed up resource is a backup appliance application.
getter/setter pair
dataSourceGcpResource ↔ DataSourceGcpResource?
The backed up resource is a Google Cloud resource.
getter/setter pair
etag ↔ String?
Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The DataSource resource instance state.
getter/setter pair
totalStoredBytes ↔ String?
The number of bytes (metadata and data) stored in this datasource.
getter/setter pair
updateTime ↔ String?
The time when the instance was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited