DataSourceBackupApplianceApplication class

BackupApplianceApplication describes a Source Resource when it is an application backed up by a BackupAppliance.

Constructors

DataSourceBackupApplianceApplication({String? applianceId, String? applicationId, String? applicationName, String? backupAppliance, String? hostId, String? hostname, String? type})
DataSourceBackupApplianceApplication.fromJson(Map json_)

Properties

applianceId ↔ String?
Appliance Id of the Backup Appliance.
getter/setter pair
applicationId ↔ String?
The appid field of the application within the Backup Appliance.
getter/setter pair
applicationName ↔ String?
The name of the Application as known to the Backup Appliance.
getter/setter pair
backupAppliance ↔ String?
Appliance name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostId ↔ String?
Hostid of the application host.
getter/setter pair
hostname ↔ String?
Hostname of the host where the application is running.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the application.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited