DataSourceGcpResourceInfo class

The Google Cloud resource that the DataSource is associated with.

Constructors

DataSourceGcpResourceInfo({AlloyDBClusterDataSourceReferenceProperties? alloyDbClusterProperties, CloudSqlInstanceDataSourceReferenceProperties? cloudSqlInstanceProperties, FilestoreInstanceDataSourceReferenceProperties? filestoreInstanceProperties, String? gcpResourcename, String? location, String? type})
DataSourceGcpResourceInfo.fromJson(Map json_)

Properties

alloyDbClusterProperties ↔ AlloyDBClusterDataSourceReferenceProperties?
The properties of the AlloyDB cluster.
getter/setter pair
cloudSqlInstanceProperties ↔ CloudSqlInstanceDataSourceProperties?
The properties of the Cloud SQL instance.
getter/setter pair
filestoreInstanceProperties ↔ FilestoreInstanceDataSourceReferenceProperties?
The properties of the Filestore instance.
getter/setter pair
gcpResourcename ↔ String?
The resource name of the Google Cloud resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
The location of the Google Cloud resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the Google Cloud resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited