DataSourceReference class

DataSourceReference is a reference to a DataSource resource.

Constructors

DataSourceReference({String? createTime, String? dataSource, DataSourceBackupConfigInfo? dataSourceBackupConfigInfo, String? dataSourceBackupConfigState, String? dataSourceBackupCount, DataSourceGcpResourceInfo? dataSourceGcpResourceInfo, String? name, String? totalStoredBytes})
DataSourceReference.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the DataSourceReference was created.
getter/setter pair
dataSource ↔ String?
The resource name of the DataSource.
getter/setter pair
dataSourceBackupConfigInfo ↔ DataSourceBackupConfigInfo?
Information of backup configuration on the DataSource.
getter/setter pair
dataSourceBackupConfigState ↔ String?
The backup configuration state of the DataSource.
getter/setter pair
dataSourceBackupCount ↔ String?
Number of backups in the DataSource.
getter/setter pair
dataSourceGcpResourceInfo ↔ DataSourceGcpResourceInfo?
The Google Cloud resource that the DataSource is associated with.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalStoredBytes ↔ String?
Total size of the storage used by all backup resources for the referenced datasource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited