DiskDataSourceProperties class

DiskDataSourceProperties represents the properties of a Disk resource that are stored in the DataSource.

.

Constructors

DiskDataSourceProperties({String? description, String? name, String? sizeGb, String? type})
DiskDataSourceProperties.fromJson(Map json_)

Properties

description ↔ String?
The description of the disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the disk backed up by the datasource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeGb ↔ String?
The size of the disk in GB.
getter/setter pair
type ↔ String?
The type of the disk.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited