labels property

List<LabelKeyValPair>? labels
getter/setter pair

Labels used to identify disks for exclusion from the backup.

If a disk carries any of these labels, it will be excluded (OR logic).

Optional.

Implementation

core.List<LabelKeyValPair>? labels;