DiskTargetEnvironment class

DiskTargetEnvironment represents the target environment for the disk.

Constructors

DiskTargetEnvironment({String? project, bool? useProjectServiceAccount, String? zone})
DiskTargetEnvironment.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
project ↔ String?
Target project for the disk.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useProjectServiceAccount ↔ bool?
Whether to use the project service account for the disk restore.
getter/setter pair
zone ↔ String?
Target zone for the disk.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited