FetchAccessTokenResponse class

Response message for FetchAccessToken.

Constructors

FetchAccessTokenResponse({String? expireTime, String? readLocation, String? token, String? writeLocation})
FetchAccessTokenResponse.fromJson(Map json_)

Properties

expireTime ↔ String?
The token is valid until this time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readLocation ↔ String?
The location in bucket that can be used for reading.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
Input only.
getter/setter pair
writeLocation ↔ String?
The location in bucket that can be used for writing.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited