FilestoreInstanceDataSourceReferenceProperties class

FilestoreInstanceDataSourceReferenceProperties represents the properties of a Filestore resource that are stored in the DataSourceReference.

.

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceCreateTime ↔ String?
The instance creation timestamp.
getter/setter pair
name ↔ String?
Name of the Filestore instance backed up by the datasource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited