FinalizeBackupRequest class

Message for finalizing a Backup.

Constructors

FinalizeBackupRequest({String? backupId, String? consistencyTime, String? description, String? recoveryRangeEndTime, String? recoveryRangeStartTime, String? requestId, String? retentionDuration})
FinalizeBackupRequest.fromJson(Map json_)

Properties

backupId ↔ String?
Resource ID of the Backup resource to be finalized.
getter/setter pair
consistencyTime ↔ String?
The point in time when this backup was captured from the source.
getter/setter pair
description ↔ String?
This will be assigned to the description field of the newly created Backup.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
recoveryRangeEndTime ↔ String?
The latest timestamp of data available in this Backup.
getter/setter pair
recoveryRangeStartTime ↔ String?
The earliest timestamp of data available in this Backup.
getter/setter pair
requestId ↔ String?
An optional request ID to identify requests.
getter/setter pair
retentionDuration ↔ String?
The ExpireTime on the backup will be set to FinalizeTime plus this duration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited