GcpBackupConfig class

GcpBackupConfig captures the Backup configuration details for Google Cloud resources.

All Google Cloud resources regardless of type are protected with backup plan associations.

Constructors

GcpBackupConfig({String? backupPlan, String? backupPlanAssociation, String? backupPlanDescription, String? backupPlanRevisionId, String? backupPlanRevisionName, List<String>? backupPlanRules})
GcpBackupConfig.fromJson(Map json_)

Properties

backupPlan ↔ String?
The name of the backup plan.
getter/setter pair
backupPlanAssociation ↔ String?
The name of the backup plan association.
getter/setter pair
backupPlanDescription ↔ String?
The description of the backup plan.
getter/setter pair
backupPlanRevisionId ↔ String?
The user friendly id of the backup plan revision.
getter/setter pair
backupPlanRevisionName ↔ String?
The name of the backup plan revision.
getter/setter pair
backupPlanRules ↔ List<String>?
The names of the backup plan rules which point to this backupvault
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited