backupPlanLocation property

String? backupPlanLocation
getter/setter pair

The location where the BackupPlan will be created.

This field is required for multi-region BackupVaults and is optional for regional BackupVaults. It is useful when creating a Backup Vault in a multi-region, allowing the BackupPlan to reside in a specific region within that multi-region. If this field is not provided, the BackupPlan will be created in the same location as specified in the name field.

Optional.

Implementation

core.String? backupPlanLocation;