validateOnly property
If set, validates the request and returns the result, but does not actually run it.
Optional.
Implementation
core.bool? validateOnly;
If set, validates the request and returns the result, but does not actually run it.
Optional.
core.bool? validateOnly;