key property
Key of the label.
The key must follow the format: \\p{Ll}\\p{Lo}{0,62}. This means the key
must start with a lowercase letter or a lowercase international character,
followed by zero or more lowercase letters, lowercase international
characters, numbers, underscores, or dashes. The key must be at most 63
characters long. International characters are allowed.
Implementation
core.String? key;