ManagementServer class

ManagementServer describes a single BackupDR ManagementServer instance.

Constructors

ManagementServer({List<String>? baProxyUri, String? createTime, String? description, String? etag, Map<String, String>? labels, ManagementURI? managementUri, String? name, List<NetworkConfig>? networks, String? oauth2ClientId, bool? satisfiesPzi, bool? satisfiesPzs, String? state, String? type, String? updateTime, WorkforceIdentityBasedManagementURI? workforceIdentityBasedManagementUri, WorkforceIdentityBasedOAuth2ClientID? workforceIdentityBasedOauth2ClientId})
ManagementServer.fromJson(Map json_)

Properties

baProxyUri ↔ List<String>?
The hostname or ip address of the exposed AGM endpoints, used by BAs to connect to BA proxy.
getter/setter pair
createTime ↔ String?
The time when the instance was created.
getter/setter pair
description ↔ String?
The description of the ManagementServer instance (2048 characters or less).
getter/setter pair
etag ↔ String?
Server specified ETag for the ManagementServer resource to prevent simultaneous updates from overwiting each other.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
managementUri ↔ ManagementURI?
The hostname or ip address of the exposed AGM endpoints, used by clients to connect to AGM/RD graphical user interface and APIs.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
networks ↔ List<NetworkConfig>?
VPC networks to which the ManagementServer instance is connected.
getter/setter pair
oauth2ClientId ↔ String?
The OAuth 2.0 client id is required to make API calls to the Backup and DR instance API of this ManagementServer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
state ↔ String?
The ManagementServer state.
getter/setter pair
type ↔ String?
The type of the ManagementServer resource.
getter/setter pair
updateTime ↔ String?
The time when the instance was updated.
getter/setter pair
workforceIdentityBasedManagementUri ↔ WorkforceIdentityBasedManagementURI?
The hostnames of the exposed AGM endpoints for both types of user i.e. 1p and 3p, used to connect AGM/RM UI.
getter/setter pair
workforceIdentityBasedOauth2ClientId ↔ WorkforceIdentityBasedOAuth2ClientID?
The OAuth client IDs for both types of user i.e. 1p and 3p.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited