NetworkConfig class

Network configuration for ManagementServer instance.

Constructors

NetworkConfig({String? network, String? peeringMode})
NetworkConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
network ↔ String?
The resource name of the Google Compute Engine VPC network to which the ManagementServer instance is connected.
getter/setter pair
peeringMode ↔ String?
The network connect mode of the ManagementServer instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited