fetch method
Fetches ResourceBackupConfigs.
Request parameters:
parent - Required. The project, folder or organization and location for
which to retrieve resource backup configs. Format:
'projects/{project_id}/locations/{location}',
'folders/{folder_id}/locations/{location}', or
'organizations/{organization_id}/locations/{location}'.
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
filter - Optional. Filtering results.
orderBy - Optional. Hint for how to order the results.
pageSize - Optional. Requested page size. Server may return fewer items
than requested. If unspecified, server will use 100 as default. Maximum
value is 500 and values above 500 will be coerced to 500.
pageToken - Optional. A token identifying a page of results the server
should return.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a FetchResourceBackupConfigsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<FetchResourceBackupConfigsResponse> fetch(
core.String parent, {
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v1/' + core.Uri.encodeFull('$parent') + '/resourceBackupConfigs:fetch';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return FetchResourceBackupConfigsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}