useProjectServiceAccount property
Whether to use the project service account for the disk restore.
Optional.
Implementation
core.bool? useProjectServiceAccount;
Whether to use the project service account for the disk restore.
Optional.
core.bool? useProjectServiceAccount;