ResourceBackupConfig class

ResourceBackupConfig represents a resource along with its backup configurations.

Constructors

ResourceBackupConfig({List<BackupConfigDetails>? backupConfigsDetails, bool? backupConfigured, String? name, String? targetResource, String? targetResourceDisplayName, Map<String, String>? targetResourceLabels, String? targetResourceType, String? uid, bool? vaulted})
ResourceBackupConfig.fromJson(Map json_)

Properties

backupConfigsDetails ↔ List<BackupConfigDetails>?
Backup configurations applying to the target resource, including those targeting its related/child resources.
getter/setter pair
backupConfigured ↔ bool?
Whether the target resource is configured for backup.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetResource ↔ String?
The full resource name of the cloud resource that this configuration applies to.
getter/setter pair
targetResourceDisplayName ↔ String?
The human friendly name of the target resource.
getter/setter pair
targetResourceLabels ↔ Map<String, String>?
Labels associated with the target resource.
getter/setter pair
targetResourceType ↔ String?
The type of the target resource.
getter/setter pair
uid ↔ String?
The unique identifier of the resource backup config.
getter/setter pair
vaulted ↔ bool?
Whether the target resource is protected by a backup vault.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited