bootDisk property

bool? bootDisk
getter/setter pair

Specifies that the boot disk should be restored from the instance backup.

This field should only be set to true if selected.

Implementation

core.bool? bootDisk;