RuleConfigInfo class

Message for rules config info.

Constructors

RuleConfigInfo({Status? lastBackupError, String? lastBackupState, String? lastSuccessfulBackupConsistencyTime, String? ruleId})
RuleConfigInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastBackupError ↔ Status?
google.rpc.Status object to store the last backup error.
getter/setter pair
lastBackupState ↔ String?
The last backup state for rule.
getter/setter pair
lastSuccessfulBackupConsistencyTime ↔ String?
The point in time when the last successful backup was captured from the source.
getter/setter pair
ruleId ↔ String?
Backup Rule id fetched from backup plan.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited