Scheduling class

Sets the scheduling options for an Instance.

Constructors

Scheduling({bool? automaticRestart, String? instanceTerminationAction, SchedulingDuration? localSsdRecoveryTimeout, int? minNodeCpus, List<NodeAffinity>? nodeAffinities, String? onHostMaintenance, bool? preemptible, String? provisioningModel})
Scheduling.fromJson(Map json_)

Properties

automaticRestart ↔ bool?
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceTerminationAction ↔ String?
Specifies the termination action for the instance.
getter/setter pair
localSsdRecoveryTimeout ↔ SchedulingDuration?
Specifies the maximum amount of time a Local Ssd Vm should wait while recovery of the Local Ssd state is attempted.
getter/setter pair
minNodeCpus ↔ int?
The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
getter/setter pair
nodeAffinities ↔ List<NodeAffinity>?
A set of node affinity and anti-affinity configurations.
getter/setter pair
onHostMaintenance ↔ String?
Defines the maintenance behavior for this instance.
getter/setter pair
preemptible ↔ bool?
Defines whether the instance is preemptible.
getter/setter pair
provisioningModel ↔ String?
Specifies the provisioning model of the instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited