StandardSchedule class

StandardSchedule defines a schedule that run within the confines of a defined window of days.

We can define recurrence type for schedule as HOURLY, DAILY, WEEKLY, MONTHLY or YEARLY.

Constructors

StandardSchedule({BackupWindow? backupWindow, List<int>? daysOfMonth, List<String>? daysOfWeek, int? hourlyFrequency, List<String>? months, String? recurrenceType, String? timeZone, WeekDayOfMonth? weekDayOfMonth})
StandardSchedule.fromJson(Map json_)

Properties

backupWindow ↔ BackupWindow?
A BackupWindow defines the window of day during which backup jobs will run.
getter/setter pair
daysOfMonth ↔ List<int>?
Specifies days of months like 1, 5, or 14 on which jobs will run.
getter/setter pair
daysOfWeek ↔ List<String>?
Specifies days of week like, MONDAY or TUESDAY, on which jobs will run.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hourlyFrequency ↔ int?
Specifies frequency for hourly backups.
getter/setter pair
months ↔ List<String>?
Specifies the months of year, like FEBRUARY and/or MAY, on which jobs will run.
getter/setter pair
recurrenceType ↔ String?
Specifies the RecurrenceType for the schedule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone ↔ String?
The time zone to be used when interpreting the schedule.
getter/setter pair
weekDayOfMonth ↔ WeekDayOfMonth?
Specifies a week day of the month like, FIRST SUNDAY or LAST MONDAY, on which jobs will run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited