TriggerBackupRequest class

Request message for triggering a backup.

Constructors

TriggerBackupRequest({int? customRetentionDays, Map<String, String>? labels, String? requestId, String? ruleId})
TriggerBackupRequest.fromJson(Map json_)

Properties

customRetentionDays ↔ int?
The duration for which backup data will be kept, while taking an on-demand backup with custom retention.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels to be applied on the backup.
getter/setter pair
requestId ↔ String?
An optional request ID to identify requests.
getter/setter pair
ruleId ↔ String?
backup rule_id for which a backup needs to be triggered.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited