WeekDayOfMonth class

WeekDayOfMonth defines the week day of the month on which the backups will run.

The message combines a WeekOfMonth and DayOfWeek to produce values like FIRST/MONDAY or LAST/FRIDAY.

Constructors

WeekDayOfMonth({String? dayOfWeek, String? weekOfMonth})
WeekDayOfMonth.fromJson(Map json_)

Properties

dayOfWeek ↔ String?
Specifies the day of the week.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weekOfMonth ↔ String?
Specifies the week of the month.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited