WorkforceIdentityBasedManagementURI class

ManagementURI depending on the Workforce Identity i.e. either 1p or 3p.

Constructors

WorkforceIdentityBasedManagementURI({String? firstPartyManagementUri, String? thirdPartyManagementUri})
WorkforceIdentityBasedManagementURI.fromJson(Map json_)

Properties

firstPartyManagementUri ↔ String?
First party Management URI for Google Identities.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thirdPartyManagementUri ↔ String?
Third party Management URI for External Identity Providers.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited