Lun class

A storage volume logical unit number (LUN).

Constructors

Lun({bool? bootLun, String? expireTime, String? id, List<String>? instances, String? multiprotocolType, String? name, bool? shareable, String? sizeGb, String? state, String? storageType, String? storageVolume, String? wwid})
Lun.fromJson(Map json_)

Properties

bootLun ↔ bool?
Display if this LUN is a boot LUN.
getter/setter pair
expireTime ↔ String?
Time after which LUN will be fully deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
An identifier for the LUN, generated by the backend.
getter/setter pair
instances ↔ List<String>?
Instances this Lun is attached to.
getter/setter pair
multiprotocolType ↔ String?
The LUN multiprotocol type ensures the characteristics of the LUN are optimized for each operating system. Possible string values are:
getter/setter pair
name ↔ String?
The name of the LUN.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareable ↔ bool?
Display if this LUN can be shared between multiple physical servers.
getter/setter pair
sizeGb ↔ String?
The size of this LUN, in GiB.
getter/setter pair
state ↔ String?
The state of this storage volume. Possible string values are:
getter/setter pair
storageType ↔ String?
The storage type for this LUN. Possible string values are:
getter/setter pair
storageVolume ↔ String?
Display the storage volume for this LUN.
getter/setter pair
wwid ↔ String?
The WWID for this LUN.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited