VlanAttachment class

VLAN attachment details.

Constructors

VlanAttachment({String? id, String? interconnectAttachment, String? pairingKey, String? peerIp, String? peerVlanId, QosPolicy? qosPolicy, String? routerIp})
VlanAttachment.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The identifier of the attachment within vrf.
getter/setter pair
interconnectAttachment ↔ String?
The name of the vlan attachment within vrf.
getter/setter pair
pairingKey ↔ String?
Input only.
getter/setter pair
peerIp ↔ String?
The peer IP of the attachment.
getter/setter pair
peerVlanId ↔ String?
The peer vlan ID of the attachment.
getter/setter pair
qosPolicy ↔ QosPolicy?
The QOS policy applied to this VLAN attachment.
getter/setter pair
routerIp ↔ String?
The router IP of the attachment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited