AgentMetadata class

VM Agent Metadata.

Constructors

AgentMetadata({String? creationTime, String? creator, String? imageVersion, String? instance, String? instanceId, bool? instancePreemptionNoticeReceived, String? machineType, Map<String, String>? osRelease, String? version, String? zone})
AgentMetadata.fromJson(Map json_)

Properties

creationTime ↔ String?
When the VM agent started.
getter/setter pair
creator ↔ String?
Full name of the entity that created this vm.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageVersion ↔ String?
image version for the VM that this agent is installed on.
getter/setter pair
instance ↔ String?
GCP instance name (go/instance-name).
getter/setter pair
instanceId ↔ String?
GCP instance ID (go/instance-id).
getter/setter pair
instancePreemptionNoticeReceived ↔ bool?
If the GCP instance has received preemption notice.
getter/setter pair
machineType ↔ String?
machine type of the VM
getter/setter pair
osRelease ↔ Map<String, String>?
parsed contents of /etc/os-release
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
agent binary version running on VM
getter/setter pair
zone ↔ String?
Agent zone.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited