AgentTaskLoggingOption class

AgentTaskLoggingOption contains the options for the logging of the task.

Properties

hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels to be added to the log entry.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited