AgentTaskUserAccount class

AgentTaskUserAccount contains the information of a POSIX account on the guest os which is used to execute the runnables.

Properties

gid ↔ String?
gid id an unique identifier of the POSIX account group corresponding to the user account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String?
uid is an unique identifier of the POSIX account corresponding to the user account.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited