AgentTimingInfo class

VM timing information

Constructors

AgentTimingInfo({String? agentStartupTime, String? bootTime, String? scriptStartupTime})
AgentTimingInfo.fromJson(Map json_)

Properties

agentStartupTime ↔ String?
Agent startup time
getter/setter pair
bootTime ↔ String?
Boot timestamp of the VM OS
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptStartupTime ↔ String?
Startup time of the Batch VM script.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited