AttachedDisk class

A new or an existing persistent disk (PD) or a local ssd attached to a VM instance.

Constructors

AttachedDisk({String? deviceName, String? existingDisk, Disk? newDisk})
AttachedDisk.fromJson(Map json_)

Properties

deviceName ↔ String?
Device name that the guest operating system will see.
getter/setter pair
existingDisk ↔ String?
Name of an existing PD.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newDisk ↔ Disk?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited