InstancePolicyOrTemplate class

InstancePolicyOrTemplate lets you define the type of resources to use for this job either with an InstancePolicy or an instance template.

If undefined, Batch picks the type of VM to use and doesn't include optional VM resources such as GPUs and extra disks.

Constructors

InstancePolicyOrTemplate({bool? blockProjectSshKeys, bool? installGpuDrivers, bool? installOpsAgent, String? instanceTemplate, InstancePolicy? policy})
InstancePolicyOrTemplate.fromJson(Map json_)

Properties

blockProjectSshKeys ↔ bool?
Set this field to true if you want Batch to block project-level SSH keys from accessing this job's VMs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installGpuDrivers ↔ bool?
Set this field true if you want Batch to help fetch drivers from a third party location and install them for GPUs specified in policy.accelerators or instance_template on your behalf.
getter/setter pair
installOpsAgent ↔ bool?
Set this field true if you want Batch to install Ops Agent on your behalf.
getter/setter pair
instanceTemplate ↔ String?
Name of an instance template used to create VMs.
getter/setter pair
policy ↔ InstancePolicy?
InstancePolicy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited