Job class

The Cloud Batch Job description.

Constructors

Job({AllocationPolicy? allocationPolicy, String? createTime, Map<String, String>? labels, LogsPolicy? logsPolicy, String? name, List<JobNotification>? notifications, String? priority, JobStatus? status, List<TaskGroup>? taskGroups, String? uid, String? updateTime})
Job.fromJson(Map json_)

Properties

allocationPolicy ↔ AllocationPolicy?
Compute resource allocation for all TaskGroups in the Job.
getter/setter pair
createTime ↔ String?
When the Job was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Custom labels to apply to the job and any Cloud Logging LogEntry that it generates.
getter/setter pair
logsPolicy ↔ LogsPolicy?
Log preservation policy for the Job.
getter/setter pair
name ↔ String?
Job name.
getter/setter pair
notifications ↔ List<JobNotification>?
Notification configurations.
getter/setter pair
priority ↔ String?
Priority of the Job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ JobStatus?
Job status.
getter/setter pair
taskGroups ↔ List<TaskGroup>?
TaskGroups in the Job.
getter/setter pair
uid ↔ String?
A system generated unique ID for the Job.
getter/setter pair
updateTime ↔ String?
The last time the Job was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited