LifecyclePolicy class

LifecyclePolicy describes how to deal with task failures based on different conditions.

Constructors

LifecyclePolicy({String? action, ActionCondition? actionCondition})
LifecyclePolicy.fromJson(Map json_)

Properties

action ↔ String?
Action to execute when ActionCondition is true.
getter/setter pair
actionCondition ↔ ActionCondition?
Conditions that decide why a task failure is dealt with a specific action.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited