ListTasksResponse class

ListTasks Response.

Constructors

ListTasksResponse({String? nextPageToken, List<Task>? tasks, List<String>? unreachable})
ListTasksResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Next page token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tasks ↔ List<Task>?
Tasks.
getter/setter pair
unreachable ↔ List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited