PlacementPolicy class

PlacementPolicy describes a group placement policy for the VMs controlled by this AllocationPolicy.

Constructors

PlacementPolicy({String? collocation, String? maxDistance})
PlacementPolicy.fromJson(Map json_)

Properties

collocation ↔ String?
UNSPECIFIED vs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxDistance ↔ String?
When specified, causes the job to fail if more than max_distance logical switches are required between VMs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited