ProjectsLocationsStateResource class

Constructors

ProjectsLocationsStateResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report(ReportAgentStateRequest request, String parent, {String? $fields}) → Future<ReportAgentStateResponse>
Report agent's state, e.g. agent status and tasks information
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited