TaskStatus class

Status of a task.

Constructors

TaskStatus({String? state, List<StatusEvent>? statusEvents})
TaskStatus.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Task state. Possible string values are:
getter/setter pair
statusEvents ↔ List<StatusEvent>?
Detailed info about why the state is reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited