AppGateway class

A BeyondCorp AppGateway resource represents a BeyondCorp protected AppGateway to a remote application.

It creates all the necessary GCP components needed for creating a BeyondCorp protected AppGateway. Multiple connectors can be authorised for a single AppGateway.

Constructors

AppGateway({List<AllocatedConnection>? allocatedConnections, String? createTime, String? displayName, String? hostType, Map<String, String>? labels, String? name, bool? satisfiesPzi, bool? satisfiesPzs, String? state, String? type, String? uid, String? updateTime, String? uri})
AppGateway.fromJson(Map json_)

Properties

allocatedConnections ↔ List<AllocatedConnection>?
A list of connections allocated for the Gateway
getter/setter pair
createTime ↔ String?
Timestamp when the resource was created.
getter/setter pair
displayName ↔ String?
An arbitrary user-provided name for the AppGateway.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostType ↔ String?
The type of hosting used by the AppGateway.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
name ↔ String?
Unique resource name of the AppGateway.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
state ↔ String?
The current state of the AppGateway.
getter/setter pair
type ↔ String?
The type of network connectivity used by the AppGateway.
getter/setter pair
uid ↔ String?
A unique identifier for the instance generated by the system.
getter/setter pair
updateTime ↔ String?
Timestamp when the resource was last modified.
getter/setter pair
uri ↔ String?
Server-defined URI for this resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited