biglake/v1 library

Lakehouse API - v1

The Lakehouse API (formerly BigLake API) provides access to a serverless, fully managed, and highly available metastore that provides a single source of truth for your data lakehouse. It lets multiple engines—including Apache Spark, Google Managed Spark, Apache Flink, Trino and BigQuery—share tables and metadata for key open formats (Apache Iceberg, Apache Hive), and query the same copy of data. Plus, through the Lakehouse runtime catalog federation seamlessly unite your lakehouse ecosystem, letting Iceberg compatible engines on Google Cloud (BigQuery, Google Managed Spark) discover and analyze enterprise data across Snowflake, Databricks, and AWS Glue.

For more information, see cloud.google.com/products/lakehouse

Create an instance of BigLakeServiceApi to access these resources:

Classes

AuditConfig
Specifies the audit configuration for a service.
BigLakeServiceApi
The Lakehouse API (formerly BigLake API) provides access to a serverless, fully managed, and highly available metastore that provides a single source of truth for your data lakehouse.
Binding
Associates members, or principals, with a role.
Catalog
Catalog is the container of databases.
Database
Database is the container of tables.
HiveDatabaseOptions
Options of a Hive database.
HiveTableOptions
Options of a Hive table.
ListCatalogsResponse
Response message for the ListCatalogs method.
ListDatabasesResponse
Response message for the ListDatabases method.
ListTablesResponse
Response message for the ListTables method.
Policy
An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources.
ProjectsCatalogsNamespacesResource
ProjectsCatalogsNamespacesTablesResource
ProjectsCatalogsResource
ProjectsLocationsCatalogsDatabasesResource
ProjectsLocationsCatalogsDatabasesTablesResource
ProjectsLocationsCatalogsResource
ProjectsLocationsResource
ProjectsResource
RenameTableRequest
Request message for the RenameTable method in MetastoreService
SerDeInfo
Serializer and deserializer information.
SetIamPolicyRequest
Request message for SetIamPolicy method.
StorageDescriptor
Stores physical storage information of the data.
Table
Represents a table.

Typedefs

AuditLogConfig = $AuditLogConfig
Provides the configuration for logging a type of permissions.
Expr = $Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
TestIamPermissionsRequest = $TestIamPermissionsRequest00
Request message for TestIamPermissions method.
TestIamPermissionsResponse = $PermissionsResponse
Response message for TestIamPermissions method.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.