Database class

Database is the container of tables.

Constructors

Database({String? createTime, String? deleteTime, String? expireTime, HiveDatabaseOptions? hiveOptions, String? name, String? type, String? updateTime})
Database.fromJson(Map json_)

Properties

createTime ↔ String?
The creation time of the database.
getter/setter pair
deleteTime ↔ String?
The deletion time of the database.
getter/setter pair
expireTime ↔ String?
The time when this database is considered expired.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hiveOptions ↔ HiveDatabaseOptions?
Options of a Hive database.
getter/setter pair
name ↔ String?
The resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The database type. Possible string values are:
getter/setter pair
updateTime ↔ String?
The last modification time of the database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited