AggregateClassificationMetrics class

Aggregate metrics for classification/classifier models.

For multi-class models, the metrics are either macro-averaged or micro-averaged. When macro-averaged, the metrics are calculated for each label and then an unweighted average is taken of those values. When micro-averaged, the metric is calculated globally by counting the total number of correctly predicted rows.

Constructors

AggregateClassificationMetrics({double? accuracy, double? f1Score, double? logLoss, double? precision, double? recall, double? rocAuc, double? threshold})
AggregateClassificationMetrics.fromJson(Map json_)

Properties

accuracy ↔ double?
Accuracy is the fraction of predictions given the correct label.
getter/setter pair
f1Score ↔ double?
The F1 score is an average of recall and precision.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
logLoss ↔ double?
Logarithmic Loss.
getter/setter pair
precision ↔ double?
Precision is the fraction of actual positive predictions that had positive actual labels.
getter/setter pair
recall ↔ double?
Recall is the fraction of actual positive labels that were given a positive prediction.
getter/setter pair
rocAuc ↔ double?
Area Under a ROC Curve.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold ↔ double?
Threshold at which the metrics are computed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited