ArrowRecordBatch class
Arrow RecordBatch.
This feature is not yet available.
Constructors
- ArrowRecordBatch({String? serializedRecordBatch})
- ArrowRecordBatch.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializedRecordBatch ↔ String?
-
IPC-serialized Arrow RecordBatch.
getter/setter pair
-
serializedRecordBatchAsBytes
↔ List<
int> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited