ArrowSerializationOptions class
Contains options specific to Arrow Serialization.
This feature is not yet available.
Constructors
- ArrowSerializationOptions({String? bufferCompression, String? picosTimestampPrecision})
- ArrowSerializationOptions.fromJson(Map json_)
Properties
- bufferCompression ↔ String?
-
The compression codec to use for Arrow buffers in serialized record
batches.
Possible string values are:
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- picosTimestampPrecision ↔ String?
-
Set timestamp precision option.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited