picosTimestampPrecision property

String? picosTimestampPrecision
getter/setter pair

Set timestamp precision option.

If not set, the default precision is microseconds.

Optional. Possible string values are:

  • "PICOS_TIMESTAMP_PRECISION_UNSPECIFIED" : Unspecified timestamp precision. The default precision is microseconds.
  • "TIMESTAMP_PRECISION_MICROS" : Timestamp values returned in the results will be truncated to microsecond level precision. The value will be encoded as Arrow TIMESTAMP type in a 64 bit integer.
  • "TIMESTAMP_PRECISION_NANOS" : Timestamp values returned in the results will be truncated to nanosecond level precision. The value will be encoded as Arrow TIMESTAMP type in a 64 bit integer.
  • "TIMESTAMP_PRECISION_PICOS" : Timestamp values returned in the results will contain full precision picosecond value. The value will be encoded as a string which conforms to ISO 8601 format.

Implementation

core.String? picosTimestampPrecision;