BiEngineReason class

Reason why BI Engine didn't accelerate the query (or sub-query).

Constructors

BiEngineReason({String? code, String? message})
BiEngineReason.fromJson(Map json_)

Properties

code ↔ String?
High-level BI Engine reason for partial or disabled acceleration
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
Free form human-readable reason for partial or disabled acceleration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited