BiEngineStatistics class

Statistics for a BI Engine specific query.

Populated as part of JobStatistics2

Constructors

BiEngineStatistics({String? accelerationMode, String? biEngineMode, List<BiEngineReason>? biEngineReasons})
BiEngineStatistics.fromJson(Map json_)

Properties

accelerationMode ↔ String?
Specifies which mode of BI Engine acceleration was performed (if any).
getter/setter pair
biEngineMode ↔ String?
Specifies which mode of BI Engine acceleration was performed (if any).
getter/setter pair
biEngineReasons ↔ List<BiEngineReason>?
In case of DISABLED or PARTIAL bi_engine_mode, these contain the explanatory reasons as to why BI Engine could not accelerate.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited