BigQueryModelTraining class

Constructors

BigQueryModelTraining({int? currentIteration, String? expectedTotalIterations})
BigQueryModelTraining.fromJson(Map json_)

Properties

currentIteration ↔ int?
Deprecated.
getter/setter pair
expectedTotalIterations ↔ String?
Deprecated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited