BigtableColumn class

Information related to a Bigtable column.

Constructors

BigtableColumn({String? encoding, String? fieldName, bool? onlyReadLatest, BigtableProtoConfig? protoConfig, String? qualifierEncoded, String? qualifierString, String? type})
BigtableColumn.fromJson(Map json_)

Properties

encoding ↔ String?
The encoding of the values when the type is not STRING.
getter/setter pair
fieldName ↔ String?
If the qualifier is not a valid BigQuery field identifier i.e. does not match a-zA-Z*, a valid identifier must be provided as the column field name and is used as field name in queries.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
onlyReadLatest ↔ bool?
If this is set, only the latest version of value in this column are exposed.
getter/setter pair
protoConfig ↔ BigtableProtoConfig?
Protobuf-specific configurations, only takes effect when the encoding is PROTO_BINARY.
getter/setter pair
qualifierEncoded ↔ String?
Qualifier of the column.
getter/setter pair
qualifierEncodedAsBytes ↔ List<int>
getter/setter pair
qualifierString ↔ String?
Qualifier string.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type to convert the value in cells of this column.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited