BigtableOptions class

Options specific to Google Cloud Bigtable data sources.

Constructors

BigtableOptions({List<BigtableColumnFamily>? columnFamilies, bool? ignoreUnspecifiedColumnFamilies, bool? outputColumnFamiliesAsJson, bool? readRowkeyAsString})
BigtableOptions.fromJson(Map json_)

Properties

columnFamilies ↔ List<BigtableColumnFamily>?
List of column families to expose in the table schema along with their types.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreUnspecifiedColumnFamilies ↔ bool?
If field is true, then the column families that are not specified in columnFamilies list are not exposed in the table schema.
getter/setter pair
outputColumnFamiliesAsJson ↔ bool?
If field is true, then each column family will be read as a single JSON column.
getter/setter pair
readRowkeyAsString ↔ bool?
If field is true, then the rowkey column families will be read and converted to string.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited