BinaryConfusionMatrix class

Confusion matrix for binary classification models.

Constructors

BinaryConfusionMatrix({double? accuracy, double? f1Score, String? falseNegatives, String? falsePositives, double? positiveClassThreshold, double? precision, double? recall, String? trueNegatives, String? truePositives})
BinaryConfusionMatrix.fromJson(Map json_)

Properties

accuracy ↔ double?
The fraction of predictions given the correct label.
getter/setter pair
f1Score ↔ double?
The equally weighted average of recall and precision.
getter/setter pair
falseNegatives ↔ String?
Number of false samples predicted as false.
getter/setter pair
falsePositives ↔ String?
Number of false samples predicted as true.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
positiveClassThreshold ↔ double?
Threshold value used when computing each of the following metric.
getter/setter pair
precision ↔ double?
The fraction of actual positive predictions that had positive actual labels.
getter/setter pair
recall ↔ double?
The fraction of actual positive labels that were given a positive prediction.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trueNegatives ↔ String?
Number of true samples predicted as false.
getter/setter pair
truePositives ↔ String?
Number of true samples predicted as true.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited