BqmlTrainingRunTrainingOptions class

Deprecated.

Constructors

BqmlTrainingRunTrainingOptions({bool? earlyStop, double? l1Reg, double? l2Reg, double? learnRate, String? learnRateStrategy, double? lineSearchInitLearnRate, String? maxIteration, double? minRelProgress, bool? warmStart})
BqmlTrainingRunTrainingOptions.fromJson(Map json_)

Properties

earlyStop ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
l1Reg ↔ double?
getter/setter pair
l2Reg ↔ double?
getter/setter pair
learnRate ↔ double?
getter/setter pair
learnRateStrategy ↔ String?
getter/setter pair
lineSearchInitLearnRate ↔ double?
getter/setter pair
maxIteration ↔ String?
getter/setter pair
minRelProgress ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warmStart ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited