Cluster class

Message containing the information about one cluster.

Constructors

Cluster({String? centroidId, String? count, List<FeatureValue>? featureValues})
Cluster.fromJson(Map json_)

Properties

centroidId ↔ String?
Centroid id.
getter/setter pair
count ↔ String?
Count of training data rows that were assigned to this cluster.
getter/setter pair
featureValues ↔ List<FeatureValue>?
Values of highly variant features for this cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited