ClusterInfo class

Information about a single cluster for clustering model.

Constructors

ClusterInfo({String? centroidId, double? clusterRadius, String? clusterSize})
ClusterInfo.fromJson(Map json_)

Properties

centroidId ↔ String?
Centroid id.
getter/setter pair
clusterRadius ↔ double?
Cluster radius, the average distance from centroid to each point assigned to the cluster.
getter/setter pair
clusterSize ↔ String?
Cluster size, the total number of points assigned to the cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited