ConfusionMatrix class

Confusion matrix for multi-class classification models.

Constructors

ConfusionMatrix({double? confidenceThreshold, List<Row>? rows})
ConfusionMatrix.fromJson(Map json_)

Properties

confidenceThreshold ↔ double?
Confidence threshold used when computing the entries of the confusion matrix.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rows ↔ List<Row>?
One row per actual label.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited