DataFormatOptions class

Options for data format adjustments.

Constructors

DataFormatOptions({String? timestampOutputFormat, bool? useInt64Timestamp})
DataFormatOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampOutputFormat ↔ String?
The API output format for a timestamp.
getter/setter pair
useInt64Timestamp ↔ bool?
Output timestamp as usec int64.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited