DataPolicyList class
A list of data policy options.
For more information, see Mask data by applying data policies to a column.
Constructors
-
DataPolicyList({List<
DataPolicyOption> ? dataPolicies}) - DataPolicyList.fromJson(Map json_)
Properties
-
dataPolicies
↔ List<
DataPolicyOption> ? -
Contains a list of data policy options.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited