DataSplitResult class

Data split result.

This contains references to the training and evaluation data tables that were used to train the model.

Constructors

DataSplitResult({TableReference? evaluationTable, TableReference? testTable, TableReference? trainingTable})
DataSplitResult.fromJson(Map json_)

Properties

evaluationTable ↔ TableReference?
Table reference of the evaluation data after split.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testTable ↔ TableReference?
Table reference of the test data after split.
getter/setter pair
trainingTable ↔ TableReference?
Table reference of the training data after split.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited