DatasetAccess class

An object that defines dataset access for an entity.

Constructors

DatasetAccess({Expr? condition, DatasetAccessEntry? dataset, String? domain, String? groupByEmail, String? iamMember, String? role, RoutineReference? routine, String? specialGroup, String? userByEmail, TableReference? view})
DatasetAccess.fromJson(Map json_)

Properties

condition ↔ Expr?
condition for the binding.
getter/setter pair
dataset ↔ DatasetAccessEntry?
[Pick one] A grant authorizing all resources of a particular type in a particular dataset access to this dataset.
getter/setter pair
domain ↔ String?
[Pick one] A domain to grant access to.
getter/setter pair
groupByEmail ↔ String?
[Pick one] An email address of a Google Group to grant access to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iamMember ↔ String?
[Pick one] Some other type of member that appears in the IAM Policy but isn't a user, group, domain, or special group.
getter/setter pair
role ↔ String?
An IAM role ID that should be granted to the user, group, or domain specified in this access entry.
getter/setter pair
routine ↔ RoutineReference?
[Pick one] A routine from a different dataset to grant access to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
specialGroup ↔ String?
[Pick one] A special group to grant access to.
getter/setter pair
userByEmail ↔ String?
[Pick one] An email address of a user to grant access to.
getter/setter pair
view ↔ TableReference?
[Pick one] A view from a different dataset to grant access to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited