DatasetListDatasets class

A dataset resource with only a subset of fields, to be returned in a list of datasets.

Constructors

DatasetListDatasets({String? catalogSource, DatasetReference? datasetReference, ExternalDatasetReference? externalDatasetReference, String? friendlyName, String? id, String? kind, Map<String, String>? labels, String? location, String? type})
DatasetListDatasets.fromJson(Map json_)

Properties

catalogSource ↔ String?
The origin of the dataset, one of: * (Unset) - Native BigQuery Dataset.
getter/setter pair
datasetReference ↔ DatasetReference?
The dataset reference.
getter/setter pair
externalDatasetReference ↔ ExternalDatasetReference?
Reference to a read-only external dataset defined in data catalogs outside of BigQuery.
getter/setter pair
friendlyName ↔ String?
An alternate name for the dataset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The fully-qualified, unique, opaque ID of the dataset.
getter/setter pair
kind ↔ String?
The resource type.
getter/setter pair
labels ↔ Map<String, String>?
The labels associated with this dataset.
getter/setter pair
location ↔ String?
The geographic location where the dataset resides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Same as type in Dataset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited