list method

Future<DatasetList> list(
  1. String projectId, {
  2. bool? all,
  3. String? filter,
  4. int? maxResults,
  5. String? pageToken,
  6. String? $fields,
})

Lists all datasets in the specified project to which the user has been granted the READER dataset role.

IAM Permissions Requires no specific IAM permission(s) to use this

method. Results are filtered to only include datasets on which the caller has the bigquery.datasets.get permission.

Request parameters:

projectId - Required. Project ID of the datasets to be listed Value must have pattern ^\[^/\]+$.

all - Whether to list all datasets, including hidden ones

filter - An expression for filtering the results of the request by label. The syntax is labels.[:]. Multiple filters can be AND-ed together by connecting with a space. Example: labels.department:receiving labels.active. See Filtering datasets using labels for details.

maxResults - The maximum number of results to return in a single response page. Leverage the page tokens to iterate through the entire collection.

pageToken - Page token, returned by a previous call, to request the next page of results

$fields - Selector specifying which fields to include in a partial response.

Completes with a DatasetList.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<DatasetList> list(
  core.String projectId, {
  core.bool? all,
  core.String? filter,
  core.int? maxResults,
  core.String? pageToken,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'all': ?all == null ? null : ['${all}'],
    'filter': ?filter == null ? null : [filter],
    'maxResults': ?maxResults == null ? null : ['${maxResults}'],
    'pageToken': ?pageToken == null ? null : [pageToken],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'projects/' + core.Uri.encodeFull('$projectId') + '/datasets';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return DatasetList.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}