ErrorProto class

Error details.

Constructors

ErrorProto({String? debugInfo, String? location, String? message, String? reason})
ErrorProto.fromJson(Map json_)

Properties

debugInfo ↔ String?
Debugging information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
Specifies where the error occurred, if present.
getter/setter pair
message ↔ String?
A human-readable description of the error.
getter/setter pair
reason ↔ String?
A short error code that summarizes the error.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited