ExplainQueryStage class

A single stage of query execution.

Constructors

ExplainQueryStage({String? completedParallelInputs, String? computeMode, String? computeMsAvg, String? computeMsMax, double? computeRatioAvg, double? computeRatioMax, String? endMs, String? id, List<String>? inputStages, String? name, String? parallelInputs, String? readMsAvg, String? readMsMax, double? readRatioAvg, double? readRatioMax, String? recordsRead, String? recordsWritten, String? shuffleOutputBytes, String? shuffleOutputBytesSpilled, String? slotMs, String? startMs, String? status, List<ExplainQueryStep>? steps, String? waitMsAvg, String? waitMsMax, double? waitRatioAvg, double? waitRatioMax, String? writeMsAvg, String? writeMsMax, double? writeRatioAvg, double? writeRatioMax})
ExplainQueryStage.fromJson(Map json_)

Properties

completedParallelInputs ↔ String?
Number of parallel input segments completed.
getter/setter pair
computeMode ↔ String?
Compute mode for this stage.
getter/setter pair
computeMsAvg ↔ String?
Milliseconds the average shard spent on CPU-bound tasks.
getter/setter pair
computeMsMax ↔ String?
Milliseconds the slowest shard spent on CPU-bound tasks.
getter/setter pair
computeRatioAvg ↔ double?
Relative amount of time the average shard spent on CPU-bound tasks.
getter/setter pair
computeRatioMax ↔ double?
Relative amount of time the slowest shard spent on CPU-bound tasks.
getter/setter pair
endMs ↔ String?
Stage end time represented as milliseconds since the epoch.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique ID for the stage within the plan.
getter/setter pair
inputStages ↔ List<String>?
IDs for stages that are inputs to this stage.
getter/setter pair
name ↔ String?
Human-readable name for the stage.
getter/setter pair
parallelInputs ↔ String?
Number of parallel input segments to be processed
getter/setter pair
readMsAvg ↔ String?
Milliseconds the average shard spent reading input.
getter/setter pair
readMsMax ↔ String?
Milliseconds the slowest shard spent reading input.
getter/setter pair
readRatioAvg ↔ double?
Relative amount of time the average shard spent reading input.
getter/setter pair
readRatioMax ↔ double?
Relative amount of time the slowest shard spent reading input.
getter/setter pair
recordsRead ↔ String?
Number of records read into the stage.
getter/setter pair
recordsWritten ↔ String?
Number of records written by the stage.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleOutputBytes ↔ String?
Total number of bytes written to shuffle.
getter/setter pair
shuffleOutputBytesSpilled ↔ String?
Total number of bytes written to shuffle and spilled to disk.
getter/setter pair
slotMs ↔ String?
Slot-milliseconds used by the stage.
getter/setter pair
startMs ↔ String?
Stage start time represented as milliseconds since the epoch.
getter/setter pair
status ↔ String?
Current status for this stage.
getter/setter pair
steps ↔ List<ExplainQueryStep>?
List of operations within the stage in dependency order (approximately chronological).
getter/setter pair
waitMsAvg ↔ String?
Milliseconds the average shard spent waiting to be scheduled.
getter/setter pair
waitMsMax ↔ String?
Milliseconds the slowest shard spent waiting to be scheduled.
getter/setter pair
waitRatioAvg ↔ double?
Relative amount of time the average shard spent waiting to be scheduled.
getter/setter pair
waitRatioMax ↔ double?
Relative amount of time the slowest shard spent waiting to be scheduled.
getter/setter pair
writeMsAvg ↔ String?
Milliseconds the average shard spent on writing output.
getter/setter pair
writeMsMax ↔ String?
Milliseconds the slowest shard spent on writing output.
getter/setter pair
writeRatioAvg ↔ double?
Relative amount of time the average shard spent on writing output.
getter/setter pair
writeRatioMax ↔ double?
Relative amount of time the slowest shard spent on writing output.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited