ExternalDataConfiguration class

Constructors

ExternalDataConfiguration({bool? autodetect, AvroOptions? avroOptions, BigtableOptions? bigtableOptions, String? compression, String? connectionId, CsvOptions? csvOptions, String? dateFormat, String? datetimeFormat, List<String>? decimalTargetTypes, String? fileSetSpecType, GoogleSheetsOptions? googleSheetsOptions, HivePartitioningOptions? hivePartitioningOptions, bool? ignoreUnknownValues, String? jsonExtension, JsonOptions? jsonOptions, int? maxBadRecords, String? metadataCacheMode, String? objectMetadata, ParquetOptions? parquetOptions, String? referenceFileSchemaUri, TableSchema? schema, String? sourceFormat, List<String>? sourceUris, String? timeFormat, String? timeZone, String? timestampFormat, List<int>? timestampTargetPrecision})
ExternalDataConfiguration.fromJson(Map json_)

Properties

autodetect ↔ bool?
Try to detect schema and format options automatically.
getter/setter pair
avroOptions ↔ AvroOptions?
Additional properties to set if sourceFormat is set to AVRO.
getter/setter pair
bigtableOptions ↔ BigtableOptions?
Additional options if sourceFormat is set to BIGTABLE.
getter/setter pair
compression ↔ String?
The compression type of the data source.
getter/setter pair
connectionId ↔ String?
The connection specifying the credentials to be used to read external storage, such as Azure Blob, Cloud Storage, or S3.
getter/setter pair
csvOptions ↔ CsvOptions?
Additional properties to set if sourceFormat is set to CSV.
getter/setter pair
dateFormat ↔ String?
Format used to parse DATE values.
getter/setter pair
datetimeFormat ↔ String?
Format used to parse DATETIME values.
getter/setter pair
decimalTargetTypes ↔ List<String>?
Defines the list of possible SQL data types to which the source decimal values are converted.
getter/setter pair
fileSetSpecType ↔ String?
Specifies how source URIs are interpreted for constructing the file set to load.
getter/setter pair
googleSheetsOptions ↔ GoogleSheetsOptions?
Additional options if sourceFormat is set to GOOGLE_SHEETS.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hivePartitioningOptions ↔ HivePartitioningOptions?
When set, configures hive partitioning support.
getter/setter pair
ignoreUnknownValues ↔ bool?
Indicates if BigQuery should allow extra values that are not represented in the table schema.
getter/setter pair
jsonExtension ↔ String?
Load option to be used together with source_format newline-delimited JSON to indicate that a variant of JSON is being loaded.
getter/setter pair
jsonOptions ↔ JsonOptions?
Additional properties to set if sourceFormat is set to JSON.
getter/setter pair
maxBadRecords ↔ int?
The maximum number of bad records that BigQuery can ignore when reading data.
getter/setter pair
metadataCacheMode ↔ String?
Metadata Cache Mode for the table.
getter/setter pair
objectMetadata ↔ String?
ObjectMetadata is used to create Object Tables.
getter/setter pair
parquetOptions ↔ ParquetOptions?
Additional properties to set if sourceFormat is set to PARQUET.
getter/setter pair
referenceFileSchemaUri ↔ String?
When creating an external table, the user can provide a reference file with the table schema.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ TableSchema?
The schema for the data.
getter/setter pair
sourceFormat ↔ String?
The data format.
getter/setter pair
sourceUris ↔ List<String>?
The fully-qualified URIs that point to your data in Google Cloud.
getter/setter pair
timeFormat ↔ String?
Format used to parse TIME values.
getter/setter pair
timestampFormat ↔ String?
Format used to parse TIMESTAMP values.
getter/setter pair
timestampTargetPrecision ↔ List<int>?
Precisions (maximum number of total digits in base 10) for seconds of TIMESTAMP types that are allowed to the destination table for autodetection mode.
getter/setter pair
timeZone ↔ String?
Time zone used when parsing timestamp values that do not have specific time zone information (e.g. 2024-04-20 12:34:56).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited