ExternalDatasetReference class

Configures the access a dataset defined in an external metadata storage.

Constructors

ExternalDatasetReference({String? connection, String? externalSource})
ExternalDatasetReference.fromJson(Map json_)

Properties

connection ↔ String?
The connection id that is used to access the external_source.
getter/setter pair
externalSource ↔ String?
External source that backs this dataset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited