ExternalRuntimeOptions class

Options for the runtime of the external system.

Constructors

ExternalRuntimeOptions({double? containerCpu, String? containerMemory, String? containerRequestConcurrency, String? maxBatchingRows, String? runtimeConnection, String? runtimeVersion})
ExternalRuntimeOptions.fromJson(Map json_)

Properties

containerCpu ↔ double?
Amount of CPU provisioned for a Python UDF container instance.
getter/setter pair
containerMemory ↔ String?
Amount of memory provisioned for a Python UDF container instance.
getter/setter pair
containerRequestConcurrency ↔ String?
Maximum number of requests that a Python UDF instance can handle concurrently.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxBatchingRows ↔ String?
Maximum number of rows in each batch sent to the external runtime.
getter/setter pair
runtimeConnection ↔ String?
Fully qualified name of the connection whose service account will be used to execute the code in the container.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeVersion ↔ String?
Language runtime version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited