FeatureValue class

Representative value of a single feature within the cluster.

Constructors

FeatureValue({CategoricalValue? categoricalValue, String? featureColumn, double? numericalValue})
FeatureValue.fromJson(Map json_)

Properties

categoricalValue ↔ CategoricalValue?
The categorical feature value.
getter/setter pair
featureColumn ↔ String?
The feature column name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numericalValue ↔ double?
The numerical feature value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited