GenAiErrorStats class

Provides error statistics for the query job across all AI function calls.

Constructors

GenAiErrorStats({List<String>? errors})
GenAiErrorStats.fromJson(Map json_)

Properties

errors List<String>?
A list of unique errors at query level (up to 5, truncated to 100 chars)
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited