GeneratedColumn class

Definition of how values are generated for the field.

Only valid for top-level schema fields (not nested fields).

Optional.

Constructors

GeneratedColumn({GeneratedExpressionInfo? generatedExpressionInfo, String? generatedMode})
GeneratedColumn.fromJson(Map json_)

Properties

generatedExpressionInfo ↔ GeneratedExpressionInfo?
Definition of the expression used to generate the field.
getter/setter pair
generatedMode ↔ String?
Dictates when system generated values are used to populate the field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited