generatedExpressionInfo property
Definition of the expression used to generate the field.
Implementation
GeneratedExpressionInfo? generatedExpressionInfo;
Definition of the expression used to generate the field.
GeneratedExpressionInfo? generatedExpressionInfo;