GeneratedExpressionInfo class

Definition of the expression used to generate the field.

Constructors

GeneratedExpressionInfo({bool? asynchronous, String? generationExpression, bool? stored})
GeneratedExpressionInfo.fromJson(Map json_)

Properties

asynchronous bool?
Whether the column generation is done asynchronously.
getter/setter pair
generationExpression String?
The generation expression (e.g. AI.EMBED(...)) used to generate the field.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stored bool?
Whether the generated column is stored in the table.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited