GetQueryResultsResponse class

Response object of GetQueryResults.

Constructors

GetQueryResultsResponse({bool? cacheHit, List<ErrorProto>? errors, String? etag, bool? jobComplete, JobReference? jobReference, String? kind, String? numDmlAffectedRows, String? pageToken, List<TableRow>? rows, TableSchema? schema, String? totalBytesProcessed, String? totalRows})
GetQueryResultsResponse.fromJson(Map json_)

Properties

cacheHit ↔ bool?
Whether the query result was fetched from the query cache.
getter/setter pair
errors ↔ List<ErrorProto>?
The first errors or warnings encountered during the running of the job.
getter/setter pair
etag ↔ String?
A hash of this response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobComplete ↔ bool?
Whether the query has completed or not.
getter/setter pair
jobReference ↔ JobReference?
Reference to the BigQuery Job that was created to run the query.
getter/setter pair
kind ↔ String?
The resource type of the response.
getter/setter pair
numDmlAffectedRows ↔ String?
The number of rows affected by a DML statement.
getter/setter pair
pageToken ↔ String?
A token used for paging results.
getter/setter pair
rows ↔ List<TableRow>?
An object with as many results as can be contained within the maximum permitted reply size.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ TableSchema?
The schema of the results.
getter/setter pair
totalBytesProcessed ↔ String?
The total number of bytes processed for this query.
getter/setter pair
totalRows ↔ String?
The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited