HighCardinalityJoin class

High cardinality join detailed information.

Constructors

HighCardinalityJoin({String? leftRows, String? outputRows, String? rightRows, int? stepIndex})
HighCardinalityJoin.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
leftRows ↔ String?
Count of left input rows.
getter/setter pair
outputRows ↔ String?
Count of the output rows.
getter/setter pair
rightRows ↔ String?
Count of right input rows.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepIndex ↔ int?
The index of the join operator in the ExplainQueryStep lists.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited