HivePartitioningOptions class

Options for configuring hive partitioning detect.

Constructors

HivePartitioningOptions({List<String>? fields, String? mode, bool? requirePartitionFilter, String? sourceUriPrefix})
HivePartitioningOptions.fromJson(Map json_)

Properties

fields ↔ List<String>?
For permanent external tables, this field is populated with the hive partition keys in the order they were inferred.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?
When set, what mode of hive partitioning to use when reading data.
getter/setter pair
requirePartitionFilter ↔ bool?
If set to true, queries over this table require a partition filter that can be used for partition elimination to be specified.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceUriPrefix ↔ String?
When hive partition detection is requested, a common prefix for all source uris must be required.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited