HparamTuningTrial class

Training info of a trial in hyperparameter tuning models.

Constructors

HparamTuningTrial({String? endTimeMs, String? errorMessage, double? evalLoss, EvaluationMetrics? evaluationMetrics, EvaluationMetrics? hparamTuningEvaluationMetrics, TrainingOptions? hparams, String? startTimeMs, String? status, double? trainingLoss, String? trialId})
HparamTuningTrial.fromJson(Map json_)

Properties

endTimeMs ↔ String?
Ending time of the trial.
getter/setter pair
errorMessage ↔ String?
Error message for FAILED and INFEASIBLE trial.
getter/setter pair
evalLoss ↔ double?
Loss computed on the eval data at the end of trial.
getter/setter pair
evaluationMetrics ↔ EvaluationMetrics?
Evaluation metrics of this trial calculated on the test data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hparams ↔ TrainingOptions?
The hyperprameters selected for this trial.
getter/setter pair
hparamTuningEvaluationMetrics ↔ EvaluationMetrics?
Hyperparameter tuning evaluation metrics of this trial calculated on the eval data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimeMs ↔ String?
Starting time of the trial.
getter/setter pair
status ↔ String?
The status of the trial. Possible string values are:
getter/setter pair
trainingLoss ↔ double?
Loss computed on the training data at the end of trial.
getter/setter pair
trialId ↔ String?
1-based index of the trial.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited