incrementalRowCount property
Number of rows that were in the latest result set before query completion.
Output only.
Implementation
core.String? incrementalRowCount;
Number of rows that were in the latest result set before query completion.
Output only.
core.String? incrementalRowCount;