IndexUnusedReason class

Reason about why no search index was used in the search query (or sub-query).

Constructors

IndexUnusedReason({TableReference? baseTable, String? code, String? indexName, String? message})
IndexUnusedReason.fromJson(Map json_)

Properties

baseTable ↔ TableReference?
Specifies the base table involved in the reason that no search index was used.
getter/setter pair
code ↔ String?
Specifies the high-level reason for the scenario when no search index was used. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indexName ↔ String?
Specifies the name of the unused search index, if available.
getter/setter pair
message ↔ String?
Free form human-readable reason for the scenario when no search index was used.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited