IterationResult class

Information about a single iteration of the training run.

Constructors

IterationResult({ArimaResult? arimaResult, List<ClusterInfo>? clusterInfos, String? durationMs, double? evalLoss, int? index, double? learnRate, List<PrincipalComponentInfo>? principalComponentInfos, double? trainingLoss})
IterationResult.fromJson(Map json_)

Properties

arimaResult ↔ ArimaResult?
Arima result.
getter/setter pair
clusterInfos ↔ List<ClusterInfo>?
Information about top clusters for clustering models.
getter/setter pair
durationMs ↔ String?
Time taken to run the iteration in milliseconds.
getter/setter pair
evalLoss ↔ double?
Loss computed on the eval data at the end of iteration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int?
Index of the iteration, 0 based.
getter/setter pair
learnRate ↔ double?
Learn rate used for this iteration.
getter/setter pair
principalComponentInfos ↔ List<PrincipalComponentInfo>?
The information of the principal components.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingLoss ↔ double?
Loss computed on the training data at the end of iteration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited