JobConfigurationLoad class

JobConfigurationLoad contains the configuration properties for loading data into a destination table.

Constructors

JobConfigurationLoad({bool? allowJaggedRows, bool? allowQuotedNewlines, bool? autodetect, Clustering? clustering, String? columnNameCharacterMap, List<ConnectionProperty>? connectionProperties, bool? copyFilesOnly, String? createDisposition, bool? createSession, String? dateFormat, String? datetimeFormat, List<String>? decimalTargetTypes, EncryptionConfiguration? destinationEncryptionConfiguration, TableReference? destinationTable, DestinationTableProperties? destinationTableProperties, String? encoding, String? fieldDelimiter, String? fileSetSpecType, HivePartitioningOptions? hivePartitioningOptions, bool? ignoreUnknownValues, String? jsonExtension, int? maxBadRecords, String? nullMarker, List<String>? nullMarkers, ParquetOptions? parquetOptions, bool? preserveAsciiControlCharacters, List<String>? projectionFields, String? quote, RangePartitioning? rangePartitioning, String? referenceFileSchemaUri, TableSchema? schema, String? schemaInline, String? schemaInlineFormat, List<String>? schemaUpdateOptions, int? skipLeadingRows, String? sourceColumnMatch, String? sourceFormat, List<String>? sourceUris, String? timeFormat, TimePartitioning? timePartitioning, String? timeZone, String? timestampFormat, List<int>? timestampTargetPrecision, bool? useAvroLogicalTypes, String? writeDisposition})
JobConfigurationLoad.fromJson(Map json_)

Properties

allowJaggedRows ↔ bool?
Accept rows that are missing trailing optional columns.
getter/setter pair
allowQuotedNewlines ↔ bool?
Indicates if BigQuery should allow quoted data sections that contain newline characters in a CSV file.
getter/setter pair
autodetect ↔ bool?
Indicates if we should automatically infer the options and schema for CSV and JSON sources.
getter/setter pair
clustering ↔ Clustering?
Clustering specification for the destination table.
getter/setter pair
columnNameCharacterMap ↔ String?
Character map supported for column names in CSV/Parquet loads.
getter/setter pair
connectionProperties ↔ List<ConnectionProperty>?
Connection properties which can modify the load job behavior.
getter/setter pair
copyFilesOnly ↔ bool?
[Experimental] Configures the load job to copy files directly to the destination BigLake managed table, bypassing file content reading and rewriting.
getter/setter pair
createDisposition ↔ String?
Specifies whether the job is allowed to create new tables.
getter/setter pair
createSession ↔ bool?
If this property is true, the job creates a new session using a randomly generated session_id.
getter/setter pair
dateFormat ↔ String?
Date format used for parsing DATE values.
getter/setter pair
datetimeFormat ↔ String?
Date format used for parsing DATETIME values.
getter/setter pair
decimalTargetTypes ↔ List<String>?
Defines the list of possible SQL data types to which the source decimal values are converted.
getter/setter pair
destinationEncryptionConfiguration ↔ EncryptionConfiguration?
Custom encryption configuration (e.g., Cloud KMS keys)
getter/setter pair
destinationTable ↔ TableReference?
The destination table to load the data into.
getter/setter pair
destinationTableProperties ↔ DestinationTableProperties?
[Experimental] Properties with which to create the destination table if it is new.
getter/setter pair
encoding ↔ String?
The character encoding of the data.
getter/setter pair
fieldDelimiter ↔ String?
The separator character for fields in a CSV file.
getter/setter pair
fileSetSpecType ↔ String?
Specifies how source URIs are interpreted for constructing the file set to load.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hivePartitioningOptions ↔ HivePartitioningOptions?
When set, configures hive partitioning support.
getter/setter pair
ignoreUnknownValues ↔ bool?
Indicates if BigQuery should allow extra values that are not represented in the table schema.
getter/setter pair
jsonExtension ↔ String?
Load option to be used together with source_format newline-delimited JSON to indicate that a variant of JSON is being loaded.
getter/setter pair
maxBadRecords ↔ int?
The maximum number of bad records that BigQuery can ignore when running the job.
getter/setter pair
nullMarker ↔ String?
Specifies a string that represents a null value in a CSV file.
getter/setter pair
nullMarkers ↔ List<String>?
A list of strings represented as SQL NULL value in a CSV file.
getter/setter pair
parquetOptions ↔ ParquetOptions?
Additional properties to set if sourceFormat is set to PARQUET.
getter/setter pair
preserveAsciiControlCharacters ↔ bool?
When sourceFormat is set to "CSV", this indicates whether the embedded ASCII control characters (the first 32 characters in the ASCII-table, from '\x00' to '\x1F') are preserved.
getter/setter pair
projectionFields ↔ List<String>?
If sourceFormat is set to "DATASTORE_BACKUP", indicates which entity properties to load into BigQuery from a Cloud Datastore backup.
getter/setter pair
quote ↔ String?
The value that is used to quote data sections in a CSV file.
getter/setter pair
rangePartitioning ↔ RangePartitioning?
Range partitioning specification for the destination table.
getter/setter pair
referenceFileSchemaUri ↔ String?
The user can provide a reference file with the reader schema.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ TableSchema?
The schema for the destination table.
getter/setter pair
schemaInline ↔ String?
The inline schema.
getter/setter pair
schemaInlineFormat ↔ String?
The format of the schemaInline property.
getter/setter pair
schemaUpdateOptions ↔ List<String>?
Allows the schema of the destination table to be updated as a side effect of the load job if a schema is autodetected or supplied in the job configuration.
getter/setter pair
skipLeadingRows ↔ int?
The number of rows at the top of a CSV file that BigQuery will skip when loading the data.
getter/setter pair
sourceColumnMatch ↔ String?
Controls the strategy used to match loaded columns to the schema.
getter/setter pair
sourceFormat ↔ String?
The format of the data files.
getter/setter pair
sourceUris ↔ List<String>?
The fully-qualified URIs that point to your data in Google Cloud.
getter/setter pair
timeFormat ↔ String?
Date format used for parsing TIME values.
getter/setter pair
timePartitioning ↔ TimePartitioning?
Time-based partitioning specification for the destination table.
getter/setter pair
timestampFormat ↔ String?
Date format used for parsing TIMESTAMP values.
getter/setter pair
timestampTargetPrecision ↔ List<int>?
Precisions (maximum number of total digits in base 10) for seconds of TIMESTAMP types that are allowed to the destination table for autodetection mode.
getter/setter pair
timeZone ↔ String?
Default time zone that will apply when parsing timestamp values that have no specific time zone.
getter/setter pair
useAvroLogicalTypes ↔ bool?
If sourceFormat is set to "AVRO", indicates whether to interpret logical types as the corresponding BigQuery data type (for example, TIMESTAMP), instead of using the raw type (for example, INTEGER).
getter/setter pair
writeDisposition ↔ String?
Specifies the action that occurs if the destination table already exists.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited