JobListJobs class

ListFormatJob is a partial projection of job information returned as part of a jobs.list response.

Constructors

JobListJobs({JobConfiguration? configuration, ErrorProto? errorResult, String? id, JobReference? jobReference, String? kind, String? principalSubject, String? state, JobStatistics? statistics, JobStatus? status, String? userEmail})
JobListJobs.fromJson(Map json_)

Properties

configuration ↔ JobConfiguration?
Describes the job configuration.
getter/setter pair
errorResult ↔ ErrorProto?
A result object that will be present only if the job has failed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique opaque ID of the job.
getter/setter pair
jobReference ↔ JobReference?
Unique opaque ID of the job.
getter/setter pair
kind ↔ String?
The resource type.
getter/setter pair
principalSubject ↔ String?
[Full-projection-only] String representation of identity of requesting party.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Running state of the job.
getter/setter pair
statistics ↔ JobStatistics?
Information about the job, including starting time and ending time of the job.
getter/setter pair
status ↔ JobStatus?
[Full-projection-only] Describes the status of this job.
getter/setter pair
userEmail ↔ String?
[Full-projection-only] Email address of the user who ran the job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited