JobStatistics class

Statistics for a single job execution.

Constructors

JobStatistics({double? completionRatio, JobStatistics5? copy, String? creationTime, DataMaskingStatistics? dataMaskingStatistics, String? edition, String? endTime, JobStatistics4? extract, String? finalExecutionDurationMs, List<String>? globalQueryRemoteRegions, JobStatistics3? load, String? numChildJobs, JobReference? parentGlobalQueryJob, String? parentJobId, JobStatistics2? query, List<String>? quotaDeferments, List<String>? reservationGroupPath, List<JobStatisticsReservationUsage>? reservationUsage, String? reservationId, RowLevelSecurityStatistics? rowLevelSecurityStatistics, ScriptStatistics? scriptStatistics, SessionInfo? sessionInfo, String? startTime, String? totalBytesProcessed, String? totalSlotMs, TransactionInfo? transactionInfo})
JobStatistics.fromJson(Map json_)

Properties

completionRatio ↔ double?
[TrustedTester] Job progress (0.0 -> 1.0) for LOAD and EXTRACT jobs.
getter/setter pair
copy ↔ JobStatistics5?
Statistics for a copy job.
getter/setter pair
creationTime ↔ String?
Creation time of this job, in milliseconds since the epoch.
getter/setter pair
dataMaskingStatistics ↔ DataMaskingStatistics?
Statistics for data-masking.
getter/setter pair
edition ↔ String?
Name of edition corresponding to the reservation for this job at the time of this update.
getter/setter pair
endTime ↔ String?
End time of this job, in milliseconds since the epoch.
getter/setter pair
extract ↔ JobStatistics4?
Statistics for an extract job.
getter/setter pair
finalExecutionDurationMs ↔ String?
The duration in milliseconds of the execution of the final attempt of this job, as BigQuery may internally re-attempt to execute the job.
getter/setter pair
globalQueryRemoteRegions ↔ List<String>?
Regions where the global query accesses data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
load ↔ JobStatistics3?
Statistics for a load job.
getter/setter pair
numChildJobs ↔ String?
Number of child jobs executed.
getter/setter pair
parentGlobalQueryJob ↔ JobReference?
The global query that created this job.
getter/setter pair
parentJobId ↔ String?
If this is a child job, specifies the job ID of the parent.
getter/setter pair
query ↔ JobStatistics2?
Statistics for a query job.
getter/setter pair
quotaDeferments ↔ List<String>?
Quotas which delayed this job's start time.
getter/setter pair
reservationGroupPath ↔ List<String>?
The reservation group path of the reservation assigned to this job.
getter/setter pair
reservationId ↔ String?
Name of the primary reservation assigned to this job.
getter/setter pair
reservationUsage ↔ List<JobStatisticsReservationUsage>?
Job resource usage breakdown by reservation.
getter/setter pair
rowLevelSecurityStatistics ↔ RowLevelSecurityStatistics?
Statistics for row-level security.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptStatistics ↔ ScriptStatistics?
If this a child job of a script, specifies information about the context of this job within the script.
getter/setter pair
sessionInfo ↔ SessionInfo?
Information of the session if this job is part of one.
getter/setter pair
startTime ↔ String?
Start time of this job, in milliseconds since the epoch.
getter/setter pair
totalBytesProcessed ↔ String?
Total bytes processed for the job.
getter/setter pair
totalSlotMs ↔ String?
Slot-milliseconds for the job.
getter/setter pair
transactionInfo ↔ TransactionInfo?
[Alpha] Information of the multi-statement transaction if this job is part of one.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited