objectStorageStats property
Storage and caching statistics per cloud provider for queries over object storage.
Output only.
Implementation
core.List<ObjectStorageStats>? objectStorageStats;
Storage and caching statistics per cloud provider for queries over object storage.
Output only.
core.List<ObjectStorageStats>? objectStorageStats;