transferredBytes property

String? transferredBytes
getter/setter pair

Total bytes transferred for BigQuery Omni queries from the remote cloud back to Google Cloud.

This tracks data movement over Google-managed connections (like query results). It doesn't include input data read from the external data lake (for example, S3) because that data stays within the remote cloud.

Output only.

Implementation

core.String? transferredBytes;