JobStatistics3 class

Statistics for a load job.

Constructors

JobStatistics3({String? badRecords, String? inputFileBytes, String? inputFiles, String? outputBytes, String? outputRows, List<QueryTimelineSample>? timeline})
JobStatistics3.fromJson(Map json_)

Properties

badRecords ↔ String?
The number of bad records encountered.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputFileBytes ↔ String?
Number of bytes of source data in a load job.
getter/setter pair
inputFiles ↔ String?
Number of source files in a load job.
getter/setter pair
outputBytes ↔ String?
Size of the loaded data in bytes.
getter/setter pair
outputRows ↔ String?
Number of rows imported in a load job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeline ↔ List<QueryTimelineSample>?
Describes a timeline of job execution.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited