JobStatistics4 class

Statistics for an extract job.

Constructors

JobStatistics4({List<String>? destinationUriFileCounts, String? inputBytes, List<QueryTimelineSample>? timeline})
JobStatistics4.fromJson(Map json_)

Properties

destinationUriFileCounts ↔ List<String>?
Number of files per destination URI or URI pattern specified in the extract configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputBytes ↔ String?
Number of user bytes extracted into the result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeline ↔ List<QueryTimelineSample>?
Describes a timeline of job execution.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited