JobStatistics5 class

Statistics for a copy job.

Constructors

JobStatistics5({String? copiedLogicalBytes, String? copiedRows, String? remoteDestinationRegion})
JobStatistics5.fromJson(Map json_)

Properties

copiedLogicalBytes ↔ String?
Number of logical bytes copied to the destination table.
getter/setter pair
copiedRows ↔ String?
Number of rows copied to the destination table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
remoteDestinationRegion ↔ String?
Destination region for a cross-region copy job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited