JobStatus class

Constructors

JobStatus({ErrorProto? errorResult, List<ErrorProto>? errors, String? state})
JobStatus.fromJson(Map json_)

Properties

errorResult ↔ ErrorProto?
Final error result of the job.
getter/setter pair
errors ↔ List<ErrorProto>?
The first errors encountered during the running of the job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Running state of the job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited