ListModelsResponse class

Response format for a single page when listing BigQuery ML models.

Constructors

ListModelsResponse({List<Model>? models, String? nextPageToken})
ListModelsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
models ↔ List<Model>?
Models in the requested dataset.
getter/setter pair
nextPageToken ↔ String?
A token to request the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited