MaterializedView class

A materialized view considered for a query job.

Constructors

MaterializedView({bool? chosen, String? estimatedBytesSaved, String? rejectedReason, TableReference? tableReference})
MaterializedView.fromJson(Map json_)

Properties

chosen ↔ bool?
Whether the materialized view is chosen for the query.
getter/setter pair
estimatedBytesSaved ↔ String?
If present, specifies a best-effort estimation of the bytes saved by using the materialized view rather than its base tables.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rejectedReason ↔ String?
If present, specifies the reason why the materialized view was not chosen for the query. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableReference ↔ TableReference?
The candidate materialized view.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited