MaterializedViewDefinition class

Definition and configuration of a materialized view.

Constructors

MaterializedViewDefinition({bool? allowNonIncrementalDefinition, bool? enableRefresh, String? lastRefreshTime, String? maxStaleness, String? query, String? refreshIntervalMs})
MaterializedViewDefinition.fromJson(Map json_)

Properties

allowNonIncrementalDefinition ↔ bool?
This option declares the intention to construct a materialized view that isn't refreshed incrementally.
getter/setter pair
enableRefresh ↔ bool?
Enable automatic refresh of the materialized view when the base table is updated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastRefreshTime ↔ String?
The time when this materialized view was last refreshed, in milliseconds since the epoch.
getter/setter pair
maxStaleness ↔ String?
Max staleness of data that could be returned when materizlized view is queried (formatted as Google SQL Interval type).
getter/setter pair
maxStalenessAsBytes ↔ List<int>
getter/setter pair
query ↔ String?
A query whose results are persisted.
getter/setter pair
refreshIntervalMs ↔ String?
The maximum frequency at which this materialized view will be refreshed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited