avgPreviousStalenessMs property
Average column metadata index staleness of previous runs with the same query hash.
Output only.
Implementation
core.String? avgPreviousStalenessMs;
Average column metadata index staleness of previous runs with the same query hash.
Output only.
core.String? avgPreviousStalenessMs;