stalenessPercentageIncrease property

double? stalenessPercentageIncrease
getter/setter pair

The percent increase in staleness between the current job and the average staleness of previous jobs with the same query hash.

Output only.

Implementation

core.double? stalenessPercentageIncrease;