MlStatistics class

Job statistics specific to a BigQuery ML training job.

Constructors

MlStatistics({List<HparamTuningTrial>? hparamTrials, List<IterationResult>? iterationResults, String? maxIterations, String? modelType, String? trainingType})
MlStatistics.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hparamTrials ↔ List<HparamTuningTrial>?
Trials of a hyperparameter tuning job sorted by trial_id.
getter/setter pair
iterationResults ↔ List<IterationResult>?
Results for all completed iterations.
getter/setter pair
maxIterations ↔ String?
Maximum number of iterations specified as max_iterations in the 'CREATE MODEL' query.
getter/setter pair
modelType ↔ String?
The type of the model that is being trained.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trainingType ↔ String?
Training type of the job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited