ModelReference class

Id path of a model.

Constructors

ModelReference({String? datasetId, String? modelId, String? projectId})
ModelReference.fromJson(Map json_)

Properties

datasetId ↔ String?
The ID of the dataset containing this model.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modelId ↔ String?
The ID of the model.
getter/setter pair
projectId ↔ String?
The ID of the project containing this model.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited