ObjectStorageStats class

Storage and caching statistics for object storage.

Constructors

ObjectStorageStats({String? cacheBytesRead, String? cloudProvider, String? objectStorageBytesRead})
ObjectStorageStats.fromJson(Map json_)

Properties

cacheBytesRead String?
Total bytes read from the GCP Lakehouse-internal cache, avoiding an object storage read.
getter/setter pair
cloudProvider String?
The cloud provider for this block of statistics. Possible string values are:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
objectStorageBytesRead String?
Total bytes read directly from the cloud provider's storage.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited