ParquetOptions class

Parquet Options for load and make external tables.

Constructors

ParquetOptions({bool? enableListInference, bool? enumAsString, String? mapTargetType})
ParquetOptions.fromJson(Map json_)

Properties

enableListInference ↔ bool?
Indicates whether to use schema inference specifically for Parquet LIST logical type.
getter/setter pair
enumAsString ↔ bool?
Indicates whether to infer Parquet ENUM logical type as STRING instead of BYTES by default.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mapTargetType ↔ String?
Indicates how to represent a Parquet map if present.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited