projects property
Projects to which the user has at least READ access.
This field can be omitted if totalItems is 0.
Implementation
core.List<ProjectListProjects>? projects;
Projects to which the user has at least READ access.
This field can be omitted if totalItems is 0.
core.List<ProjectListProjects>? projects;