ProjectListProjects class

Information about a single project.

Constructors

ProjectListProjects({String? friendlyName, String? id, String? kind, String? numericId, ProjectReference? projectReference})
ProjectListProjects.fromJson(Map json_)

Properties

friendlyName ↔ String?
A descriptive name for this project.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
An opaque ID of this project.
getter/setter pair
kind ↔ String?
The resource type.
getter/setter pair
numericId ↔ String?
The numeric ID of this project.
getter/setter pair
projectReference ↔ ProjectReference?
A unique reference to this project.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited