getServiceAccount method

Future<GetServiceAccountResponse> getServiceAccount(
  1. String projectId, {
  2. String? $fields,
})

RPC to get the service account for a project used for interactions with Google Cloud KMS.

Requires the bigquery.jobs.create permission on the project resource. This permission is required to authorize the retrieval of the project's service identity for technical management tasks like encryption configuration.

Request parameters:

projectId - Required. ID of the project. Value must have pattern ^\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GetServiceAccountResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GetServiceAccountResponse> getServiceAccount(
  core.String projectId, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'projects/' + core.Uri.encodeFull('$projectId') + '/serviceAccount';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return GetServiceAccountResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}