PropertyGraphReference class

Id path of a property graph.

Constructors

PropertyGraphReference({String? datasetId, String? projectId, String? propertyGraphId})
PropertyGraphReference.fromJson(Map json_)

Properties

datasetId String?
The ID of the dataset containing this property graph.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
projectId String?
The ID of the project containing this property graph.
getter/setter pair
propertyGraphId String?
The ID of the property graph.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited