PythonOptions class

Options for a user-defined Python function.

Constructors

PythonOptions({String? entryPoint, List<String>? packages})
PythonOptions.fromJson(Map json_)

Properties

entryPoint ↔ String?
The name of the function defined in Python code as the entry point when the Python UDF is invoked.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
packages ↔ List<String>?
A list of Python package names along with versions to be installed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited