QueryParameter class

A parameter given to a query.

Constructors

QueryParameter({String? name, QueryParameterType? parameterType, QueryParameterValue? parameterValue})
QueryParameter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
If unset, this is a positional parameter.
getter/setter pair
parameterType ↔ QueryParameterType?
The type of this parameter.
getter/setter pair
parameterValue ↔ QueryParameterValue?
The value of this parameter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited