QueryParameterType class

The type of a query parameter.

Constructors

QueryParameterType({QueryParameterType? arrayType, QueryParameterType? rangeElementType, List<QueryParameterTypeStructTypes>? structTypes, String? timestampPrecision, String? type})
QueryParameterType.fromJson(Map json_)

Properties

arrayType ↔ QueryParameterType?
The type of the array's elements, if this is an array.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rangeElementType ↔ QueryParameterType?
The element type of the range, if this is a range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structTypes ↔ List<QueryParameterTypeStructTypes>?
The types of the fields of this struct, in order, if this is a struct.
getter/setter pair
timestampPrecision ↔ String?
Precision (maximum number of total digits in base 10) for seconds of TIMESTAMP type.
getter/setter pair
type ↔ String?
The top level type of this field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited