QueryParameterValue class

The value of a query parameter.

Constructors

QueryParameterValue({List<QueryParameterValue>? arrayValues, RangeValue? rangeValue, Map<String, QueryParameterValue>? structValues, String? value})
QueryParameterValue.fromJson(Map json_)

Properties

arrayValues ↔ List<QueryParameterValue>?
The array values, if this is an array type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rangeValue ↔ RangeValue?
The range value, if this is a range type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structValues ↔ Map<String, QueryParameterValue>?
The struct field values.
getter/setter pair
value ↔ String?
The value of this value, if a simple scalar type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited