QueryResponse class

Constructors

QueryResponse({ArrowRecordBatch? arrowRecordBatch, ArrowSchema? arrowSchema, bool? cacheHit, String? creationTime, DmlStatistics? dmlStats, String? endTime, List<ErrorProto>? errors, bool? jobComplete, JobCreationReason? jobCreationReason, JobReference? jobReference, String? kind, String? location, String? numDmlAffectedRows, String? pageRowCount, String? pageToken, String? queryId, List<TableRow>? rows, TableSchema? schema, SessionInfo? sessionInfo, String? startTime, String? statementType, String? totalBytesBilled, String? totalBytesProcessed, String? totalRows, String? totalSlotMs})
QueryResponse.fromJson(Map json_)

Properties

arrowRecordBatch ↔ ArrowRecordBatch?
Serialized row data in Arrow RecordBatch format.
getter/setter pair
arrowSchema ↔ ArrowSchema?
Arrow schema
getter/setter pair
cacheHit ↔ bool?
Whether the query result was fetched from the query cache.
getter/setter pair
creationTime ↔ String?
Creation time of this query, in milliseconds since the epoch.
getter/setter pair
dmlStats ↔ DmlStatistics?
Detailed statistics for DML statements INSERT, UPDATE, DELETE, MERGE or TRUNCATE.
getter/setter pair
endTime ↔ String?
End time of this query, in milliseconds since the epoch.
getter/setter pair
errors ↔ List<ErrorProto>?
The first errors or warnings encountered during the running of the job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobComplete ↔ bool?
Whether the query has completed or not.
getter/setter pair
jobCreationReason ↔ JobCreationReason?
The reason why a Job was created.
getter/setter pair
jobReference ↔ JobReference?
Reference to the Job that was created to run the query.
getter/setter pair
kind ↔ String?
The resource type.
getter/setter pair
location ↔ String?
The geographic location of the query.
getter/setter pair
numDmlAffectedRows ↔ String?
The number of rows affected by a DML statement.
getter/setter pair
pageRowCount ↔ String?
The number of rows out of total_rows returned in this response.
getter/setter pair
pageToken ↔ String?
A token used for paging results.
getter/setter pair
queryId ↔ String?
Auto-generated ID for the query.
getter/setter pair
rows ↔ List<TableRow>?
An object with as many results as can be contained within the maximum permitted reply size.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ TableSchema?
The schema of the results.
getter/setter pair
sessionInfo ↔ SessionInfo?
Information of the session if this job is part of one.
getter/setter pair
startTime ↔ String?
Start time of this query, in milliseconds since the epoch.
getter/setter pair
statementType ↔ String?
The type of query statement, if valid.
getter/setter pair
totalBytesBilled ↔ String?
If the project is configured to use on-demand pricing, then this field contains the total bytes billed for the job.
getter/setter pair
totalBytesProcessed ↔ String?
The total number of bytes processed for this query.
getter/setter pair
totalRows ↔ String?
The total number of rows in the complete query result set, which can be more than the number of rows in this single page of results.
getter/setter pair
totalSlotMs ↔ String?
Number of slot ms the user is actually billed for.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited