QueryTimelineSample class

Summary of the state of query execution at a given time.

Constructors

QueryTimelineSample({String? activeUnits, String? completedUnits, String? elapsedMs, String? estimatedRunnableUnits, String? pendingUnits, double? shuffleRamUsageRatio, String? totalSlotMs})
QueryTimelineSample.fromJson(Map json_)

Properties

activeUnits ↔ String?
Total number of active workers.
getter/setter pair
completedUnits ↔ String?
Total parallel units of work completed by this query.
getter/setter pair
elapsedMs ↔ String?
Milliseconds elapsed since the start of query execution.
getter/setter pair
estimatedRunnableUnits ↔ String?
Units of work that can be scheduled immediately.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pendingUnits ↔ String?
Total units of work remaining for the query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleRamUsageRatio ↔ double?
Total shuffle usage ratio in shuffle RAM per reservation of this query.
getter/setter pair
totalSlotMs ↔ String?
Cumulative slot-ms consumed by the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited