RankingMetrics class

Evaluation metrics used by weighted-ALS models specified by feedback_type=implicit.

Constructors

RankingMetrics({double? averageRank, double? meanAveragePrecision, double? meanSquaredError, double? normalizedDiscountedCumulativeGain})
RankingMetrics.fromJson(Map json_)

Properties

averageRank ↔ double?
Determines the goodness of a ranking by computing the percentile rank from the predicted confidence and dividing it by the original rank.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
meanAveragePrecision ↔ double?
Calculates a precision per user for all the items by ranking them and then averages all the precisions across all the users.
getter/setter pair
meanSquaredError ↔ double?
Similar to the mean squared error computed in regression and explicit recommendation models except instead of computing the rating directly, the output from evaluate is computed against a preference which is 1 or 0 depending on if the rating exists or not.
getter/setter pair
normalizedDiscountedCumulativeGain ↔ double?
A metric to determine the goodness of a ranking calculated from the predicted confidence by comparing it to an ideal rank measured by the original ratings.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited