RemoteFunctionOptions class

Options for a remote user-defined function.

Constructors

RemoteFunctionOptions({String? connection, String? endpoint, String? maxBatchingRows, Map<String, String>? userDefinedContext})
RemoteFunctionOptions.fromJson(Map json_)

Properties

connection ↔ String?
Fully qualified name of the user-provided connection object which holds the authentication information to send requests to the remote service.
getter/setter pair
endpoint ↔ String?
Endpoint of the user-provided remote service, e.g. https://us-east1-my_gcf_project.cloudfunctions.net/remote_add
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxBatchingRows ↔ String?
Max number of rows in each batch sent to the remote service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userDefinedContext ↔ Map<String, String>?
User-defined context as a set of key/value pairs, which will be sent as function invocation context together with batched arguments in the requests to the remote service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited