RemoteModelInfo class

Remote Model Info

Constructors

RemoteModelInfo({String? connection, String? endpoint, String? maxBatchingRows, String? remoteModelVersion, String? remoteServiceType, String? speechRecognizer})
RemoteModelInfo.fromJson(Map json_)

Properties

connection ↔ String?
Fully qualified name of the user-provided connection object of the remote model.
getter/setter pair
endpoint ↔ String?
The endpoint for remote model.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxBatchingRows ↔ String?
Max number of rows in each batch sent to the remote service.
getter/setter pair
remoteModelVersion ↔ String?
The model version for LLM.
getter/setter pair
remoteServiceType ↔ String?
The remote service type for remote model.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speechRecognizer ↔ String?
The name of the speech recognizer to use for speech recognition.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited