RowAccessPolicyReference class

Id path of a row access policy.

Constructors

RowAccessPolicyReference({String? datasetId, String? policyId, String? projectId, String? tableId})
RowAccessPolicyReference.fromJson(Map json_)

Properties

datasetId ↔ String?
The ID of the dataset containing this row access policy.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
policyId ↔ String?
The ID of the row access policy.
getter/setter pair
projectId ↔ String?
The ID of the project containing this row access policy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId ↔ String?
The ID of the table containing this row access policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited