ScriptOptions class

Options related to script execution.

Constructors

ScriptOptions({String? keyResultStatement, String? statementByteBudget, String? statementTimeoutMs})
ScriptOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyResultStatement ↔ String?
Determines which statement in the script represents the "key result", used to populate the schema and query results of the script job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statementByteBudget ↔ String?
Limit on the number of bytes billed per statement.
getter/setter pair
statementTimeoutMs ↔ String?
Timeout period for each statement in a script.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited