SearchStatistics class

Statistics for a search query.

Populated as part of JobStatistics2.

Constructors

SearchStatistics({List<IndexPruningStats>? indexPruningStats, List<IndexUnusedReason>? indexUnusedReasons, String? indexUsageMode})
SearchStatistics.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexPruningStats ↔ List<IndexPruningStats>?
Search index pruning statistics, one for each base table that has a search index.
getter/setter pair
indexUnusedReasons ↔ List<IndexUnusedReason>?
When indexUsageMode is UNUSED or PARTIALLY_USED, this field explains why indexes were not used in all or part of the search query.
getter/setter pair
indexUsageMode ↔ String?
Specifies the index usage mode for the query. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited