SkewSource class
Details about source stages which produce skewed data.
Constructors
- SkewSource({String? outputBytesMax, String? outputBytesMedian, String? outputBytesP95, String? stageId})
- SkewSource.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputBytesMax ↔ String?
-
Max partition output size (in bytes) for this stage.
getter/setter pair
- outputBytesMedian ↔ String?
-
Median partition output size (in bytes) for this stage.
getter/setter pair
- outputBytesP95 ↔ String?
-
95-th percentile of partition output size (in bytes) for this stage.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stageId ↔ String?
-
Stage id of the skew source stage.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited