SnapshotDefinition class

Information about base table and snapshot time of the snapshot.

Constructors

SnapshotDefinition({TableReference? baseTableReference, DateTime? snapshotTime})
SnapshotDefinition.fromJson(Map json_)

Properties

baseTableReference ↔ TableReference?
Reference describing the ID of the table that was snapshot.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotTime ↔ DateTime?
The time at which the base table was snapshot.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited