SparkStatistics class

Statistics for a BigSpark query.

Populated as part of JobStatistics2

Constructors

SparkStatistics({Map<String, String>? endpoints, String? gcsStagingBucket, String? kmsKeyName, SparkLoggingInfo? loggingInfo, String? sparkJobId, String? sparkJobLocation})
SparkStatistics.fromJson(Map json_)

Properties

endpoints ↔ Map<String, String>?
Endpoints returned from Dataproc.
getter/setter pair
gcsStagingBucket ↔ String?
The Google Cloud Storage bucket that is used as the default file system by the Spark application.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
The Cloud KMS encryption key that is used to protect the resources created by the Spark job.
getter/setter pair
loggingInfo ↔ SparkLoggingInfo?
Logging info is used to generate a link to Cloud Logging.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkJobId ↔ String?
Spark job ID if a Spark job is created successfully.
getter/setter pair
sparkJobLocation ↔ String?
Location where the Spark job is executed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited