StagePerformanceChangeInsight class

Performance insights compared to the previous executions for a specific stage.

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputDataChange ↔ InputDataChange?
Input data change insight of the query stage.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stageId ↔ String?
The stage id that the insight mapped to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited