StandardSqlDataType class

The data type of a variable such as a function argument.

Examples include: * INT64: {"typeKind": "INT64"} * ARRAY: { "typeKind": "ARRAY", "arrayElementType": {"typeKind": "STRING"} } * STRUCT>: { "typeKind": "STRUCT", "structType": { "fields": [ { "name": "x", "type": {"typeKind": "STRING"} }, { "name": "y", "type": { "typeKind": "ARRAY", "arrayElementType": {"typeKind": "DATE"} } } ] } } * RANGE: { "typeKind": "RANGE", "rangeElementType": {"typeKind": "DATE"} }

Constructors

StandardSqlDataType({StandardSqlDataType? arrayElementType, StandardSqlDataType? rangeElementType, StandardSqlStructType? structType, String? typeKind})
StandardSqlDataType.fromJson(Map json_)

Properties

arrayElementType ↔ StandardSqlDataType?
The type of the array's elements, if type_kind = "ARRAY".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rangeElementType ↔ StandardSqlDataType?
The type of the range's elements, if type_kind = "RANGE".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structType ↔ StandardSqlStructType?
The fields of this struct, in order, if type_kind = "STRUCT".
getter/setter pair
typeKind ↔ String?
The top level type of this field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited