StoredColumnsUnusedReason class

If the stored column was not used, explain why.

Constructors

StoredColumnsUnusedReason({String? code, String? message, List<String>? uncoveredColumns})
StoredColumnsUnusedReason.fromJson(Map json_)

Properties

code ↔ String?
Specifies the high-level reason for the unused scenario, each reason must have a code associated. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
Specifies the detailed description for the scenario.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uncoveredColumns ↔ List<String>?
Specifies which columns were not covered by the stored columns for the specified code up to 20 columns.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited