Streamingbuffer class

Constructors

Streamingbuffer({String? estimatedBytes, String? estimatedRows, String? oldestEntryTime})
Streamingbuffer.fromJson(Map json_)

Properties

estimatedBytes ↔ String?
A lower-bound estimate of the number of bytes currently in the streaming buffer.
getter/setter pair
estimatedRows ↔ String?
A lower-bound estimate of the number of rows currently in the streaming buffer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oldestEntryTime ↔ String?
Contains the timestamp of the oldest entry in the streaming buffer, in milliseconds since the epoch, if the streaming buffer is available.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited