Table class

Constructors

Table({BigLakeConfiguration? biglakeConfiguration, CloneDefinition? cloneDefinition, Clustering? clustering, String? creationTime, String? defaultCollation, String? defaultRoundingMode, String? description, EncryptionConfiguration? encryptionConfiguration, String? etag, String? expirationTime, ExternalCatalogTableOptions? externalCatalogTableOptions, ExternalDataConfiguration? externalDataConfiguration, String? friendlyName, String? id, String? kind, Map<String, String>? labels, String? lastModifiedTime, String? location, String? managedTableType, MaterializedViewDefinition? materializedView, MaterializedViewStatus? materializedViewStatus, String? maxStaleness, ModelDefinition? model, String? numActiveLogicalBytes, String? numActivePhysicalBytes, String? numBytes, String? numCurrentPhysicalBytes, String? numLongTermBytes, String? numLongTermLogicalBytes, String? numLongTermPhysicalBytes, String? numPartitions, String? numPhysicalBytes, String? numRows, String? numTimeTravelPhysicalBytes, String? numTotalLogicalBytes, String? numTotalPhysicalBytes, PartitioningDefinition? partitionDefinition, RangePartitioning? rangePartitioning, List<TableReference>? replicas, bool? requirePartitionFilter, Map<String, String>? resourceTags, RestrictionConfig? restrictions, TableSchema? schema, String? selfLink, SnapshotDefinition? snapshotDefinition, Streamingbuffer? streamingBuffer, TableConstraints? tableConstraints, TableReference? tableReference, TableReplicationInfo? tableReplicationInfo, TimePartitioning? timePartitioning, String? type, ViewDefinition? view})
Table.fromJson(Map json_)

Properties

biglakeConfiguration ↔ BigLakeConfiguration?
Specifies the configuration of a BigQuery table for Apache Iceberg.
getter/setter pair
cloneDefinition ↔ CloneDefinition?
Contains information about the clone.
getter/setter pair
clustering ↔ Clustering?
Clustering specification for the table.
getter/setter pair
creationTime ↔ String?
The time when this table was created, in milliseconds since the epoch.
getter/setter pair
defaultCollation ↔ String?
Defines the default collation specification of new STRING fields in the table.
getter/setter pair
defaultRoundingMode ↔ String?
Defines the default rounding mode specification of new decimal fields (NUMERIC OR BIGNUMERIC) in the table.
getter/setter pair
description ↔ String?
A user-friendly description of this table.
getter/setter pair
encryptionConfiguration ↔ EncryptionConfiguration?
Custom encryption configuration (e.g., Cloud KMS keys).
getter/setter pair
etag ↔ String?
A hash of this resource.
getter/setter pair
expirationTime ↔ String?
The time when this table expires, in milliseconds since the epoch.
getter/setter pair
externalCatalogTableOptions ↔ ExternalCatalogTableOptions?
Options defining open source compatible table.
getter/setter pair
externalDataConfiguration ↔ ExternalDataConfiguration?
Describes the data format, location, and other properties of a table stored outside of BigQuery.
getter/setter pair
friendlyName ↔ String?
A descriptive name for this table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
An opaque ID uniquely identifying the table.
getter/setter pair
kind ↔ String?
The type of resource ID.
getter/setter pair
labels ↔ Map<String, String>?
The labels associated with this table.
getter/setter pair
lastModifiedTime ↔ String?
The time when this table was last modified, in milliseconds since the epoch.
getter/setter pair
location ↔ String?
The geographic location where the table resides.
getter/setter pair
managedTableType ↔ String?
If set, overrides the default managed table type configured in the dataset.
getter/setter pair
materializedView ↔ MaterializedViewDefinition?
The materialized view definition.
getter/setter pair
materializedViewStatus ↔ MaterializedViewStatus?
The materialized view status.
getter/setter pair
maxStaleness ↔ String?
The maximum staleness of data that could be returned when the table (or stale MV) is queried.
getter/setter pair
model ↔ ModelDefinition?
Deprecated.
getter/setter pair
numActiveLogicalBytes ↔ String?
Number of logical bytes that are less than 90 days old.
getter/setter pair
numActivePhysicalBytes ↔ String?
Number of physical bytes less than 90 days old.
getter/setter pair
numBytes ↔ String?
The size of this table in logical bytes, excluding any data in the streaming buffer.
getter/setter pair
numCurrentPhysicalBytes ↔ String?
Number of physical bytes used by current live data storage.
getter/setter pair
numLongTermBytes ↔ String?
The number of logical bytes in the table that are considered "long-term storage".
getter/setter pair
numLongTermLogicalBytes ↔ String?
Number of logical bytes that are more than 90 days old.
getter/setter pair
numLongTermPhysicalBytes ↔ String?
Number of physical bytes more than 90 days old.
getter/setter pair
numPartitions ↔ String?
The number of partitions present in the table or materialized view.
getter/setter pair
numPhysicalBytes ↔ String?
The physical size of this table in bytes.
getter/setter pair
numRows ↔ String?
The number of rows of data in this table, excluding any data in the streaming buffer.
getter/setter pair
numTimeTravelPhysicalBytes ↔ String?
Number of physical bytes used by time travel storage (deleted or changed data).
getter/setter pair
numTotalLogicalBytes ↔ String?
Total number of logical bytes in the table or materialized view.
getter/setter pair
numTotalPhysicalBytes ↔ String?
The physical size of this table in bytes.
getter/setter pair
partitionDefinition ↔ PartitioningDefinition?
The partition information for all table formats, including managed partitioned tables, hive partitioned tables, iceberg partitioned, and metastore partitioned tables.
getter/setter pair
rangePartitioning ↔ RangePartitioning?
If specified, configures range partitioning for this table.
getter/setter pair
replicas ↔ List<TableReference>?
Table references of all replicas currently active on the table.
getter/setter pair
requirePartitionFilter ↔ bool?
If set to true, queries over this table require a partition filter that can be used for partition elimination to be specified.
getter/setter pair
resourceTags ↔ Map<String, String>?
The tags associated with this table.
getter/setter pair
restrictions ↔ RestrictionConfig?
Restriction config for table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ TableSchema?
Describes the schema of this table.
getter/setter pair
A URL that can be used to access this resource again.
getter/setter pair
snapshotDefinition ↔ SnapshotDefinition?
Contains information about the snapshot.
getter/setter pair
streamingBuffer ↔ Streamingbuffer?
Contains information regarding this table's streaming buffer, if one is present.
getter/setter pair
tableConstraints ↔ TableConstraints?
Tables Primary Key and Foreign Key information
getter/setter pair
tableReference ↔ TableReference?
Reference describing the ID of this table.
getter/setter pair
tableReplicationInfo ↔ TableReplicationInfo?
Table replication info for table created AS REPLICA DDL like: CREATE MATERIALIZED VIEW mv1 AS REPLICA OF src_mv
getter/setter pair
timePartitioning ↔ TimePartitioning?
If specified, configures time-based partitioning for this table.
getter/setter pair
type ↔ String?
Describes the table type.
getter/setter pair
view ↔ ViewDefinition?
The view definition.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited