TableConstraints class

The TableConstraints defines the primary key and foreign key.

Properties

foreignKeys ↔ List<TableConstraintsForeignKeys>?
Present only if the table has a foreign key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
primaryKey ↔ TableConstraintsPrimaryKey?
Represents the primary key constraint on a table's columns.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited