TableConstraintsForeignKeysColumnReferences class

The pair of the foreign key column and primary key column.

Properties

hashCode → int
The hash code for this object.
no setterinherited
referencedColumn ↔ String?
The column in the primary key that are referenced by the referencing_column.
getter/setter pair
referencingColumn ↔ String?
The column that composes the foreign key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited