TableDataInsertAllRequest class

Request for sending a single streaming insert.

Constructors

TableDataInsertAllRequest({bool? ignoreUnknownValues, String? kind, List<TableDataInsertAllRequestRows>? rows, bool? skipInvalidRows, String? templateSuffix, String? traceId})
TableDataInsertAllRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreUnknownValues ↔ bool?
Accept rows that contain values that do not match the schema.
getter/setter pair
kind ↔ String?
The resource type of the response.
getter/setter pair
rows ↔ List<TableDataInsertAllRequestRows>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipInvalidRows ↔ bool?
Insert all valid rows of a request, even if invalid rows exist.
getter/setter pair
templateSuffix ↔ String?
If specified, treats the destination table as a base template, and inserts the rows into an instance table named "{destination}{templateSuffix}".
getter/setter pair
traceId ↔ String?
Unique request trace id.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited