TableDataInsertAllRequestRows class

Data for a single insertion row.

Properties

hashCode → int
The hash code for this object.
no setterinherited
insertId ↔ String?
Insertion ID for best-effort deduplication.
getter/setter pair
json ↔ Map<String, Object?>?
Data for a single row.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited