TableFieldSchema class

A field in TableSchema

Constructors

TableFieldSchema({TableFieldSchemaCategories? categories, String? collation, TableFieldSchemaDataGovernanceTagsInfo? dataGovernanceTagsInfo, List<DataPolicyOption>? dataPolicies, DataPolicyList? dataPolicyList, String? defaultValueExpression, String? description, List<TableFieldSchema>? fields, String? foreignTypeDefinition, GeneratedColumn? generatedColumn, String? maxLength, String? mode, String? name, TableFieldSchemaPolicyTags? policyTags, String? precision, TableFieldSchemaRangeElementType? rangeElementType, String? roundingMode, String? scale, String? timestampPrecision, String? type})
TableFieldSchema.fromJson(Map json_)

Properties

categories ↔ TableFieldSchemaCategories?
Deprecated.
getter/setter pair
collation ↔ String?
Field collation can be set only when the type of field is STRING.
getter/setter pair
dataGovernanceTagsInfo ↔ TableFieldSchemaDataGovernanceTagsInfo?
Specifies the data governance tags on this field.
getter/setter pair
dataPolicies ↔ List<DataPolicyOption>?
Data policies attached to this field, used for field-level access control.
getter/setter pair
dataPolicyList ↔ DataPolicyList?
Specifies data policies attached to this field, used for field-level access control.
getter/setter pair
defaultValueExpression ↔ String?
A SQL expression to specify the default value for this field.
getter/setter pair
description ↔ String?
The field description.
getter/setter pair
fields ↔ List<TableFieldSchema>?
Describes the nested schema fields if the type property is set to RECORD.
getter/setter pair
foreignTypeDefinition ↔ String?
Definition of the foreign data type.
getter/setter pair
generatedColumn ↔ GeneratedColumn?
Definition of how values are generated for the field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxLength ↔ String?
Maximum length of values of this field for STRINGS or BYTES.
getter/setter pair
mode ↔ String?
The field mode.
getter/setter pair
name ↔ String?
The field name.
getter/setter pair
policyTags ↔ TableFieldSchemaPolicyTags?
The policy tags attached to this field, used for field-level access control.
getter/setter pair
precision ↔ String?
Precision (maximum number of total digits in base 10) and scale (maximum number of digits in the fractional part in base 10) constraints for values of this field for NUMERIC or BIGNUMERIC.
getter/setter pair
rangeElementType ↔ TableFieldSchemaRangeElementType?
Represents the type of a field element.
getter/setter pair
roundingMode ↔ String?
Specifies the rounding mode to be used when storing values of NUMERIC and BIGNUMERIC type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ String?
See documentation for precision.
getter/setter pair
timestampPrecision ↔ String?
Precision (maximum number of total digits in base 10) for seconds of TIMESTAMP type.
getter/setter pair
type ↔ String?
The field data type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited