dataPolicyList property

DataPolicyList? dataPolicyList
getter/setter pair

Specifies data policies attached to this field, used for field-level access control.

When set, this will be the source of truth for data policy information.

Optional.

Implementation

DataPolicyList? dataPolicyList;