TableMetadataCacheUsage class

Table level detail on the usage of metadata caching.

Only set for Metadata caching eligible tables referenced in the query.

Constructors

TableMetadataCacheUsage({String? explanation, PruningStats? pruningStats, String? staleness, TableReference? tableReference, String? tableType, String? unusedReason})
TableMetadataCacheUsage.fromJson(Map json_)

Properties

explanation ↔ String?
Free form human-readable reason metadata caching was unused for the job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pruningStats ↔ PruningStats?
The column metadata index pruning statistics.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staleness ↔ String?
Duration since last refresh as of this job for managed tables (indicates metadata cache staleness as seen by this job).
getter/setter pair
tableReference ↔ TableReference?
Metadata caching eligible table referenced in the query.
getter/setter pair
tableType ↔ String?
Table type.
getter/setter pair
unusedReason ↔ String?
Reason for not using metadata caching for the table. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited