TableReference class

Constructors

TableReference({String? datasetId, String? projectId, String? tableId})
TableReference.fromJson(Map json_)

Properties

datasetId ↔ String?
The ID of the dataset containing this table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
projectId ↔ String?
The ID of the project containing this table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId ↔ String?
The ID of the table.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited