TableReplicationInfo class

Replication info of a table created using AS REPLICA DDL like: CREATE MATERIALIZED VIEW mv1 AS REPLICA OF src_mv

Constructors

TableReplicationInfo({String? replicatedSourceLastRefreshTime, ErrorProto? replicationError, String? replicationIntervalMs, String? replicationStatus, TableReference? sourceTable})
TableReplicationInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
replicatedSourceLastRefreshTime ↔ String?
If source is a materialized view, this field signifies the last refresh time of the source.
getter/setter pair
replicationError ↔ ErrorProto?
Replication error that will permanently stopped table replication.
getter/setter pair
replicationIntervalMs ↔ String?
Specifies the interval at which the source table is polled for updates.
getter/setter pair
replicationStatus ↔ String?
Replication status of configured replication.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceTable ↔ TableReference?
Source table reference that is replicated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited