TableSchema class

Schema of a table

Constructors

TableSchema({List<TableFieldSchema>? fields, ForeignTypeInfo? foreignTypeInfo})
TableSchema.fromJson(Map json_)

Properties

fields ↔ List<TableFieldSchema>?
Describes the fields in a table.
getter/setter pair
foreignTypeInfo ↔ ForeignTypeInfo?
Specifies metadata of the foreign data type definition in field schema (TableFieldSchema.foreign_type_definition).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited