TimePartitioning class

Constructors

TimePartitioning({String? expirationMs, String? field, bool? requirePartitionFilter, String? type})
TimePartitioning.fromJson(Map json_)

Properties

expirationMs ↔ String?
Number of milliseconds for which to keep the storage for a partition.
getter/setter pair
field ↔ String?
If not set, the table is partitioned by pseudo column '_PARTITIONTIME'; if set, the table is partitioned by this field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requirePartitionFilter ↔ bool?
If set to true, queries over this table require a partition filter that can be used for partition elimination to be specified.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The supported types are DAY, HOUR, MONTH, and YEAR, which will generate one partition per day, hour, month, and year, respectively.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited