TrainingOptions class

Options used in model training.

Constructors

TrainingOptions({String? activationFn, bool? adjustStepChanges, bool? approxGlobalFeatureContrib, bool? autoArima, String? autoArimaMaxOrder, String? autoArimaMinOrder, bool? autoClassWeights, String? batchSize, String? boosterType, double? budgetHours, bool? calculatePValues, String? categoryEncodingMethod, bool? cleanSpikesAndDips, String? colorSpace, double? colsampleBylevel, double? colsampleBynode, double? colsampleBytree, String? contributionMetric, String? dartNormalizeType, String? dataFrequency, String? dataSplitColumn, double? dataSplitEvalFraction, String? dataSplitMethod, bool? decomposeTimeSeries, List<String>? dimensionIdColumns, String? distanceType, double? dropout, bool? earlyStop, bool? enableGlobalExplain, String? endpointIdleTtl, String? feedbackType, bool? fitIntercept, double? forecastLimitLowerBound, double? forecastLimitUpperBound, List<String>? hiddenUnits, String? holidayRegion, List<String>? holidayRegions, String? horizon, List<String>? hparamTuningObjectives, String? huggingFaceModelId, bool? includeDrift, double? initialLearnRate, List<String>? inputLabelColumns, String? instanceWeightColumn, String? integratedGradientsNumSteps, String? isTestColumn, String? itemColumn, String? kmeansInitializationColumn, String? kmeansInitializationMethod, double? l1RegActivation, double? l1Regularization, double? l2Regularization, Map<String, double>? labelClassWeights, double? learnRate, String? learnRateStrategy, String? lossType, String? machineType, String? maxIterations, String? maxParallelTrials, String? maxReplicaCount, String? maxTimeSeriesLength, String? maxTreeDepth, double? minAprioriSupport, double? minRelativeProgress, String? minReplicaCount, double? minSplitLoss, String? minTimeSeriesLength, String? minTreeChildWeight, String? modelGardenModelName, String? modelRegistry, String? modelUri, ArimaOrder? nonSeasonalOrder, String? numClusters, String? numFactors, String? numParallelTree, String? numPrincipalComponents, String? numTrials, String? optimizationStrategy, String? optimizer, double? pcaExplainedVarianceRatio, String? pcaSolver, String? reservationAffinityKey, String? reservationAffinityType, List<String>? reservationAffinityValues, String? sampledShapleyNumPaths, bool? scaleFeatures, bool? standardizeFeatures, double? subsample, String? tfVersion, String? timeSeriesDataColumn, String? timeSeriesIdColumn, List<String>? timeSeriesIdColumns, double? timeSeriesLengthFraction, String? timeSeriesTimestampColumn, String? treeMethod, String? trendSmoothingWindowSize, String? userColumn, List<String>? vertexAiModelVersionAliases, double? walsAlpha, bool? warmStart, String? xgboostVersion})
TrainingOptions.fromJson(Map json_)

Properties

activationFn ↔ String?
Activation function of the neural nets.
getter/setter pair
adjustStepChanges ↔ bool?
If true, detect step changes and make data adjustment in the input time series.
getter/setter pair
approxGlobalFeatureContrib ↔ bool?
Whether to use approximate feature contribution method in XGBoost model explanation for global explain.
getter/setter pair
autoArima ↔ bool?
Whether to enable auto ARIMA or not.
getter/setter pair
autoArimaMaxOrder ↔ String?
The max value of the sum of non-seasonal p and q.
getter/setter pair
autoArimaMinOrder ↔ String?
The min value of the sum of non-seasonal p and q.
getter/setter pair
autoClassWeights ↔ bool?
Whether to calculate class weights automatically based on the popularity of each label.
getter/setter pair
batchSize ↔ String?
Batch size for dnn models.
getter/setter pair
boosterType ↔ String?
Booster type for boosted tree models. Possible string values are:
getter/setter pair
budgetHours ↔ double?
Budget in hours for AutoML training.
getter/setter pair
calculatePValues ↔ bool?
Whether or not p-value test should be computed for this model.
getter/setter pair
categoryEncodingMethod ↔ String?
Categorical feature encoding method. Possible string values are:
getter/setter pair
cleanSpikesAndDips ↔ bool?
If true, clean spikes and dips in the input time series.
getter/setter pair
colorSpace ↔ String?
Enums for color space, used for processing images in Object Table.
getter/setter pair
colsampleBylevel ↔ double?
Subsample ratio of columns for each level for boosted tree models.
getter/setter pair
colsampleBynode ↔ double?
Subsample ratio of columns for each node(split) for boosted tree models.
getter/setter pair
colsampleBytree ↔ double?
Subsample ratio of columns when constructing each tree for boosted tree models.
getter/setter pair
contributionMetric ↔ String?
The contribution metric.
getter/setter pair
dartNormalizeType ↔ String?
Type of normalization algorithm for boosted tree models using dart booster. Possible string values are:
getter/setter pair
dataFrequency ↔ String?
The data frequency of a time series. Possible string values are:
getter/setter pair
dataSplitColumn ↔ String?
The column to split data with.
getter/setter pair
dataSplitEvalFraction ↔ double?
The fraction of evaluation data over the whole input data.
getter/setter pair
dataSplitMethod ↔ String?
The data split type for training and evaluation, e.g. RANDOM. Possible string values are:
getter/setter pair
decomposeTimeSeries ↔ bool?
If true, perform decompose time series and save the results.
getter/setter pair
dimensionIdColumns ↔ List<String>?
Names of the columns to slice on.
getter/setter pair
distanceType ↔ String?
Distance type for clustering models. Possible string values are:
getter/setter pair
dropout ↔ double?
Dropout probability for dnn models.
getter/setter pair
earlyStop ↔ bool?
Whether to stop early when the loss doesn't improve significantly any more (compared to min_relative_progress).
getter/setter pair
enableGlobalExplain ↔ bool?
If true, enable global explanation during training.
getter/setter pair
endpointIdleTtl ↔ String?
The idle TTL of the endpoint before the resources get destroyed.
getter/setter pair
feedbackType ↔ String?
Feedback type that specifies which algorithm to run for matrix factorization. Possible string values are:
getter/setter pair
fitIntercept ↔ bool?
Whether the model should include intercept during model training.
getter/setter pair
forecastLimitLowerBound ↔ double?
The forecast limit lower bound that was used during ARIMA model training with limits.
getter/setter pair
forecastLimitUpperBound ↔ double?
The forecast limit upper bound that was used during ARIMA model training with limits.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hiddenUnits ↔ List<String>?
Hidden units for dnn models.
getter/setter pair
holidayRegion ↔ String?
The geographical region based on which the holidays are considered in time series modeling.
getter/setter pair
holidayRegions ↔ List<String>?
A list of geographical regions that are used for time series modeling.
getter/setter pair
horizon ↔ String?
The number of periods ahead that need to be forecasted.
getter/setter pair
hparamTuningObjectives ↔ List<String>?
The target evaluation metrics to optimize the hyperparameters for.
getter/setter pair
huggingFaceModelId ↔ String?
The id of a Hugging Face model.
getter/setter pair
includeDrift ↔ bool?
Include drift when fitting an ARIMA model.
getter/setter pair
initialLearnRate ↔ double?
Specifies the initial learning rate for the line search learn rate strategy.
getter/setter pair
inputLabelColumns ↔ List<String>?
Name of input label columns in training data.
getter/setter pair
instanceWeightColumn ↔ String?
Name of the instance weight column for training data.
getter/setter pair
integratedGradientsNumSteps ↔ String?
Number of integral steps for the integrated gradients explain method.
getter/setter pair
isTestColumn ↔ String?
Name of the column used to determine the rows corresponding to control and test.
getter/setter pair
itemColumn ↔ String?
Item column specified for matrix factorization models.
getter/setter pair
kmeansInitializationColumn ↔ String?
The column used to provide the initial centroids for kmeans algorithm when kmeans_initialization_method is CUSTOM.
getter/setter pair
kmeansInitializationMethod ↔ String?
The method used to initialize the centroids for kmeans algorithm. Possible string values are:
getter/setter pair
l1RegActivation ↔ double?
L1 regularization coefficient to activations.
getter/setter pair
l1Regularization ↔ double?
L1 regularization coefficient.
getter/setter pair
l2Regularization ↔ double?
L2 regularization coefficient.
getter/setter pair
labelClassWeights ↔ Map<String, double>?
Weights associated with each label class, for rebalancing the training data.
getter/setter pair
learnRate ↔ double?
Learning rate in training.
getter/setter pair
learnRateStrategy ↔ String?
The strategy to determine learn rate for the current iteration. Possible string values are:
getter/setter pair
lossType ↔ String?
Type of loss function used during training run. Possible string values are:
getter/setter pair
machineType ↔ String?
The type of the machine used to deploy and serve the model.
getter/setter pair
maxIterations ↔ String?
The maximum number of iterations in training.
getter/setter pair
maxParallelTrials ↔ String?
Maximum number of trials to run in parallel.
getter/setter pair
maxReplicaCount ↔ String?
The maximum number of machine replicas that will be deployed on an endpoint.
getter/setter pair
maxTimeSeriesLength ↔ String?
The maximum number of time points in a time series that can be used in modeling the trend component of the time series.
getter/setter pair
maxTreeDepth ↔ String?
Maximum depth of a tree for boosted tree models.
getter/setter pair
minAprioriSupport ↔ double?
The apriori support minimum.
getter/setter pair
minRelativeProgress ↔ double?
When early_stop is true, stops training when accuracy improvement is less than 'min_relative_progress'.
getter/setter pair
minReplicaCount ↔ String?
The minimum number of machine replicas that will be always deployed on an endpoint.
getter/setter pair
minSplitLoss ↔ double?
Minimum split loss for boosted tree models.
getter/setter pair
minTimeSeriesLength ↔ String?
The minimum number of time points in a time series that are used in modeling the trend component of the time series.
getter/setter pair
minTreeChildWeight ↔ String?
Minimum sum of instance weight needed in a child for boosted tree models.
getter/setter pair
modelGardenModelName ↔ String?
The name of a Vertex model garden publisher model.
getter/setter pair
modelRegistry ↔ String?
The model registry. Possible string values are:
getter/setter pair
modelUri ↔ String?
Google Cloud Storage URI from which the model was imported.
getter/setter pair
nonSeasonalOrder ↔ ArimaOrder?
A specification of the non-seasonal part of the ARIMA model: the three components (p, d, q) are the AR order, the degree of differencing, and the MA order.
getter/setter pair
numClusters ↔ String?
Number of clusters for clustering models.
getter/setter pair
numFactors ↔ String?
Num factors specified for matrix factorization models.
getter/setter pair
numParallelTree ↔ String?
Number of parallel trees constructed during each iteration for boosted tree models.
getter/setter pair
numPrincipalComponents ↔ String?
Number of principal components to keep in the PCA model.
getter/setter pair
numTrials ↔ String?
Number of trials to run this hyperparameter tuning job.
getter/setter pair
optimizationStrategy ↔ String?
Optimization strategy for training linear regression models. Possible string values are:
getter/setter pair
optimizer ↔ String?
Optimizer used for training the neural nets.
getter/setter pair
pcaExplainedVarianceRatio ↔ double?
The minimum ratio of cumulative explained variance that needs to be given by the PCA model.
getter/setter pair
pcaSolver ↔ String?
The solver for PCA. Possible string values are:
getter/setter pair
reservationAffinityKey ↔ String?
Corresponds to the label key of a reservation resource used by Vertex AI.
getter/setter pair
reservationAffinityType ↔ String?
Specifies the reservation affinity type used to configure a Vertex AI resource.
getter/setter pair
reservationAffinityValues ↔ List<String>?
Corresponds to the label values of a reservation resource used by Vertex AI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampledShapleyNumPaths ↔ String?
Number of paths for the sampled Shapley explain method.
getter/setter pair
scaleFeatures ↔ bool?
If true, scale the feature values by dividing the feature standard deviation.
getter/setter pair
standardizeFeatures ↔ bool?
Whether to standardize numerical features.
getter/setter pair
subsample ↔ double?
Subsample fraction of the training data to grow tree to prevent overfitting for boosted tree models.
getter/setter pair
tfVersion ↔ String?
Based on the selected TF version, the corresponding docker image is used to train external models.
getter/setter pair
timeSeriesDataColumn ↔ String?
Column to be designated as time series data for ARIMA model.
getter/setter pair
timeSeriesIdColumn ↔ String?
The time series id column that was used during ARIMA model training.
getter/setter pair
timeSeriesIdColumns ↔ List<String>?
The time series id columns that were used during ARIMA model training.
getter/setter pair
timeSeriesLengthFraction ↔ double?
The fraction of the interpolated length of the time series that's used to model the time series trend component.
getter/setter pair
timeSeriesTimestampColumn ↔ String?
Column to be designated as time series timestamp for ARIMA model.
getter/setter pair
treeMethod ↔ String?
Tree construction algorithm for boosted tree models. Possible string values are:
getter/setter pair
trendSmoothingWindowSize ↔ String?
Smoothing window size for the trend component.
getter/setter pair
userColumn ↔ String?
User column specified for matrix factorization models.
getter/setter pair
vertexAiModelVersionAliases ↔ List<String>?
The version aliases to apply in Vertex AI model registry.
getter/setter pair
walsAlpha ↔ double?
Hyperparameter for matrix factoration when implicit feedback type is specified.
getter/setter pair
warmStart ↔ bool?
Whether to train a model from the last checkpoint.
getter/setter pair
xgboostVersion ↔ String?
User-selected XGBoost versions for training of XGBoost models.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited