TrainingRun class

Information about a single training query run for the model.

Constructors

TrainingRun({List<GlobalExplanation>? classLevelGlobalExplanations, DataSplitResult? dataSplitResult, EvaluationMetrics? evaluationMetrics, GlobalExplanation? modelLevelGlobalExplanation, List<IterationResult>? results, String? startTime, TrainingOptions? trainingOptions, String? trainingStartTime, String? vertexAiModelId, String? vertexAiModelVersion})
TrainingRun.fromJson(Map json_)

Properties

classLevelGlobalExplanations ↔ List<GlobalExplanation>?
Global explanation contains the explanation of top features on the class level.
getter/setter pair
dataSplitResult ↔ DataSplitResult?
Data split result of the training run.
getter/setter pair
evaluationMetrics ↔ EvaluationMetrics?
The evaluation metrics over training/eval data that were computed at the end of training.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modelLevelGlobalExplanation ↔ GlobalExplanation?
Global explanation contains the explanation of top features on the model level.
getter/setter pair
results ↔ List<IterationResult>?
Output of each iteration run, results.size() <= max_iterations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The start time of this training run.
getter/setter pair
trainingOptions ↔ TrainingOptions?
Options that were used for this training run, includes user specified and default options that were used.
getter/setter pair
trainingStartTime ↔ String?
The start time of this training run, in milliseconds since epoch.
getter/setter pair
vertexAiModelId ↔ String?
The model id in the Vertex AI Model Registry for this training run.
getter/setter pair
vertexAiModelVersion ↔ String?
The model version in the Vertex AI Model Registry for this training run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited