VectorSearchStatistics class

Statistics for a vector search query.

Populated as part of JobStatistics2.

Constructors

VectorSearchStatistics({List<IndexUnusedReason>? indexUnusedReasons, String? indexUsageMode, List<StoredColumnsUsage>? storedColumnsUsages})
VectorSearchStatistics.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexUnusedReasons ↔ List<IndexUnusedReason>?
When indexUsageMode is UNUSED or PARTIALLY_USED, this field explains why indexes were not used in all or part of the vector search query.
getter/setter pair
indexUsageMode ↔ String?
Specifies the index usage mode for the query. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedColumnsUsages ↔ List<StoredColumnsUsage>?
Specifies the usage of stored columns in the query when stored columns are used in the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited