AzureProperties class

Container for connection properties specific to Azure.

Constructors

AzureProperties({String? application, String? clientId, String? customerTenantId, String? federatedApplicationClientId, String? identity, String? objectId, String? redirectUri})
AzureProperties.fromJson(Map json_)

Properties

application ↔ String?
The name of the Azure Active Directory Application.
getter/setter pair
clientId ↔ String?
The client id of the Azure Active Directory Application.
getter/setter pair
customerTenantId ↔ String?
The id of customer's directory that host the data.
getter/setter pair
federatedApplicationClientId ↔ String?
The client ID of the user's Azure Active Directory Application used for a federated connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identity ↔ String?
A unique Google-owned and Google-generated identity for the Connection.
getter/setter pair
objectId ↔ String?
The object id of the Azure Active Directory Application.
getter/setter pair
redirectUri ↔ String?
The URL user will be redirected to after granting consent during connection setup.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited