Connection class

Configuration parameters to establish connection with an external data source, except the credential attributes.

Constructors

Connection({AwsProperties? aws, AzureProperties? azure, CloudResourceProperties? cloudResource, CloudSpannerProperties? cloudSpanner, CloudSqlProperties? cloudSql, ConnectorConfiguration? configuration, String? creationTime, String? description, String? friendlyName, bool? hasCredential, String? kmsKeyName, String? lastModifiedTime, String? name, SalesforceDataCloudProperties? salesforceDataCloud, SparkProperties? spark})
Connection.fromJson(Map json_)

Properties

aws ↔ AwsProperties?
Amazon Web Services (AWS) properties.
getter/setter pair
azure ↔ AzureProperties?
Azure properties.
getter/setter pair
cloudResource ↔ CloudResourceProperties?
Cloud Resource properties.
getter/setter pair
cloudSpanner ↔ CloudSpannerProperties?
Cloud Spanner properties.
getter/setter pair
cloudSql ↔ CloudSqlProperties?
Cloud SQL properties.
getter/setter pair
configuration ↔ ConnectorConfiguration?
Connector configuration.
getter/setter pair
creationTime ↔ String?
The creation timestamp of the connection.
getter/setter pair
description ↔ String?
User provided description.
getter/setter pair
friendlyName ↔ String?
User provided display name for the connection.
getter/setter pair
hasCredential ↔ bool?
True, if credential is configured for this connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
The Cloud KMS key that is used for credentials encryption.
getter/setter pair
lastModifiedTime ↔ String?
The last update timestamp of the connection.
getter/setter pair
name ↔ String?
The resource name of the connection in the form of: projects/{project_id}/locations/{location_id}/connections/{connection_id}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salesforceDataCloud ↔ SalesforceDataCloudProperties?
Salesforce DataCloud properties.
getter/setter pair
spark ↔ SparkProperties?
Spark properties.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited