ConnectorConfiguration class

Represents concrete parameter values for Connector Configuration.

Properties

asset ↔ ConnectorConfigurationAsset?
Data asset.
getter/setter pair
authentication ↔ ConnectorConfigurationAuthentication?
Client authentication.
getter/setter pair
connectorId ↔ String?
The ID of the Connector these parameters are configured for.
getter/setter pair
endpoint ↔ ConnectorConfigurationEndpoint?
Specifies how to reach the remote system this connection is pointing to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
network ↔ ConnectorConfigurationNetwork?
Networking configuration.
getter/setter pair
parameters ↔ Map<String, ConnectorConfigurationParameterValue>?
A map of name-value pairs for connector-specific parameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tls ↔ ConnectorConfigurationTls?
TLS configuration options.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited