ConnectorConfigurationAuthentication class

Client authentication.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Google-managed service account associated with this connection, e.g., service-{project_number}@gcp-sa-bigqueryconnection.iam.gserviceaccount.com.
getter/setter pair
usernamePassword ↔ ConnectorConfigurationUsernamePassword?
Username/password authentication.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited