ConnectorConfigurationTls class

TLS configuration options.

Properties

hashCode int
The hash code for this object.
no setterinherited
mode String?
The mode of TLS configuration.
getter/setter pair
privatePki ConnectorConfigurationTlsPrivatePki?
Private PKI.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webPki ConnectorConfigurationTlsWebPki?
Web PKI.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited