SparkProperties class

Container for connection properties to execute stored procedures for Apache Spark.

Constructors

SparkProperties({MetastoreServiceConfig? metastoreServiceConfig, String? serviceAccountId, SparkHistoryServerConfig? sparkHistoryServerConfig})
SparkProperties.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metastoreServiceConfig ↔ MetastoreServiceConfig?
Dataproc Metastore Service configuration for the connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountId ↔ String?
The account ID of the service created for the purpose of this connection.
getter/setter pair
sparkHistoryServerConfig ↔ SparkHistoryServerConfig?
Spark History Server configuration for the connection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited