DataGovernanceTag class

This is a namespaced name specifying the key and the value.

For example: project-id/pii/sensitive.

Constructors

DataGovernanceTag({String? key, String? value})
DataGovernanceTag.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
Tag keys are globally unique.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
Specifies the tag value as the short name, for example sensitive.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited