key property

String? key
getter/setter pair

Tag keys are globally unique.

Tag key is expected to be in the namespaced format, for example parent-id/pii where parent-id is the ID of the parent organization or project resource for this tag key.

Optional.

Implementation

core.String? key;