DataSource class

Defines the properties and custom parameters for a data source.

Constructors

DataSource({String? authorizationType, String? clientId, String? dataRefreshType, String? dataSourceId, int? defaultDataRefreshWindowDays, String? defaultSchedule, String? description, String? displayName, String? helpUrl, bool? manualRunsDisabled, String? minimumScheduleInterval, String? name, List<DataSourceParameter>? parameters, List<String>? scopes, bool? supportsCustomSchedule, bool? supportsMultipleTransfers, String? transferType, int? updateDeadlineSeconds})
DataSource.fromJson(Map json_)

Properties

authorizationType ↔ String?
Indicates the type of authorization. Possible string values are:
getter/setter pair
clientId ↔ String?
Data source client id which should be used to receive refresh token.
getter/setter pair
dataRefreshType ↔ String?
Specifies whether the data source supports automatic data refresh for the past few days, and how it's supported.
getter/setter pair
dataSourceId ↔ String?
Data source id.
getter/setter pair
defaultDataRefreshWindowDays ↔ int?
Default data refresh window on days.
getter/setter pair
defaultSchedule ↔ String?
Default data transfer schedule.
getter/setter pair
description ↔ String?
User friendly data source description string.
getter/setter pair
displayName ↔ String?
User friendly data source name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
helpUrl ↔ String?
Url for the help document for this data source.
getter/setter pair
manualRunsDisabled ↔ bool?
Disables backfilling and manual run scheduling for the data source.
getter/setter pair
minimumScheduleInterval ↔ String?
The minimum interval for scheduler to schedule runs.
getter/setter pair
name ↔ String?
Data source resource name.
getter/setter pair
parameters ↔ List<DataSourceParameter>?
Data source parameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>?
Api auth scopes for which refresh token needs to be obtained.
getter/setter pair
supportsCustomSchedule ↔ bool?
Specifies whether the data source supports a user defined schedule, or operates on the default schedule.
getter/setter pair
supportsMultipleTransfers ↔ bool?
This field has no effect.
getter/setter pair
transferType ↔ String?
This field has no effect.
getter/setter pair
updateDeadlineSeconds ↔ int?
The number of seconds to wait for an update from the data source before the Data Transfer Service marks the transfer as FAILED.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited