DataSourceParameter class

A parameter used to define custom fields in a data source definition.

Constructors

DataSourceParameter({List<String>? allowedValues, bool? deprecated, String? description, String? displayName, List<DataSourceParameter>? fields, bool? immutable, String? maxListSize, double? maxValue, double? minValue, String? paramId, bool? recurse, bool? repeated, bool? required, String? type, String? validationDescription, String? validationHelpUrl, String? validationRegex})
DataSourceParameter.fromJson(Map json_)

Properties

allowedValues ↔ List<String>?
All possible values for the parameter.
getter/setter pair
deprecated ↔ bool?
If true, it should not be used in new transfers, and it should not be visible to users.
getter/setter pair
description ↔ String?
Parameter description.
getter/setter pair
displayName ↔ String?
Parameter display name in the user interface.
getter/setter pair
fields ↔ List<DataSourceParameter>?
This field has no effect.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
immutable ↔ bool?
Cannot be changed after initial creation.
getter/setter pair
maxListSize ↔ String?
For list parameters, the max size of the list.
getter/setter pair
maxValue ↔ double?
For integer and double values specifies maximum allowed value.
getter/setter pair
minValue ↔ double?
For integer and double values specifies minimum allowed value.
getter/setter pair
paramId ↔ String?
Parameter identifier.
getter/setter pair
recurse ↔ bool?
This field has no effect.
getter/setter pair
repeated ↔ bool?
This field has no effect.
getter/setter pair
required ↔ bool?
Is parameter required.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Parameter type. Possible string values are:
getter/setter pair
validationDescription ↔ String?
Description of the requirements for this field, in case the user input does not fulfill the regex pattern or min/max values.
getter/setter pair
validationHelpUrl ↔ String?
URL to a help document to further explain the naming requirements.
getter/setter pair
validationRegex ↔ String?
Regular expression which can be used for parameter validation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited