entryGroup property
The Dataplex Universal Catalog entry group for importing the metadata.
entry_group has the format of
projects/{project_id}/locations/{region}/entryGroups/{entry_group_id}.
Required.
Implementation
core.String? entryGroup;
The Dataplex Universal Catalog entry group for importing the metadata.
entry_group has the format of
projects/{project_id}/locations/{region}/entryGroups/{entry_group_id}.
Required.
core.String? entryGroup;