ListTransferConfigsResponse class

The returned list of pipelines in the project.

Constructors

ListTransferConfigsResponse({String? nextPageToken, List<TransferConfig>? transferConfigs})
ListTransferConfigsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The next-pagination token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferConfigs ↔ List<TransferConfig>?
The stored pipeline transfer configurations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited