ListTransferResourcesResponse class
Response for the ListTransferResources RPC.
Constructors
-
ListTransferResourcesResponse({String? nextPageToken, List<
TransferResource> ? transferResources}) - ListTransferResourcesResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
A token, which can be sent as
page_tokento retrieve the next page.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transferResources
↔ List<
TransferResource> ? -
The transfer resources.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited