ProjectsLocationsTransferConfigsResource class

Constructors

ProjectsLocationsTransferConfigsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runs → ProjectsLocationsTransferConfigsRunsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferResources → ProjectsLocationsTransferConfigsTransferResourcesResource
no setter

Methods

create(TransferConfig request, String parent, {String? authorizationCode, String? serviceAccountName, String? versionInfo, String? $fields}) → Future<TransferConfig>
Creates a new data transfer configuration.
delete(String name, {String? $fields}) → Future<Empty>
Deletes a data transfer configuration, including any associated transfer runs and logs.
get(String name, {String? $fields}) → Future<TransferConfig>
Returns information about a data transfer config.
list(String parent, {List<String>? dataSourceIds, int? pageSize, String? pageToken, String? $fields}) → Future<ListTransferConfigsResponse>
Returns information about all transfer configs owned by a project in the specified location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(TransferConfig request, String name, {String? authorizationCode, String? serviceAccountName, String? updateMask, String? versionInfo, String? $fields}) → Future<TransferConfig>
Updates a data transfer configuration.
scheduleRuns(ScheduleTransferRunsRequest request, String parent, {String? $fields}) → Future<ScheduleTransferRunsResponse>
Creates transfer runs for a time range [start_time, end_time].
startManualRuns(StartManualTransferRunsRequest request, String parent, {String? $fields}) → Future<StartManualTransferRunsResponse>
Manually initiates transfer runs.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited