list method

Future<ListTransferResourcesResponse> list(
  1. String parent, {
  2. String? filter,
  3. int? pageSize,
  4. String? pageToken,
  5. String? $fields,
})

Returns information about transfer resources.

Request parameters:

parent - Required. Name of transfer configuration for which transfer resources should be retrieved. The name should be in one of the following forms: * projects/{project}/transferConfigs/{transfer_config} * projects/{project}/locations/{location_id}/transferConfigs/{transfer_config} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/transferConfigs/\[^/\]+$.

filter - Optional. Filter for the transfer resources. Currently supported filters include: * Resource name: name - Wildcard supported * Resource type: type * Resource destination: destination * Latest resource state: latest_status_detail.state * Last update time: update_time - RFC-3339 format * Parent table name: hierarchy_detail.partition_detail.table Multiple filters can be applied using the AND/OR operator. Examples: * name="*123" AND (type="TABLE" OR latest_status_detail.state="SUCCEEDED") * update_time >= "2012-04-21T11:30:00-04:00" * hierarchy_detail.partition_detail.table = "table1"

pageSize - Optional. The maximum number of transfer resources to return. The maximum value is 1000; values above 1000 will be coerced to 1000. The default page size is the maximum value of 1000 results.

pageToken - Optional. A page token, received from a previous ListTransferResources call. Provide this to retrieve the subsequent page. When paginating, all other parameters provided to ListTransferResources must match the call that provided the page token.

$fields - Selector specifying which fields to include in a partial response.

Completes with a ListTransferResourcesResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<ListTransferResourcesResponse> list(
  core.String parent, {
  core.String? filter,
  core.int? pageSize,
  core.String? pageToken,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'filter': ?filter == null ? null : [filter],
    'pageSize': ?pageSize == null ? null : ['${pageSize}'],
    'pageToken': ?pageToken == null ? null : [pageToken],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/transferResources';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return ListTransferResourcesResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}