ProjectsResource class

Constructors

ProjectsResource(ApiRequester client)

Properties

dataSources → ProjectsDataSourcesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
locations → ProjectsLocationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferConfigs → ProjectsTransferConfigsResource
no setter

Methods

enrollDataSources(EnrollDataSourcesRequest request, String name, {String? $fields}) → Future<Empty>
Enroll data sources in a user project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited