ScheduleOptions class

Options customizing the data transfer schedule.

Constructors

ScheduleOptions({bool? disableAutoScheduling, String? endTime, String? startTime})
ScheduleOptions.fromJson(Map json_)

Properties

disableAutoScheduling ↔ bool?
If true, automatic scheduling of data transfer runs for this configuration will be disabled.
getter/setter pair
endTime ↔ String?
Defines time to stop scheduling transfer runs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Specifies time to start scheduling transfer runs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited