TimeBasedSchedule class

Options customizing the time based transfer schedule.

Options are migrated from the original ScheduleOptions message.

Constructors

TimeBasedSchedule({String? endTime, String? schedule, String? startTime})
TimeBasedSchedule.fromJson(Map json_)

Properties

endTime ↔ String?
Defines time to stop scheduling transfer runs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule ↔ String?
Data transfer schedule.
getter/setter pair
startTime ↔ String?
Specifies time to start scheduling transfer runs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited