TransferConfig class

Represents a data transfer configuration.

A transfer configuration contains all metadata needed to perform a data transfer. For example, destination_dataset_id specifies where data should be stored. When a new transfer configuration is created, the specified destination_dataset_id is created when needed and shared with the appropriate data source service account.

Constructors

TransferConfig({int? dataRefreshWindowDays, String? dataSourceId, String? datasetRegion, String? destinationDatasetId, bool? disabled, String? displayName, EmailPreferences? emailPreferences, EncryptionConfiguration? encryptionConfiguration, Status? error, String? managedTableType, MetadataDestination? metadataDestination, String? name, String? nextRunTime, String? notificationPubsubTopic, UserInfo? ownerInfo, Map<String, Object?>? params, String? schedule, ScheduleOptions? scheduleOptions, ScheduleOptionsV2? scheduleOptionsV2, String? state, String? updateTime, String? userId})
TransferConfig.fromJson(Map json_)

Properties

dataRefreshWindowDays ↔ int?
The number of days to look back to automatically refresh the data.
getter/setter pair
datasetRegion ↔ String?
Region in which BigQuery dataset is located.
getter/setter pair
dataSourceId ↔ String?
Data source ID.
getter/setter pair
destinationDatasetId ↔ String?
The BigQuery target dataset id.
getter/setter pair
disabled ↔ bool?
Is this config disabled.
getter/setter pair
displayName ↔ String?
User specified display name for the data transfer.
getter/setter pair
emailPreferences ↔ EmailPreferences?
Email notifications will be sent according to these preferences to the email address of the user who owns this transfer config.
getter/setter pair
encryptionConfiguration ↔ EncryptionConfiguration?
The encryption configuration part.
getter/setter pair
error ↔ Status?
Error code with detailed information about reason of the latest config failure.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
managedTableType ↔ String?
The classification of the destination table. Possible string values are:
getter/setter pair
metadataDestination ↔ MetadataDestination?
The metadata destination of the transfer config.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
nextRunTime ↔ String?
Next time when data transfer will run.
getter/setter pair
notificationPubsubTopic ↔ String?
Pub/Sub topic where notifications will be sent after transfer runs associated with this transfer config finish.
getter/setter pair
ownerInfo ↔ UserInfo?
Information about the user whose credentials are used to transfer data.
getter/setter pair
params ↔ Map<String, Object?>?
Parameters specific to each data source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule ↔ String?
Data transfer schedule.
getter/setter pair
scheduleOptions ↔ ScheduleOptions?
Options customizing the data transfer schedule.
getter/setter pair
scheduleOptionsV2 ↔ ScheduleOptionsV2?
Options customizing different types of data transfer schedule.
getter/setter pair
state ↔ String?
State of the most recently updated transfer run.
getter/setter pair
updateTime ↔ String?
Data transfer modification time.
getter/setter pair
userId ↔ String?
Unique ID of the user on whose behalf transfer is done.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited