TransferMessage class

Represents a user facing message for a particular data transfer run.

Constructors

TransferMessage({String? messageText, String? messageTime, String? severity})
TransferMessage.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageText ↔ String?
Message text.
getter/setter pair
messageTime ↔ String?
Time when message was logged.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Message severity. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited