TransferRun class

Represents a data transfer run.

Constructors

TransferRun({String? dataSourceId, String? destinationDatasetId, EmailPreferences? emailPreferences, String? endTime, Status? errorStatus, String? name, String? notificationPubsubTopic, Map<String, Object?>? params, String? runTime, String? schedule, String? scheduleTime, String? startTime, String? state, String? updateTime, String? userId})
TransferRun.fromJson(Map json_)

Properties

dataSourceId ↔ String?
Data source id.
getter/setter pair
destinationDatasetId ↔ String?
The BigQuery target dataset id.
getter/setter pair
emailPreferences ↔ EmailPreferences?
Email notifications will be sent according to these preferences to the email address of the user who owns the transfer config this run was derived from.
getter/setter pair
endTime ↔ String?
Time when transfer run ended.
getter/setter pair
errorStatus ↔ Status?
Status of the transfer run.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
notificationPubsubTopic ↔ String?
Pub/Sub topic where a notification will be sent after this transfer run finishes.
getter/setter pair
params ↔ Map<String, Object?>?
Parameters specific to each data source.
getter/setter pair
runTime ↔ String?
For batch transfer runs, specifies the date and time of the data should be ingested.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule ↔ String?
Describes the schedule of this transfer run if it was created as part of a regular schedule.
getter/setter pair
scheduleTime ↔ String?
Minimum time after which a transfer run can be started.
getter/setter pair
startTime ↔ String?
Time when transfer run was started.
getter/setter pair
state ↔ String?
Data transfer run state.
getter/setter pair
updateTime ↔ String?
Last time the data transfer run state was updated.
getter/setter pair
userId ↔ String?
Unique ID of the user on whose behalf transfer is done.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited