TransferRunBrief class

Basic information about a transfer run.

Constructors

TransferRunBrief({String? run, String? startTime})
TransferRunBrief.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
run ↔ String?
Run URI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Start time of the transfer run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited