TransferStatusMetric class

Metrics for tracking the transfer status.

Constructors

TransferStatusMetric({String? completed, String? failed, String? pending, String? total, String? unit})
TransferStatusMetric.fromJson(Map json_)

Properties

completed String?
Number of units transferred successfully.
getter/setter pair
failed String?
Number of units that failed to transfer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pending String?
Number of units pending transfer.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total String?
Total number of units for the transfer.
getter/setter pair
unit String?
Unit for measuring progress (e.g., BYTES).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited