Assignment class

An assignment allows a project to submit jobs of a certain type using slots from the specified reservation.

Constructors

Assignment({String? assignee, bool? enableGeminiInBigquery, String? jobType, String? name, SchedulingPolicy? schedulingPolicy, String? state})
Assignment.fromJson(Map json_)

Properties

assignee ↔ String?
The resource which will use the reservation.
getter/setter pair
enableGeminiInBigquery ↔ bool?
Deprecated: "Gemini in BigQuery" is now available by default for all BigQuery editions and should not be explicitly set.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobType ↔ String?
Which type of jobs will use the reservation.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulingPolicy ↔ SchedulingPolicy?
The scheduling policy to use for jobs and queries of this assignee when running under the associated reservation.
getter/setter pair
state ↔ String?
State of the assignment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited