condition property
Common Expression Language (CEL) condition that defines the matching criteria for this assignment.
The condition must resolve to a boolean value. Supported variables will be added later.
Optional.
Implementation
Expr? condition;
Common Expression Language (CEL) condition that defines the matching criteria for this assignment.
The condition must resolve to a boolean value. Supported variables will be added later.
Optional.
Expr? condition;