MergeCapacityCommitmentsRequest class

The request for ReservationService.MergeCapacityCommitments.

Constructors

MergeCapacityCommitmentsRequest({String? capacityCommitmentId, List<String>? capacityCommitmentIds})
MergeCapacityCommitmentsRequest.fromJson(Map json_)

Properties

capacityCommitmentId ↔ String?
The optional resulting capacity commitment ID.
getter/setter pair
capacityCommitmentIds ↔ List<String>?
Ids of capacity commitments to merge.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited