ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

capacityCommitments → ProjectsLocationsCapacityCommitmentsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
reservationGroups → ProjectsLocationsReservationGroupsResource
no setter
reservations → ProjectsLocationsReservationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBiReservation(String name, {String? $fields}) → Future<BiReservation>
Retrieves a BI reservation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchAllAssignments(String parent, {int? pageSize, String? pageToken, String? query, String? $fields}) → Future<SearchAllAssignmentsResponse>
Looks up assignments for a specified resource for a particular region.
searchAssignments(String parent, {int? pageSize, String? pageToken, String? query, String? $fields}) → Future<SearchAssignmentsResponse>
Deprecated: Looks up assignments for a specified resource for a particular region.
toString() → String
A string representation of this object.
inherited
updateBiReservation(BiReservation request, String name, {String? updateMask, String? $fields}) → Future<BiReservation>
Updates a BI reservation.

Operators

operator ==(Object other) → bool
The equality operator.
inherited