ReplicationStatus class

Disaster Recovery(DR) replication status of the reservation.

Constructors

ReplicationStatus({Status? error, String? lastErrorTime, String? lastReplicationTime, String? softFailoverStartTime})
ReplicationStatus.fromJson(Map json_)

Properties

error ↔ Status?
The last error encountered while trying to replicate changes from the primary to the secondary.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastErrorTime ↔ String?
The time at which the last error was encountered while trying to replicate changes from the primary to the secondary.
getter/setter pair
lastReplicationTime ↔ String?
A timestamp corresponding to the last change on the primary that was successfully replicated to the secondary.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softFailoverStartTime ↔ String?
The time at which a soft failover for the reservation and its associated datasets was initiated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited