Reservation class

A reservation is a mechanism used to guarantee slots to users.

Constructors

Reservation({Autoscale? autoscale, String? concurrency, String? creationTime, String? edition, bool? ignoreIdleSlots, Map<String, String>? labels, String? maxSlots, bool? multiRegionAuxiliary, String? name, String? originalPrimaryLocation, String? primaryLocation, ReplicationStatus? replicationStatus, String? reservationGroup, String? scalingMode, SchedulingPolicy? schedulingPolicy, String? secondaryLocation, String? slotCapacity, String? updateTime})
Reservation.fromJson(Map json_)

Properties

autoscale ↔ Autoscale?
The configuration parameters for the auto scaling feature.
getter/setter pair
concurrency ↔ String?
Job concurrency target which sets a soft upper bound on the number of jobs that can run concurrently in this reservation.
getter/setter pair
creationTime ↔ String?
Creation time of the reservation.
getter/setter pair
edition ↔ String?
Edition of the reservation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreIdleSlots ↔ bool?
If false, any query or pipeline job using this reservation will use idle slots from other reservations within the same admin project.
getter/setter pair
labels ↔ Map<String, String>?
The labels associated with this reservation.
getter/setter pair
maxSlots ↔ String?
The overall max slots for the reservation, covering slot_capacity (baseline), idle slots (if ignore_idle_slots is false) and scaled slots.
getter/setter pair
multiRegionAuxiliary ↔ bool?
Applicable only for reservations located within one of the BigQuery multi-regions (US or EU).
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
originalPrimaryLocation ↔ String?
The location where the reservation was originally created.
getter/setter pair
primaryLocation ↔ String?
The current location of the reservation's primary replica.
getter/setter pair
replicationStatus ↔ ReplicationStatus?
The Disaster Recovery(DR) replication status of the reservation.
getter/setter pair
reservationGroup ↔ String?
The reservation group that this reservation belongs to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalingMode ↔ String?
The scaling mode for the reservation.
getter/setter pair
schedulingPolicy ↔ SchedulingPolicy?
The scheduling policy to use for jobs and queries running under this reservation.
getter/setter pair
secondaryLocation ↔ String?
The current location of the reservation's secondary replica.
getter/setter pair
slotCapacity ↔ String?
Baseline slots available to this reservation.
getter/setter pair
updateTime ↔ String?
Last update time of the reservation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited