ReservationGroup class

A reservation group is a container for reservations.

Constructors

ReservationGroup({String? creationTime, String? name, String? parentGroup, String? updateTime})
ReservationGroup.fromJson(Map json_)

Properties

creationTime String?
Creation time of the reservation group.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
parentGroup String?
The parent reservation group of the reservation group.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTime String?
Last update time of the reservation group via a user operation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited