updateTime property
Last update time of the reservation group via a user operation.
This timestamp is updated only when an update operation explicitly targets this reservation group directly. It is not updated when parent or child groups are created, updated, or deleted.
Output only.
Implementation
core.String? updateTime;