AppProfile class

A configuration object describing how Cloud Bigtable should treat traffic from a particular end user application.

Constructors

AppProfile({DataBoostIsolationReadOnly? dataBoostIsolationReadOnly, String? description, String? etag, MultiClusterRoutingUseAny? multiClusterRoutingUseAny, String? name, String? priority, SingleClusterRouting? singleClusterRouting, StandardIsolation? standardIsolation})
AppProfile.fromJson(Map json_)

Properties

dataBoostIsolationReadOnly ↔ DataBoostIsolationReadOnly?
Specifies that this app profile is intended for read-only usage via the Data Boost feature.
getter/setter pair
description ↔ String?
Long form description of the use case for this AppProfile.
getter/setter pair
etag ↔ String?
Strongly validated etag for optimistic concurrency control.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
multiClusterRoutingUseAny ↔ MultiClusterRoutingUseAny?
Use a multi-cluster routing policy.
getter/setter pair
name ↔ String?
The unique name of the app profile, up to 50 characters long.
getter/setter pair
priority ↔ String?
This field has been deprecated in favor of standard_isolation.priority.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleClusterRouting ↔ SingleClusterRouting?
Use a single-cluster routing policy.
getter/setter pair
standardIsolation ↔ StandardIsolation?
The standard options used for isolating this app profile's traffic from other use cases.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited