AutomatedBackupPolicy class
Defines an automated backup policy for a table
Constructors
-
AutomatedBackupPolicy({String? frequency, List<
String> ? locations, String? retentionPeriod}) - AutomatedBackupPolicy.fromJson(Map json_)
Properties
- frequency ↔ String?
-
How frequently automated backups should occur.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locations
↔ List<
String> ? -
A list of Cloud Bigtable zones where automated backups are allowed to be
created.
getter/setter pair
- retentionPeriod ↔ String?
-
How long the automated backups should be retained.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited