AutoscalingLimits class

Limits for the number of nodes a Cluster can autoscale up/down to.

Constructors

AutoscalingLimits({int? maxServeNodes, int? minServeNodes})
AutoscalingLimits.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxServeNodes ↔ int?
Maximum number of nodes to scale up to.
getter/setter pair
minServeNodes ↔ int?
Minimum number of nodes to scale down to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited