logicalDataHddBytes property
The logical data bytes of the column family stored on HDD.
Output only.
Implementation
core.String? logicalDataHddBytes;
The logical data bytes of the column family stored on HDD.
Output only.
core.String? logicalDataHddBytes;