logicalDataSsdBytes property
The logical data bytes of the column family stored on SSD.
Output only.
Implementation
core.String? logicalDataSsdBytes;
The logical data bytes of the column family stored on SSD.
Output only.
core.String? logicalDataSsdBytes;