DataBoostIsolationReadOnly class

Data Boost is a serverless compute capability that lets you run high-throughput read jobs and queries on your Bigtable data, without impacting the performance of the clusters that handle your application traffic.

Data Boost supports read-only use cases with single-cluster routing.

Constructors

DataBoostIsolationReadOnly({String? computeBillingOwner})
DataBoostIsolationReadOnly.fromJson(Map json_)

Properties

computeBillingOwner ↔ String?
The Compute Billing Owner for this Data Boost App Profile. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited