DropRowRangeRequest class

Request message for google.bigtable.admin.v2.BigtableTableAdmin.DropRowRange

Constructors

DropRowRangeRequest({bool? deleteAllDataFromTable, String? rowKeyPrefix})
DropRowRangeRequest.fromJson(Map json_)

Properties

deleteAllDataFromTable ↔ bool?
Delete all rows in the table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rowKeyPrefix ↔ String?
Delete all rows that start with this row key prefix.
getter/setter pair
rowKeyPrefixAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited