EncryptionConfig class

Cloud Key Management Service (Cloud KMS) settings for a CMEK-protected cluster.

Constructors

EncryptionConfig({String? kmsKeyName})
EncryptionConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
Describes the Cloud KMS encryption key that will be used to protect the destination Bigtable cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited