EncryptionInfo class

Encryption information for a given resource.

If this resource is protected with customer managed encryption, the in-use Cloud Key Management Service (Cloud KMS) key version is specified along with its status.

Constructors

EncryptionInfo({Status? encryptionStatus, String? encryptionType, String? kmsKeyVersion})
EncryptionInfo.fromJson(Map json_)

Properties

encryptionStatus ↔ Status?
The status of encrypt/decrypt calls on underlying data for this resource.
getter/setter pair
encryptionType ↔ String?
The type of encryption used to protect this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyVersion ↔ String?
The version of the Cloud KMS key specified in the parent cluster that is in use for the data underlying this table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited