GoogleBigtableAdminV2TypeArray class

An ordered list of elements of a given type.

Values of type Array are stored in Value.array_value.

Properties

elementType ↔ Type?
The type of the elements in the array.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited