GoogleBigtableAdminV2TypeBool class
bool Values of type Bool are stored in Value.bool_value.
Constructors
Properties
- encoding ↔ DataBoostReadLocalWrites?
-
Specifies the encoding to use when converting to or from lower level
types.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited