encoding property
Specifies the encoding to use when converting to or from lower level types.
Implementation
GoogleBigtableAdminV2TypeBoolEncoding? encoding;
Specifies the encoding to use when converting to or from lower level types.
GoogleBigtableAdminV2TypeBoolEncoding? encoding;