encoding property
The encoding to use when converting to or from lower level types.
Implementation
GoogleBigtableAdminV2TypeInt32Encoding? encoding;
The encoding to use when converting to or from lower level types.
GoogleBigtableAdminV2TypeInt32Encoding? encoding;