GoogleBigtableAdminV2TypeStringEncoding class

Rules used to convert to or from lower level types.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utf8Bytes ↔ GoogleBigtableAdminV2TypeStringEncodingUtf8Bytes?
Use Utf8Bytes encoding.
getter/setter pair
utf8Raw ↔ GoogleBigtableAdminV2TypeStringEncodingUtf8Raw?
Deprecated: if set, converts to an empty utf8_bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited