Instance class

A collection of Bigtable Tables and the resources that serve them.

All tables in an instance are served from all Clusters in the instance.

Constructors

Instance({String? createTime, String? displayName, String? edition, String? knowledgeCatalogRegion, Map<String, String>? labels, String? name, bool? satisfiesPzi, bool? satisfiesPzs, String? state, Map<String, String>? tags, String? type})
Instance.fromJson(Map json_)

Properties

createTime ↔ String?
A commit timestamp representing when this Instance was created.
getter/setter pair
displayName ↔ String?
The descriptive name for this instance as it appears in UIs.
getter/setter pair
edition ↔ String?
The edition of the instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
knowledgeCatalogRegion ↔ String?
The region where Knowledge Catalog data is synced to and stored, including user-created aspects.
getter/setter pair
labels ↔ Map<String, String>?
Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies.
getter/setter pair
name ↔ String?
The unique name of the instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
state ↔ String?
The current state of the instance.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
type ↔ String?
The type of the instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited