knowledgeCatalogRegion property
The region where Knowledge Catalog data is synced to and stored, including user-created aspects.
Output only.
Implementation
core.String? knowledgeCatalogRegion;
The region where Knowledge Catalog data is synced to and stored, including user-created aspects.
Output only.
core.String? knowledgeCatalogRegion;