ListLogicalViewsResponse class

Response message for BigtableInstanceAdmin.ListLogicalViews.

Constructors

ListLogicalViewsResponse({List<LogicalView>? logicalViews, String? nextPageToken})
ListLogicalViewsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logicalViews ↔ List<LogicalView>?
The list of requested logical views.
getter/setter pair
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited