ListMemoryLayersResponse class

Response message for BigtableInstanceAdmin.ListMemoryLayers.

Constructors

ListMemoryLayersResponse({List<String>? failedLocations, List<MemoryLayer>? memoryLayers, String? nextPageToken})
ListMemoryLayersResponse.fromJson(Map json_)

Properties

failedLocations List<String>?
Locations from which MemoryLayer information could not be retrieved, due to an outage or some other transient condition.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
memoryLayers List<MemoryLayer>?
The list of requested memory layers.
getter/setter pair
nextPageToken String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited