failedLocations property

List<String>? failedLocations
getter/setter pair

Locations from which MemoryLayer information could not be retrieved, due to an outage or some other transient condition.

MemoryLayers from these locations may be missing from memory_layers, or may only have partial information returned. Values are of the form projects//locations/

Implementation

core.List<core.String>? failedLocations;