MaterializedView class

A materialized view object that can be referenced in SQL queries.

Constructors

MaterializedView({Map<String, GoogleBigtableAdminV2MaterializedViewClusterState>? clusterStates, bool? deletionProtection, String? etag, String? name, String? query})
MaterializedView.fromJson(Map json_)

Properties

clusterStates ↔ Map<String, GoogleBigtableAdminV2MaterializedViewClusterState>?
Map from cluster ID to per-cluster materialized view state.
getter/setter pair
deletionProtection ↔ bool?
Set to true to make the MaterializedView protected against deletion.
getter/setter pair
etag ↔ String?
The etag for this materialized view.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
query ↔ String?
The materialized view's select query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited