MemoryConfig typedef

MemoryConfig = $Empty

If set, eligible single-row requests (currently limited to ReadRows) using this app profile will be routed to the memory layer.

All eligible writes populate the memory layer. MemoryConfig can only be set if the AppProfile uses single cluster routing and the configured cluster has a memory layer enabled.

Implementation

typedef MemoryConfig = $Empty;