state property

String? state
getter/setter pair

The current state of the memory layer.

Output only. Possible string values are:

  • "STATE_NOT_KNOWN" : The state of the memory layer could not be determined.
  • "READY" : The memory layer has been successfully enabled and is ready to serve requests.
  • "ENABLING" : The memory layer is currently being enabled, and may be disabled if the enablement process encounters an error. A cluster may not be able to serve requests from the memory layer while being enabled.
  • "RESIZING" : The memory layer is currently being resized, and may revert to its previous storage size if the process encounters an error. The memory layer is still capable of serving requests while being resized, but may exhibit performance as if its number of allocated nodes is between the starting and requested states.
  • "DISABLED" : The memory layer is disabled. The default state for a cluster without a memory layer.

Implementation

core.String? state;