Modification class

A create, update, or delete of a particular column family.

Constructors

Modification({ColumnFamily? create, bool? drop, String? id, ColumnFamily? update, String? updateMask})
Modification.fromJson(Map json_)

Properties

create ↔ ColumnFamily?
Create a new column family with the specified schema, or fail if one already exists with the given ID.
getter/setter pair
drop ↔ bool?
Drop (delete) the column family with the given ID, or fail if no such family exists.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the column family to be modified.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
update ↔ ColumnFamily?
Update an existing column family to the specified schema, or fail if no column family exists with the given ID.
getter/setter pair
updateMask ↔ String?
A mask specifying which fields (e.g. gc_rule) in the update mod should be updated, ignored for other modification types.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited