SingleClusterRouting class

Unconditionally routes all read/write requests to a specific cluster.

This option preserves read-your-writes consistency but does not improve availability.

Constructors

SingleClusterRouting({bool? allowTransactionalWrites, String? clusterId})
SingleClusterRouting.fromJson(Map json_)

Properties

allowTransactionalWrites ↔ bool?
Whether or not CheckAndMutateRow and ReadModifyWriteRow requests are allowed by this app profile.
getter/setter pair
clusterId ↔ String?
The cluster to which read/write requests should be routed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited