StandardIsolation class
Standard options for isolating this app profile's traffic from other use cases.
Constructors
- StandardIsolation({MemoryConfig? memoryConfig, String? priority})
- StandardIsolation.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- memoryConfig ↔ DataBoostReadLocalWrites?
-
The memory config to use for requests sent using this app profile.
getter/setter pair
- priority ↔ String?
-
The priority of requests sent using this app profile.
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited