Type class

Type represents the type of data that is written to, read from, or stored in Bigtable.

It is heavily based on the GoogleSQL standard to help maintain familiarity and consistency across products and features. For compatibility with Bigtable's existing untyped APIs, each Type includes an Encoding which describes how to convert to or from the underlying data. Each encoding can operate in one of two modes: - Sorted: In this mode, Bigtable guarantees that Encode(X) <= Encode(Y) if and only if X <= Y. This is useful anywhere sort order is important, for example when encoding keys. - Distinct: In this mode, Bigtable guarantees that if X != Y then Encode(X) != Encode(Y). However, the converse is not guaranteed. For example, both {'foo': '1', 'bar': '2'} and {'bar': '2', 'foo': '1'} are valid encodings of the same JSON value. The API clearly documents which mode is used wherever an encoding can be configured. Each encoding also documents which values are supported in which modes. For example, when encoding INT64 as a numeric STRING, negative numbers cannot be encoded in sorted mode. This is because INT64(1) > INT64(-1), but STRING("-00001") > STRING("00001").

Properties

aggregateType ↔ GoogleBigtableAdminV2TypeAggregate?
Aggregate
getter/setter pair
arrayType ↔ GoogleBigtableAdminV2TypeArray?
Array
getter/setter pair
boolType ↔ GoogleBigtableAdminV2TypeBool?
Bool
getter/setter pair
bytesType ↔ GoogleBigtableAdminV2TypeBytes?
Bytes
getter/setter pair
dateType ↔ DataBoostReadLocalWrites?
Date
getter/setter pair
enumType ↔ GoogleBigtableAdminV2TypeEnum?
Enum
getter/setter pair
float32Type ↔ DataBoostReadLocalWrites?
Float32
getter/setter pair
float64Type ↔ DataBoostReadLocalWrites?
Float64
getter/setter pair
geographyType ↔ DataBoostReadLocalWrites?
Geography
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
int32Type ↔ GoogleBigtableAdminV2TypeInt32?
Int32
getter/setter pair
int64Type ↔ GoogleBigtableAdminV2TypeInt64?
Int64
getter/setter pair
mapType ↔ GoogleBigtableAdminV2TypeMap?
Map
getter/setter pair
protoType ↔ GoogleBigtableAdminV2TypeProto?
Proto
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringType ↔ GoogleBigtableAdminV2TypeString?
String
getter/setter pair
structType ↔ GoogleBigtableAdminV2TypeStruct?
Struct
getter/setter pair
timestampType ↔ GoogleBigtableAdminV2TypeTimestamp?
Timestamp
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited