SigstoreAuthority class

A Sigstore authority, used to verify signatures that are created by Sigstore.

An authority is analogous to an attestation authenticator, verifying that a signature is valid or invalid.

Constructors

SigstoreAuthority({String? displayName, SigstorePublicKeySet? publicKeySet})
SigstoreAuthority.fromJson(Map json_)

Properties

displayName ↔ String?
A user-provided name for this SigstoreAuthority.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
publicKeySet ↔ SigstorePublicKeySet?
A simple set of public keys.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited