EthereumEndpoints class

Contains endpoint information specific to Ethereum nodes.

Constructors

EthereumEndpoints({String? beaconApiEndpoint, String? beaconPrometheusMetricsApiEndpoint, String? executionClientPrometheusMetricsApiEndpoint})
EthereumEndpoints.fromJson(Map json_)

Properties

beaconApiEndpoint ↔ String?
The assigned URL for the node's Beacon API endpoint.
getter/setter pair
beaconPrometheusMetricsApiEndpoint ↔ String?
The assigned URL for the node's Beacon Prometheus metrics endpoint.
getter/setter pair
executionClientPrometheusMetricsApiEndpoint ↔ String?
The assigned URL for the node's execution client's Prometheus metrics endpoint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited