BlogList class

Constructors

BlogList({List<BlogUserInfo>? blogUserInfos, List<Blog>? items, String? kind})
BlogList.fromJson(Map json_)

Properties

blogUserInfos ↔ List<BlogUserInfo>?
Admin level list of blog per-user information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Blog>?
The list of Blogs this user has Authorship or Admin rights over.
getter/setter pair
kind ↔ String?
The kind of this entity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited