BlogPosts class

The container of posts in this blog.

Constructors

BlogPosts({List<Post>? items, String? selfLink, int? totalItems})
BlogPosts.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Post>?
The List of Posts for this Blog.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The URL of the container for posts in this blog.
getter/setter pair
totalItems ↔ int?
The count of posts in this blog.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited