CommentList class

Constructors

CommentList({String? etag, List<Comment>? items, String? kind, String? nextPageToken, String? prevPageToken})
CommentList.fromJson(Map json_)

Properties

etag ↔ String?
Etag of the response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Comment>?
The List of Comments for a Post.
getter/setter pair
kind ↔ String?
The kind of this entry.
getter/setter pair
nextPageToken ↔ String?
Pagination token to fetch the next page, if one exists.
getter/setter pair
prevPageToken ↔ String?
Pagination token to fetch the previous page, if one exists.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited