Post class

Constructors

Post({PostAuthor? author, PostBlog? blog, String? content, String? customMetaData, String? etag, String? id, List<PostImages>? images, String? kind, List<String>? labels, PostLocation? location, String? published, String? readerComments, PostReplies? replies, String? selfLink, String? status, String? title, String? titleLink, String? trashed, String? updated, String? url})
Post.fromJson(Map json_)

Properties

author ↔ PostAuthor?
The author of this Post.
getter/setter pair
blog ↔ PostBlog?
Data about the blog containing this Post.
getter/setter pair
content ↔ String?
The content of the Post.
getter/setter pair
customMetaData ↔ String?
The JSON meta-data for the Post.
getter/setter pair
etag ↔ String?
Etag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The identifier of this Post.
getter/setter pair
images ↔ List<PostImages>?
Display image for the Post.
getter/setter pair
kind ↔ String?
The kind of this entity.
getter/setter pair
labels ↔ List<String>?
The list of labels this Post was tagged with.
getter/setter pair
location ↔ PostLocation?
The location for geotagged posts.
getter/setter pair
published ↔ String?
RFC 3339 date-time when this Post was published.
getter/setter pair
readerComments ↔ String?
Comment control and display setting for readers of this post. Possible string values are:
getter/setter pair
replies ↔ PostReplies?
The container of comments on this Post.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The API REST URL to fetch this resource from.
getter/setter pair
status ↔ String?
Status of the post.
getter/setter pair
title ↔ String?
The title of the Post.
getter/setter pair
The title link URL, similar to atom's related link.
getter/setter pair
trashed ↔ String?
RFC 3339 date-time when this Post was last trashed.
getter/setter pair
updated ↔ String?
RFC 3339 date-time when this Post was last updated.
getter/setter pair
url ↔ String?
The URL where this Post is displayed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited