PostLocation class

The location for geotagged posts.

Constructors

PostLocation({double? lat, double? lng, String? name, String? span})
PostLocation.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lat ↔ double?
Location's latitude.
getter/setter pair
lng ↔ double?
Location's longitude.
getter/setter pair
name ↔ String?
Location name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
span ↔ String?
Location's viewport span.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited