PostPerUserInfo class

Constructors

PostPerUserInfo({String? blogId, bool? hasEditAccess, String? kind, String? postId, String? userId})
PostPerUserInfo.fromJson(Map json_)

Properties

blogId ↔ String?
ID of the Blog that the post resource belongs to.
getter/setter pair
hasEditAccess ↔ bool?
True if the user has Author level access to the post.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of this entity.
getter/setter pair
postId ↔ String?
ID of the Post resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userId ↔ String?
ID of the User.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited