PostUserInfo class

Constructors

PostUserInfo({String? kind, Post? post, PostPerUserInfo? postUserInfo})
PostUserInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of this entity.
getter/setter pair
post ↔ Post?
The Post resource.
getter/setter pair
postUserInfo ↔ PostPerUserInfo?
Information about a User for the Post.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited