PostUserInfosList class

Constructors

PostUserInfosList({List<PostUserInfo>? items, String? kind, String? nextPageToken})
PostUserInfosList.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<PostUserInfo>?
The list of Posts with User information for the post, for this Blog.
getter/setter pair
kind ↔ String?
The kind of this entity.
getter/setter pair
nextPageToken ↔ String?
Pagination token to fetch the next page, if one exists.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited