User class

Constructors

User({String? about, UserBlogs? blogs, String? created, String? displayName, String? id, String? kind, UserLocale? locale, String? selfLink, String? url})
User.fromJson(Map json_)

Properties

about ↔ String?
Profile summary information.
getter/setter pair
blogs ↔ UserBlogs?
The container of blogs for this user.
getter/setter pair
created ↔ String?
The timestamp of when this profile was created, in seconds since epoch.
getter/setter pair
displayName ↔ String?
The display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The identifier for this User.
getter/setter pair
kind ↔ String?
The kind of this entity.
getter/setter pair
locale ↔ UserLocale?
This user's locale
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The API REST URL to fetch this resource from.
getter/setter pair
url ↔ String?
The user's profile page.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited