Annotation class

Constructors

Annotation({String? afterSelectedText, String? beforeSelectedText, AnnotationClientVersionRanges? clientVersionRanges, String? created, AnnotationCurrentVersionRanges? currentVersionRanges, String? data, bool? deleted, String? highlightStyle, String? id, String? kind, String? layerId, AnnotationLayerSummary? layerSummary, List<String>? pageIds, String? selectedText, String? selfLink, String? updated, String? volumeId})
Annotation.fromJson(Map json_)

Properties

afterSelectedText ↔ String?
Anchor text after excerpt.
getter/setter pair
beforeSelectedText ↔ String?
Anchor text before excerpt.
getter/setter pair
clientVersionRanges ↔ AnnotationClientVersionRanges?
Selection ranges sent from the client.
getter/setter pair
created ↔ String?
Timestamp for the created time of this annotation.
getter/setter pair
currentVersionRanges ↔ AnnotationCurrentVersionRanges?
Selection ranges for the most recent content version.
getter/setter pair
data ↔ String?
User-created data for this annotation.
getter/setter pair
deleted ↔ bool?
Indicates that this annotation is deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highlightStyle ↔ String?
The highlight style for this annotation.
getter/setter pair
id ↔ String?
Id of this annotation, in the form of a GUID.
getter/setter pair
kind ↔ String?
Resource type.
getter/setter pair
layerId ↔ String?
The layer this annotation is for.
getter/setter pair
layerSummary ↔ AnnotationLayerSummary?
getter/setter pair
pageIds ↔ List<String>?
Pages that this annotation spans.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedText ↔ String?
Excerpt from the volume.
getter/setter pair
URL to this resource.
getter/setter pair
updated ↔ String?
Timestamp for the last time this annotation was modified.
getter/setter pair
volumeId ↔ String?
The volume that this annotation belongs to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited