AnnotationClientVersionRanges class

Selection ranges sent from the client.

Properties

cfiRange ↔ BooksAnnotationsRange?
Range in CFI format for this annotation sent by client.
getter/setter pair
contentVersion ↔ String?
Content version the client sent in.
getter/setter pair
gbImageRange ↔ BooksAnnotationsRange?
Range in GB image format for this annotation sent by client.
getter/setter pair
gbTextRange ↔ BooksAnnotationsRange?
Range in GB text format for this annotation sent by client.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageCfiRange ↔ BooksAnnotationsRange?
Range in image CFI format for this annotation sent by client.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited