AnnotationLayerSummary class

Constructors

AnnotationLayerSummary({int? allowedCharacterCount, String? limitType, int? remainingCharacterCount})
AnnotationLayerSummary.fromJson(Map json_)

Properties

allowedCharacterCount ↔ int?
Maximum allowed characters on this layer, especially for the "copy" layer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limitType ↔ String?
Type of limitation on this layer.
getter/setter pair
remainingCharacterCount ↔ int?
Remaining allowed characters on this layer, especially for the "copy" layer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited