Annotationsdata class

Constructors

Annotationsdata({List<GeoAnnotationdata>? items, String? kind, String? nextPageToken, int? totalItems})
Annotationsdata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<GeoAnnotationdata>?
A list of Annotation Data.
getter/setter pair
kind ↔ String?
Resource type
getter/setter pair
nextPageToken ↔ String?
Token to pass in for pagination for the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalItems ↔ int?
The total number of volume annotations found.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited