BooksAnnotationsRange class

Constructors

BooksAnnotationsRange({String? endOffset, String? endPosition, String? startOffset, String? startPosition})
BooksAnnotationsRange.fromJson(Map json_)

Properties

endOffset ↔ String?
The offset from the ending position.
getter/setter pair
endPosition ↔ String?
The ending position for the range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startOffset ↔ String?
The offset from the starting position.
getter/setter pair
startPosition ↔ String?
The starting position for the range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited