ConcurrentAccessRestriction class

Constructors

ConcurrentAccessRestriction({bool? deviceAllowed, String? kind, int? maxConcurrentDevices, String? message, String? nonce, String? reasonCode, bool? restricted, String? signature, String? source, int? timeWindowSeconds, String? volumeId})
ConcurrentAccessRestriction.fromJson(Map json_)

Properties

deviceAllowed ↔ bool?
Whether access is granted for this (user, device, volume).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Resource type.
getter/setter pair
maxConcurrentDevices ↔ int?
The maximum number of concurrent access licenses for this volume.
getter/setter pair
message ↔ String?
Error/warning message.
getter/setter pair
nonce ↔ String?
Client nonce for verification.
getter/setter pair
reasonCode ↔ String?
Error/warning reason code.
getter/setter pair
restricted ↔ bool?
Whether this volume has any concurrent access restrictions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature ↔ String?
Response signature.
getter/setter pair
source ↔ String?
Client app identifier for verification.
getter/setter pair
timeWindowSeconds ↔ int?
Time in seconds for license auto-expiration.
getter/setter pair
volumeId ↔ String?
Identifies the volume for which this entry applies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited