DictionaryAnnotationdata class

Constructors

DictionaryAnnotationdata({String? annotationType, Dictlayerdata? data, String? encodedData, String? id, String? kind, String? layerId, String? selfLink, String? updated, String? volumeId})
DictionaryAnnotationdata.fromJson(Map json_)

Properties

annotationType ↔ String?
The type of annotation this data is for.
getter/setter pair
data ↔ Dictlayerdata?
JSON encoded data for this dictionary annotation data.
getter/setter pair
encodedData ↔ String?
Base64 encoded data for this annotation data.
getter/setter pair
encodedDataAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique id for this annotation data.
getter/setter pair
kind ↔ String?
Resource Type
getter/setter pair
layerId ↔ String?
The Layer id for this data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
URL for this resource.
getter/setter pair
updated ↔ String?
Timestamp for the last time this data was updated.
getter/setter pair
volumeId ↔ String?
The volume id for this data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited