DiscoveryclustersClustersBannerWithContentContainer class

Constructors

DiscoveryclustersClustersBannerWithContentContainer({String? fillColorArgb, String? imageUrl, String? maskColorArgb, String? moreButtonText, String? moreButtonUrl, String? textColorArgb})
DiscoveryclustersClustersBannerWithContentContainer.fromJson(Map json_)

Properties

fillColorArgb ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageUrl ↔ String?
getter/setter pair
maskColorArgb ↔ String?
getter/setter pair
moreButtonText ↔ String?
getter/setter pair
moreButtonUrl ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textColorArgb ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited