MetadataItems class

Constructors

MetadataItems({String? downloadUrl, String? encryptedKey, String? language, String? size, String? version})
MetadataItems.fromJson(Map json_)

Properties

downloadUrl ↔ String?
getter/setter pair
encryptedKey ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
language ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ String?
getter/setter pair
version ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited