Notification class

Constructors

Notification({String? body, List<String>? crmExperimentIds, String? docId, String? docType, bool? dontShowNotification, String? iconUrl, bool? isDocumentMature, String? kind, String? notificationGroup, String? notificationType, String? pcampaignId, String? reason, bool? showNotificationSettingsAction, String? targetUrl, String? timeToExpireMs, String? title})
Notification.fromJson(Map json_)

Properties

body ↔ String?
getter/setter pair
crmExperimentIds ↔ List<String>?
The list of crm experiment ids.
getter/setter pair
docId ↔ String?
getter/setter pair
docType ↔ String?
getter/setter pair
dontShowNotification ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconUrl ↔ String?
getter/setter pair
isDocumentMature ↔ bool?
getter/setter pair
kind ↔ String?
Resource type.
getter/setter pair
notificationGroup ↔ String?
getter/setter pair
notificationType ↔ String?
getter/setter pair
pcampaignId ↔ String?
getter/setter pair
reason ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showNotificationSettingsAction ↔ bool?
getter/setter pair
targetUrl ↔ String?
getter/setter pair
timeToExpireMs ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited