PromoofferResource class

Constructors

PromoofferResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

accept({String? androidId, String? device, String? manufacturer, String? model, String? offerId, String? product, String? serial, String? volumeId, String? $fields}) → Future<Empty>
Accepts the promo offer.
dismiss({String? androidId, String? device, String? manufacturer, String? model, String? offerId, String? product, String? serial, String? $fields}) → Future<Empty>
Marks the promo offer as dismissed.
get({String? androidId, String? device, String? manufacturer, String? model, String? product, String? serial, String? $fields}) → Future<Offers>
Returns a list of promo offers available to the user
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited