RequestAccessData class

Constructors

RequestAccessData({ConcurrentAccessRestriction? concurrentAccess, DownloadAccessRestriction? downloadAccess, String? kind})
RequestAccessData.fromJson(Map json_)

Properties

concurrentAccess ↔ ConcurrentAccessRestriction?
A concurrent access response.
getter/setter pair
downloadAccess ↔ DownloadAccessRestriction?
A download access response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Resource type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited