ReviewSource class

Information regarding the source of this review, when the review is not from a Google Books user.

Constructors

ReviewSource({String? description, String? extraDescription, String? url})
ReviewSource.fromJson(Map json_)

Properties

description ↔ String?
Name of the source.
getter/setter pair
extraDescription ↔ String?
Extra text about the source of the review.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
URL of the source of the review.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited