UsersettingsNotification class

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchMyInterests ↔ UsersettingsNotificationMatchMyInterests?
getter/setter pair
moreFromAuthors ↔ UsersettingsNotificationMoreFromAuthors?
getter/setter pair
moreFromSeries ↔ UsersettingsNotificationMoreFromSeries?
getter/setter pair
priceDrop ↔ UsersettingsNotificationPriceDrop?
getter/setter pair
rewardExpirations ↔ UsersettingsNotificationRewardExpirations?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited