Volume class

Constructors

Volume({VolumeAccessInfo? accessInfo, String? etag, String? id, String? kind, VolumeLayerInfo? layerInfo, VolumeRecommendedInfo? recommendedInfo, VolumeSaleInfo? saleInfo, VolumeSearchInfo? searchInfo, String? selfLink, VolumeUserInfo? userInfo, VolumeVolumeInfo? volumeInfo})
Volume.fromJson(Map json_)

Properties

accessInfo ↔ VolumeAccessInfo?
Any information about a volume related to reading or obtaining that volume text.
getter/setter pair
etag ↔ String?
Opaque identifier for a specific version of a volume resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique identifier for a volume.
getter/setter pair
kind ↔ String?
Resource type for a volume.
getter/setter pair
layerInfo ↔ VolumeLayerInfo?
What layers exist in this volume and high level information about them.
getter/setter pair
recommendedInfo ↔ VolumeRecommendedInfo?
Recommendation related information for this volume.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleInfo ↔ VolumeSaleInfo?
Any information about a volume related to the eBookstore and/or purchaseability.
getter/setter pair
searchInfo ↔ VolumeSearchInfo?
Search result information related to this volume.
getter/setter pair
URL to this resource.
getter/setter pair
userInfo ↔ VolumeUserInfo?
User specific information related to this volume.
getter/setter pair
volumeInfo ↔ VolumeVolumeInfo?
General volume information.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited