Volume2 class

Constructors

Volume2({List<Volume>? items, String? kind, String? nextPageToken})
Volume2.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Volume>?
A list of volumes.
getter/setter pair
kind ↔ String?
Resource type.
getter/setter pair
nextPageToken ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited