VolumeVolumeInfo class

General volume information.

Constructors

VolumeVolumeInfo({bool? allowAnonLogging, List<String>? authors, double? averageRating, String? canonicalVolumeLink, List<String>? categories, bool? comicsContent, String? contentVersion, String? description, VolumeVolumeInfoDimensions? dimensions, VolumeVolumeInfoImageLinks? imageLinks, List<VolumeVolumeInfoIndustryIdentifiers>? industryIdentifiers, String? infoLink, String? language, String? mainCategory, String? maturityRating, int? pageCount, VolumeVolumeInfoPanelizationSummary? panelizationSummary, String? previewLink, String? printType, int? printedPageCount, String? publishedDate, String? publisher, int? ratingsCount, VolumeVolumeInfoReadingModes? readingModes, int? samplePageCount, Volumeseriesinfo? seriesInfo, String? subtitle, String? title})
VolumeVolumeInfo.fromJson(Map json_)

Properties

allowAnonLogging ↔ bool?
Whether anonymous logging should be allowed.
getter/setter pair
authors ↔ List<String>?
The names of the authors and/or editors for this volume.
getter/setter pair
averageRating ↔ double?
The mean review rating for this volume.
getter/setter pair
Canonical URL for a volume.
getter/setter pair
categories ↔ List<String>?
A list of subject categories, such as "Fiction", "Suspense", etc.
getter/setter pair
comicsContent ↔ bool?
Whether the volume has comics content.
getter/setter pair
contentVersion ↔ String?
An identifier for the version of the volume content (text & images).
getter/setter pair
description ↔ String?
A synopsis of the volume.
getter/setter pair
dimensions ↔ VolumeVolumeInfoDimensions?
Physical dimensions of this volume.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
A list of image links for all the sizes that are available.
getter/setter pair
industryIdentifiers ↔ List<VolumeVolumeInfoIndustryIdentifiers>?
Industry standard identifiers for this volume.
getter/setter pair
URL to view information about this volume on the Google Books site.
getter/setter pair
language ↔ String?
Best language for this volume (based on content).
getter/setter pair
mainCategory ↔ String?
The main category to which this volume belongs.
getter/setter pair
maturityRating ↔ String?
getter/setter pair
pageCount ↔ int?
Total number of pages as per publisher metadata.
getter/setter pair
panelizationSummary ↔ VolumeVolumeInfoPanelizationSummary?
A top-level summary of the panelization info in this volume.
getter/setter pair
URL to preview this volume on the Google Books site.
getter/setter pair
printedPageCount ↔ int?
Total number of printed pages in generated pdf representation.
getter/setter pair
printType ↔ String?
Type of publication of this volume.
getter/setter pair
publishedDate ↔ String?
Date of publication.
getter/setter pair
publisher ↔ String?
Publisher of this volume.
getter/setter pair
ratingsCount ↔ int?
The number of review ratings for this volume.
getter/setter pair
readingModes ↔ VolumeVolumeInfoReadingModes?
The reading modes available for this volume.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samplePageCount ↔ int?
Total number of sample pages as per publisher metadata.
getter/setter pair
seriesInfo ↔ Volumeseriesinfo?
getter/setter pair
subtitle ↔ String?
Volume subtitle.
getter/setter pair
title ↔ String?
Volume title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited