Volumeannotation class

Constructors

Volumeannotation({String? annotationDataId, String? annotationDataLink, String? annotationType, VolumeannotationContentRanges? contentRanges, String? data, bool? deleted, String? id, String? kind, String? layerId, List<String>? pageIds, String? selectedText, String? selfLink, String? updated, String? volumeId})
Volumeannotation.fromJson(Map json_)

Properties

annotationDataId ↔ String?
The annotation data id for this volume annotation.
getter/setter pair
Link to get data for this annotation.
getter/setter pair
annotationType ↔ String?
The type of annotation this is.
getter/setter pair
contentRanges ↔ VolumeannotationContentRanges?
The content ranges to identify the selected text.
getter/setter pair
data ↔ String?
Data for this annotation.
getter/setter pair
deleted ↔ bool?
Indicates that this annotation is deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique id of this volume annotation.
getter/setter pair
kind ↔ String?
Resource Type
getter/setter pair
layerId ↔ String?
The Layer this annotation is for.
getter/setter pair
pageIds ↔ List<String>?
Pages the annotation spans.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedText ↔ String?
Excerpt from the volume.
getter/setter pair
URL to this resource.
getter/setter pair
updated ↔ String?
Timestamp for the last time this anntoation was updated.
getter/setter pair
volumeId ↔ String?
The Volume this annotation is for.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited