SearchKeywordCount class

Represents a single search keyword and its value.

Constructors

SearchKeywordCount({InsightsValue? insightsValue, String? searchKeyword})
SearchKeywordCount.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
insightsValue ↔ InsightsValue?
One of either: 1) The sum of the number of unique users that used the keyword in a month, aggregated for each month requested.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword ↔ String?
The lower-cased string that the user entered.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited