Calendar class
Constructors
- Calendar({bool? autoAcceptInvitations, ConferenceProperties? conferenceProperties, String? dataOwner, String? description, String? etag, String? id, String? kind, LabelProperties? labelProperties, String? location, String? summary, String? timeZone})
- Calendar.fromJson(Map json_)
Properties
- autoAcceptInvitations ↔ bool?
-
Whether this calendar automatically accepts invitations.
getter/setter pair
- conferenceProperties ↔ ConferenceProperties?
-
Conferencing properties for this calendar, for example what types of
conferences are allowed.
getter/setter pair
- dataOwner ↔ String?
-
The email of the owner of the calendar.
getter/setter pair
- description ↔ String?
-
Description of the calendar.
getter/setter pair
- etag ↔ String?
-
ETag of the resource.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Identifier of the calendar.
getter/setter pair
- kind ↔ String?
-
Type of the resource ("calendar#calendar").
getter/setter pair
- labelProperties ↔ LabelProperties?
-
Label properties defined on this calendar.
getter/setter pair
- location ↔ String?
-
Geographic location of the calendar as free-form text.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary ↔ String?
-
Title of the calendar.
getter/setter pair
- timeZone ↔ String?
-
The time zone of the calendar.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited