CalendarListEntry class

Constructors

CalendarListEntry({String? accessRole, bool? autoAcceptInvitations, String? backgroundColor, String? colorId, ConferenceProperties? conferenceProperties, String? dataOwner, List<EventReminder>? defaultReminders, bool? deleted, String? description, String? etag, String? foregroundColor, bool? hidden, String? id, String? kind, String? location, CalendarListEntryNotificationSettings? notificationSettings, bool? primary, bool? selected, String? summary, String? summaryOverride, String? timeZone})
CalendarListEntry.fromJson(Map json_)

Properties

accessRole ↔ String?
The effective access role that the authenticated user has on the calendar.
getter/setter pair
autoAcceptInvitations ↔ bool?
Whether this calendar automatically accepts invitations.
getter/setter pair
backgroundColor ↔ String?
The main color of the calendar in the hexadecimal format "#0088aa".
getter/setter pair
colorId ↔ String?
The color of the calendar.
getter/setter pair
conferenceProperties ↔ ConferenceProperties?
Conferencing properties for this calendar, for example what types of conferences are allowed.
getter/setter pair
dataOwner ↔ String?
The email of the owner of the calendar.
getter/setter pair
defaultReminders ↔ List<EventReminder>?
The default reminders that the authenticated user has for this calendar.
getter/setter pair
deleted ↔ bool?
Whether this calendar list entry has been deleted from the calendar list.
getter/setter pair
description ↔ String?
Description of the calendar.
getter/setter pair
etag ↔ String?
ETag of the resource.
getter/setter pair
foregroundColor ↔ String?
The foreground color of the calendar in the hexadecimal format "#ffffff".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hidden ↔ bool?
Whether the calendar has been hidden from the list.
getter/setter pair
id ↔ String?
Identifier of the calendar.
getter/setter pair
kind ↔ String?
Type of the resource ("calendar#calendarListEntry").
getter/setter pair
location ↔ String?
Geographic location of the calendar as free-form text.
getter/setter pair
notificationSettings ↔ CalendarListEntryNotificationSettings?
The notifications that the authenticated user is receiving for this calendar.
getter/setter pair
primary ↔ bool?
Whether the calendar is the primary calendar of the authenticated user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selected ↔ bool?
Whether the calendar content shows up in the calendar UI.
getter/setter pair
summary ↔ String?
Title of the calendar.
getter/setter pair
summaryOverride ↔ String?
The summary that the authenticated user has set for this calendar.
getter/setter pair
timeZone ↔ String?
The time zone of the calendar.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited