ConferenceSolution class

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconUri ↔ String?
The user-visible icon for this solution.
getter/setter pair
key ↔ ConferenceSolutionKey?
The key which can uniquely identify the conference solution for this event.
getter/setter pair
name ↔ String?
The user-visible name of this solution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited