EntryPoint class

Constructors

EntryPoint({String? accessCode, List<String>? entryPointFeatures, String? entryPointType, String? label, String? meetingCode, String? passcode, String? password, String? pin, String? regionCode, String? uri})
EntryPoint.fromJson(Map json_)

Properties

accessCode ↔ String?
The access code to access the conference.
getter/setter pair
entryPointFeatures ↔ List<String>?
Features of the entry point, such as being toll or toll-free.
getter/setter pair
entryPointType ↔ String?
The type of the conference entry point. Possible values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
The label for the URI.
getter/setter pair
meetingCode ↔ String?
The meeting code to access the conference.
getter/setter pair
passcode ↔ String?
The passcode to access the conference.
getter/setter pair
password ↔ String?
The password to access the conference.
getter/setter pair
pin ↔ String?
The PIN to access the conference.
getter/setter pair
regionCode ↔ String?
The CLDR/ISO 3166 region code for the country associated with this phone access.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
The URI of the entry point.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited