Event class

Constructors

Event({bool? anyoneCanAddSelf, List<EventAttachment>? attachments, List<EventAttendee>? attendees, bool? attendeesOmitted, EventBirthdayProperties? birthdayProperties, String? colorId, ConferenceData? conferenceData, DateTime? created, EventCreator? creator, String? description, EventDateTime? end, bool? endTimeUnspecified, String? etag, String? eventLabelId, String? eventType, EventExtendedProperties? extendedProperties, EventFocusTimeProperties? focusTimeProperties, EventGadget? gadget, bool? guestsCanInviteOthers, bool? guestsCanModify, bool? guestsCanSeeOtherGuests, String? hangoutLink, String? htmlLink, String? iCalUID, String? id, String? kind, String? location, bool? locked, EventOrganizer? organizer, EventDateTime? originalStartTime, EventOutOfOfficeProperties? outOfOfficeProperties, bool? privateCopy, List<String>? recurrence, String? recurringEventId, EventReminders? reminders, int? sequence, EventSource? source, EventDateTime? start, String? status, String? summary, String? transparency, DateTime? updated, String? visibility, EventWorkingLocationProperties? workingLocationProperties})
Event.fromJson(Map json_)

Properties

anyoneCanAddSelf ↔ bool?
Whether anyone can invite themselves to the event (deprecated).
getter/setter pair
attachments ↔ List<EventAttachment>?
File attachments for the event. In order to modify attachments the supportsAttachments request parameter should be set to true. There can be at most 25 attachments per event,
getter/setter pair
attendees ↔ List<EventAttendee>?
The attendees of the event.
getter/setter pair
attendeesOmitted ↔ bool?
Whether attendees may have been omitted from the event's representation.
getter/setter pair
birthdayProperties ↔ EventBirthdayProperties?
Birthday or special event data.
getter/setter pair
colorId ↔ String?
The color of the event.
getter/setter pair
conferenceData ↔ ConferenceData?
The conference-related information, such as details of a Google Meet conference.
getter/setter pair
created ↔ DateTime?
Creation time of the event (as a RFC3339 timestamp).
getter/setter pair
creator ↔ EventCreator?
The creator of the event.
getter/setter pair
description ↔ String?
Description of the event.
getter/setter pair
end ↔ EventDateTime?
The (exclusive) end time of the event.
getter/setter pair
endTimeUnspecified ↔ bool?
Whether the end time is actually unspecified.
getter/setter pair
etag ↔ String?
ETag of the resource.
getter/setter pair
eventLabelId ↔ String?
The ID of the event label assigned to the event.
getter/setter pair
eventType ↔ String?
Specific type of the event.
getter/setter pair
extendedProperties ↔ EventExtendedProperties?
Extended properties of the event.
getter/setter pair
focusTimeProperties ↔ EventFocusTimeProperties?
Focus Time event data.
getter/setter pair
gadget ↔ EventGadget?
A gadget that extends this event.
getter/setter pair
guestsCanInviteOthers ↔ bool?
Whether attendees other than the organizer can invite others to the event.
getter/setter pair
guestsCanModify ↔ bool?
Whether attendees other than the organizer can modify the event.
getter/setter pair
guestsCanSeeOtherGuests ↔ bool?
Whether attendees other than the organizer can see who the event's attendees are.
getter/setter pair
An absolute link to the Google Hangout associated with this event.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
An absolute link to this event in the Google Calendar Web UI.
getter/setter pair
iCalUID ↔ String?
Event unique identifier as defined in RFC5545.
getter/setter pair
id ↔ String?
Opaque identifier of the event.
getter/setter pair
kind ↔ String?
Type of the resource ("calendar#event").
getter/setter pair
location ↔ String?
Geographic location of the event as free-form text.
getter/setter pair
locked ↔ bool?
Whether this is a locked event copy where no changes can be made to the main event fields "summary", "description", "location", "start", "end" or "recurrence".
getter/setter pair
organizer ↔ EventOrganizer?
The organizer of the event.
getter/setter pair
originalStartTime ↔ EventDateTime?
For an instance of a recurring event, this is the time at which this event would start according to the recurrence data in the recurring event identified by recurringEventId.
getter/setter pair
outOfOfficeProperties ↔ EventOutOfOfficeProperties?
Out of office event data.
getter/setter pair
privateCopy ↔ bool?
If set to True, Event propagation is disabled.
getter/setter pair
recurrence ↔ List<String>?
List of RRULE, EXRULE, RDATE and EXDATE lines for a recurring event, as specified in RFC5545.
getter/setter pair
recurringEventId ↔ String?
For an instance of a recurring event, this is the id of the recurring event to which this instance belongs.
getter/setter pair
reminders ↔ EventReminders?
Information about the event's reminders for the authenticated user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequence ↔ int?
Sequence number as per iCalendar.
getter/setter pair
source ↔ EventSource?
Source from which the event was created.
getter/setter pair
start ↔ EventDateTime?
The (inclusive) start time of the event.
getter/setter pair
status ↔ String?
Status of the event.
getter/setter pair
summary ↔ String?
Title of the event.
getter/setter pair
transparency ↔ String?
Whether the event blocks time on the calendar.
getter/setter pair
updated ↔ DateTime?
Last modification time of the main event data (as a RFC3339 timestamp).
getter/setter pair
visibility ↔ String?
Visibility of the event.
getter/setter pair
workingLocationProperties ↔ EventWorkingLocationProperties?
Working location event data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited