eventLabelId property

String? eventLabelId
getter/setter pair

The ID of the event label assigned to the event.

Optional. This refers to the ID of an entry in the labelProperties.eventLabels property of the calendar (see the Calendars.get endpoint.) This property supersedes the index-based colorId property. To set or change this property, you need to specify eventLabelVersion=1 in the parameters of the insert, import, update, and patch methods. Setting an empty string, or not setting this field at all, will remove the existing label from the event.

Implementation

core.String? eventLabelId;