EventCreator class

The creator of the event.

Read-only.

Constructors

EventCreator({String? displayName, String? email, String? id, bool? self})
EventCreator.fromJson(Map json_)

Properties

displayName ↔ String?
The creator's name, if available.
getter/setter pair
email ↔ String?
The creator's email address, if available.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The creator's Profile ID, if available.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
self ↔ bool?
Whether the creator corresponds to the calendar on which this copy of the event appears.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited