EventDateTime class

Constructors

EventDateTime({DateTime? date, DateTime? dateTime, String? timeZone})
EventDateTime.fromJson(Map json_)

Properties

date ↔ DateTime?
The date, in the format "yyyy-mm-dd", if this is an all-day event.
getter/setter pair
dateTime ↔ DateTime?
The time, as a combined date-time value (formatted according to RFC3339).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone ↔ String?
The time zone in which the time is specified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited