EventExtendedProperties class

Extended properties of the event.

Properties

hashCode → int
The hash code for this object.
no setterinherited
private ↔ Map<String, String>?
Properties that are private to the copy of the event that appears on this calendar.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shared ↔ Map<String, String>?
Properties that are shared between copies of the event on other attendees' calendars.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited