EventFocusTimeProperties class

Constructors

EventFocusTimeProperties({String? autoDeclineMode, String? chatStatus, String? declineMessage})
EventFocusTimeProperties.fromJson(Map json_)

Properties

autoDeclineMode ↔ String?
Whether to decline meeting invitations which overlap Focus Time events.
getter/setter pair
chatStatus ↔ String?
The status to mark the user in Chat and related products.
getter/setter pair
declineMessage ↔ String?
Response message to set if an existing event or new invitation is automatically declined by Calendar.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited