EventReminder class

Constructors

EventReminder({String? method, int? minutes})
EventReminder.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
method ↔ String?
The method used by this reminder.
getter/setter pair
minutes ↔ int?
Number of minutes before the start of the event when the reminder should trigger.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited