EventReminders class

Information about the event's reminders for the authenticated user.

Note that changing reminders does not also change the updated property of the enclosing event.

Constructors

EventReminders({List<EventReminder>? overrides, bool? useDefault})
EventReminders.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
overrides ↔ List<EventReminder>?
If the event doesn't use the default reminders, this lists the reminders specific to the event, or, if not set, indicates that no reminders are set for this event.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useDefault ↔ bool?
Whether the default reminders of the calendar apply to the event.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited