Events class

Constructors

Events({String? accessRole, List<EventReminder>? defaultReminders, String? description, String? etag, List<Event>? items, String? kind, String? nextPageToken, String? nextSyncToken, String? summary, String? timeZone, DateTime? updated})
Events.fromJson(Map json_)

Properties

accessRole ↔ String?
The user's access role for this calendar.
getter/setter pair
defaultReminders ↔ List<EventReminder>?
The default reminders on the calendar for the authenticated user.
getter/setter pair
description ↔ String?
Description of the calendar.
getter/setter pair
etag ↔ String?
ETag of the collection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Event>?
List of events on the calendar.
getter/setter pair
kind ↔ String?
Type of the collection ("calendar#events").
getter/setter pair
nextPageToken ↔ String?
Token used to access the next page of this result.
getter/setter pair
nextSyncToken ↔ String?
Token used at a later point in time to retrieve only the entries that have changed since this result was returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary ↔ String?
Title of the calendar.
getter/setter pair
timeZone ↔ String?
The time zone of the calendar.
getter/setter pair
updated ↔ DateTime?
Last modification time of the calendar (as a RFC3339 timestamp).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited