eventLabels property

List<EventLabel>? eventLabels
getter/setter pair

Event labels defined on this calendar.

If this is present when updating the calendar, it will replace the existing event labels. Extend the list to add a new event label, and remove entities from the list to delete a label from calendar. Each calendar can have a maximum of 200 labels.

Implementation

core.List<EventLabel>? eventLabels;