TimePeriod class

Constructors

TimePeriod({DateTime? end, DateTime? start})
TimePeriod.fromJson(Map json_)

Properties

end ↔ DateTime?
The (exclusive) end of the time period.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ DateTime?
The (inclusive) start of the time period.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited