GclbTarget class

Describes a Target Proxy that uses this Certificate Map.

Constructors

GclbTarget({List<IpConfig>? ipConfigs, String? targetHttpsProxy, String? targetSslProxy})
GclbTarget.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipConfigs ↔ List<IpConfig>?
IP configurations for this Target Proxy where the Certificate Map is serving.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetHttpsProxy ↔ String?
This field returns the resource name in the following format: //compute.googleapis.com/projects / * /global/targetHttpsProxies / * .
getter/setter pair
targetSslProxy ↔ String?
This field returns the resource name in the following format: //compute.googleapis.com/projects / * /global/targetSslProxies / * .
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited