IPs class

IPs troubleshooting information.

Constructors

IPs({List<String>? resolved, List<String>? serving, List<String>? servingOnAltPorts})
IPs.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
resolved ↔ List<String>?
The list of IP addresses resolved from the domain's A/AAAA records.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serving ↔ List<String>?
The list of IP addresses, where the certificate is attached and port 443 is open.
getter/setter pair
servingOnAltPorts ↔ List<String>?
The list of IP addresses, where the certificate is attached, but port 443 is not open.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited