ProvisioningIssue class

Information about issues with provisioning a Managed Certificate.

Constructors

ProvisioningIssue({String? details, String? reason})
ProvisioningIssue.fromJson(Map json_)

Properties

details ↔ String?
Human readable explanation about the issue.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reason ↔ String?
Reason for provisioning failures.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited