TrustConfig class

Defines a trust config.

Constructors

TrustConfig({List<AllowlistedCertificate>? allowlistedCertificates, String? createTime, String? description, String? etag, Map<String, String>? labels, String? name, Map<String, TrustStore>? spiffeTrustStores, Map<String, String>? tags, List<TrustStore>? trustStores, String? updateTime})
TrustConfig.fromJson(Map json_)

Properties

allowlistedCertificates ↔ List<AllowlistedCertificate>?
A certificate matching an allowlisted certificate is always considered valid as long as the certificate is parseable, proof of private key possession is established, and constraints on the certificate's SAN field are met.
getter/setter pair
createTime ↔ String?
The creation timestamp of a TrustConfig.
getter/setter pair
description ↔ String?
One or more paragraphs of text description of a TrustConfig.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Set of labels associated with a TrustConfig.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spiffeTrustStores ↔ Map<String, TrustStore>?
Defines a mapping from a trust domain to a TrustStore.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
trustStores ↔ List<TrustStore>?
Set of trust stores to perform validation against.
getter/setter pair
updateTime ↔ String?
The last update timestamp of a TrustConfig.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited