ces/v1 library
Gemini Enterprise for Customer Experience API - v1
For more information, see docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps
Create an instance of CustomerEngagementSuiteApi to access these resources:
- ProjectsResource
- ProjectsLocationsResource
- ProjectsLocationsAppsResource
- ProjectsLocationsAppsAgentsResource
- ProjectsLocationsAppsChangelogsResource
- ProjectsLocationsAppsConversationsResource
- ProjectsLocationsAppsDeploymentsResource
- ProjectsLocationsAppsExamplesResource
- ProjectsLocationsAppsGuardrailsResource
- ProjectsLocationsAppsMessageResource
- ProjectsLocationsAppsSessionsResource
- ProjectsLocationsAppsToolsResource
- ProjectsLocationsAppsToolsetsResource
- ProjectsLocationsAppsVersionsResource
- ProjectsLocationsOperationsResource
- ProjectsLocationsAppsResource
- ProjectsLocationsResource
Classes
- Action
- Configuration of an Action for the tool to use.
- ActionEntityOperation
- Entity CRUD operation specification.
- Agent
- An agent acts as the fundamental building block that provides instructions to the Large Language Model (LLM) for executing specific tasks.
- AgentAgentToolset
- A toolset with a selection of its tools.
- AgentCard
- AgentCard conveys key information about a remote agent.
- AgentInterface
- Declares a combination of a target URL, transport and protocol version for interacting with the agent.
- AgentRemoteDialogflowAgent
- The agent which will transfer execution to a remote Dialogflow CX agent.
- AgentSkill
- Represents a distinct capability or function that an agent can perform.
- AgentTool
- Represents a tool that allows the agent to call another agent.
- AmbientSoundConfig
- Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.
- ApiAuthentication
- Authentication information required for API calls.
- ApiKeyConfig
- Configurations for authentication with API key.
- App
- An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations.
- AppSnapshot
- A snapshot of the app.
- AppVariableDeclaration
- Defines the structure and metadata for a variable.
- AppVersion
- In Customer Engagement Suite (CES), an app version is a snapshot of the app at a specific point in time.
- AudioProcessingConfig
- Configuration for how the input and output audio should be processed and delivered.
- AudioRecordingConfig
- Configuration for how the audio interactions should be recorded.
- BargeInConfig
- Configuration for how the user barge-in activities should be handled.
- BatchDeleteConversationsRequest
- Request message for AgentService.BatchDeleteConversations.
- BearerTokenConfig
- Configurations for authentication with a bearer token.
- BigQueryExportSettings
- Settings to describe the BigQuery export behaviors for the app.
- Callback
- A callback defines the custom logic to be executed at various stages of agent interaction.
- Changelog
- Changelogs represent a change made to the app or to an resource within the app.
- ChannelProfile
- A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.
- ChannelProfileInstagramConfig
- Configuration specific to Instagram deployments.
- ChannelProfilePersonaProperty
- Represents the persona property of a channel.
- ChannelProfileWebWidgetConfig
- Message for configuration for the web widget.
- ChannelProfileWebWidgetConfigSecuritySettings
- Security settings for the web widget.
- ChannelProfileWhatsAppConfig
- Configuration specific to WhatsApp deployments.
- Chunk
- A chunk of content within a message.
- Citations
- Citations associated with the agent response.
- CitationsCitedChunk
- Piece of cited information.
- ClientCertificateSettings
- Settings for custom client certificates.
- ClientFunction
- Represents a client-side function that the agent can invoke.
- CloudLoggingSettings
- Settings to describe the Cloud Logging behaviors for the app.
- CodeBlock
- A code block to be executed instead of a real tool call.
- ConnectorTool
- A ConnectorTool allows connections to different integrations.
- ConnectorToolset
- A toolset that generates tools from an Integration Connectors Connection.
- Conversation
- A conversation represents an interaction between an end user and the CES app.
- ConversationLoggingSettings
- Settings to describe the conversation logging behaviors for the app.
- ConversationTurn
- All information about a single turn in the conversation.
- CustomerEngagementSuiteApi
- DataStore
- A DataStore resource in Vertex AI Search.
- DataStoreConnectorConfig
- The connector config for the data store connection.
- DataStoreSettings
- Data store related settings for the app.
- DataStoreSettingsEngine
- An engine to which the data stores are connected.
- DataStoreTool
- Tool to retrieve from Vertex AI Search datastore or engine for grounding.
- DataStoreToolBoostSpec
- Boost specification to boost certain documents.
- DataStoreToolBoostSpecConditionBoostSpec
- Boost specification for a condition.
- DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec
- Specification for custom ranking based on customer specified attribute value.
- DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint
- The control points used to define the curve.
- DataStoreToolBoostSpecs
- Boost specifications to boost certain documents.
- DataStoreToolDataStoreSource
- Configuration for searching within a specific DataStore.
- DataStoreToolEngineSource
- Configuration for searching within an Engine, potentially targeting specific DataStores.
- DataStoreToolGroundingConfig
- Grounding configuration.
- DataStoreToolModalityConfig
- If specified, will apply the given configuration for the specified modality.
- DataStoreToolRewriterConfig
- Rewriter configuration.
- DataStoreToolSnippetsConfig
- Snippets configuration.
- DataStoreToolSummarizationConfig
- Summarization configuration.
- Deployment
- A deployment represents an immutable, queryable version of the app.
- EndUserAuthConfig
- End-user authentication configuration used for Connection calls.
- EndUserAuthConfigOauth2AuthCodeConfig
- Oauth 2.0 Authorization Code authentication configuration.
- EndUserAuthConfigOauth2JwtBearerConfig
- JWT Profile Oauth 2.0 Authorization Grant authentication configuration.
- ErrorHandlingSettings
- Settings to describe how errors should be handled in the app.
- ErrorHandlingSettingsEndSessionConfig
- Configuration for ending the session in case of system errors (e.g. LLM errors).
- ErrorHandlingSettingsFallbackResponseConfig
- Configuration for handling fallback responses.
- EvaluationMetricsThresholds
- Threshold settings for metrics in an Evaluation.
- EvaluationMetricsThresholdsGoldenEvaluationMetricsThresholds
- Settings for golden evaluations.
- EvaluationMetricsThresholdsGoldenEvaluationMetricsThresholdsExpectationLevelMetricsThresholds
- Expectation level metrics thresholds.
- EvaluationMetricsThresholdsGoldenEvaluationMetricsThresholdsTurnLevelMetricsThresholds
- Turn level metrics thresholds.
- EvaluationMetricsThresholdsToolMatchingSettings
- Settings for matching tool calls.
- Event
- Event input.
- Example
- An example represents a sample conversation between the user and the agent(s).
- ExecuteToolRequest
- Request message for ToolService.ExecuteTool.
- ExecuteToolResponse
- Response message for ToolService.ExecuteTool.
- ExperimentConfig
- Experiment for the deployment.
- ExperimentConfigVersionRelease
- Version release for the experiment.
- ExperimentConfigVersionReleaseTrafficAllocation
- Traffic allocation for the version release.
- ExportAppRequest
- Request message for AgentService.ExportApp.
- ExpressionCondition
- Expression condition based on session state.
- FileSearchTool
- The file search tool allows the agent to search across the files uploaded by the app/agent developer.
- GenerateChatTokenRequest
- Request message for WidgetService.GenerateChatToken.
- GenerateChatTokenResponse
- Response message for WidgetService.GenerateChatToken.
- GoogleSearchSuggestions
- Search suggestions from Google Search Tool.
- GoogleSearchTool
- Represents a tool to perform Google web searches for grounding.
- GoogleSearchToolPromptConfig
- Prompt settings used by the model when processing or summarizing the google search results.
- Guardrail
- Guardrail contains a list of checks and balances to keep the agents safe and secure.
- GuardrailCodeCallback
- Guardrail that blocks the conversation based on the code callbacks provided.
- GuardrailContentFilter
- Guardrail that bans certain content from being used in the conversation.
- GuardrailLlmPolicy
- Guardrail that blocks the conversation if the LLM response is considered violating the policy based on the LLM classification.
- GuardrailLlmPromptSecurity
- Guardrail that blocks the conversation if the input is considered unsafe based on the LLM classification.
- GuardrailLlmPromptSecurityDefaultSecuritySettings
- Configuration for default system security settings.
- GuardrailModelSafety
- Model safety settings overrides.
- GuardrailModelSafetySafetySetting
- Safety setting.
- ImportAppRequest
- Request message for AgentService.ImportApp.
- ImportAppRequestImportOptions
- Configuration options for the app import process.
- InputAudioConfig
- InputAudioConfig configures how the CES agent should interpret the incoming audio data.
- InstagramCredentials
- Ephemeral Meta credentials for Instagram native integration.
- LanguageSettings
- Language settings of the app.
- LfA2aV1AgentCapabilities
- Defines optional capabilities supported by an agent.
- LfA2aV1AgentCard
- A self-describing manifest for an agent.
- LfA2aV1AgentCardSignature
- AgentCardSignature represents a JWS signature of an AgentCard.
- LfA2aV1AgentExtension
- A declaration of a protocol extension supported by an Agent.
- LfA2aV1AgentInterface
- Declares a combination of a target URL, transport and protocol version for interacting with the agent.
- LfA2aV1AgentProvider
- Represents the service provider of an agent.
- LfA2aV1AgentSkill
- Represents a distinct capability or function that an agent can perform.
- LfA2aV1APIKeySecurityScheme
- Defines a security scheme using an API key.
- LfA2aV1Artifact
- Artifacts represent task outputs.
- LfA2aV1AuthenticationInfo
- Defines authentication details, used for push notifications.
- LfA2aV1AuthorizationCodeOAuthFlow
- Defines configuration details for the OAuth 2.0 Authorization Code flow.
- LfA2aV1ClientCredentialsOAuthFlow
- Defines configuration details for the OAuth 2.0 Client Credentials flow.
- LfA2aV1DeviceCodeOAuthFlow
- Defines configuration details for the OAuth 2.0 Device Code flow (RFC 8628).
- LfA2aV1HTTPAuthSecurityScheme
- Defines a security scheme using HTTP authentication.
- LfA2aV1ImplicitOAuthFlow
- Deprecated: Use Authorization Code + PKCE instead.
- LfA2aV1Message
-
Messageis one unit of communication between client and server. - LfA2aV1MutualTlsSecurityScheme
- Defines a security scheme using mTLS authentication.
- LfA2aV1OAuth2SecurityScheme
- Defines a security scheme using OAuth 2.0.
- LfA2aV1OAuthFlows
- Defines the configuration for the supported OAuth 2.0 flows.
- LfA2aV1OpenIdConnectSecurityScheme
- Defines a security scheme using OpenID Connect.
- LfA2aV1Part
-
Partrepresents a container for a section of communication content. - LfA2aV1PasswordOAuthFlow
- Deprecated: Use Authorization Code + PKCE or Device Code.
- LfA2aV1SecurityRequirement
- Defines the security requirements for an agent.
- LfA2aV1SecurityScheme
- Defines a security scheme that can be used to secure an agent's endpoints.
- LfA2aV1SendMessageConfiguration
- Configuration of a send message request.
- LfA2aV1SendMessageRequest
-
Represents a request for the
SendMessagemethod. - LfA2aV1SendMessageResponse
-
Represents the response for the
SendMessagemethod. - LfA2aV1StringList
- protolint:disable REPEATED_FIELD_NAMES_PLURALIZED A list of strings.
- LfA2aV1Task
-
Taskis the core unit of action for A2A. - LfA2aV1TaskPushNotificationConfig
- A container associating a push notification configuration with a specific task.
- LfA2aV1TaskStatus
- A container for the status of a task
- ListAgentsResponse
- Response message for AgentService.ListAgents.
- ListAppsResponse
- Response message for AgentService.ListApps.
- ListAppVersionsResponse
- Response message for AgentService.ListAppVersions.
- ListChangelogsResponse
- Response message for AgentService.ListChangelogs.
- ListConversationsResponse
- Response message for AgentService.ListConversations.
- ListDeploymentsResponse
- Response message for AgentService.ListDeployments.
- ListExamplesResponse
- Response message for AgentService.ListExamples.
- ListGuardrailsResponse
- Response message for AgentService.ListGuardrails.
- ListLocationsResponse
- The response message for Locations.ListLocations.
- ListOperationsResponse
- The response message for Operations.ListOperations.
- ListToolsetsResponse
- Response message for AgentService.ListToolsets.
- ListToolsResponse
- Response message for AgentService.ListTools.
- LoggingSettings
- Settings to describe the logging behaviors for the app.
- McpTool
- An MCP tool.
- McpToolDefinition
- Container for a tool's core definition elements that are snapshot.
- McpToolOverride
- Overrides associated with a given tool in a Toolset.
- McpToolset
- A toolset that contains a list of tools that are offered by the MCP server.
- Message
- A message within a conversation.
- MetricAnalysisSettings
- Settings to describe the conversation data collection behaviors for LLM analysis metrics pipeline.
- MockConfig
- Mock tool calls configuration for the session.
- MockedToolCall
- A mocked tool call.
- ModelSettings
- Model settings contains various configurations for the LLM model.
- OAuthConfig
- Configurations for authentication with OAuth.
- OpenApiTool
- A remote API tool defined by an OpenAPI schema.
- OpenApiToolset
- A toolset that contains a list of tools that are defined by an OpenAPI schema.
- Operation
- This resource represents a long-running operation that is the result of a network API call.
- OutputAudioConfig
- OutputAudioConfig configures how the CES agent should synthesize outgoing audio responses.
- ProjectsLocationsAppsAgentsResource
- ProjectsLocationsAppsChangelogsResource
- ProjectsLocationsAppsConversationsResource
- ProjectsLocationsAppsDeploymentsMessageResource
- ProjectsLocationsAppsDeploymentsResource
- ProjectsLocationsAppsExamplesResource
- ProjectsLocationsAppsGuardrailsResource
- ProjectsLocationsAppsMessageResource
- ProjectsLocationsAppsResource
- ProjectsLocationsAppsSessionsResource
- ProjectsLocationsAppsToolsetsResource
- ProjectsLocationsAppsToolsResource
- ProjectsLocationsAppsVersionsMessageResource
- ProjectsLocationsAppsVersionsResource
- ProjectsLocationsOperationsResource
- ProjectsLocationsResource
- ProjectsResource
- PythonCodeCondition
- Python code block to evaluate the condition.
- PythonFunction
- A Python function tool.
- RedactionConfig
- Configuration to instruct how sensitive data should be handled.
- RemoteAgentTool
- Represents a tool that allows the agent to call another remote agent.
- RetrieveToolSchemaRequest
- Request message for ToolService.RetrieveToolSchema.
- RetrieveToolSchemaResponse
- Response message for ToolService.RetrieveToolSchema.
- RetrieveToolsRequest
- Request message for ToolService.RetrieveTools.
- RetrieveToolsResponse
- Response message for ToolService.RetrieveTools.
- RunSessionRequest
- Request message for SessionService.RunSession.
- RunSessionResponse
- Response message for SessionService.RunSession.
- Schema
- Represents a select subset of an OpenAPI 3.0 schema object.
- ServiceAccountAuthConfig
- Configurations for authentication using a custom service account.
- ServiceDirectoryConfig
- Configuration for tools using Service Directory.
- SessionConfig
- The configuration for the session.
- SessionConfigRemoteDialogflowQueryParameters
- QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.
- SessionInput
- Input for the session.
- SessionOutput
- Output for the session.
- SessionOutputDiagnosticInfo
- Contains execution details during the processing.
- Span
- A span is a unit of work or a single operation during the request processing.
- SynthesizeSpeechConfig
- Configuration for how the agent response should be synthesized.
- SystemTool
- Pre-defined system tool.
- TimeZoneSettings
- TimeZone settings of the app.
- TlsConfig
- The TLS configuration.
- TlsConfigCaCert
- The CA certificate.
- Tool
- A tool represents an action that the CES agent can take to achieve certain goals.
- ToolCall
- Request for the client or the agent to execute the specified tool.
- ToolCalls
- Request for the client to execute the tools and return the execution results before continuing the session.
- ToolFakeConfig
- Configuration for tool behavior in fake mode.
- ToolResponse
- The execution result of a specific tool from the client or the agent.
- ToolResponses
- Execution results for the requested tool calls from the client.
- Toolset
- A toolset represents a group of dynamically managed tools that can be used by the agent.
- TransferRule
- Rule for transferring to a specific agent.
- TransferRuleDeterministicTransfer
- Deterministic transfer rule.
- TransferRuleDisablePlannerTransfer
- A rule that prevents the planner from transferring to the target agent.
- TriggerAction
- Action that is taken when a certain precondition is met.
- TriggerActionGenerativeAnswer
- The agent will immediately respond with a generative answer.
- TriggerActionRespondImmediately
- The agent will immediately respond with a preconfigured response.
- TriggerActionResponse
- Represents a response from the agent.
- TriggerActionTransferAgent
- The agent will transfer the conversation to a different agent.
- VpcScSettings
- VPC-SC settings for the app.
- WebSearchQuery
- Represents a single web search query and its associated search uri.
- WhatsAppCredentials
- Ephemeral Meta credentials for WhatsApp native integration.
- WidgetTool
- Represents a widget tool that the agent can invoke.
- WidgetToolDataMapping
- Configuration for mapping data from a source tool to the widget's input parameters.
- WidgetToolTextResponseConfig
- Configuration for the text response returned with the widget.
Typedefs
- AgentLlmAgent = $Empty
- Default agent type.
- AgentTransfer = $AgentTransfer
- Represents an event indicating the transfer of a conversation to a different agent.
- Blob = $Blob
- Represents a blob input or output in the conversation.
- CancelOperationRequest = $Empty
- The request message for Operations.CancelOperation.
- Empty = $Empty
- A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
- EndSession = $EndSession
- Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation.
- Image = $Image
- Represents an image input or output in the conversation.
- Location = $Location00
- A resource that represents a Google Cloud location.
- RestoreAppVersionRequest = $Empty
- Request message for AgentService.RestoreAppVersion
- ServiceAgentIdTokenAuthConfig = $Empty
- Configurations for authentication with ID token generated from service agent.
- Status = $Status00
-
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. - ToolsetTool = $ToolsetTool
- A tool that is created from a toolset.
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.