inputFields property

List<String>? inputFields
getter/setter pair

Entity fields to use as inputs for the operation.

If no fields are specified, all fields of the Entity will be used.

Optional.

Implementation

core.List<core.String>? inputFields;