afterAgentCallbacks property

List<Callback>? afterAgentCallbacks
getter/setter pair

The callbacks to execute after the agent is called.

The provided callbacks are executed sequentially in the exact order they are given in the list. If a callback returns an overridden response, execution stops and any remaining callbacks are skipped.

Optional.

Implementation

core.List<Callback>? afterAgentCallbacks;