afterModelCallbacks property

List<Callback>? afterModelCallbacks
getter/setter pair

The callbacks to execute after the model is called.

If there are multiple calls to the model, the callback will be executed multiple times. The provided callbacks are executed sequentially in the exact order they are given in the list. If a callback returns an overridden response, execution stops and any remaining callbacks are skipped.

Optional.

Implementation

core.List<Callback>? afterModelCallbacks;