afterToolCallbacks property

List<Callback>? afterToolCallbacks
getter/setter pair

The callbacks to execute after the tool is invoked.

If there are multiple tool invocations, the callback will be executed multiple times. The provided callbacks are executed sequentially in the exact order they are given in the list. If a callback returns an overridden response, execution stops and any remaining callbacks are skipped.

Optional.

Implementation

core.List<Callback>? afterToolCallbacks;