etag property
Etag used to ensure the object hasn't changed during a read-modify-write operation.
If the etag is empty, the update will overwrite any concurrent changes.
Implementation
core.String? etag;
Etag used to ensure the object hasn't changed during a read-modify-write operation.
If the etag is empty, the update will overwrite any concurrent changes.
core.String? etag;