generatedSummary property
If the agent is generated by the LLM assistant, this field contains a descriptive summary of the generation.
Output only.
Implementation
core.String? generatedSummary;
If the agent is generated by the LLM assistant, this field contains a descriptive summary of the generation.
Output only.
core.String? generatedSummary;