remoteDialogflowAgent property

AgentRemoteDialogflowAgent? remoteDialogflowAgent
getter/setter pair

The remote Dialogflow agent to be used for the agent execution.

If this field is set, all other agent level properties will be ignored. Note: If the Dialogflow agent is in a different project from the app, you should grant roles/dialogflow.client to the CES service agent service-@gcp-sa-ces.iam.gserviceaccount.com.

Optional.

Implementation

AgentRemoteDialogflowAgent? remoteDialogflowAgent;