AgentAgentToolset class

A toolset with a selection of its tools.

Constructors

AgentAgentToolset({List<String>? toolIds, String? toolset})
AgentAgentToolset.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolIds ↔ List<String>?
The tools IDs to filter the toolset.
getter/setter pair
toolset ↔ String?
The resource name of the toolset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited