AgentCard class

AgentCard conveys key information about a remote agent.

It is a trimmed version of the AgentCard defined in the A2A protocol https://a2a-protocol.org/dev/specification/#441-agentcard

Constructors

AgentCard({String? description, String? name, List<AgentSkill>? skills, List<AgentInterface>? supportedInterfaces, String? version})
AgentCard.fromJson(Map json_)

Properties

description String?
A description of the agent's domain of action/solution space.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
A human-readable name for the agent.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skills List<AgentSkill>?
Skills represent a unit of ability an agent can perform.
getter/setter pair
supportedInterfaces List<AgentInterface>?
Ordered list of supported interfaces.
getter/setter pair
version String?
The version of the agent.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited