skills property

List<AgentSkill>? skills
getter/setter pair

Skills represent a unit of ability an agent can perform.

This may somewhat abstract but represents a more focused set of actions that the agent is highly likely to succeed at.

Required.

Implementation

core.List<AgentSkill>? skills;