AgentInterface class

Declares a combination of a target URL, transport and protocol version for interacting with the agent.

This allows agents to expose the same functionality over multiple protocol binding mechanisms.

Constructors

AgentInterface({String? protocolBinding, String? protocolVersion, String? tenant, String? url})
AgentInterface.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
protocolBinding String?
The protocol binding supported at this URL.
getter/setter pair
protocolVersion String?
The version of the A2A protocol this interface exposes.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenant String?
Tenant ID to be used in the request when calling the agent.
getter/setter pair
url String?
The URL where this interface is available.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited