protocolVersion property
The version of the A2A protocol this interface exposes.
Use the latest supported minor version per major version. Examples: "0.3", "1.0"
Required.
Implementation
core.String? protocolVersion;
The version of the A2A protocol this interface exposes.
Use the latest supported minor version per major version. Examples: "0.3", "1.0"
Required.
core.String? protocolVersion;