environmentId property

String? environmentId
getter/setter pair

The environment ID of the Dialogflow agent to be used for the agent execution.

If not specified, the draft environment will be used.

Optional.

Implementation

core.String? environmentId;