inputVariableMapping property

Map<String, String>? inputVariableMapping
getter/setter pair

The mapping of the app variables names to the Dialogflow session parameters names to be sent to the Dialogflow agent as input.

Optional.

Implementation

core.Map<core.String, core.String>? inputVariableMapping;