languageCodeVariable property

String? languageCodeVariable
getter/setter pair

The name of the variable that contains the language code to be used for the Dialogflow session.

If unspecified, the default language code of the Dialogflow agent will be used.

Optional.

Implementation

core.String? languageCodeVariable;