outputVariableMapping property

Map<String, String>? outputVariableMapping
getter/setter pair

The mapping of the Dialogflow session parameters names to the app variables names to be sent back to the CES agent after the Dialogflow agent execution ends.

Optional.

Implementation

core.Map<core.String, core.String>? outputVariableMapping;