AgentSkill class

Represents a distinct capability or function that an agent can perform.

Constructors

AgentSkill({String? description, List<String>? examples, String? id, List<String>? inputModes, String? name, List<String>? outputModes, List<String>? tags})
AgentSkill.fromJson(Map json_)

Properties

description String?
A detailed description of the skill.
getter/setter pair
examples List<String>?
Example prompts or scenarios that this skill can handle.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
A unique identifier for the agent's skill.
getter/setter pair
inputModes List<String>?
The set of supported input media types for this skill, overriding the agent's defaults.
getter/setter pair
name String?
A human-readable name for the skill.
getter/setter pair
outputModes List<String>?
The set of supported output media types for this skill, overriding the agent's defaults.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>?
A set of keywords describing the skill's capabilities.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited