agent property
The resource name of the agent that is the entry point of the tool.
Format: projects/{project}/locations/{location}/agents/{agent}
Optional.
Implementation
core.String? agent;
The resource name of the agent that is the entry point of the tool.
Format: projects/{project}/locations/{location}/agents/{agent}
Optional.
core.String? agent;