AgentTransfer typedef
AgentTransfer = $AgentTransfer
Represents an event indicating the transfer of a conversation to a different agent.
Implementation
typedef AgentTransfer = $AgentTransfer;
Represents an event indicating the transfer of a conversation to a different agent.
typedef AgentTransfer = $AgentTransfer;