ApiAuthentication class
Authentication information required for API calls.
Constructors
- ApiAuthentication({ApiKeyConfig? apiKeyConfig, BearerTokenConfig? bearerTokenConfig, OAuthConfig? oauthConfig, ServiceAccountAuthConfig? serviceAccountAuthConfig, ServiceAgentIdTokenAuthConfig? serviceAgentIdTokenAuthConfig})
- ApiAuthentication.fromJson(Map json_)
Properties
- apiKeyConfig ↔ ApiKeyConfig?
-
Config for API key auth.
getter/setter pair
- bearerTokenConfig ↔ BearerTokenConfig?
-
Config for bearer token auth.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- oauthConfig ↔ OAuthConfig?
-
Config for OAuth.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceAccountAuthConfig ↔ ServiceAccountAuthConfig?
-
Config for service account authentication.
getter/setter pair
- serviceAgentIdTokenAuthConfig ↔ AgentLlmAgent?
-
Config for ID token auth generated from CES service agent.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited