ApiKeyConfig class
Configurations for authentication with API key.
Constructors
- ApiKeyConfig({String? apiKeySecretVersion, String? keyName, String? requestLocation})
- ApiKeyConfig.fromJson(Map json_)
Properties
- apiKeySecretVersion ↔ String?
-
The name of the SecretManager secret version resource storing the API key.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyName ↔ String?
-
The parameter name or the header name of the API key.
getter/setter pair
- requestLocation ↔ String?
-
Key location in the request.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited