globalInstruction property

String? globalInstruction
getter/setter pair

Instructions for all the agents in the app.

You can use this instruction to set up a stable identity or personality across all the agents.

Optional.

Implementation

core.String? globalInstruction;