locked property
Indicates whether the app is locked for changes.
If the app is locked, modifications to the app resources will be rejected.
Optional.
Implementation
core.bool? locked;
Indicates whether the app is locked for changes.
If the app is locked, modifications to the app resources will be rejected.
Optional.
core.bool? locked;