rootAgent property
The root agent is the entry point of the app.
Format:
projects/{project}/locations/{location}/apps/{app}/agents/{agent}
Optional.
Implementation
core.String? rootAgent;
The root agent is the entry point of the app.
Format:
projects/{project}/locations/{location}/apps/{app}/agents/{agent}
Optional.
core.String? rootAgent;