AppVariableDeclaration class

Defines the structure and metadata for a variable.

Constructors

AppVariableDeclaration({String? description, String? name, Schema? schema})
AppVariableDeclaration.fromJson(Map json_)

Properties

description ↔ String?
The description of the variable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the variable.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ Schema?
The schema of the variable.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited