name property
The name of the variable.
The name must start with a letter or underscore and contain only letters, numbers, or underscores.
Required.
Implementation
core.String? name;
The name of the variable.
The name must start with a letter or underscore and contain only letters, numbers, or underscores.
Required.
core.String? name;