AudioProcessingConfig class

Configuration for how the input and output audio should be processed and delivered.

Constructors

AudioProcessingConfig({AmbientSoundConfig? ambientSoundConfig, BargeInConfig? bargeInConfig, String? inactivityTimeout, Map<String, SynthesizeSpeechConfig>? synthesizeSpeechConfigs})
AudioProcessingConfig.fromJson(Map json_)

Properties

ambientSoundConfig ↔ AmbientSoundConfig?
Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.
getter/setter pair
bargeInConfig ↔ BargeInConfig?
Configures the agent behavior for the user barge-in activities.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inactivityTimeout ↔ String?
The duration of user inactivity (no speech or interaction) before the agent prompts the user for reengagement.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
synthesizeSpeechConfigs ↔ Map<String, SynthesizeSpeechConfig>?
Configuration of how the agent response should be synthesized, mapping from the language code to SynthesizeSpeechConfig.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited