synthesizeSpeechConfigs property
Configuration of how the agent response should be synthesized, mapping from the language code to SynthesizeSpeechConfig.
If the configuration for the specified language code is not found, the configuration for the root language code will be used. For example, if the map contains "en-us" and "en", and the specified language code is "en-gb", then "en" configuration will be used. Note: Language code is case-insensitive.
Optional.
Implementation
core.Map<core.String, SynthesizeSpeechConfig>? synthesizeSpeechConfigs;