gcsBucket property

String? gcsBucket
getter/setter pair

The Cloud Storage bucket to store the session audio recordings.

The URI must start with "gs://". Please choose a bucket location that meets your data residency requirements. Note: If the Cloud Storage bucket is in a different project from the app, you should grant storage.objects.create permission to the CES service agent service-@gcp-sa-ces.iam.gserviceaccount.com.

Optional.

Implementation

core.String? gcsBucket;