gcsPathPrefix property

String? gcsPathPrefix
getter/setter pair

The Cloud Storage path prefix for audio recordings.

This prefix can include the following placeholders, which will be dynamically substituted at serving time: - $project: project ID - $location: app location - $app: app ID - $date: session date in YYYY-MM-DD format - $session: session ID If the path prefix is not specified, the default prefix $project/$location/$app/$date/$session/ will be used.

Optional.

Implementation

core.String? gcsPathPrefix;