bargeInAwareness property
If enabled, the agent will adapt its next response based on the assumption that the user hasn't heard the full preceding agent message.
This should not be used in scenarios where agent responses are displayed visually.
Optional.
Implementation
core.bool? bargeInAwareness;