BigQueryExportSettings class

Settings to describe the BigQuery export behaviors for the app.

Constructors

BigQueryExportSettings({String? dataset, bool? enabled, String? project})
BigQueryExportSettings.fromJson(Map json_)

Properties

dataset ↔ String?
The BigQuery dataset ID to export the data to.
getter/setter pair
enabled ↔ bool?
Indicates whether the BigQuery export is enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
project ↔ String?
The project ID of the BigQuery dataset to export the data to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited