proactiveExecutionEnabled property
If enabled, the callback will also be executed on intermediate model outputs.
This setting only affects after model callback. ENABLE WITH CAUTION. Typically after model callback only needs to be executed after receiving all model responses. Enabling proactive execution may have negative implication on the execution cost and latency, and should only be enabled in rare situations.
Optional.
Implementation
core.bool? proactiveExecutionEnabled;