description property
Description of the change.
which typically captures the changed fields in the resource.
Output only.
Implementation
core.String? description;
Description of the change.
which typically captures the changed fields in the resource.
Output only.
core.String? description;