disableBargeInControl property

bool? disableBargeInControl
getter/setter pair

Whether to disable user barge-in control in the conversation.

  • true: User interruptions are disabled while the agent is speaking. - false: The agent retains automatic control over when the user can interrupt.

Optional.

Implementation

core.bool? disableBargeInControl;