ChannelProfileInstagramConfig class
Configuration specific to Instagram deployments.
Constructors
- ChannelProfileInstagramConfig({String? description, String? displayName, String? instagramAccountId, String? thumbnailUrl})
- ChannelProfileInstagramConfig.fromJson(Map json_)
Properties
- description ↔ String?
-
The description of the Meta business page or profile.
getter/setter pair
- displayName ↔ String?
-
The fetched Meta business page name.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- instagramAccountId ↔ String?
-
The Instagram Account ID.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnailUrl ↔ String?
-
The fetched Meta business profile thumbnail URL.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited