ChannelProfileWebWidgetConfig class
Message for configuration for the web widget.
Constructors
- ChannelProfileWebWidgetConfig({String? modality, ChannelProfileWebWidgetConfigSecuritySettings? securitySettings, String? theme, String? webWidgetTitle})
- ChannelProfileWebWidgetConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- modality ↔ String?
-
The modality of the web widget.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securitySettings ↔ ChannelProfileWebWidgetConfigSecuritySettings?
-
The security settings of the web widget.
getter/setter pair
- theme ↔ String?
-
The theme of the web widget.
getter/setter pair
- webWidgetTitle ↔ String?
-
The title of the web widget.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited