ChannelProfileWebWidgetConfigSecuritySettings class

Security settings for the web widget.

Constructors

ChannelProfileWebWidgetConfigSecuritySettings({List<String>? allowedOrigins, bool? enableOriginCheck, bool? enablePublicAccess, bool? enableRecaptcha})
ChannelProfileWebWidgetConfigSecuritySettings.fromJson(Map json_)

Properties

allowedOrigins ↔ List<String>?
The origins that are allowed to host the web widget.
getter/setter pair
enableOriginCheck ↔ bool?
Indicates whether origin check for the web widget is enabled.
getter/setter pair
enablePublicAccess ↔ bool?
Indicates whether public access to the web widget is enabled.
getter/setter pair
enableRecaptcha ↔ bool?
Indicates whether reCAPTCHA verification for the web widget is enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited