enablePublicAccess property
Indicates whether public access to the web widget is enabled.
If true, the web widget will be publicly accessible. If false, the web
widget must be integrated with your own authentication and authorization
system to return valid credentials for accessing the CES agent.
Optional.
Implementation
core.bool? enablePublicAccess;