ChannelProfileWhatsAppConfig class
Configuration specific to WhatsApp deployments.
Constructors
- ChannelProfileWhatsAppConfig({String? description, String? displayName, String? phoneNumber, String? phoneNumberId, String? thumbnailUrl, String? wabaId})
- ChannelProfileWhatsAppConfig.fromJson(Map json_)
Properties
- description ↔ String?
-
The description of the Meta business page or profile.
getter/setter pair
- displayName ↔ String?
-
The fetched Meta business page name.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- phoneNumber ↔ String?
-
The phone number in E.164 format.
getter/setter pair
- phoneNumberId ↔ String?
-
The Meta phone number ID.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnailUrl ↔ String?
-
The fetched Meta business profile thumbnail URL.
getter/setter pair
- wabaId ↔ String?
-
The WhatsApp Business Account ID.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited