defaultVariables property
A struct represents default variables at the start of the conversation, keyed by variable names.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Object?>? defaultVariables;