updatedVariables property

Map<String, Object?>? updatedVariables
getter/setter pair

A struct represents variables that were updated in the conversation, keyed by variable names.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? updatedVariables;