ClientCertificateSettings class
Settings for custom client certificates.
Constructors
- ClientCertificateSettings({String? passphrase, String? privateKey, String? tlsCertificate})
- ClientCertificateSettings.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- passphrase ↔ String?
-
The name of the SecretManager secret version resource storing the
passphrase to decrypt the private key.
getter/setter pair
- privateKey ↔ String?
-
The name of the SecretManager secret version resource storing the private
key encoded in PEM format.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tlsCertificate ↔ String?
-
The TLS certificate encoded in PEM format.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited