passphrase property
The name of the SecretManager secret version resource storing the passphrase to decrypt the private key.
Should be left unset if the private key is not encrypted. Format:
projects/{project}/secrets/{secret}/versions/{version}
Optional.
Implementation
core.String? passphrase;