authConfig property

EndUserAuthConfig? authConfig
getter/setter pair

Configures how authentication is handled in Integration Connectors.

By default, an admin authentication is passed in the Integration Connectors API requests. You can override it with a different end-user authentication config. Note: The Connection must have authentication override enabled in order to specify an EUC configuration here - otherwise, the ConnectorTool creation will fail. See https://cloud.google.com/application-integration/docs/configure-connectors-task#configure-authentication-override for details.

Optional.

Implementation

EndUserAuthConfig? authConfig;