description property

String? description
getter/setter pair

The description of the tool that can be used by the Agent to decide whether to call this ConnectorTool.

Optional.

Implementation

core.String? description;