connection property
The full resource name of the referenced Integration Connectors Connection.
Format: projects/{project}/locations/{location}/connections/{connection}
Required.
Implementation
core.String? connection;
The full resource name of the referenced Integration Connectors Connection.
Format: projects/{project}/locations/{location}/connections/{connection}
Required.
core.String? connection;