Conversation class

A conversation represents an interaction between an end user and the CES app.

Constructors

Conversation({String? appVersion, String? channelType, String? deployment, String? endTime, String? entryAgent, List<String>? inputTypes, String? languageCode, List<Message>? messages, String? name, String? source, String? startTime, int? turnCount, List<ConversationTurn>? turns})
Conversation.fromJson(Map json_)

Properties

appVersion ↔ String?
The version of the app used for processing the conversation.
getter/setter pair
channelType ↔ String?
Please use input_types instead.
getter/setter pair
deployment ↔ String?
The deployment of the app used for processing the conversation.
getter/setter pair
endTime ↔ String?
Timestamp when the conversation was completed.
getter/setter pair
entryAgent ↔ String?
The agent that initially handles the conversation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputTypes ↔ List<String>?
The input types of the conversation.
getter/setter pair
languageCode ↔ String?
The language code of the conversation.
getter/setter pair
messages ↔ List<Message>?
Use turns instead.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
Indicate the source of the conversation.
getter/setter pair
startTime ↔ String?
Timestamp when the conversation was created.
getter/setter pair
turnCount ↔ int?
The number of turns in the conversation.
getter/setter pair
turns ↔ List<ConversationTurn>?
The turns in the conversation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited