appVersion property
The version of the app used for processing the conversation.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}
Output only.
Implementation
core.String? appVersion;
The version of the app used for processing the conversation.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}
Output only.
core.String? appVersion;