deployment property
The deployment of the app used for processing the conversation.
Format:
projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}
Output only.
Implementation
core.String? deployment;
The deployment of the app used for processing the conversation.
Format:
projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}
Output only.
core.String? deployment;