retentionWindow property
Controls the retention window for the conversation.
If not set, the conversation will be retained for 365 days.
Optional.
Implementation
core.String? retentionWindow;
Controls the retention window for the conversation.
If not set, the conversation will be retained for 365 days.
Optional.
core.String? retentionWindow;