templateAttributes property
Variables or configurations referenced by the template engine during dynamic prompt generation.
This allows reconstructing the exact prompt sent to the model for this turn.
Optional.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Object?>? templateAttributes;