userIntendedText property
The intended ground-truth text from the Simulated Caller (Polysynth).
Only populated when word error rate metrics are enabled.
Optional.
Implementation
core.String? userIntendedText;
The intended ground-truth text from the Simulated Caller (Polysynth).
Only populated when word error rate metrics are enabled.
Optional.
core.String? userIntendedText;