DataStore class

A DataStore resource in Vertex AI Search.

Constructors

DataStore({DataStoreConnectorConfig? connectorConfig, String? createTime, String? displayName, String? documentProcessingMode, String? name, String? type})
DataStore.fromJson(Map json_)

Properties

connectorConfig DataStoreConnectorConfig?
The connector config for the data store connection.
getter/setter pair
createTime String?
Timestamp when the data store was created.
getter/setter pair
displayName String?
The display name of the data store.
getter/setter pair
documentProcessingMode String?
The document processing mode for the data store connection.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Full resource name of the DataStore.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of the data store.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited