DataStoreToolBoostSpecConditionBoostSpec class

Boost specification for a condition.

Properties

boost ↔ double?
Strength of the boost, which should be in [-1, 1].
getter/setter pair
boostControlSpec ↔ DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec?
Complex specification for custom ranking based on customer defined attribute value.
getter/setter pair
condition ↔ String?
An expression which specifies a boost condition.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited