DataStoreToolBoostSpecConditionBoostSpecBoostControlSpec class

Specification for custom ranking based on customer specified attribute value.

It provides more controls for customized ranking than the simple (condition, boost) combination above.

Properties

attributeType ↔ String?
The attribute type to be used to determine the boost amount.
getter/setter pair
controlPoints ↔ List<DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint>?
The control points used to define the curve.
getter/setter pair
fieldName ↔ String?
The name of the field whose value will be used to determine the boost amount.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interpolationType ↔ String?
The interpolation type to be applied to connect the control points listed below.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited