DataStoreToolBoostSpecConditionBoostSpecBoostControlSpecControlPoint class

The control points used to define the curve.

The curve defined through these control points can only be monotonically increasing or decreasing(constant values are acceptable).

Properties

attributeValue ↔ String?
Can be one of: 1.
getter/setter pair
boostAmount ↔ double?
The value between -1 to 1 by which to boost the score if the attribute_value evaluates to the value specified above.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited