DataStoreToolBoostSpecs class

Boost specifications to boost certain documents.

For more information, please refer to https://cloud.google.com/generative-ai-app-builder/docs/boosting.

Properties

dataStores ↔ List<String>?
The Data Store where the boosting configuration is applied.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ List<DataStoreToolBoostSpec>?
A list of boosting specifications.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited