DataStoreToolEngineSource class

Configuration for searching within an Engine, potentially targeting specific DataStores.

Properties

dataStoreSources ↔ List<DataStoreToolDataStoreSource>?
Use to target specific DataStores within the Engine.
getter/setter pair
engine ↔ String?
Full resource name of the Engine.
getter/setter pair
filter ↔ String?
A filter applied to the search across the Engine.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited