DataStoreToolModalityConfig class

If specified, will apply the given configuration for the specified modality.

Properties

groundingConfig ↔ DataStoreToolGroundingConfig?
The grounding configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modalityType ↔ String?
The modality type.
getter/setter pair
rewriterConfig ↔ DataStoreToolRewriterConfig?
The rewriter config.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippetsConfig ↔ DataStoreToolSnippetsConfig?
The snippets configuration.
getter/setter pair
summarizationConfig ↔ DataStoreToolSummarizationConfig?
The summarization config.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited