DataStoreToolRewriterConfig class

Rewriter configuration.

Constructors

DataStoreToolRewriterConfig({bool? disabled, ModelSettings? modelSettings, String? prompt})
DataStoreToolRewriterConfig.fromJson(Map json_)

Properties

disabled ↔ bool?
Whether the rewriter is disabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modelSettings ↔ ModelSettings?
Configurations for the LLM model.
getter/setter pair
prompt ↔ String?
The prompt definition.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited