Deployment class

A deployment represents an immutable, queryable version of the app.

It is used to deploy an app version with a specific channel profile.

Constructors

Deployment({String? appVersion, ChannelProfile? channelProfile, String? createTime, String? displayName, String? etag, ExperimentConfig? experimentConfig, InstagramCredentials? instagramCredentials, String? modality, ModelSettings? modelSettings, String? name, String? updateTime, WhatsAppCredentials? whatsappCredentials})
Deployment.fromJson(Map json_)

Properties

appVersion String?
The resource name of the app version to deploy.
getter/setter pair
channelProfile ChannelProfile?
The channel profile used in the deployment.
getter/setter pair
createTime String?
Timestamp when this deployment was created.
getter/setter pair
displayName String?
Display name of the deployment.
getter/setter pair
etag String?
Etag used to ensure the object hasn't changed during a read-modify-write operation.
getter/setter pair
experimentConfig ExperimentConfig?
Experiment configuration for the deployment.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
instagramCredentials InstagramCredentials?
Input only.
getter/setter pair
modality String?
The modality of the deployment.
getter/setter pair
modelSettings ModelSettings?
Model settings for the deployment.
getter/setter pair
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTime String?
Timestamp when this deployment was last updated.
getter/setter pair
whatsappCredentials WhatsAppCredentials?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited