EndUserAuthConfigOauth2JwtBearerConfig class
JWT Profile Oauth 2.0 Authorization Grant authentication configuration.
Constructors
- EndUserAuthConfigOauth2JwtBearerConfig({String? clientKey, String? issuer, String? subject})
- EndUserAuthConfigOauth2JwtBearerConfig.fromJson(Map json_)
Properties
- clientKey ↔ String?
-
Client parameter name to pass through.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- issuer ↔ String?
-
Issuer parameter name to pass through.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject ↔ String?
-
Subject parameter name to pass through.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited