ErrorHandlingSettings class

Settings to describe how errors should be handled in the app.

Constructors

ErrorHandlingSettings({ErrorHandlingSettingsEndSessionConfig? endSessionConfig, String? errorHandlingStrategy, ErrorHandlingSettingsFallbackResponseConfig? fallbackResponseConfig})
ErrorHandlingSettings.fromJson(Map json_)

Properties

endSessionConfig ErrorHandlingSettingsEndSessionConfig?
Configuration for ending the session in case of system errors (e.g. LLM errors).
getter/setter pair
errorHandlingStrategy String?
The strategy to use for error handling.
getter/setter pair
fallbackResponseConfig ErrorHandlingSettingsFallbackResponseConfig?
Configuration for handling fallback responses.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited