maxFallbackAttempts property
The maximum number of fallback attempts to make before the agent emitting EndSession Signal.
Optional.
Implementation
core.int? maxFallbackAttempts;
The maximum number of fallback attempts to make before the agent emitting EndSession Signal.
Optional.
core.int? maxFallbackAttempts;