invalid property
The example may become invalid if referencing resources are deleted.
Invalid examples will not be used as few-shot examples.
Output only.
Implementation
core.bool? invalid;
The example may become invalid if referencing resources are deleted.
Invalid examples will not be used as few-shot examples.
Output only.
core.bool? invalid;