args property

Map<String, Object?>? args
getter/setter pair

The input parameters and values for the tool in JSON object format.

Optional.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? args;