variables property

Map<String, Object?>? variables
getter/setter pair

The variables that are available for the tool execution.

Optional.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? variables;