ExecuteToolResponse class

Response message for ToolService.ExecuteTool.

Constructors

ExecuteToolResponse({Citations? citations, GoogleSearchSuggestions? googleSearchSuggestions, Map<String, Object?>? response, String? tool, ToolsetTool? toolsetTool, Map<String, Object?>? variables})
ExecuteToolResponse.fromJson(Map json_)

Properties

citations Citations?
Citations that provide the source information for the tool's execution.
getter/setter pair
googleSearchSuggestions GoogleSearchSuggestions?
The suggestions returned from Google Search as a result of invoking the Google Search Tool during the tool execution.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
response Map<String, Object?>?
The tool execution result in JSON object format.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tool String?
The name of the tool that got executed.
getter/setter pair
toolsetTool ToolsetTool?
The toolset tool that got executed.
getter/setter pair
variables Map<String, Object?>?
The variable values at the end of the tool execution.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited