googleSearchSuggestions property

GoogleSearchSuggestions? googleSearchSuggestions
getter/setter pair

The suggestions returned from Google Search as a result of invoking the Google Search Tool during the tool execution.

Implementation

GoogleSearchSuggestions? googleSearchSuggestions;