variables property

Map<String, Object?>? variables
getter/setter pair

The variable values at the end of the tool execution.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? variables;