ExperimentConfig class
Experiment for the deployment.
Constructors
- ExperimentConfig({ExperimentConfigVersionRelease? versionRelease})
- ExperimentConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- versionRelease ↔ ExperimentConfigVersionRelease?
-
Version release for the experiment.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited