appVersion property
The resource name of the app version to export.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}.
Optional.
Implementation
core.String? appVersion;
The resource name of the app version to export.
Format:
projects/{project}/locations/{location}/apps/{app}/versions/{version}.
Optional.
core.String? appVersion;