ExpressionCondition class

Expression condition based on session state.

Constructors

ExpressionCondition({String? expression})
ExpressionCondition.fromJson(Map json_)

Properties

expression String?
The string representation of cloud.api.Expression condition.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited