GoogleSearchSuggestions class

Search suggestions from Google Search Tool.

Constructors

GoogleSearchSuggestions({List<String>? htmls, List<WebSearchQuery>? webSearchQueries})
GoogleSearchSuggestions.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
htmls List<String>?
Compliant HTML and CSS styling for search suggestions.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webSearchQueries List<WebSearchQuery>?
List of queries used to perform the google search along with the search result URIs forming the search suggestions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited