htmls property

List<String>? htmls
getter/setter pair

Compliant HTML and CSS styling for search suggestions.

The provided HTML and CSS automatically adapts to your device settings, displaying in either light or dark mode indicated by @media(prefers-color-scheme).

Implementation

core.List<core.String>? htmls;