webSearchQueries property
List of queries used to perform the google search along with the search result URIs forming the search suggestions.
Implementation
core.List<WebSearchQuery>? webSearchQueries;
List of queries used to perform the google search along with the search result URIs forming the search suggestions.
core.List<WebSearchQuery>? webSearchQueries;