promptConfig property
Prompt instructions passed to planner on how the search results should be processed for text and voice.
Optional.
Implementation
GoogleSearchToolPromptConfig? promptConfig;
Prompt instructions passed to planner on how the search results should be processed for text and voice.
Optional.
GoogleSearchToolPromptConfig? promptConfig;