textPrompt property
Defines the prompt used for the system instructions when interacting with the agent in chat conversations.
If not set, default prompt will be used.
Optional.
Implementation
core.String? textPrompt;
Defines the prompt used for the system instructions when interacting with the agent in chat conversations.
If not set, default prompt will be used.
Optional.
core.String? textPrompt;