voicePrompt property
Defines the prompt used for the system instructions when interacting with the agent in voice conversations.
If not set, default prompt will be used.
Optional.
Implementation
core.String? voicePrompt;
Defines the prompt used for the system instructions when interacting with the agent in voice conversations.
If not set, default prompt will be used.
Optional.
core.String? voicePrompt;