codeCallback property
Guardrail that potentially blocks the conversation based on the result of the callback execution.
Optional.
Implementation
GuardrailCodeCallback? codeCallback;
Guardrail that potentially blocks the conversation based on the result of the callback execution.
Optional.
GuardrailCodeCallback? codeCallback;