llmPolicy property
Guardrail that blocks the conversation if the LLM response is considered violating the policy based on the LLM classification.
Optional.
Implementation
GuardrailLlmPolicy? llmPolicy;
Guardrail that blocks the conversation if the LLM response is considered violating the policy based on the LLM classification.
Optional.
GuardrailLlmPolicy? llmPolicy;