llmPromptSecurity property
Guardrail that blocks the conversation if the prompt is considered unsafe based on the LLM classification.
Optional.
Implementation
GuardrailLlmPromptSecurity? llmPromptSecurity;
Guardrail that blocks the conversation if the prompt is considered unsafe based on the LLM classification.
Optional.
GuardrailLlmPromptSecurity? llmPromptSecurity;