modelSafety property
Guardrail that blocks the conversation if the LLM response is considered unsafe based on the model safety settings.
Optional.
Implementation
GuardrailModelSafety? modelSafety;
Guardrail that blocks the conversation if the LLM response is considered unsafe based on the model safety settings.
Optional.
GuardrailModelSafety? modelSafety;