beforeModelCallback property

Callback? beforeModelCallback
getter/setter pair

The callback to execute before the model is called.

If there are multiple calls to the model, the callback will be executed multiple times. Each callback function is expected to return a structure (e.g., a dict or object) containing at least: - 'decision': Either 'OK' or 'TRIGGER'. - 'reason': A string explaining the decision. A 'TRIGGER' decision may halt further processing.

Optional.

Implementation

Callback? beforeModelCallback;