failOpen property
If an error occurs during the policy check, fail open and do not trigger the guardrail.
Optional.
Implementation
core.bool? failOpen;
If an error occurs during the policy check, fail open and do not trigger the guardrail.
Optional.
core.bool? failOpen;