GuardrailLlmPromptSecurity class
Guardrail that blocks the conversation if the input is considered unsafe based on the LLM classification.
Constructors
- GuardrailLlmPromptSecurity({GuardrailLlmPolicy? customPolicy, GuardrailLlmPromptSecurityDefaultSecuritySettings? defaultSettings, bool? failOpen})
- GuardrailLlmPromptSecurity.fromJson(Map json_)
Properties
- customPolicy ↔ GuardrailLlmPolicy?
-
Use a user-defined LlmPolicy to configure the security guardrail.
getter/setter pair
- defaultSettings ↔ GuardrailLlmPromptSecurityDefaultSecuritySettings?
-
Use the system's predefined default security settings.
getter/setter pair
- failOpen ↔ bool?
-
Determines the behavior when the guardrail encounters an LLM error.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited