GuardrailLlmPromptSecurityDefaultSecuritySettings class
Configuration for default system security settings.
Constructors
- GuardrailLlmPromptSecurityDefaultSecuritySettings({String? defaultPromptTemplate})
- GuardrailLlmPromptSecurityDefaultSecuritySettings.fromJson(Map json_)
Properties
- defaultPromptTemplate ↔ String?
-
The default prompt template used by the system.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited