defaultPromptTemplate property

String? defaultPromptTemplate
getter/setter pair

The default prompt template used by the system.

This field is for display purposes to show the user what prompt the system uses by default. It is OUTPUT_ONLY.

Output only.

Implementation

core.String? defaultPromptTemplate;