GuardrailModelSafety class

Model safety settings overrides.

When this is set, it will override the default settings and trigger the guardrail if the response is considered unsafe.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetySettings List<GuardrailModelSafetySafetySetting>?
List of safety settings.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited