ImportAppRequest class

Request message for AgentService.ImportApp.

Constructors

ImportAppRequest({String? appContent, String? appId, String? displayName, String? gcsUri, bool? ignoreAppLock, ImportAppRequestImportOptions? importOptions})
ImportAppRequest.fromJson(Map json_)

Properties

appContent ↔ String?
Raw bytes representing the compressed zip file with the app folder structure.
getter/setter pair
appContentAsBytes ↔ List<int>
getter/setter pair
appId ↔ String?
The ID to use for the imported app.
getter/setter pair
displayName ↔ String?
The display name of the app to import.
getter/setter pair
gcsUri ↔ String?
The Google Cloud Storage URI from which to import app.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreAppLock ↔ bool?
Flag for overriding the app lock during import.
getter/setter pair
importOptions ↔ ImportAppRequestImportOptions?
Options governing the import process for the app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited