ignoreAppLock property
Flag for overriding the app lock during import.
If set to true, the import process will ignore the app lock.
Optional.
Implementation
core.bool? ignoreAppLock;
Flag for overriding the app lock during import.
If set to true, the import process will ignore the app lock.
Optional.
core.bool? ignoreAppLock;