fallbackAction property

  1. @Deprecated('Not supported. Member documentation may have more information.')
String? fallbackAction
getter/setter pair

Deprecated: This feature is no longer supported.

Use enable_multilingual_support instead to improve handling of multilingual input. The action to perform when an agent receives input in an unsupported language. This can be a predefined action or a custom tool call. Valid values are: - A tool's full resource name, which triggers a specific tool execution. - A predefined system action, such as "escalate" or "exit", which triggers an EndSession signal with corresponding metadata to terminate the conversation.

Optional.

Implementation

@core.Deprecated(
  'Not supported. Member documentation may have more information.',
)
core.String? fallbackAction;