LfA2aV1APIKeySecurityScheme class

Defines a security scheme using an API key.

Constructors

LfA2aV1APIKeySecurityScheme({String? description, String? location, String? name})
LfA2aV1APIKeySecurityScheme.fromJson(Map json_)

Properties

description String?
An optional description for the security scheme.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location String?
The location of the API key.
getter/setter pair
name String?
The name of the header, query, or cookie parameter to be used.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited