LfA2aV1AgentCapabilities class

Defines optional capabilities supported by an agent.

Constructors

LfA2aV1AgentCapabilities({bool? extendedAgentCard, List<LfA2aV1AgentExtension>? extensions, bool? pushNotifications, bool? streaming})
LfA2aV1AgentCapabilities.fromJson(Map json_)

Properties

extendedAgentCard bool?
Indicates if the agent supports providing an extended agent card when authenticated.
getter/setter pair
extensions List<LfA2aV1AgentExtension>?
A list of protocol extensions supported by the agent.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pushNotifications bool?
Indicates if the agent supports sending push notifications for asynchronous task updates.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streaming bool?
Indicates if the agent supports streaming responses.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited