pushNotifications property
Indicates if the agent supports sending push notifications for asynchronous task updates.
Implementation
core.bool? pushNotifications;
Indicates if the agent supports sending push notifications for asynchronous task updates.
core.bool? pushNotifications;