securitySchemes property
The security scheme details used for authenticating with this agent.
Implementation
core.Map<core.String, LfA2aV1SecurityScheme>? securitySchemes;
The security scheme details used for authenticating with this agent.
core.Map<core.String, LfA2aV1SecurityScheme>? securitySchemes;