LfA2aV1AgentCardSignature class
AgentCardSignature represents a JWS signature of an AgentCard.
This follows the JSON format of an RFC 7515 JSON Web Signature (JWS).
Constructors
-
LfA2aV1AgentCardSignature({Map<
String, Object?> ? header, String? protected, String? signature}) - LfA2aV1AgentCardSignature.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
header
↔ Map<
String, Object?> ? -
The unprotected JWS header values.
getter/setter pair
- protected ↔ String?
-
The protected JWS header for the signature.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature ↔ String?
-
The computed signature, base64url-encoded.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited