LfA2aV1AgentExtension class

A declaration of a protocol extension supported by an Agent.

Constructors

LfA2aV1AgentExtension({String? description, Map<String, Object?>? params, bool? required, String? uri})
LfA2aV1AgentExtension.fromJson(Map json_)

Properties

description String?
A human-readable description of how this agent uses the extension.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
params Map<String, Object?>?
Extension-specific configuration parameters.
getter/setter pair
required bool?
If true, the client must understand and comply with the extension's requirements.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
The unique URI identifying the extension.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited