LfA2aV1AgentProvider class

Represents the service provider of an agent.

Constructors

LfA2aV1AgentProvider({String? organization, String? url})
LfA2aV1AgentProvider.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
organization String?
The name of the agent provider's organization.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
A URL for the agent provider's website or relevant documentation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited