LfA2aV1AuthenticationInfo class

Defines authentication details, used for push notifications.

Constructors

LfA2aV1AuthenticationInfo({String? credentials, String? scheme})
LfA2aV1AuthenticationInfo.fromJson(Map json_)

Properties

credentials String?
Push Notification credentials.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme String?
HTTP Authentication Scheme from the IANA registry.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited