LfA2aV1AuthorizationCodeOAuthFlow class

Defines configuration details for the OAuth 2.0 Authorization Code flow.

Constructors

LfA2aV1AuthorizationCodeOAuthFlow({String? authorizationUrl, bool? pkceRequired, String? refreshUrl, Map<String, String>? scopes, String? tokenUrl})
LfA2aV1AuthorizationCodeOAuthFlow.fromJson(Map json_)

Properties

authorizationUrl String?
The authorization URL to be used for this flow.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pkceRequired bool?
Indicates if PKCE (RFC 7636) is required for this flow.
getter/setter pair
refreshUrl String?
The URL to be used for obtaining refresh tokens.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes Map<String, String>?
The available scopes for the OAuth2 security scheme.
getter/setter pair
tokenUrl String?
The token URL to be used for this flow.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited