pkceRequired property
Indicates if PKCE (RFC 7636) is required for this flow.
PKCE should always be used for public clients and is recommended for all clients.
Implementation
core.bool? pkceRequired;
Indicates if PKCE (RFC 7636) is required for this flow.
PKCE should always be used for public clients and is recommended for all clients.
core.bool? pkceRequired;