LfA2aV1ClientCredentialsOAuthFlow class

Defines configuration details for the OAuth 2.0 Client Credentials flow.

Properties

hashCode int
The hash code for this object.
no setterinherited
refreshUrl String?
The URL to be used for obtaining refresh tokens.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes Map<String, String>?
The available scopes for the OAuth2 security scheme.
getter/setter pair
tokenUrl String?
The token URL to be used for this flow.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited