LfA2aV1Message class

Message is one unit of communication between client and server.

It can be associated with a context and/or a task. For server messages, context_id must be provided, and task_id only if a task was created. For client messages, both fields are optional, with the caveat that if both are provided, they have to match (the context_id has to be the one that is set on the task). If only task_id is provided, the server will infer context_id from it.

Constructors

LfA2aV1Message({String? contextId, List<String>? extensions, String? messageId, Map<String, Object?>? metadata, List<LfA2aV1Part>? parts, List<String>? referenceTaskIds, String? role, String? taskId})
LfA2aV1Message.fromJson(Map json_)

Properties

contextId String?
The context id of the message.
getter/setter pair
extensions List<String>?
The URIs of extensions that are present or contributed to this Message.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
messageId String?
The unique identifier (e.g. UUID) of the message.
getter/setter pair
metadata Map<String, Object?>?
Any metadata to provide along with the message.
getter/setter pair
parts List<LfA2aV1Part>?
Parts is the container of the message content.
getter/setter pair
referenceTaskIds List<String>?
A list of task IDs that this message references for additional context.
getter/setter pair
role String?
Identifies the sender of the message.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskId String?
The task id of the message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited