contextId property
The context id of the message.
If set, the message will be associated with the given context.
Optional.
Implementation
core.String? contextId;
The context id of the message.
If set, the message will be associated with the given context.
Optional.
core.String? contextId;