LfA2aV1OpenIdConnectSecurityScheme class

Defines a security scheme using OpenID Connect.

Properties

description String?
An optional description for the security scheme.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
openIdConnectUrl String?
The OpenID Connect Discovery URL for the OIDC provider's metadata.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited