LfA2aV1Part class
Part represents a container for a section of communication content.
Parts can be purely textual, some sort of file (image, video, etc) or a structured data blob (i.e. JSON).
Constructors
Properties
- data ↔ Object?
-
Arbitrary structured
dataas a JSON value (object, array, string, number, boolean, or null).getter/setter pair - filename ↔ String?
-
An optional
filenamefor the file (e.g., "document.pdf").getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- mediaType ↔ String?
-
The
media_type(MIME type) of the part content (e.g., "text/plain", "application/json", "image/png").getter/setter pair -
metadata
↔ Map<
String, Object?> ? -
metadata associated with this part.
getter/setter pair
- raw ↔ String?
-
The
rawbyte content of a file.getter/setter pair -
rawAsBytes
↔ List<
int> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String?
-
The string content of the
textpart.getter/setter pair - url ↔ String?
-
A
urlpointing to the file's content.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited