returnImmediately property

bool? returnImmediately
getter/setter pair

If true, the operation returns immediately after creating the task, even if processing is still in progress.

If false (default), the operation MUST wait until the task reaches a terminal (COMPLETED, FAILED, CANCELED, REJECTED) or interrupted (INPUT_REQUIRED, AUTH_REQUIRED) state before returning.

Implementation

core.bool? returnImmediately;