LfA2aV1SendMessageResponse class

Represents the response for the SendMessage method.

Properties

hashCode int
The hash code for this object.
no setterinherited
message LfA2aV1Message?
A message from the agent.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task LfA2aV1Task?
The task created or updated by the message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited