LfA2aV1Task class
Task is the core unit of action for A2A.
It has a current status and when results are created for the task they are stored in the artifact. If there are multiple turns for a task, these are stored in history.
Constructors
-
LfA2aV1Task({List<
LfA2aV1Artifact> ? artifacts, String? contextId, List<LfA2aV1Message> ? history, String? id, Map<String, Object?> ? metadata, LfA2aV1TaskStatus? status}) - LfA2aV1Task.fromJson(Map json_)
Properties
-
artifacts
↔ List<
LfA2aV1Artifact> ? -
A set of output artifacts for a
Task.getter/setter pair - contextId ↔ String?
-
Unique identifier (e.g. UUID) for the contextual collection of
interactions (tasks and messages).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
history
↔ List<
LfA2aV1Message> ? -
protolint:disable REPEATED_FIELD_NAMES_PLURALIZED The history of
interactions from a
Task.getter/setter pair - id ↔ String?
-
Unique identifier (e.g. UUID) for the task, generated by the server for a
new task.
getter/setter pair
-
metadata
↔ Map<
String, Object?> ? -
protolint:enable REPEATED_FIELD_NAMES_PLURALIZED A key/value object to
store custom metadata about a task.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ LfA2aV1TaskStatus?
-
The current status of a
Task, includingstateand amessage.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited