tenant property

String? tenant
getter/setter pair

Opaque routing identifier.

Must match the tenant value from the selected AgentInterface in the Agent Card when that field is set.

Optional.

Implementation

core.String? tenant;