LfA2aV1TaskStatus class

A container for the status of a task

Constructors

LfA2aV1TaskStatus({LfA2aV1Message? message, String? state, String? timestamp})
LfA2aV1TaskStatus.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
message LfA2aV1Message?
A message associated with the status.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The current state of this task.
getter/setter pair
timestamp String?
ISO 8601 Timestamp when the status was recorded.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited