state property

String? state
getter/setter pair

The current state of this task.

Required. Possible string values are:

  • "TASK_STATE_UNSPECIFIED" : The task is in an unknown or indeterminate state.
  • "TASK_STATE_SUBMITTED" : Indicates that a task has been successfully submitted and acknowledged.
  • "TASK_STATE_WORKING" : Indicates that a task is actively being processed by the agent.
  • "TASK_STATE_COMPLETED" : Indicates that a task has finished successfully. This is a terminal state.
  • "TASK_STATE_FAILED" : Indicates that a task has finished with an error. This is a terminal state.
  • "TASK_STATE_CANCELED" : Indicates that a task was canceled before completion. This is a terminal state.
  • "TASK_STATE_INPUT_REQUIRED" : Indicates that the agent requires additional user input to proceed. This is an interrupted state.
  • "TASK_STATE_REJECTED" : Indicates that the agent has decided to not perform the task. This may be done during initial task creation or later once an agent has determined it can't or won't proceed. This is a terminal state.
  • "TASK_STATE_AUTH_REQUIRED" : Indicates that authentication is required to proceed. This is an interrupted state.

Implementation

core.String? state;