ListAppsResponse class

Response message for AgentService.ListApps.

Constructors

ListAppsResponse({List<App>? apps, String? nextPageToken, List<String>? unreachable})
ListAppsResponse.fromJson(Map json_)

Properties

apps List<App>?
The list of apps.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextPageToken String?
A token that can be sent as ListAppsRequest.page_token to retrieve the next page.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreachable List<String>?
Unordered list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited