ListGuardrailsResponse class

Response message for AgentService.ListGuardrails.

Constructors

ListGuardrailsResponse({List<Guardrail>? guardrails, String? nextPageToken})
ListGuardrailsResponse.fromJson(Map json_)

Properties

guardrails List<Guardrail>?
The list of guardrails.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextPageToken String?
A token that can be sent as ListGuardrailsRequest.page_token to retrieve the next page.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited