ListToolsetsResponse class

Response message for AgentService.ListToolsets.

Constructors

ListToolsetsResponse({String? nextPageToken, List<Toolset>? toolsets})
ListToolsetsResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
nextPageToken String?
A token that can be sent as ListToolsetsRequest.page_token to retrieve the next page.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolsets List<Toolset>?
The list of toolsets.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited