nextPageToken property
A token that can be sent as ListToolsetsRequest.page_token to retrieve the next page.
Absence of this field indicates there are no subsequent pages.
Implementation
core.String? nextPageToken;
A token that can be sent as ListToolsetsRequest.page_token to retrieve the next page.
Absence of this field indicates there are no subsequent pages.
core.String? nextPageToken;