bigqueryExportSettings property
Configures the BigQuery export behaviors for the app.
The conversation data is subject to redaction as configured in RedactionConfig.
Optional.
Implementation
BigQueryExportSettings? bigqueryExportSettings;
Configures the BigQuery export behaviors for the app.
The conversation data is subject to redaction as configured in RedactionConfig.
Optional.
BigQueryExportSettings? bigqueryExportSettings;