cloudLoggingSettings property
Settings to describe the Cloud Logging behaviors for the app.
Optional.
Implementation
CloudLoggingSettings? cloudLoggingSettings;
Settings to describe the Cloud Logging behaviors for the app.
Optional.
CloudLoggingSettings? cloudLoggingSettings;