conversationLoggingSettings property
Settings to describe the conversation logging behaviors for the app.
Optional.
Implementation
ConversationLoggingSettings? conversationLoggingSettings;
Settings to describe the conversation logging behaviors for the app.
Optional.
ConversationLoggingSettings? conversationLoggingSettings;