metricAnalysisSettings property
Settings to describe the conversation data collection behaviors for the LLM analysis pipeline for the app.
Optional.
Implementation
MetricAnalysisSettings? metricAnalysisSettings;
Settings to describe the conversation data collection behaviors for the LLM analysis pipeline for the app.
Optional.
MetricAnalysisSettings? metricAnalysisSettings;