McpTool class

Constructors

McpTool({ApiAuthentication? apiAuthentication, Map<String, String>? customHeaders, String? description, Schema? inputSchema, String? name, String? nameOverride, Schema? outputSchema, String? serverAddress, ServiceDirectoryConfig? serviceDirectoryConfig, String? state, TlsConfig? tlsConfig})
McpTool.fromJson(Map json_)

Properties

apiAuthentication ApiAuthentication?
Authentication information required to execute the tool against the MCP server.
getter/setter pair
customHeaders Map<String, String>?
The custom headers to send in the request to the MCP server.
getter/setter pair
description String?
The description of the MCP tool.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inputSchema Schema?
The schema of the input arguments of the MCP tool.
getter/setter pair
name String?
The name of the MCP tool.
getter/setter pair
nameOverride String?
The name override of the MCP tool.
getter/setter pair
outputSchema Schema?
The schema of the output arguments of the MCP tool.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverAddress String?
The server address of the MCP server, e.g., "https://example.com/mcp/".
getter/setter pair
serviceDirectoryConfig ServiceDirectoryConfig?
Service Directory configuration for VPC-SC, used to resolve service names within a perimeter.
getter/setter pair
state String?
The dynamic availability state of the tool on the external server.
getter/setter pair
tlsConfig TlsConfig?
The TLS configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited