McpToolOverride class

Overrides associated with a given tool in a Toolset.

This enables "pinning" or "overriding" of tool definitions from the external dynamic server.

Constructors

McpToolOverride({String? descriptionOverride, String? nameOverride, McpToolDefinition? snapshot, String? tool})
McpToolOverride.fromJson(Map json_)

Properties

descriptionOverride String?
If present, this tool uses this description instead of the original description from the server.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nameOverride String?
If present, this tool uses this name in the Agent instead of the original name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshot McpToolDefinition?
If present, this tool is "Pinned" and uses the snapshot values as fallbacks if the server becomes temporarily unavailable or if no Override is present.
getter/setter pair
tool String?
The original name of the tool as it is emitted by the MCP server.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited