McpToolset class

A toolset that contains a list of tools that are offered by the MCP server.

Constructors

McpToolset({ApiAuthentication? apiAuthentication, Map<String, String>? customHeaders, String? serverAddress, ServiceDirectoryConfig? serviceDirectoryConfig, TlsConfig? tlsConfig, List<McpToolOverride>? toolOverrides})
McpToolset.fromJson(Map json_)

Properties

apiAuthentication ApiAuthentication?
Authentication information required to access tools and execute a tool against the MCP server.
getter/setter pair
customHeaders Map<String, String>?
The custom headers to send in the request to the MCP server.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverAddress String?
The address of the MCP server, for example, "https://example.com/mcp/".
getter/setter pair
serviceDirectoryConfig ServiceDirectoryConfig?
Service Directory configuration for VPC-SC, used to resolve service names within a perimeter.
getter/setter pair
tlsConfig TlsConfig?
The TLS configuration.
getter/setter pair
toolOverrides List<McpToolOverride>?
Overrides for individual tools within this toolset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited