apiAuthentication property

ApiAuthentication? apiAuthentication
getter/setter pair

Authentication information required to access tools and execute a tool against the MCP server.

For bearer token authentication, the token applies only to tool execution, not to listing tools. This requires that tools can be listed without authentication.

Optional.

Implementation

ApiAuthentication? apiAuthentication;