Message class

A message within a conversation.

Constructors

Message({List<Chunk>? chunks, String? eventTime, String? role})
Message.fromJson(Map json_)

Properties

chunks ↔ List<Chunk>?
Content of the message as a series of chunks.
getter/setter pair
eventTime ↔ String?
Timestamp when the message was sent or received.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
role ↔ String?
The role within the conversation, e.g., user, agent.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited