eventTime property
Timestamp when the message was sent or received.
Should not be used if the message is part of an example.
Optional.
Implementation
core.String? eventTime;
Timestamp when the message was sent or received.
Should not be used if the message is part of an example.
Optional.
core.String? eventTime;