MockConfig class

Mock tool calls configuration for the session.

Constructors

MockConfig({List<MockedToolCall>? mockedToolCalls, String? unmatchedToolCallBehavior})
MockConfig.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
mockedToolCalls List<MockedToolCall>?
All tool calls to mock for the duration of the session.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unmatchedToolCallBehavior String?
Beavhior for tool calls that don't match any args patterns in mocked_tool_calls.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited