unmatchedToolCallBehavior property

String? unmatchedToolCallBehavior
getter/setter pair

Beavhior for tool calls that don't match any args patterns in mocked_tool_calls.

Required. Possible string values are:

  • "UNMATCHED_TOOL_CALL_BEHAVIOR_UNSPECIFIED" : Default value. This value is unused.
  • "FAIL" : Throw an error for any tool calls that don't match a mock expected input pattern.
  • "PASS_THROUGH" : For unmatched tool calls, pass the tool call through to real tool.

Implementation

core.String? unmatchedToolCallBehavior;