expectedArgsPattern property

Map<String, Object?>? expectedArgsPattern
getter/setter pair

A pattern to match against the args / inputs of all dispatched tool calls.

If the tool call inputs match this pattern, then mock output will be returned.

Required.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? expectedArgsPattern;