mockResponse property

Map<String, Object?>? mockResponse
getter/setter pair

The mock response / output to return if the tool call args / inputs match the pattern.

Optional.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? mockResponse;