ModelSettings class
Model settings contains various configurations for the LLM model.
Constructors
- ModelSettings({String? model, double? temperature})
- ModelSettings.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- model ↔ String?
-
The LLM model that the agent should use.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperature ↔ double?
-
If set, this temperature will be used for the LLM model.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited