model property
The LLM model that the agent should use.
If not set, the agent will inherit the model from its parent agent.
Optional.
Implementation
core.String? model;
The LLM model that the agent should use.
If not set, the agent will inherit the model from its parent agent.
Optional.
core.String? model;