OAuthConfig class

Configurations for authentication with OAuth.

Constructors

OAuthConfig({String? clientId, String? clientSecretVersion, String? oauthGrantType, List<String>? scopes, String? tokenEndpoint})
OAuthConfig.fromJson(Map json_)

Properties

clientId ↔ String?
The client ID from the OAuth provider.
getter/setter pair
clientSecretVersion ↔ String?
The name of the SecretManager secret version resource storing the client secret.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oauthGrantType ↔ String?
OAuth grant types.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>?
The OAuth scopes to grant.
getter/setter pair
tokenEndpoint ↔ String?
The token endpoint in the OAuth provider to exchange for an access token.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited