OpenApiTool class

A remote API tool defined by an OpenAPI schema.

Constructors

OpenApiTool({ApiAuthentication? apiAuthentication, String? description, bool? ignoreUnknownFields, String? name, String? openApiSchema, ServiceDirectoryConfig? serviceDirectoryConfig, TlsConfig? tlsConfig, String? url})
OpenApiTool.fromJson(Map json_)

Properties

apiAuthentication ApiAuthentication?
Authentication information required by the API.
getter/setter pair
description String?
The description of the tool.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ignoreUnknownFields bool?
If true, the agent will ignore unknown fields in the API response.
getter/setter pair
name String?
The name of the tool.
getter/setter pair
openApiSchema String?
The OpenAPI schema in JSON or YAML format.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceDirectoryConfig ServiceDirectoryConfig?
Service Directory configuration.
getter/setter pair
tlsConfig TlsConfig?
The TLS configuration.
getter/setter pair
url String?
The server URL of the Open API schema.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited