description property
The description of the tool.
If not provided, the description of the tool will be derived from the
OpenAPI schema, from operation.description or operation.summary.
Optional.
Implementation
core.String? description;
The description of the tool.
If not provided, the description of the tool will be derived from the
OpenAPI schema, from operation.description or operation.summary.
Optional.
core.String? description;