name property
The name of the tool.
If not provided, the name of the tool will be derived from the OpenAPI
schema, from operation.operationId.
Optional.
Implementation
core.String? name;
The name of the tool.
If not provided, the name of the tool will be derived from the OpenAPI
schema, from operation.operationId.
Optional.
core.String? name;