tlsConfig property
The TLS configuration.
Includes the custom server certificates that the client will trust.
Optional.
Implementation
TlsConfig? tlsConfig;
The TLS configuration.
Includes the custom server certificates that the client will trust.
Optional.
TlsConfig? tlsConfig;