url property

String? url
getter/setter pair

The server URL of the Open API schema.

This field is only set in tools in the environment dependencies during the export process if the schema contains a server url. During the import process, if this url is present in the environment dependencies and the schema has the $env_var placeholder, it will replace the placeholder in the schema.

Optional.

Implementation

core.String? url;