OutputAudioConfig class

OutputAudioConfig configures how the CES agent should synthesize outgoing audio responses.

Constructors

OutputAudioConfig({String? audioEncoding, int? sampleRateHertz})
OutputAudioConfig.fromJson(Map json_)

Properties

audioEncoding String?
The encoding of the output audio data.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRateHertz int?
The sample rate (in Hertz) of the output audio data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited