ProjectsLocationsAppsAgentsResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(Agent request, String parent, {String? agentId, String? $fields})
→ Future<Agent>
-
Creates a new agent in the given app.
-
delete(String name, {String? etag, bool? force, String? $fields})
→ Future<Empty>
-
Deletes the specified agent.
-
get(String name, {String? $fields})
→ Future<Agent>
-
Gets details of the specified agent.
-
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields})
→ Future<ListAgentsResponse>
-
Lists agents in the given app.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(Agent request, String name, {String? updateMask, String? $fields})
→ Future<Agent>
-
Updates the specified agent.
-
toString()
→ String
-
A string representation of this object.
inherited