list method
Lists agents in the given app.
Request parameters:
parent - Required. The resource name of the app to list agents from.
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+$.
filter - Optional. Filter to be applied when listing the agents. See
https://google.aip.dev/160 for more details.
orderBy - Optional. Field to sort by. Only "name" and "create_time" is
supported. See https://google.aip.dev/132#ordering for more details.
pageSize - Optional. Requested page size. Server may return fewer items
than requested. If unspecified, server will pick an appropriate default.
pageToken - Optional. The next_page_token value returned from a previous
list AgentService.ListAgents call.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListAgentsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListAgentsResponse> list(
core.String parent, {
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/agents';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListAgentsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}