delete method
Deletes the specified conversation.
Request parameters:
name - Required. The resource name of the conversation to delete.
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+/conversations/\[^/\]+$.
source - Optional. Indicate the source of the conversation. If not set,
Source.Live will be applied by default.
Possible string values are:
- "SOURCE_UNSPECIFIED" : Unspecified source.
- "LIVE" : The conversation is from the live end user.
- "SIMULATOR" : The conversation is from the simulator.
- "EVAL" : The conversation is from the evaluation.
- "AGENT_TOOL" : The conversation is from an agent tool. Agent tool runs the agent in a separate session, which is persisted for testing and debugging purposes.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Empty.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Empty> delete(
core.String name, {
core.String? source,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'source': ?source == null ? null : [source],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'DELETE',
queryParams: queryParams_,
);
return Empty.fromJson(response_ as core.Map<core.String, core.dynamic>);
}