ProjectsLocationsAppsDeploymentsResource class

Constructors

ProjectsLocationsAppsDeploymentsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
message ProjectsLocationsAppsDeploymentsMessageResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Deployment request, String parent, {String? deploymentId, String? $fields}) Future<Deployment>
Creates a new deployment in the given app.
delete(String name, {String? etag, String? $fields}) Future<Empty>
Deletes the specified deployment.
get(String name, {String? $fields}) Future<Deployment>
Gets details of the specified deployment.
getExtendedAgentCard(String tenant, {String? $fields}) Future<LfA2aV1AgentCard>
Gets the extended agent card for the authenticated agent.
list(String parent, {String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListDeploymentsResponse>
Lists deployments in the given app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Deployment request, String name, {String? updateMask, String? $fields}) Future<Deployment>
Updates the specified deployment.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited