list method
Lists deployments in the given app.
Request parameters:
parent - Required. The parent app. Format:
projects/{project}/locations/{location}/apps/{app}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+$.
orderBy - Optional. Field to sort by. Only "name" and "create_time" is
supported. See https://google.aip.dev/132#ordering for more details.
pageSize - Optional. The maximum number of deployments to return. The
service may return fewer than this value. If unspecified, at most 50
deployments will be returned. The maximum value is 1000; values above 1000
will be coerced to 1000.
pageToken - Optional. A page token, received from a previous
ListDeployments call. Provide this to retrieve the subsequent page. When
paginating, all other parameters provided to ListDeployments must match
the call that provided the page token.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListDeploymentsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListDeploymentsResponse> list(
core.String parent, {
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/deployments';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListDeploymentsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}