create method
Creates a new example in the given app.
request - The metadata request object.
Request parameters:
parent - Required. The resource name of the app to create an example in.
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+$.
exampleId - Optional. The ID to use for the example, which will become
the final component of the example's resource name. If not provided, a
unique ID will be automatically assigned for the example.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Example.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Example> create(
Example request,
core.String parent, {
core.String? exampleId,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'exampleId': ?exampleId == null ? null : [exampleId],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/examples';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Example.fromJson(response_ as core.Map<core.String, core.dynamic>);
}