ProjectsLocationsAppsGuardrailsResource class

Constructors

ProjectsLocationsAppsGuardrailsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Guardrail request, String parent, {String? guardrailId, String? $fields}) Future<Guardrail>
Creates a new guardrail in the given app.
delete(String name, {String? etag, bool? force, String? $fields}) Future<Empty>
Deletes the specified guardrail.
get(String name, {String? $fields}) Future<Guardrail>
Gets details of the specified guardrail.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListGuardrailsResponse>
Lists guardrails in the given app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Guardrail request, String name, {String? updateMask, String? $fields}) Future<Guardrail>
Updates the specified guardrail.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited