ProjectsLocationsAppsResource class

Constructors

ProjectsLocationsAppsResource(ApiRequester client)

Methods

create(App request, String parent, {String? appId, String? $fields}) Future<Operation>
Creates a new app in the given project and location.
delete(String name, {String? etag, String? $fields}) Future<Operation>
Deletes the specified app.
executeTool(ExecuteToolRequest request, String parent, {String? $fields}) Future<ExecuteToolResponse>
Executes the given tool with the given arguments.
exportApp(ExportAppRequest request, String name, {String? $fields}) Future<Operation>
Exports the specified app.
get(String name, {String? $fields}) Future<App>
Gets details of the specified app.
getExtendedAgentCard(String tenant, {String? $fields}) Future<LfA2aV1AgentCard>
Gets the extended agent card for the authenticated agent.
importApp(ImportAppRequest request, String parent, {String? $fields}) Future<Operation>
Imports the specified app.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListAppsResponse>
Lists apps in the given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(App request, String name, {String? updateMask, String? $fields}) Future<App>
Updates the specified app.
retrieveToolSchema(RetrieveToolSchemaRequest request, String parent, {String? $fields}) Future<RetrieveToolSchemaResponse>
Retrieve the schema of the given tool.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited