create method
Creates a new app in the given project and location.
request - The metadata request object.
Request parameters:
parent - Required. The resource name of the location to create an app
in.
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
appId - Optional. The ID to use for the app, which will become the final
component of the app's resource name. If not provided, a unique ID will be
automatically assigned for the app.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Operation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Operation> create(
App request,
core.String parent, {
core.String? appId,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'appId': ?appId == null ? null : [appId],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/apps';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}