delete method

Future<Operation> delete(
  1. String name, {
  2. String? etag,
  3. String? $fields,
})

Deletes the specified app.

Request parameters:

name - Required. The resource name of the app to delete. Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+$.

etag - Optional. The current etag of the app. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the app, deletion will be blocked and an ABORTED error will be returned.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Operation.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Operation> delete(
  core.String name, {
  core.String? etag,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'etag': ?etag == null ? null : [etag],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'DELETE',
    queryParams: queryParams_,
  );
  return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}