getExtendedAgentCard method

Future<LfA2aV1AgentCard> getExtendedAgentCard(
  1. String tenant, {
  2. String? $fields,
})

Gets the extended agent card for the authenticated agent.

Request parameters:

tenant - Optional. Opaque routing identifier. Must match the tenant value from the selected AgentInterface in the Agent Card when that field is set. Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a LfA2aV1AgentCard.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<LfA2aV1AgentCard> getExtendedAgentCard(
  core.String tenant, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$tenant') + '/extendedAgentCard';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return LfA2aV1AgentCard.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}