retrieveToolSchema method
Future<RetrieveToolSchemaResponse>
retrieveToolSchema(
- RetrieveToolSchemaRequest request,
- String parent, {
- String? $fields,
Retrieve the schema of the given tool.
The schema is computed on the fly for the given instance of the tool.
request - The metadata request object.
Request parameters:
parent - Required. The resource name of the app which the tool/toolset
belongs to. Format: projects/{project}/locations/{location}/apps/{app}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a RetrieveToolSchemaResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<RetrieveToolSchemaResponse> retrieveToolSchema(
RetrieveToolSchemaRequest request,
core.String parent, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + ':retrieveToolSchema';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return RetrieveToolSchemaResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}