ProjectsLocationsAppsToolsResource class

Constructors

ProjectsLocationsAppsToolsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Tool request, String parent, {String? toolId, String? $fields}) Future<Tool>
Creates a new tool in the given app.
delete(String name, {String? etag, bool? force, String? $fields}) Future<Empty>
Deletes the specified tool.
get(String name, {String? $fields}) Future<Tool>
Gets details of the specified tool.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListToolsResponse>
Lists tools in the given app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Tool request, String name, {String? updateMask, String? $fields}) Future<Tool>
Updates the specified tool.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited