create method

Future<Tool> create(
  1. Tool request,
  2. String parent, {
  3. String? toolId,
  4. String? $fields,
})

Creates a new tool in the given app.

request - The metadata request object.

Request parameters:

parent - Required. The resource name of the app to create a tool in. Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+$.

toolId - Optional. The ID to use for the tool, which will become the final component of the tool's resource name. If not provided, a unique ID will be automatically assigned for the tool.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Tool.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Tool> create(
  Tool request,
  core.String parent, {
  core.String? toolId,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'toolId': ?toolId == null ? null : [toolId],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/tools';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return Tool.fromJson(response_ as core.Map<core.String, core.dynamic>);
}