ProjectsLocationsAppsToolsetsResource class

Constructors

ProjectsLocationsAppsToolsetsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Toolset request, String parent, {String? toolsetId, String? $fields}) Future<Toolset>
Creates a new toolset in the given app.
delete(String name, {String? etag, bool? force, String? $fields}) Future<Empty>
Deletes the specified toolset.
get(String name, {String? $fields}) Future<Toolset>
Gets details of the specified toolset.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListToolsetsResponse>
Lists toolsets in the given app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Toolset request, String name, {String? updateMask, String? $fields}) Future<Toolset>
Updates the specified toolset.
retrieveTools(RetrieveToolsRequest request, String toolset, {String? $fields}) Future<RetrieveToolsResponse>
Retrieve the list of tools included in the specified toolset.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited