create method
Creates a new toolset in the given app.
request - The metadata request object.
Request parameters:
parent - Required. The resource name of the app to create a toolset in.
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+$.
toolsetId - Optional. The ID to use for the toolset, which will become
the final component of the toolset's resource name. If not provided, a
unique ID will be automatically assigned for the toolset.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Toolset.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Toolset> create(
Toolset request,
core.String parent, {
core.String? toolsetId,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'toolsetId': ?toolsetId == null ? null : [toolsetId],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/toolsets';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Toolset.fromJson(response_ as core.Map<core.String, core.dynamic>);
}