delete method

Future<Empty> delete(
  1. String name, {
  2. String? etag,
  3. bool? force,
  4. String? $fields,
})

Deletes the specified toolset.

Request parameters:

name - Required. The resource name of the toolset to delete. Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+/toolsets/\[^/\]+$.

etag - Optional. The current etag of the toolset. If an etag is not provided, the deletion will overwrite any concurrent changes. If an etag is provided and does not match the current etag of the toolset, deletion will be blocked and an ABORTED error will be returned.

force - Optional. Indicates whether to forcefully delete the toolset, even if it is still referenced by app/agents. * If force = false, the deletion fails if any agents still reference the toolset. * If force = true, all existing references from agents will be removed and the toolset will be deleted.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Empty.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Empty> delete(
  core.String name, {
  core.String? etag,
  core.bool? force,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'etag': ?etag == null ? null : [etag],
    'force': ?force == null ? null : ['${force}'],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'DELETE',
    queryParams: queryParams_,
  );
  return Empty.fromJson(response_ as core.Map<core.String, core.dynamic>);
}