ProjectsLocationsAppsVersionsMessageResource class

Constructors

ProjectsLocationsAppsVersionsMessageResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(LfA2aV1SendMessageRequest request, String tenant, {String? $fields}) Future<LfA2aV1SendMessageResponse>
Sends a message to an agent.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited