ProjectsLocationsAppsVersionsResource class

Constructors

ProjectsLocationsAppsVersionsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
message ProjectsLocationsAppsVersionsMessageResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(AppVersion request, String parent, {String? appVersionId, String? $fields}) Future<AppVersion>
Creates a new app version in the given app.
delete(String name, {String? etag, String? $fields}) Future<Empty>
Deletes the specified app version.
get(String name, {String? $fields}) Future<AppVersion>
Gets details of the specified app version.
getExtendedAgentCard(String tenant, {String? $fields}) Future<LfA2aV1AgentCard>
Gets the extended agent card for the authenticated agent.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListAppVersionsResponse>
Lists all app versions in the given app.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restore(RestoreAppVersionRequest request, String name, {String? $fields}) Future<Operation>
Restores the specified app version.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited