PythonCodeCondition class

Python code block to evaluate the condition.

Constructors

PythonCodeCondition({String? pythonCode})
PythonCodeCondition.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pythonCode ↔ String?
The python code to execute.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited