PythonFunction class

A Python function tool.

Constructors

PythonFunction({String? description, String? name, String? pythonCode, ServiceDirectoryConfig? serviceDirectoryConfig})
PythonFunction.fromJson(Map json_)

Properties

description ↔ String?
The description of the Python function, parsed from the python code's docstring.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the Python function to execute.
getter/setter pair
pythonCode ↔ String?
The Python code to execute for the tool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceDirectoryConfig ↔ ServiceDirectoryConfig?
Service Directory configuration for the tool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited