description property
The description of the Python function, parsed from the python code's docstring.
Output only.
Implementation
core.String? description;
The description of the Python function, parsed from the python code's docstring.
Output only.
core.String? description;