name property

String? name
getter/setter pair

The name of the Python function to execute.

Must match a Python function name defined in the python code. Case sensitive. If the name is not provided, the first function defined in the python code will be used.

Optional.

Implementation

core.String? name;