RedactionConfig class

Configuration to instruct how sensitive data should be handled.

Constructors

RedactionConfig({String? deidentifyTemplate, bool? enableRedaction, String? inspectTemplate})
RedactionConfig.fromJson(Map json_)

Properties

deidentifyTemplate String?
DLP deidentify template name to instruct on how to de-identify content.
getter/setter pair
enableRedaction bool?
If true, redaction will be applied in various logging scenarios, including conversation history, Cloud Logging and audio recording.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inspectTemplate String?
DLP inspect template name to configure detection of sensitive data types.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited