RemoteAgentTool class

Represents a tool that allows the agent to call another remote agent.

Constructors

RemoteAgentTool({AgentCard? agentCard, String? description, String? name})
RemoteAgentTool.fromJson(Map json_)

Properties

agentCard ↔ AgentCard?
The agent card of the remote agent that this tool invokes.
getter/setter pair
description ↔ String?
The description of the tool.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the tool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited