RetrieveToolSchemaRequest class
Request message for ToolService.RetrieveToolSchema.
Constructors
- RetrieveToolSchemaRequest({String? tool, ToolsetTool? toolsetTool})
- RetrieveToolSchemaRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tool ↔ String?
-
The name of the tool to retrieve the schema for.
getter/setter pair
- toolsetTool ↔ ToolsetTool?
-
The toolset tool to retrieve the schema for.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited