toolsetTool property
The toolset tool to retrieve the schema for.
Only one tool should match the predicate from the toolset. Otherwise, an error will be returned.
Optional.
Implementation
ToolsetTool? toolsetTool;
The toolset tool to retrieve the schema for.
Only one tool should match the predicate from the toolset. Otherwise, an error will be returned.
Optional.
ToolsetTool? toolsetTool;