tool property
The name of the tool that the schema is for.
Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}
Implementation
core.String? tool;
The name of the tool that the schema is for.
Format: projects/{project}/locations/{location}/apps/{app}/tools/{tool}
core.String? tool;