toolIds property

List<String>? toolIds
getter/setter pair

The identifiers of the tools to retrieve from the toolset.

If empty, all tools in the toolset will be returned.

Optional.

Implementation

core.List<core.String>? toolIds;