uniqueItems property
Indicate the items in the array must be unique.
Only applies to TYPE.ARRAY.
Optional.
Implementation
core.bool? uniqueItems;
Indicate the items in the array must be unique.
Only applies to TYPE.ARRAY.
Optional.
core.bool? uniqueItems;