SessionConfig class

The configuration for the session.

Constructors

SessionConfig({String? deployment, bool? enableTextStreaming, String? entryAgent, bool? excludeDiagnosticInfo, List<Message>? historicalContexts, InputAudioConfig? inputAudioConfig, OutputAudioConfig? outputAudioConfig, SessionConfigRemoteDialogflowQueryParameters? remoteDialogflowQueryParameters, String? timeZone, bool? useToolFakes})
SessionConfig.fromJson(Map json_)

Properties

deployment ↔ String?
The deployment of the app to use for the session.
getter/setter pair
enableTextStreaming ↔ bool?
Whether to enable streaming text outputs from the model.
getter/setter pair
entryAgent ↔ String?
The entry agent to handle the session.
getter/setter pair
excludeDiagnosticInfo ↔ bool?
Whether to exclude diagnostic info from the session output.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
historicalContexts ↔ List<Message>?
The historical context of the session, including user inputs, agent responses, and other messages.
getter/setter pair
inputAudioConfig ↔ InputAudioConfig?
Configuration for processing the input audio.
getter/setter pair
outputAudioConfig ↔ OutputAudioConfig?
Configuration for generating the output audio.
getter/setter pair
remoteDialogflowQueryParameters ↔ SessionConfigRemoteDialogflowQueryParameters?
QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone ↔ String?
The time zone of the user.
getter/setter pair
useToolFakes ↔ bool?
Whether to use tool fakes for the session.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited