deployment property
The deployment of the app to use for the session.
Format:
projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}
Optional.
Implementation
core.String? deployment;
The deployment of the app to use for the session.
Format:
projects/{project}/locations/{location}/apps/{app}/deployments/{deployment}
Optional.
core.String? deployment;