remoteDialogflowQueryParameters property
QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.
Optional.
Implementation
SessionConfigRemoteDialogflowQueryParameters? remoteDialogflowQueryParameters;