timeZone property

String? timeZone
getter/setter pair

The time zone of the user.

If provided, the agent will use the time zone for date and time related variables. Otherwise, the agent will use the time zone specified in the App.time_zone_settings. The format is the IANA Time Zone Database time zone, e.g. "America/Los_Angeles".

Optional.

Implementation

core.String? timeZone;