useToolFakes property

bool? useToolFakes
getter/setter pair

Whether to use tool fakes for the session.

If this field is set, the agent will attempt use tool fakes instead of calling the real tools.

Optional.

Implementation

core.bool? useToolFakes;