SessionConfigRemoteDialogflowQueryParameters class

QueryParameters to send to the remote Dialogflow agent when the session control is transferred to the remote agent.

Properties

endUserMetadata ↔ Map<String, Object?>?
The end user metadata to be sent in QueryParameters.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payload ↔ Map<String, Object?>?
The payload to be sent in QueryParameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webhookHeaders ↔ Map<String, String>?
The HTTP headers to be sent as webhook_headers in QueryParameters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited