endUserMetadata property
The end user metadata to be sent in QueryParameters.
Optional.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Object?>? endUserMetadata;