variables property

Map<String, Object?>? variables
getter/setter pair

Contextual variables for the session, keyed by name.

Only variables declared in the app will be used by the CES agent. Unrecognized variables will still be sent to the Dialogflow agent as additional session parameters.

Optional.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? variables;