googleSearchSuggestions property
The suggestions returned from Google Search as a result of invoking the GoogleSearchTool.
Implementation
GoogleSearchSuggestions? googleSearchSuggestions;
The suggestions returned from Google Search as a result of invoking the GoogleSearchTool.
GoogleSearchSuggestions? googleSearchSuggestions;