turnCompleted property
If true, the CES agent has detected the end of the current conversation turn and will provide no further output for this turn.
Implementation
core.bool? turnCompleted;
If true, the CES agent has detected the end of the current conversation turn and will provide no further output for this turn.
core.bool? turnCompleted;