turnIndex property
Indicates the sequential order of conversation turn to which this output belongs to, starting from 1.
Implementation
core.int? turnIndex;
Indicates the sequential order of conversation turn to which this output belongs to, starting from 1.
core.int? turnIndex;