SessionOutputDiagnosticInfo class
Contains execution details during the processing.
Constructors
-
SessionOutputDiagnosticInfo({List<
Message> ? messages, Span? rootSpan}) - SessionOutputDiagnosticInfo.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
↔ List<
Message> ? -
List of the messages that happened during the processing.
getter/setter pair
- rootSpan ↔ Span?
-
A trace of the entire request processing, represented as a root span.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited