timeZone property
The time zone of the app from the time zone database, e.g., America/Los_Angeles, Europe/Paris.
Optional.
Implementation
core.String? timeZone;
The time zone of the app from the time zone database, e.g., America/Los_Angeles, Europe/Paris.
Optional.
core.String? timeZone;