TlsConfigCaCert class

The CA certificate.

Constructors

TlsConfigCaCert({String? cert, String? displayName})
TlsConfigCaCert.fromJson(Map json_)

Properties

cert ↔ String?
The allowed custom CA certificates (in DER format) for HTTPS verification.
getter/setter pair
certAsBytes ↔ List<int>
getter/setter pair
displayName ↔ String?
The name of the allowed custom CA certificates.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited