displayName property
The display name of the tool, derived based on the tool's type.
For example, display name of a ClientFunction is derived from its name
property.
Output only.
Implementation
core.String? displayName;
The display name of the tool, derived based on the tool's type.
For example, display name of a ClientFunction is derived from its name
property.
Output only.
core.String? displayName;