mcpTool property
The MCP tool.
An MCP tool cannot be created or updated directly and is managed by the MCP toolset.
Optional.
Implementation
McpTool? mcpTool;
The MCP tool.
An MCP tool cannot be created or updated directly and is managed by the MCP toolset.
Optional.
McpTool? mcpTool;