id property
The unique identifier of the tool call.
If populated, the client should return the execution result with the matching ID in ToolResponse.
Optional.
Implementation
core.String? id;
The unique identifier of the tool call.
If populated, the client should return the execution result with the matching ID in ToolResponse.
Optional.
core.String? id;