ToolCalls class

Request for the client to execute the tools and return the execution results before continuing the session.

Constructors

ToolCalls({List<ToolCall>? toolCalls})
ToolCalls.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCalls List<ToolCall>?
The list of tool calls to execute.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited