ToolFakeConfig class
Configuration for tool behavior in fake mode.
Constructors
- ToolFakeConfig({CodeBlock? codeBlock, bool? enableFakeMode})
- ToolFakeConfig.fromJson(Map json_)
Properties
- codeBlock ↔ CodeBlock?
-
Code block which will be executed instead of a real tool call.
getter/setter pair
- enableFakeMode ↔ bool?
-
Whether the tool is using fake mode.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited