ToolResponses class

Execution results for the requested tool calls from the client.

Constructors

ToolResponses({List<ToolResponse>? toolResponses})
ToolResponses.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolResponses List<ToolResponse>?
The list of tool execution results.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited