connectorToolset property
A toolset that generates tools from an Integration Connectors Connection.
Optional.
Implementation
ConnectorToolset? connectorToolset;
A toolset that generates tools from an Integration Connectors Connection.
Optional.
ConnectorToolset? connectorToolset;