mcpToolset property
A toolset that contains a list of tools that are offered by the MCP server.
Optional.
Implementation
McpToolset? mcpToolset;
A toolset that contains a list of tools that are offered by the MCP server.
Optional.
McpToolset? mcpToolset;