childAgent property
The resource name of the child agent the rule applies to.
Format:
projects/{project}/locations/{location}/apps/{app}/agents/{agent}
Required.
Implementation
core.String? childAgent;
The resource name of the child agent the rule applies to.
Format:
projects/{project}/locations/{location}/apps/{app}/agents/{agent}
Required.
core.String? childAgent;