expressionCondition property
A rule that evaluates a session state condition.
If the condition evaluates to true, the transfer occurs.
Optional.
Implementation
ExpressionCondition? expressionCondition;
A rule that evaluates a session state condition.
If the condition evaluates to true, the transfer occurs.
Optional.
ExpressionCondition? expressionCondition;