TransferRuleDisablePlannerTransfer class

A rule that prevents the planner from transferring to the target agent.

Properties

expressionCondition ExpressionCondition?
If the condition evaluates to true, planner will not be allowed to transfer to the target agent.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited