TriggerActionGenerativeAnswer class

The agent will immediately respond with a generative answer.

Properties

hashCode → int
The hash code for this object.
no setterinherited
prompt ↔ String?
The prompt to use for the generative answer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited