responses property
The canned responses for the agent to choose from.
The response is chosen randomly.
Required.
Implementation
core.List<TriggerActionResponse>? responses;
The canned responses for the agent to choose from.
The response is chosen randomly.
Required.
core.List<TriggerActionResponse>? responses;