TriggerActionResponse class

Represents a response from the agent.

Constructors

TriggerActionResponse({bool? disabled, String? text})
TriggerActionResponse.fromJson(Map json_)

Properties

disabled bool?
Whether the response is disabled.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
Text for the agent to respond with.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited