agent property

String? agent
getter/setter pair

The name of the agent to transfer the conversation to.

The agent must be in the same app as the current agent. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}

Required.

Implementation

core.String? agent;