allowedOrigins property

List<String>? allowedOrigins
getter/setter pair

The allowed HTTP(s) origins that OpenAPI tools in the App are able to directly call when VPC Service Controls are enabled.

These strings must match the origin exactly, including the port if specified. For example, "https://example.com" or "https://example.com:443". This list does not yet apply to Python tools that may make direct HTTP calls.

Optional.

Implementation

core.List<core.String>? allowedOrigins;