WhatsAppCredentials class

Ephemeral Meta credentials for WhatsApp native integration.

Constructors

WhatsAppCredentials({String? authCode, String? businessAccountId, String? conversationProfileId, String? phoneNumber, String? pin, String? wabaId})
WhatsAppCredentials.fromJson(Map json_)

Properties

authCode String?
The Meta auth code provided by the embedded signup flow.
getter/setter pair
businessAccountId String?
The Business Account ID to use for the phone number.
getter/setter pair
conversationProfileId String?
The Conversation Profile ID to use for the deployment.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
phoneNumber String?
The phone number to register with WhatsApp.
getter/setter pair
pin String?
The 6-digit PIN created by the user for two-step verification.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wabaId String?
The WhatsApp Business Account ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited