dataMapping property
The mapping that defines how data from a source tool is mapped to the widget's input parameters.
Optional.
Implementation
WidgetToolDataMapping? dataMapping;
The mapping that defines how data from a source tool is mapped to the widget's input parameters.
Optional.
WidgetToolDataMapping? dataMapping;