pythonFunction property
Configuration for a Python function used to transform the source tool's output into the widget's input format.
Optional.
Implementation
PythonFunction? pythonFunction;
Configuration for a Python function used to transform the source tool's output into the widget's input format.
Optional.
PythonFunction? pythonFunction;