textResponseInstruction property
Instruction for the LLM on how to generate the text response.
Used as the description for the text response parameter if type is LLM_GENERATED.
Optional.
Implementation
core.String? textResponseInstruction;
Instruction for the LLM on how to generate the text response.
Used as the description for the text response parameter if type is LLM_GENERATED.
Optional.
core.String? textResponseInstruction;