type property

String? type
getter/setter pair

The strategy for providing the text response.

Optional. Possible string values are:

  • "TYPE_UNSPECIFIED" : Unspecified type.
  • "NONE" : The LLM dynamically decides whether to generate a text response alongside the widget based on the conversation context.
  • "LLM_GENERATED" : The LLM is explicitly required to generate a text response.
  • "STATIC" : A pre-defined static text response is always used.

Implementation

core.String? type;