AccessSettings class

Represents the access setting of the space.

Constructors

AccessSettings({AccessPermissionSettings? accessPermissionSettings, String? accessState, String? audience})
AccessSettings.fromJson(Map json_)

Properties

accessPermissionSettings ↔ AccessPermissionSettings?
Access permission settings for the space.
getter/setter pair
accessState ↔ String?
Indicates the access state of the space.
getter/setter pair
audience ↔ String?
The resource name of the target audience who can discover the space, join the space, and preview the messages in the space.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited