AccessoryWidget class

One or more interactive widgets that appear at the bottom of a message.

For details, see Add interactive widgets at the bottom of a message.

Properties

buttonList ↔ GoogleAppsCardV1ButtonList?
A list of buttons.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited