ActionResponse class

Parameters that a Chat app can use to configure how its response is posted.

Constructors

ActionResponse({DialogAction? dialogAction, String? type, UpdatedWidget? updatedWidget, String? url})
ActionResponse.fromJson(Map json_)

Properties

dialogAction ↔ DialogAction?
Input only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Input only.
getter/setter pair
updatedWidget ↔ UpdatedWidget?
Input only.
getter/setter pair
url ↔ String?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited