Attachment class

An attachment in Google Chat.

Constructors

Attachment({AttachmentDataRef? attachmentDataRef, String? contentName, String? contentType, String? downloadUri, DriveDataRef? driveDataRef, String? name, String? source, String? thumbnailUri})
Attachment.fromJson(Map json_)

Properties

attachmentDataRef ↔ AttachmentDataRef?
A reference to the attachment data.
getter/setter pair
contentName ↔ String?
The original file name for the content, not the full path.
getter/setter pair
contentType ↔ String?
The content type (MIME type) of the file.
getter/setter pair
downloadUri ↔ String?
The download URL which should be used to allow a human user to download the attachment.
getter/setter pair
driveDataRef ↔ DriveDataRef?
A reference to the Google Drive attachment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
The source of the attachment.
getter/setter pair
thumbnailUri ↔ String?
The thumbnail URL which should be used to preview the attachment to a human user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited