Audience class

A target audience in Google Chat.

A target audience represents a group of users within a Google Workspace organization, defined by an administrator. Target audiences are used to configure access and visibility settings for resources, such as making a space discoverable to a specific group of users. For more details, see Target audiences and Make a space discoverable to a target audience.

Constructors

Audience({String? name})
Audience.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The resource name of the target audience who can discover or join the space.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited