name property

String? name
getter/setter pair

The resource name of the target audience who can discover or join the space.

For details, see Make a space discoverable to a target audience. Format: audiences/{audience} To use the default target audience for the Google Workspace organization, set to audiences/default.

Implementation

core.String? name;