Availability class

Represents a user's current availability information in Google Chat, including their state (for example, Active, Away, Do Not Disturb) and any custom status.

Constructors

Availability({CustomStatus? customStatus, DoNotDisturbMetadata? doNotDisturbMetadata, String? name, String? state})
Availability.fromJson(Map json_)

Properties

customStatus ↔ CustomStatus?
The user's custom status.
getter/setter pair
doNotDisturbMetadata ↔ DoNotDisturbMetadata?
Metadata if the user state is set to DO_NOT_DISTURB.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The user's current availability state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited