doNotDisturbMetadata property
Metadata if the user state is set to DO_NOT_DISTURB.
Output only.
Implementation
DoNotDisturbMetadata? doNotDisturbMetadata;
Metadata if the user state is set to DO_NOT_DISTURB.
Output only.
DoNotDisturbMetadata? doNotDisturbMetadata;