name property

String? name
getter/setter pair

Identifier.

Resource name of the user's availability. Format: users/{user}/availability {user} is the id for the Person in the People API or Admin SDK directory API. For example, users/123456789. The user's email address or me can also be used as an alias to refer to the caller. For example, users/user@example.com or users/me.

Implementation

core.String? name;