state property

String? state
getter/setter pair

The user's current availability state.

Output only. Possible string values are:

  • "STATE_UNSPECIFIED" : Default value. The state is unspecified.
  • "ACTIVE" : The user is currently active, based on recent activity.
  • "IDLE" : The user is currently idle. This state indicates a period of inactivity after being ACTIVE, before potentially transitioning to AWAY.
  • "AWAY" : The user is currently away. This can be either automatically set after a period of inactivity in ACTIVE or IDLE state, or it can be manually set by the user. When manually set via MarkAsAway, this state persists regardless of user activity.
  • "DO_NOT_DISTURB" : The user is in Do Not Disturb state, which is manually set.

Implementation

core.String? state;