Button class

A button.

Can be a text button or an image button.

Constructors

Button({ImageButton? imageButton, TextButton? textButton})
Button.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageButton ↔ ImageButton?
A button with image and onclick action.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textButton ↔ TextButton?
A button with text and onclick action.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited