CalendarEventLinkData class

Data for Calendar event links.

Constructors

CalendarEventLinkData({String? calendarId, String? eventId})
CalendarEventLinkData.fromJson(Map json_)

Properties

calendarId ↔ String?
The Calendar identifier of the linked Calendar.
getter/setter pair
eventId ↔ String?
The Event identifier of the linked Calendar event.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited