Card class

A card is a UI element that can contain UI widgets such as text and images.

Constructors

Card({List<CardAction>? cardActions, CardHeader? header, String? name, List<Section>? sections})
Card.fromJson(Map json_)

Properties

cardActions ↔ List<CardAction>?
The actions of this card.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
The header of the card.
getter/setter pair
name ↔ String?
Name of the card.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sections ↔ List<Section>?
Sections are separated by a line divider.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited