CardHeader class

Constructors

CardHeader({String? imageStyle, String? imageUrl, String? subtitle, String? title})
CardHeader.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageStyle ↔ String?
The image's type (for example, square border or circular border). Possible string values are:
getter/setter pair
imageUrl ↔ String?
The URL of the image in the card header.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ String?
The subtitle of the card header.
getter/setter pair
title ↔ String?
The title must be specified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited