ChatSpaceLinkData class

Data for Chat space links.

Constructors

ChatSpaceLinkData({String? message, String? space, String? thread})
ChatSpaceLinkData.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
The message of the linked Chat space resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space ↔ String?
The space of the linked Chat space resource.
getter/setter pair
thread ↔ String?
The thread of the linked Chat space resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited