CustomStatus class

Represents a user's custom status in Google Chat.

This includes a short text message with an optional emoji that a user sets to give more context about their availability.

Constructors

CustomStatus({Emoji? emoji, String? expireTime, String? text, String? ttl})
CustomStatus.fromJson(Map json_)

Properties

emoji Emoji?
The emoji of the custom status.
getter/setter pair
expireTime String?
The timestamp when the custom status expires.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The text of the custom status.
getter/setter pair
ttl String?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited