DoNotDisturbMetadata class

Metadata associated with the DO_NOT_DISTURB availability state, specifying when the state is set to expire.

Constructors

DoNotDisturbMetadata({String? expirationTime})
DoNotDisturbMetadata.fromJson(Map json_)

Properties

expirationTime String?
Timestamp until which the user should be marked as DO_NOT_DISTURB.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited