expirationTime property
Timestamp until which the user should be marked as DO_NOT_DISTURB.
This can be maximum of 1 year in the future.
Output only.
Implementation
core.String? expirationTime;
Timestamp until which the user should be marked as DO_NOT_DISTURB.
This can be maximum of 1 year in the future.
Output only.
core.String? expirationTime;