DriveLinkData class

Data for Google Drive links.

Constructors

DriveLinkData({DriveDataRef? driveDataRef, String? mimeType})
DriveLinkData.fromJson(Map json_)

Properties

driveDataRef ↔ DriveDataRef?
A DriveDataRef which references a Google Drive file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mimeType ↔ String?
The mime type of the linked Google Drive resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited