Emoji class

An emoji that is used as a reaction to a message.

Constructors

Emoji({CustomEmoji? customEmoji, String? unicode})
Emoji.fromJson(Map json_)

Properties

customEmoji ↔ CustomEmoji?
A custom emoji.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unicode ↔ String?
A basic emoji represented by a unicode string.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited