FindGroupChatsResponse class

A response containing group chat spaces with exactly the calling user and the requested users.

Constructors

FindGroupChatsResponse({String? nextPageToken, List<Space>? spaces})
FindGroupChatsResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
nextPageToken String?
A token that you can send as pageToken to retrieve the next page of results.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaces List<Space>?
List of spaces in the requested (or first) page.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited