GoogleAppsCardV1Action class

An action that describes the behavior when the form is submitted.

For example, you can invoke an Apps Script script to handle the form. If the action is triggered, the form values are sent to the server. [Google Workspace add-ons and Chat apps](https://developers.google.com/workspace/extend):

Constructors

GoogleAppsCardV1Action({bool? allWidgetsAreRequired, String? function, String? interaction, String? loadIndicator, List<ActionParameter>? parameters, bool? persistValues, List<String>? requiredWidgets})
GoogleAppsCardV1Action.fromJson(Map json_)

Properties

allWidgetsAreRequired ↔ bool?
If this is true, then all widgets are considered required by this action.
getter/setter pair
function ↔ String?
A custom function to invoke when the containing element is clicked or otherwise activated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interaction ↔ String?
Required when opening a dialog.
getter/setter pair
loadIndicator ↔ String?
Specifies the loading indicator that the action displays while making the call to the action. Possible string values are:
getter/setter pair
parameters ↔ List<ActionParameter>?
List of action parameters.
getter/setter pair
persistValues ↔ bool?
Indicates whether form values persist after the action.
getter/setter pair
requiredWidgets ↔ List<String>?
Fill this list with the names of widgets that this Action needs for a valid submission.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited