GoogleAppsCardV1BorderStyle class

The style options for the border of a card or widget, including the border type and color.

[Google Workspace add-ons and Chat apps](https://developers.google.com/workspace/extend):

Constructors

GoogleAppsCardV1BorderStyle({int? cornerRadius, Color? strokeColor, String? type})
GoogleAppsCardV1BorderStyle.fromJson(Map json_)

Properties

cornerRadius ↔ int?
The corner radius for the border.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor ↔ Color?
The colors to use when the type is BORDER_TYPE_STROKE.
getter/setter pair
type ↔ String?
The border type. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited