GoogleAppsCardV1Button class

A text, icon, or text and icon button that users can click.

For an example in Google Chat apps, see Add a button. To make an image a clickable button, specify an Image (not an ImageComponent) and set an onClick action. [Google Workspace add-ons and Chat apps](https://developers.google.com/workspace/extend):

Constructors

GoogleAppsCardV1Button({String? altText, Color? color, bool? disabled, GoogleAppsCardV1Icon? icon, GoogleAppsCardV1OnClick? onClick, String? text, String? type})
GoogleAppsCardV1Button.fromJson(Map json_)

Properties

altText ↔ String?
The alternative text that's used for accessibility.
getter/setter pair
color ↔ Color?
The color of the button.
getter/setter pair
disabled ↔ bool?
If true, the button is displayed in an inactive state and doesn't respond to user actions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ GoogleAppsCardV1Icon?
An icon displayed inside the button.
getter/setter pair
onClick ↔ GoogleAppsCardV1OnClick?
The action to perform when a user clicks the button, such as opening a hyperlink or running a custom function.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The text displayed inside the button.
getter/setter pair
type ↔ String?
The type of a button.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited