GoogleAppsCardV1ButtonList class

A list of buttons layed out horizontally.

For an example in Google Chat apps, see Add a button. [Google Workspace add-ons and Chat apps](https://developers.google.com/workspace/extend):

Properties

buttons ↔ List<GoogleAppsCardV1Button>?
An array of buttons.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited