GoogleAppsCardV1CardHeader class

Represents a card header.

For an example in Google Chat apps, see Add a header. [Google Workspace add-ons and Chat apps](https://developers.google.com/workspace/extend):

Constructors

GoogleAppsCardV1CardHeader({String? imageAltText, String? imageType, String? imageUrl, String? subtitle, String? title})
GoogleAppsCardV1CardHeader.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageAltText ↔ String?
The alternative text of this image that's used for accessibility.
getter/setter pair
imageType ↔ String?
The shape used to crop the image.
getter/setter pair
imageUrl ↔ String?
The HTTPS URL of the image in the card header.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ String?
The subtitle of the card header.
getter/setter pair
title ↔ String?
The title of the card header.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited