GoogleAppsCardV1CarouselCard class

A card that can be displayed as a carousel item.

Google Chat apps:

Properties

footerWidgets ↔ List<GoogleAppsCardV1NestedWidget>?
A list of widgets displayed at the bottom of the carousel card.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widgets ↔ List<GoogleAppsCardV1NestedWidget>?
A list of widgets displayed in the carousel card.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited