GoogleAppsCardV1Chip class

A text, icon, or text and icon chip that users can click.

[Google Workspace add-ons and Chat apps](https://developers.google.com/workspace/extend):

Constructors

GoogleAppsCardV1Chip({String? altText, bool? disabled, bool? enabled, GoogleAppsCardV1Icon? icon, String? label, GoogleAppsCardV1OnClick? onClick})
GoogleAppsCardV1Chip.fromJson(Map json_)

Properties

altText ↔ String?
The alternative text that's used for accessibility.
getter/setter pair
disabled ↔ bool?
Whether the chip is in an inactive state and ignores user actions.
getter/setter pair
enabled ↔ bool?
Whether the chip is in an active state and responds to user actions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ GoogleAppsCardV1Icon?
The icon image.
getter/setter pair
label ↔ String?
The text displayed inside the chip.
getter/setter pair
onClick ↔ GoogleAppsCardV1OnClick?
The action to perform when a user clicks the chip, such as opening a hyperlink or running a custom function.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited