GoogleAppsCardV1DataSourceConfig class

A configuration object that helps configure the data sources for a widget.

Available for Google Chat apps and Google Workspace add-ons that extend Google Workspace Studio.

Constructors

GoogleAppsCardV1DataSourceConfig({int? minCharactersTrigger, GoogleAppsCardV1PlatformDataSource? platformDataSource, GoogleAppsCardV1Action? remoteDataSource})
GoogleAppsCardV1DataSourceConfig.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
minCharactersTrigger int?
The minimum number of characters the user must enter before this data provider is triggered (i.e., before it starts returning results).
getter/setter pair
platformDataSource GoogleAppsCardV1PlatformDataSource?
The data is from a Google Workspace application.
getter/setter pair
remoteDataSource GoogleAppsCardV1Action?
The data is from a remote data provider.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited