GoogleAppsCardV1EventAction class

Represents an actionthat can be performed on an ui element.

Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps.

Properties

actionRuleId ↔ String?
The unique identifier of the ActionRule.
getter/setter pair
commonWidgetAction ↔ GoogleAppsCardV1CommonWidgetAction?
Common widget action.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postEventTriggers ↔ List<GoogleAppsCardV1Trigger>?
The list of triggers that will be triggered after the EventAction is executed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited