GoogleAppsCardV1ExpressionData class

Represents the data that is used to evaluate an expression.

Available for Google Workspace add-ons that extend Google Workspace Studio. Unavailable for Google Chat apps.

Properties

conditions ↔ List<GoogleAppsCardV1Condition>?
The list of conditions that are determined by the expression evaluation result.
getter/setter pair
eventActions ↔ List<GoogleAppsCardV1EventAction>?
The list of actions that the ExpressionData can be used.
getter/setter pair
expression ↔ String?
The uncompiled expression.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier of the ExpressionData.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited