GoogleAppsCardV1NestedWidget class

A list of widgets that can be displayed in a containing layout, such as a CarouselCard.

Google Chat apps:

Properties

buttonList ↔ GoogleAppsCardV1ButtonList?
A button list widget.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ GoogleAppsCardV1Image?
An image widget.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textParagraph ↔ GoogleAppsCardV1TextParagraph?
A text paragraph widget.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited