GoogleAppsCardV1OpenLink class

Represents an onClick event that opens a hyperlink.

[Google Workspace add-ons and Chat apps](https://developers.google.com/workspace/extend):

Constructors

GoogleAppsCardV1OpenLink({String? onClose, String? openAs, String? url})
GoogleAppsCardV1OpenLink.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onClose ↔ String?
Whether the client forgets about a link after opening it, or observes it until the window closes.
getter/setter pair
openAs ↔ String?
How to open a link.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The URL to open.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited