GoogleAppsCardV1PlatformDataSource class

For a SelectionInput widget that uses a multiselect menu, a data source from Google Workspace.

Used to populate items in a multiselect menu. Google Chat apps:

Properties

commonDataSource ↔ String?
A data source shared by all Google Workspace applications, such as users in a Google Workspace organization. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostAppDataSource ↔ HostAppDataSourceMarkup?
A data source that's unique to a Google Workspace host application, such spaces in Google Chat.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited