GoogleAppsCardV1Section class

A section contains a collection of widgets that are rendered vertically in the order that they're specified.

[Google Workspace add-ons and Chat apps](https://developers.google.com/workspace/extend):

Constructors

GoogleAppsCardV1Section({GoogleAppsCardV1CollapseControl? collapseControl, bool? collapsible, String? header, String? id, int? uncollapsibleWidgetsCount, List<GoogleAppsCardV1Widget>? widgets})
GoogleAppsCardV1Section.fromJson(Map json_)

Properties

collapseControl ↔ GoogleAppsCardV1CollapseControl?
Define the expand and collapse button of the section.
getter/setter pair
collapsible ↔ bool?
Indicates whether this section is collapsible.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Text that appears at the top of a section.
getter/setter pair
id ↔ String?
A unique ID assigned to the section that's used to identify the section to be mutated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uncollapsibleWidgetsCount ↔ int?
The number of uncollapsible widgets which remain visible even when a section is collapsed.
getter/setter pair
widgets ↔ List<GoogleAppsCardV1Widget>?
All the widgets in the section.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited