GoogleAppsCardV1Trigger class

Represents a trigger.

Only supported by Google Workspace Workflow, but not Google Chat apps or Google Workspace add-ons.

Properties

actionRuleId ↔ String?
The unique identifier of the ActionRule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited