sortOrder property

int? sortOrder
getter/setter pair

The order of the section in relation to other sections.

Sections with a lower sort_order value appear before sections with a higher value.

Output only.

Implementation

core.int? sortOrder;