HostAppDataSourceMarkup class

A data source from a Google Workspace application.

The data source populates available items for a widget.

Properties

chatDataSource ↔ ChatClientDataSourceMarkup?
A data source from Google Chat.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workflowDataSource ↔ WorkflowDataSourceMarkup?
A data source from Google Workflow.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited