ImageButton class

An image button with an onclick action.

Constructors

ImageButton({String? icon, String? iconUrl, String? name, OnClick? onClick})
ImageButton.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
The icon specified by an enum that indices to an icon provided by Chat API. Possible string values are:
getter/setter pair
iconUrl ↔ String?
The icon specified by a URL.
getter/setter pair
name ↔ String?
The name of this image_button that's used for accessibility.
getter/setter pair
onClick ↔ OnClick?
The onclick action.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited