KeyValue class

A UI element contains a key (label) and a value (content).

This element can also contain some actions such as onclick button.

Constructors

KeyValue({String? bottomLabel, Button? button, String? content, bool? contentMultiline, String? icon, String? iconUrl, OnClick? onClick, String? topLabel})
KeyValue.fromJson(Map json_)

Properties

bottomLabel ↔ String?
The text of the bottom label.
getter/setter pair
button ↔ Button?
A button that can be clicked to trigger an action.
getter/setter pair
content ↔ String?
The text of the content.
getter/setter pair
contentMultiline ↔ bool?
If the content should be multiline.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ String?
An enum value that's replaced by the Chat API with the corresponding icon image. Possible string values are:
getter/setter pair
iconUrl ↔ String?
The icon specified by a URL.
getter/setter pair
onClick ↔ OnClick?
The onclick action.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topLabel ↔ String?
The text of the top label.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited