ListMessagesResponse class

Response message for listing messages.

Constructors

ListMessagesResponse({List<Message>? messages, String? nextPageToken})
ListMessagesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
messages ↔ List<Message>?
List of messages.
getter/setter pair
nextPageToken ↔ String?
You can send a token as pageToken to retrieve the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited