ListSectionsResponse class

Response message for listing sections.

Constructors

ListSectionsResponse({String? nextPageToken, List<GoogleChatV1Section>? sections})
ListSectionsResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
nextPageToken String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sections List<GoogleChatV1Section>?
The sections from the specified user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited