ttl property

String? ttl
getter/setter pair

The duration from the current time until the ACTIVE state expires.

Using a short TTL can effectively reset the user's state to be based on activity after this brief duration.

Implementation

core.String? ttl;