MarkAsDoNotDisturbRequest class

Request message for the MarkAsDoNotDisturb method.

Properties

expireTime ↔ String?
The absolute timestamp when the DND state expires.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl ↔ String?
The duration from the current time until the DND state expires.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited