MembershipCount class

Represents the count of memberships of a space, grouped into categories.

Constructors

MembershipCount({int? joinedDirectHumanUserCount, int? joinedGroupCount})
MembershipCount.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
joinedDirectHumanUserCount ↔ int?
Count of human users that have directly joined the space, not counting users joined by having membership in a joined group.
getter/setter pair
joinedGroupCount ↔ int?
Count of all groups that have directly joined the space.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited