Message class

A message in a Google Chat space.

Constructors

Message({List<AccessoryWidget>? accessoryWidgets, ActionResponse? actionResponse, List<Annotation>? annotations, String? argumentText, List<AttachedGif>? attachedGifs, List<Attachment>? attachment, List<Card>? cards, List<CardWithId>? cardsV2, String? clientAssignedMessageId, String? createTime, String? deleteTime, DeletionMetadata? deletionMetadata, List<EmojiReactionSummary>? emojiReactionSummaries, String? fallbackText, String? formattedText, String? lastUpdateTime, String? markupSyntax, MatchedUrl? matchedUrl, String? name, User? privateMessageViewer, QuotedMessageMetadata? quotedMessageMetadata, User? sender, bool? silent, SlashCommand? slashCommand, Space? space, String? text, Thread? thread, bool? threadReply})
Message.fromJson(Map json_)

Properties

accessoryWidgets ↔ List<AccessoryWidget>?
One or more interactive widgets that appear at the bottom of a message.
getter/setter pair
actionResponse ↔ ActionResponse?
Input only.
getter/setter pair
annotations ↔ List<Annotation>?
Annotations can be associated with the plain-text body of the message or with chips that link to Google Workspace resources like Google Docs or Sheets with start_index and length of 0.
getter/setter pair
argumentText ↔ String?
Plain-text body of the message with all Chat app mentions stripped out.
getter/setter pair
attachedGifs ↔ List<AttachedGif>?
GIF images that are attached to the message.
getter/setter pair
attachment ↔ List<Attachment>?
User-uploaded attachment.
getter/setter pair
cards ↔ List<Card>?
Deprecated: Use cards_v2 instead.
getter/setter pair
cardsV2 ↔ List<CardWithId>?
An array of cards.
getter/setter pair
clientAssignedMessageId ↔ String?
A custom ID for the message.
getter/setter pair
createTime ↔ String?
For spaces created in Chat, the time at which the message was created.
getter/setter pair
deleteTime ↔ String?
The time at which the message was deleted in Google Chat.
getter/setter pair
deletionMetadata ↔ DeletionMetadata?
Information about a deleted message.
getter/setter pair
emojiReactionSummaries ↔ List<EmojiReactionSummary>?
The list of emoji reaction summaries on the message.
getter/setter pair
fallbackText ↔ String?
A plain-text description of the message's cards, used when the actual cards can't be displayed—for example, mobile notifications.
getter/setter pair
formattedText ↔ String?
Contains the message text with markups added to communicate formatting.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateTime ↔ String?
The time at which the message was last edited by a user.
getter/setter pair
markupSyntax ↔ String?
Specifies how the server interprets the message text field content.
getter/setter pair
matchedUrl ↔ MatchedUrl?
A URL in the Chat message text field that matches a link preview pattern.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
privateMessageViewer ↔ User?
Input for creating a message, otherwise output only.
getter/setter pair
quotedMessageMetadata ↔ QuotedMessageMetadata?
Information about a message that another message quotes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sender ↔ User?
The user who created the message.
getter/setter pair
silent ↔ bool?
Whether this is a silent message.
getter/setter pair
slashCommand ↔ SlashCommand?
Slash command information, if applicable.
getter/setter pair
space ↔ Space?
If your Chat app authenticates as a user, the output only populates the space name.
getter/setter pair
text ↔ String?
Plain-text body of the message.
getter/setter pair
thread ↔ Thread?
The thread the message belongs to.
getter/setter pair
threadReply ↔ bool?
When true, the message is a response in a reply thread.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited