cardsV2 property

List<CardWithId>? cardsV2
getter/setter pair

An array of cards.

Chat apps can create cards with app authentication. As part of the Developer Preview Program, if your Chat app authenticates as a user, it can create card messages. If your Chat app is not part of Developer Preview Program, it can't create cards with user authentication. To learn how to create a message that contains cards, see Send a message. Card builder

Optional.

Implementation

core.List<CardWithId>? cardsV2;