matchedUrl property
A URL in the Chat message text field that matches a link preview
pattern.
For more information, see Preview links.
Output only.
Implementation
MatchedUrl? matchedUrl;
A URL in the Chat message text field that matches a link preview
pattern.
For more information, see Preview links.
Output only.
MatchedUrl? matchedUrl;