MessageUpdatedEventData class

Event payload for an updated message.

Event type: google.workspace.chat.message.v1.updated

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ Message?
The updated message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited