targetSection property
The resource name of the section to move the section item to.
Format: users/{user}/sections/{section}
Required.
Implementation
core.String? targetSection;
The resource name of the section to move the section item to.
Format: users/{user}/sections/{section}
Required.
core.String? targetSection;