PermissionSetting class

Represents a space permission setting.

Constructors

PermissionSetting({bool? assistantManagersAllowed, bool? managersAllowed, bool? membersAllowed})
PermissionSetting.fromJson(Map json_)

Properties

assistantManagersAllowed ↔ bool?
Whether space managers ROLE_ASSISTANT_MANAGER) have this permission.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
managersAllowed ↔ bool?
Whether space owners (ROLE_MANAGER) have this permission.
getter/setter pair
membersAllowed ↔ bool?
Whether basic space members (ROLE_MEMBER) have this permission.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited