PositionSectionRequest class
Request message for positioning a section.
Constructors
- PositionSectionRequest({String? relativePosition, int? sortOrder})
- PositionSectionRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- relativePosition ↔ String?
-
The relative position of the section in the list of sections.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortOrder ↔ int?
-
The absolute position of the section in the list of sections.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited