QuotedMessageMetadata class

Information about a message that another message quotes.

When you update a message, you can't add or replace the quotedMessageMetadata field, but you can remove it. For example usage, see Quote another message.

Constructors

QuotedMessageMetadata({ForwardedMetadata? forwardedMetadata, String? lastUpdateTime, String? name, String? quoteType, QuotedMessageSnapshot? quotedMessageSnapshot})
QuotedMessageMetadata.fromJson(Map json_)

Properties

forwardedMetadata ↔ ForwardedMetadata?
Metadata about the source space of the quoted message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateTime ↔ String?
The timestamp when the quoted message was created or when the quoted message was last updated.
getter/setter pair
name ↔ String?
Resource name of the message that is quoted.
getter/setter pair
quotedMessageSnapshot ↔ QuotedMessageSnapshot?
A snapshot of the quoted message's content.
getter/setter pair
quoteType ↔ String?
Specifies the quote type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited