quoteType property
Specifies the quote type.
If not set, defaults to REPLY in the message read/write path for backward compatibility.
Optional. Possible string values are:
- "QUOTE_TYPE_UNSPECIFIED" : Reserved. This value is unused.
- "REPLY" : When
quote_typeisREPLY, you can do the following: * If you're replying in a thread, you can quote another message in that thread.
- If you're creating a root message, you can quote another root message in that space.
- "FORWARD" : When
quote_typeisFORWARD, you can quote a: * Message from a different space. * Message reply from a different thread in the same space.
Implementation
core.String? quoteType;