ReactionDeletedEventData class

Event payload for a deleted reaction.

Type: google.workspace.chat.reaction.v1.deleted

Properties

hashCode → int
The hash code for this object.
no setterinherited
reaction ↔ Reaction?
The deleted reaction.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited