SearchMessageResult class

A single result item from a message search.

Constructors

SearchMessageResult({Message? message, bool? read, String? spaceMuteSetting})
SearchMessageResult.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ Message?
The matched message.
getter/setter pair
read ↔ bool?
Indicates if the matched message is read by the calling user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spaceMuteSetting ↔ String?
The mute setting of the calling user for the space where the message is posted.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited