read property

bool? read
getter/setter pair

Indicates if the matched message is read by the calling user.

Only returned if the request view is SEARCH_MESSAGES_VIEW_FULL and the calling credentials include one of the following authorization scopes:

  • https://www.googleapis.com/auth/chat.users.readstate.readonly - https://www.googleapis.com/auth/chat.users.readstate

Implementation

core.bool? read;