SearchMessagesRequest class

Request message for searching messages.

Constructors

SearchMessagesRequest({String? filter, String? markupSyntax, String? orderBy, int? pageSize, String? pageToken, String? view})
SearchMessagesRequest.fromJson(Map json_)

Properties

filter ↔ String?
A search query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
markupSyntax ↔ String?
Specifies the desired output syntax for the Chat message formatted_text field.
getter/setter pair
orderBy ↔ String?
How the results list is ordered.
getter/setter pair
pageSize ↔ int?
The maximum number of results to return.
getter/setter pair
pageToken ↔ String?
A token, received from the previous search messages call.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view ↔ String?
Specifies what kind of search results view to return.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited