orderBy property

String? orderBy
getter/setter pair

How the results list is ordered.

Supported attributes to order by are: - create_time: Sorts the results by the time of the message creation. Default value. - relevance: Sorts the results by relevance. Developer Preview. The default ordering is create_time desc. Only a single order per query (create_time or relevance) is supported. Only descending order (desc) is supported, and it must be specified after the order attribute.

Optional.

Implementation

core.String? orderBy;