pageToken property

String? pageToken
getter/setter pair

A token, received from the previous search messages call.

Provide this parameter to retrieve the subsequent page. When paginating, all other parameters provided should match the call that provided the page token. Passing different values to the other parameters might lead to unexpected results.

Optional.

Implementation

core.String? pageToken;