view property

String? view
getter/setter pair

Specifies what kind of search results view to return.

The default is SEARCH_MESSAGES_VIEW_BASIC.

Optional. Possible string values are:

  • "SEARCH_MESSAGES_VIEW_UNSPECIFIED" : The default / unset value. The API will default to the BASIC view.
  • "SEARCH_MESSAGES_VIEW_BASIC" : Includes only the matched messages in the results, but no additional metadata. This is the default value.
  • "SEARCH_MESSAGES_VIEW_FULL" : Includes everything in the results: the matched messages and additional metadata.

Implementation

core.String? view;