SectionItem class
A user's defined section item.
This is used to represent section items, such as spaces, grouped under a section.
Constructors
- SectionItem({String? name, String? space})
- SectionItem.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited