SetUpSpaceRequest class

Request to create a space and add specified users to it.

Constructors

SetUpSpaceRequest({List<Membership>? memberships, String? requestId, Space? space})
SetUpSpaceRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
memberships ↔ List<Membership>?
The Google Chat users or groups to invite to join the space.
getter/setter pair
requestId ↔ String?
A unique identifier for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space ↔ Space?
The Space.spaceType field is required.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited