Space class

A space in Google Chat.

Spaces are conversations between two or more users or 1:1 messages between a user and a Chat app.

Constructors

Space({AccessSettings? accessSettings, bool? adminInstalled, String? createTime, String? customer, String? displayName, bool? externalUserAllowed, bool? importMode, String? importModeExpireTime, String? lastActiveTime, MembershipCount? membershipCount, String? name, PermissionSettings? permissionSettings, String? predefinedPermissionSettings, bool? singleUserBotDm, SpaceDetails? spaceDetails, String? spaceHistoryState, String? spaceThreadingState, String? spaceType, String? spaceUri, bool? threaded, String? type})
Space.fromJson(Map json_)

Properties

accessSettings ↔ AccessSettings?
Specifies the access setting of the space.
getter/setter pair
adminInstalled ↔ bool?
For direct message (DM) spaces with a Chat app, whether the space was created by a Google Workspace administrator.
getter/setter pair
createTime ↔ String?
For spaces created in Chat, the time the space was created.
getter/setter pair
customer ↔ String?
The customer id of the domain of the space.
getter/setter pair
displayName ↔ String?
The space's display name.
getter/setter pair
externalUserAllowed ↔ bool?
Whether this space permits any Google Chat user as a member.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importMode ↔ bool?
Whether this space is created in Import Mode as part of a data migration into Google Workspace.
getter/setter pair
importModeExpireTime ↔ String?
The time when the space will be automatically deleted by the system if it remains in import mode.
getter/setter pair
lastActiveTime ↔ String?
Timestamp of the last message in the space.
getter/setter pair
membershipCount ↔ MembershipCount?
The count of joined memberships grouped by member type.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
permissionSettings ↔ PermissionSettings?
Space permission settings for existing spaces.
getter/setter pair
predefinedPermissionSettings ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleUserBotDm ↔ bool?
Whether the space is a DM between a Chat app and a single human.
getter/setter pair
spaceDetails ↔ SpaceDetails?
Details about the space including description and rules.
getter/setter pair
spaceHistoryState ↔ String?
The message history state for messages and threads in this space.
getter/setter pair
spaceThreadingState ↔ String?
The threading state in the Chat space.
getter/setter pair
spaceType ↔ String?
The type of space.
getter/setter pair
spaceUri ↔ String?
The URI for a user to access the space.
getter/setter pair
threaded ↔ bool?
Deprecated: Use spaceThreadingState instead.
getter/setter pair
type ↔ String?
Deprecated: Use space_type instead.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited