SpacesSpaceEventsResource class

Constructors

SpacesSpaceEventsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) → Future<SpaceEvent>
Returns an event from a Google Chat space.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListSpaceEventsResponse>
Lists events from a Google Chat space.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited