TextButton class

A button with text and onclick action.

Constructors

TextButton({OnClick? onClick, String? text})
TextButton.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
onClick ↔ OnClick?
The onclick action of the button.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The text of the button.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited