ThreadReadState class

A user's read state within a thread, used to identify read and unread messages.

Constructors

ThreadReadState({String? lastReadTime, String? name})
ThreadReadState.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastReadTime ↔ String?
The time when the user's thread read state was updated.
getter/setter pair
name ↔ String?
Resource name of the thread read state.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited