UpdatedWidget class

For selectionInput widgets, returns autocomplete suggestions for a multiselect menu.

Constructors

UpdatedWidget({SelectionItems? suggestions, String? widget})
UpdatedWidget.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestions ↔ SelectionItems?
List of widget autocomplete results
getter/setter pair
widget ↔ String?
The ID of the updated widget.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited