UsersAvailabilityResource class

Constructors

UsersAvailabilityResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) Future<Availability>
Returns availability information for a human user in Google Chat.
markAsActive(MarkAsActiveRequest request, String name, {String? $fields}) Future<Availability>
Marks user as ACTIVE in Google Chat.
markAsAway(MarkAsAwayRequest request, String name, {String? $fields}) Future<Availability>
Marks user as AWAY in Google Chat.
markAsDoNotDisturb(MarkAsDoNotDisturbRequest request, String name, {String? $fields}) Future<Availability>
Marks user as DO_NOT_DISTURB in Google Chat.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Availability request, String name, {String? updateMask, String? $fields}) Future<Availability>
Updates availability information for a human user.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited