get method

Future<Availability> get(
  1. String name, {
  2. String? $fields,
})

Returns availability information for a human user in Google Chat.

For example, this can be used to check if a user is online or away, or to retrieve their custom status message. This method only retrieves the authenticated user's availability. Requires user authentication with one of the following authorization scopes:

  • https://www.googleapis.com/auth/chat.users.availability.readonly - https://www.googleapis.com/auth/chat.users.availability

Request parameters:

name - Required. The resource name of the availability to retrieve. Format: users/{user}/availability {user} is the id for the Person in the People API or Admin SDK directory API. For example, users/123456789. The user's email address or me can also be used as an alias to refer to the caller. For example, users/user@example.com or users/me. Value must have pattern ^users/\[^/\]+/availability$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Availability.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Availability> get(
  core.String name, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return Availability.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}