patch method

Future<Availability> patch(
  1. Availability request,
  2. String name, {
  3. String? updateMask,
  4. String? $fields,
})

Updates availability information for a human user.

Only the custom_status field can be updated through this method. This method only updates the authenticated user's availability. Requires user authentication with one of the following authorization scopes:

  • https://www.googleapis.com/auth/chat.users.availability

request - The metadata request object.

Request parameters:

name - Identifier. Resource name of the user's availability. Format: users/{user}/availability {user} is the id for the Person in the People API or Admin SDK directory API. For example, users/123456789. The user's email address or me can also be used as an alias to refer to the caller. For example, users/user@example.com or users/me. Value must have pattern ^users/\[^/\]+/availability$.

updateMask - Required. The list of fields to update. The only field that can be updated is custom_status.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Availability.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Availability> patch(
  Availability request,
  core.String name, {
  core.String? updateMask,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'updateMask': ?updateMask == null ? null : [updateMask],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'PATCH',
    body: body_,
    queryParams: queryParams_,
  );
  return Availability.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}