move method

Future<MoveSectionItemResponse> move(
  1. MoveSectionItemRequest request,
  2. String name, {
  3. String? $fields,
})

Moves an item from one section to another.

For example, if a section contains spaces, this method can be used to move a space to a different section. For details, see Create and organize sections in Google Chat. Requires user authentication with the authorization scope:

  • https://www.googleapis.com/auth/chat.users.sections

request - The metadata request object.

Request parameters:

name - Required. The resource name of the section item to move. Format: users/{user}/sections/{section}/items/{item} Value must have pattern ^users/\[^/\]+/sections/\[^/\]+/items/\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a MoveSectionItemResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<MoveSectionItemResponse> move(
  MoveSectionItemRequest request,
  core.String name, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':move';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return MoveSectionItemResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}