UsersSectionsResource class

Constructors

UsersSectionsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
items UsersSectionsItemsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(GoogleChatV1Section request, String parent, {String? $fields}) Future<GoogleChatV1Section>
Creates a section in Google Chat.
delete(String name, {String? $fields}) Future<Empty>
Deletes a section of type CUSTOM_SECTION.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<ListSectionsResponse>
Lists sections available to the Chat user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleChatV1Section request, String name, {String? updateMask, String? $fields}) Future<GoogleChatV1Section>
Updates a section.
position(PositionSectionRequest request, String name, {String? $fields}) Future<PositionSectionResponse>
Changes the sort order of a section.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited