create method
- GoogleChatV1Section request,
- String parent, {
- String? $fields,
Creates a section in Google Chat.
Sections help users group conversations and customize the list of spaces
displayed in Chat navigation panel. Only sections of type CUSTOM_SECTION
can be created. For details, see
Create and organize sections in Google Chat.
Requires
user authentication
with the
authorization scope:
https://www.googleapis.com/auth/chat.users.sections
request - The metadata request object.
Request parameters:
parent - Required. The parent resource name where the section is
created. Format: users/{user}
Value must have pattern ^users/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleChatV1Section.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleChatV1Section> create(
GoogleChatV1Section request,
core.String parent, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/sections';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleChatV1Section.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}