position method
Future<PositionSectionResponse>
position(
- PositionSectionRequest request,
- String name, {
- String? $fields,
Changes the sort order of a section.
For details, see Create and organize sections in Google Chat. Requires user authentication with the authorization scope:
https://www.googleapis.com/auth/chat.users.sections
request - The metadata request object.
Request parameters:
name - Required. The resource name of the section to position. Format:
users/{user}/sections/{section}
Value must have pattern ^users/\[^/\]+/sections/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a PositionSectionResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<PositionSectionResponse> position(
PositionSectionRequest request,
core.String name, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':position';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return PositionSectionResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}