CustomersAppsResource class

Constructors

CustomersAppsResource(ApiRequester client)

Properties

android → CustomersAppsAndroidResource
no setter
chrome → CustomersAppsChromeResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
web → CustomersAppsWebResource
no setter

Methods

countChromeAppRequests(String customer, {String? orderBy, String? orgUnitId, int? pageSize, String? pageToken, String? $fields}) → Future<GoogleChromeManagementV1CountChromeAppRequestsResponse>
Generate summary of app installation requests.
fetchDevicesRequestingExtension(String customer, {String? extensionId, String? orgUnitId, int? pageSize, String? pageToken, String? $fields}) → Future<GoogleChromeManagementV1FetchDevicesRequestingExtensionResponse>
Get a list of devices that have requested to install an extension.
fetchUsersRequestingExtension(String customer, {String? extensionId, String? orgUnitId, int? pageSize, String? pageToken, String? $fields}) → Future<GoogleChromeManagementV1FetchUsersRequestingExtensionResponse>
Get a list of users that have requested to install an extension.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited