CustomersConnectorConfigsResource class

Constructors

CustomersConnectorConfigsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(GoogleChromeManagementVersionsV1ConnectorConfig request, String parent, {String? connectorConfigId, String? $fields}) Future<GoogleChromeManagementVersionsV1ConnectorConfig>
Creates a connector config.
delete(String name, {String? $fields}) Future<GoogleChromeManagementVersionsV1ClaimCertificateProvisioningProcessResponse>
Deletes a connector config.
get(String name, {String? $fields}) Future<GoogleChromeManagementVersionsV1ConnectorConfig>
Gets a connector config with customer ID and config ID.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<GoogleChromeManagementVersionsV1ListConnectorConfigsResponse>
Lists connector configs of a customer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleChromeManagementVersionsV1ConnectorConfig request, String name, {String? updateMask, String? $fields}) Future<GoogleChromeManagementVersionsV1ConnectorConfig>
Updates a connector config.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited