list method
Lists connector configs of a customer.
Request parameters:
parent - Required. Format: customers/{customer}
Value must have pattern ^customers/\[^/\]+$.
pageSize - Optional. The maximum number of connector configs to return.
The default page size is 50 if page_size is unspecified, and the maximum
page size allowed is 100. Values above 100 will be capped at 100.
pageToken - Optional. A page token, received from a previous
ListConnectorConfigs call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListConnectorConfigs
must match the call that provided the page token.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleChromeManagementVersionsV1ListConnectorConfigsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleChromeManagementVersionsV1ListConnectorConfigsResponse>
list(
core.String parent, {
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/connectorConfigs';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleChromeManagementVersionsV1ListConnectorConfigsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}