patch method
Future<GoogleChromeManagementVersionsV1ConnectorConfig>
patch(
- GoogleChromeManagementVersionsV1ConnectorConfig request,
- String name, {
- String? updateMask,
- String? $fields,
Updates a connector config.
request - The metadata request object.
Request parameters:
name - Identifier. Format:
customers/{customer}/connectorConfigs/{connector_config}
Value must have pattern ^customers/\[^/\]+/connectorConfigs/\[^/\]+$.
updateMask - Optional. The update mask that can be used to specify which
fields to update.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleChromeManagementVersionsV1ConnectorConfig.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleChromeManagementVersionsV1ConnectorConfig> patch(
GoogleChromeManagementVersionsV1ConnectorConfig request,
core.String name, {
core.String? updateMask,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'updateMask': ?updateMask == null ? null : [updateMask],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'PATCH',
body: body_,
queryParams: queryParams_,
);
return GoogleChromeManagementVersionsV1ConnectorConfig.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}