GoogleChromeManagementV1NetworkStatusReport class
State of visible/configured networks.
- This field is telemetry information and this will change over time as the device is utilized. * Data for this field is controlled via policy: ReportNetworkStatus
- Data Collection Frequency: 60 minutes * Default Data Reporting Frequency: 3 hours - Policy Controlled: Yes * Cache: If the device is offline, the collected data is stored locally, and will be reported when the device is next online: Yes * Reported for affiliated users only: Yes * Granular permission needed: TELEMETRY_API_NETWORK_REPORT
Constructors
-
GoogleChromeManagementV1NetworkStatusReport({String? connectionState, String? connectionType, bool? encryptionOn, String? gatewayIpAddress, String? gatewayIpv6Address, String? guid, List<
String> ? ipv6Address, String? lanIpAddress, String? linkDownSpeedKbps, bool? metered, String? receivingBitRateMbps, String? reportTime, String? sampleFrequency, int? signalStrengthDbm, String? transmissionBitRateMbps, int? transmissionPowerDbm, String? wifiLinkQuality, bool? wifiPowerManagementEnabled}) - GoogleChromeManagementV1NetworkStatusReport.fromJson(Map json_)
Properties
- connectionState ↔ String?
-
Current connection state of the network.
getter/setter pair
- connectionType ↔ String?
-
Network connection type.
getter/setter pair
- encryptionOn ↔ bool?
-
Whether the wifi encryption key is turned off.
getter/setter pair
- gatewayIpAddress ↔ String?
-
Gateway IP address.
getter/setter pair
- gatewayIpv6Address ↔ String?
-
The gateway IPv6 for this interface, if detected
getter/setter pair
- guid ↔ String?
-
Network connection guid.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ipv6Address
↔ List<
String> ? -
IPv6 addresses assigned to this network, if any.
getter/setter pair
- lanIpAddress ↔ String?
-
LAN IP address.
getter/setter pair
- linkDownSpeedKbps ↔ String?
-
The maximum downstream bandwidth in Kilobits per second (Kbps), if
reported by the network interface or connection.
getter/setter pair
- metered ↔ bool?
-
Whether the network was detected as metered.
getter/setter pair
- receivingBitRateMbps ↔ String?
-
Receiving bit rate measured in Megabits per second.
getter/setter pair
- reportTime ↔ String?
-
Time at which the network state was reported.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleFrequency ↔ String?
-
Frequency the report is sampled.
getter/setter pair
- signalStrengthDbm ↔ int?
-
Signal strength for wireless networks measured in decibels.
getter/setter pair
- transmissionBitRateMbps ↔ String?
-
Transmission bit rate measured in Megabits per second.
getter/setter pair
- transmissionPowerDbm ↔ int?
-
Transmission power measured in decibels.
getter/setter pair
- wifiLinkQuality ↔ String?
-
Wifi link quality.
getter/setter pair
- wifiPowerManagementEnabled ↔ bool?
-
Wifi power management enabled
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited