GoogleChromeManagementV1ProfileAppInstallInstance class

Describes a profile reporting Chrome Profile information.

Constructors

GoogleChromeManagementV1ProfileAppInstallInstance({String? email, String? profileId, String? profileOrgUnitId, String? profilePermanentId})
GoogleChromeManagementV1ProfileAppInstallInstance.fromJson(Map json_)

Properties

email String?
The email of the profile.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
profileId String?
The Chrome client side profile ID.
getter/setter pair
profileOrgUnitId String?
The organizational unit id of the profile.
getter/setter pair
profilePermanentId String?
Profile permanent ID is the unique identifier of a profile within one customer.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited