GoogleChromeManagementV1TelemetryExternalDisplayData class

External display data.

Constructors

GoogleChromeManagementV1TelemetryExternalDisplayData({String? displayName, String? edidVersion, String? refreshRate, int? resolutionHorizontal, int? resolutionVertical, int? serialNumber})
GoogleChromeManagementV1TelemetryExternalDisplayData.fromJson(Map json_)

Properties

displayName ↔ String?
The display name.
getter/setter pair
edidVersion ↔ String?
The EDID version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
refreshRate ↔ String?
The refresh rate.
getter/setter pair
resolutionHorizontal ↔ int?
The horizontal resolution.
getter/setter pair
resolutionVertical ↔ int?
The vertical resolution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialNumber ↔ int?
The serial number.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited