GoogleChromeManagementV1TelemetryNetworkConnectionStateChangeEvent class

TelemetryNetworkConnectionStateChangeEvent is triggered on network connection state changes.

  • Granular permission needed: TELEMETRY_API_NETWORK_REPORT

Properties

connectionState ↔ String?
Current connection state of the network. Possible string values are:
getter/setter pair
guid ↔ String?
Unique identifier of the network.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited