GoogleChromeManagementVersionsV1ConnectorConfigStatus class

The status of the connector config.

Properties

failureStartTime String?
Field recording time of the earliest failure since the last success event.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The state of the connector config.
getter/setter pair
updateTime String?
Field recording time of most recent modification of the status.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited