GoogleChromeManagementVersionsV1GoogleSecOpsConfig class

Google SecOps connector config.

Properties

apiKey String?
Input only.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
host String?
Host of ingestion API endpoint.
getter/setter pair
reportingSettings GoogleChromeManagementVersionsV1ReportingSettings?
The reporting settings for the Google SecOps config.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited