host property
Host of ingestion API endpoint.
Allows customer to upload events to servers in specific geographical regions. Existing configs that don't have this setting default to US.
Required.
Implementation
core.String? host;
Host of ingestion API endpoint.
Allows customer to upload events to servers in specific geographical regions. Existing configs that don't have this setting default to US.
Required.
core.String? host;