GoogleChromeManagementVersionsV1MipLabelConfig class
MIP label connector config.
Constructors
-
GoogleChromeManagementVersionsV1MipLabelConfig({List<
String> ? domains, String? microsoftTenantId}) - GoogleChromeManagementVersionsV1MipLabelConfig.fromJson(Map json_)
Properties
-
domains
↔ List<
String> ? -
Domain can be used optionally for the corner case where one Dasher
customer ID maps to multiple Microsoft tenant ID.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- microsoftTenantId ↔ String?
-
Microsoft tenant ID.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited