GoogleChromeManagementVersionsV1QueryContentTransfersBreakdownsResponse class
Response message for QueryContentTransfersBreakdowns.
Constructors
-
GoogleChromeManagementVersionsV1QueryContentTransfersBreakdownsResponse({List<
GoogleChromeManagementVersionsV1ContentTransfersBreakdown> ? contentTransfersBreakdowns, String? nextPageToken}) - GoogleChromeManagementVersionsV1QueryContentTransfersBreakdownsResponse.fromJson(Map json_)
Properties
-
contentTransfersBreakdowns
↔ List<
GoogleChromeManagementVersionsV1ContentTransfersBreakdown> ? -
The content transfer breakdowns from the specified insight.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
A token, which can be sent as
page_tokento retrieve the next page.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited