GoogleChromeManagementVersionsV1QueryContentTransfersResponse class

Response message for QueryContentTransfers.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summaries List<GoogleChromeManagementVersionsV1ContentTransfersSummary>?
A collection of summaries for various content transfers metrics.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited