GoogleChromeManagementVersionsV1QueryUrlVisitsResponse class

Response message for QueryUrlVisits.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summaries List<GoogleChromeManagementVersionsV1UrlVisitsSummary>?
A collection of summaries for various URL visit metrics.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited