enabledDeviceEvents property
The list of device events that are enabled for this config.
An empty list disables all device events, and using ALL_DEVICE_EVENTS
will enable all device events.
Optional.
Implementation
core.List<core.String>? enabledDeviceEvents;