GoogleChromeManagementVersionsV1SplunkConfig class
Splunk connector config.
Constructors
- GoogleChromeManagementVersionsV1SplunkConfig({String? hecToken, String? host, int? portNumber, GoogleChromeManagementVersionsV1ReportingSettings? reportingSettings, String? source, bool? unsecureScheme})
- GoogleChromeManagementVersionsV1SplunkConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hecToken ↔ String?
-
Input only.
getter/setter pair
- host ↔ String?
-
Host to identify the customer specific server to receive the events.
getter/setter pair
- portNumber ↔ int?
-
The port number to use.
getter/setter pair
- reportingSettings ↔ GoogleChromeManagementVersionsV1ReportingSettings?
-
The reporting settings for the Splunk config.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ String?
-
Optional source name to override the default one set in the Splunk admin
console.
getter/setter pair
- unsecureScheme ↔ bool?
-
Whether to use an unsecure HTTP scheme.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited