GoogleChromePolicyVersionsV1ModifyOrgUnitPolicyRequest class

Request parameters for modifying a policy value for a specific org unit target.

Properties

hashCode → int
The hash code for this object.
no setterinherited
policyTargetKey ↔ GoogleChromePolicyVersionsV1PolicyTargetKey?
The key of the target for which we want to modify a policy.
getter/setter pair
policyValue ↔ GoogleChromePolicyVersionsV1PolicyValue?
The new value for the policy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask ↔ String?
Policy fields to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited