Proto2FileDescriptorProto class

Describes a complete .proto file.

Constructors

Proto2FileDescriptorProto({String? editionDeprecated, List<Proto2EnumDescriptorProto>? enumType, List<Proto2DescriptorProto>? messageType, String? name, List<String>? optionDependency, String? package, String? syntax})
Proto2FileDescriptorProto.fromJson(Map json_)

Properties

editionDeprecated ↔ String?
copybara:strip_begin TODO(b/538805613) Deprecate and remove this field in favor of enums.
getter/setter pair
enumType ↔ List<Proto2EnumDescriptorProto>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageType ↔ List<Proto2DescriptorProto>?
All top-level definitions in this file.
getter/setter pair
name ↔ String?
file name, relative to root of source tree
getter/setter pair
optionDependency ↔ List<String>?
Names of files imported by this file purely for the purpose of providing option extensions.
getter/setter pair
package ↔ String?
e.g. "foo", "foo.bar", etc.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syntax ↔ String?
The syntax of the proto file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited