CollectionPeriod class

The collection period is a date range which includes the first and last day.

Constructors

CollectionPeriod({Date? firstDate, Date? lastDate})
CollectionPeriod.fromJson(Map json_)

Properties

firstDate ↔ Date?
The first day in the collection period, inclusive.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastDate ↔ Date?
The last day in the collection period, inclusive.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited