QueryRequest class

Request payload sent by a physical web client.

This request includes all necessary context to load a particular user experience record.

Constructors

QueryRequest({String? effectiveConnectionType, String? formFactor, List<String>? metrics, String? origin, String? url})
QueryRequest.fromJson(Map json_)

Properties

effectiveConnectionType ↔ String?
The effective connection type is a query dimension that specifies the effective network class that the record's data should belong to.
getter/setter pair
formFactor ↔ String?
The form factor is a query dimension that specifies the device class that the record's data should belong to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ List<String>?
The metrics that should be included in the response.
getter/setter pair
origin ↔ String?
The url pattern "origin" refers to a url pattern that is the origin of a website.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The url pattern "url" refers to a url pattern that is any arbitrary url.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited