RecordsResource class

Constructors

RecordsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
queryHistoryRecord(QueryHistoryRequest request, {String? $fields}) → Future<QueryHistoryResponse>
Queries the Chrome User Experience Report for a timeseries history record for a given site.
queryRecord(QueryRequest request, {String? $fields}) → Future<QueryResponse>
Queries the Chrome User Experience for a single record for a given site.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited