chromewebstore/v2 library

Chrome Web Store API - v2

The Chrome Web Store API provides access to data about apps and extensions, as well as developer tools for managing them.

For more information, see developer.chrome.com/docs/webstore/api

Create an instance of ChromewebstoreApi to access these resources:

Classes

ByteRange
Specifies a range of media.
ChromewebstoreApi
The Chrome Web Store API provides access to data about apps and extensions, as well as developer tools for managing them.
DeployInfo
Deployment information for a specific release channel.
DistributionChannel
Deployment information for a specific release channel
DownloadOptions
Represents options for downloading media.
FetchItemStatusResponse
Response message for FetchItemStatus.
ItemRevisionStatus
Details on the status of an item revision.
Media
Represents a media consisting of a stream of bytes, a content type and a length.
MediaResource
PartialDownloadOptions
Options for downloading a Media.
PublishersItemsResource
PublishersResource
PublishItemRequest
Request message for PublishItem.
PublishItemResponse
Response message for PublishItem.
ResumableUploadOptions
Specifies options for resumable uploads.
SetPublishedDeployPercentageRequest
Request message for SetPublishedDeployPercentage.
UploadItemPackageResponse
Response message for UploadItemPackage.
UploadOptions
Represents options for uploading a Media.

Typedefs

CancelSubmissionRequest = $Empty
Request message for CancelSubmission.
CancelSubmissionResponse = $Empty
Response message for CancelSubmission.
SetPublishedDeployPercentageResponse = $Empty
Response message for SetPublishedDeployPercentage.
UploadItemPackageRequest = $Empty
Request message for UploadItemPackage.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.