ChromewebstoreApi class

The Chrome Web Store API provides access to data about apps and extensions, as well as developer tools for managing them.

Constructors

ChromewebstoreApi(Client client, {String rootUrl = 'https://chromewebstore.googleapis.com/', String servicePath = ''})

Properties

hashCode int
The hash code for this object.
no setterinherited
media MediaResource
no setter
publishers PublishersResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

chromewebstoreReadonlyScope → const String
See and download your Chrome Web Store extensions and apps, and see licenses you have access to
chromewebstoreScope → const String
See, edit, update, or publish your Chrome Web Store extensions, themes, apps, and licences you have access to