deployPercentage property
The current deploy percentage for the release channel (nonnegative number between 0 and 100).
Required.
Implementation
core.int? deployPercentage;
The current deploy percentage for the release channel (nonnegative number between 0 and 100).
Required.
core.int? deployPercentage;