FetchItemStatusResponse class

Response message for FetchItemStatus.

Constructors

FetchItemStatusResponse({String? itemId, String? lastAsyncUploadState, String? name, String? publicKey, ItemRevisionStatus? publishedItemRevisionStatus, ItemRevisionStatus? submittedItemRevisionStatus, bool? takenDown, bool? warned})
FetchItemStatusResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
itemId String?
The ID of the item.
getter/setter pair
lastAsyncUploadState String?
The state of the last async upload for an item.
getter/setter pair
name String?
The name of the requested item.
getter/setter pair
publicKey String?
The public key of the item, which may be generated by the store.
getter/setter pair
publishedItemRevisionStatus ItemRevisionStatus?
Status of the current published revision of the item.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submittedItemRevisionStatus ItemRevisionStatus?
Status of the item revision submitted to be published.
getter/setter pair
takenDown bool?
If true, the item has been taken down for a policy violation.
getter/setter pair
warned bool?
If true, the item has been warned for a policy violation and will be taken down if not resolved.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited