lastAsyncUploadState property

String? lastAsyncUploadState
getter/setter pair

The state of the last async upload for an item.

Only set when there has been an async upload for the item in the past 24 hours.

Output only. Possible string values are:

  • "UPLOAD_STATE_UNSPECIFIED" : The default value.
  • "SUCCEEDED" : The upload succeeded.
  • "IN_PROGRESS" : The upload is currently being processed.
  • "FAILED" : The upload failed.
  • "NOT_FOUND" : Used as the value of lastAsyncUploadState in a fetchStatus response indicating that an upload attempt was not found.

Implementation

core.String? lastAsyncUploadState;