publishedItemRevisionStatus property

ItemRevisionStatus? publishedItemRevisionStatus
getter/setter pair

Status of the current published revision of the item.

Will be unset if the item is not published.

Output only.

Implementation

ItemRevisionStatus? publishedItemRevisionStatus;