submittedItemRevisionStatus property
Status of the item revision submitted to be published.
Will be unset if the item has not been submitted for publishing since the last successful publish.
Implementation
ItemRevisionStatus? submittedItemRevisionStatus;