takenDown property
If true, the item has been taken down for a policy violation.
Check the developer dashboard for details.
Implementation
core.bool? takenDown;
If true, the item has been taken down for a policy violation.
Check the developer dashboard for details.
core.bool? takenDown;