warned property

bool? warned
getter/setter pair

If true, the item has been warned for a policy violation and will be taken down if not resolved.

Check the developer dashboard for details.

Implementation

core.bool? warned;