setPublishedDeployPercentage method
- SetPublishedDeployPercentageRequest request,
- String name, {
- String? $fields,
Set a higher target deploy percentage for the item's published revision.
This will be updated without the item being submitted for review. This is only available to items with over 10,000 seven-day active users.
request - The metadata request object.
Request parameters:
name - Required. Name of the item to update the published revision of in
the form publishers/{publisherId}/items/{itemId}
Value must have pattern ^publishers/\[^/\]+/items/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a SetPublishedDeployPercentageResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<SetPublishedDeployPercentageResponse>
setPublishedDeployPercentage(
SetPublishedDeployPercentageRequest request,
core.String name, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v2/' + core.Uri.encodeFull('$name') + ':setPublishedDeployPercentage';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return SetPublishedDeployPercentageResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}