deployPercentage property
Unscaled percentage value for the publised revision (nonnegative number between 0 and 100).
It must be larger than the existing target percentage.
Required.
Implementation
core.int? deployPercentage;
Unscaled percentage value for the publised revision (nonnegative number between 0 and 100).
It must be larger than the existing target percentage.
Required.
core.int? deployPercentage;