UploadItemPackageResponse class

Response message for UploadItemPackage.

Constructors

UploadItemPackageResponse({String? crxVersion, String? itemId, String? name, String? uploadState})
UploadItemPackageResponse.fromJson(Map json_)

Properties

crxVersion String?
The extension version provided in the manifest of the uploaded package.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
itemId String?
The ID of the item the package was uploaded to.
getter/setter pair
name String?
The name of the item the package was uploaded to.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uploadState String?
The state of the upload.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited