crxVersion property

String? crxVersion
getter/setter pair

The extension version provided in the manifest of the uploaded package.

This will not be set if the upload is still in progress (upload_state is UPLOAD_IN_PROGRESS).

Implementation

core.String? crxVersion;