uploadState property

String? uploadState
getter/setter pair

The state of the upload.

If upload_state is UPLOAD_IN_PROGRESS, you can poll for updates using the fetchStatus method.

Output only. Possible string values are:

  • "UPLOAD_STATE_UNSPECIFIED" : The default value.
  • "SUCCEEDED" : The upload succeeded.
  • "IN_PROGRESS" : The upload is currently being processed.
  • "FAILED" : The upload failed.
  • "NOT_FOUND" : Used as the value of lastAsyncUploadState in a fetchStatus response indicating that an upload attempt was not found.

Implementation

core.String? uploadState;