description property

String? description
getter/setter pair

A description of the warning.

Developers should use this message to understand the warning and take appropriate action to resolve the issue.

Implementation

core.String? description;