reason property
The reason for the warning.
This is a constant value that identifies the proximate cause of the warning.
Implementation
core.String? reason;
The reason for the warning.
This is a constant value that identifies the proximate cause of the warning.
core.String? reason;