AddOnAttachment class

An add-on attachment on a post.

Constructors

AddOnAttachment({List<CopyHistory>? copyHistory, String? courseId, Date? dueDate, TimeOfDay? dueTime, String? id, String? itemId, double? maxPoints, String? postId, EmbedUri? studentViewUri, EmbedUri? studentWorkReviewUri, EmbedUri? teacherViewUri, String? title})
AddOnAttachment.fromJson(Map json_)

Properties

copyHistory ↔ List<CopyHistory>?
Identifiers of attachments that were previous copies of this attachment.
getter/setter pair
courseId ↔ String?
Identifier of the course.
getter/setter pair
dueDate ↔ Date?
Date, in UTC, that work on this attachment is due.
getter/setter pair
dueTime ↔ TimeOfDay?
Time of day, in UTC, that work on this attachment is due.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Classroom-assigned identifier for this attachment, unique per post.
getter/setter pair
itemId ↔ String?
Identifier of the Announcement, CourseWork, or CourseWorkMaterial under which the attachment is attached.
getter/setter pair
maxPoints ↔ double?
Maximum grade for this attachment.
getter/setter pair
postId ↔ String?
Deprecated, use item_id instead.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
studentViewUri ↔ EmbedUri?
URI to show the student view of the attachment.
getter/setter pair
studentWorkReviewUri ↔ EmbedUri?
URI for the teacher to see student work on the attachment, if applicable.
getter/setter pair
teacherViewUri ↔ EmbedUri?
URI to show the teacher view of the attachment.
getter/setter pair
title ↔ String?
Title of this attachment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited