AddOnAttachmentStudentSubmission class

Payload for grade update requests.

Constructors

AddOnAttachmentStudentSubmission({String? courseWorkSubmissionId, String? id, double? pointsEarned, String? postSubmissionState, String? userId})
AddOnAttachmentStudentSubmission.fromJson(Map json_)

Properties

courseWorkSubmissionId String?
Identifier of the course work submission under which this attachment submission was made.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Classroom-assigned identifier for this student submission.
getter/setter pair
pointsEarned double?
Student grade on this attachment.
getter/setter pair
postSubmissionState String?
Submission state of add-on attachment's parent post (i.e. assignment). Possible string values are:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
Identifier for the student that owns this submission.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited