id property
Classroom-assigned identifier for this student submission.
This is unique among submissions for the relevant course work and add-on attachment combination.
Output only.
Implementation
core.String? id;
Classroom-assigned identifier for this student submission.
This is unique among submissions for the relevant course work and add-on attachment combination.
Output only.
core.String? id;