AddOnContext class

Attachment-relevant metadata for Classroom add-ons in the context of a specific post.

Constructors

AddOnContext({String? courseId, String? itemId, String? postId, StudentContext? studentContext, bool? supportsStudentWork, TeacherContext? teacherContext})
AddOnContext.fromJson(Map json_)

Properties

courseId ↔ String?
Identifier of the course.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemId ↔ String?
Identifier of the Announcement, CourseWork, or CourseWorkMaterial under which the attachment is attached.
getter/setter pair
postId ↔ String?
Deprecated, use item_id instead.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
studentContext ↔ StudentContext?
Add-on context corresponding to the requesting user's role as a student.
getter/setter pair
supportsStudentWork ↔ bool?
Whether the post allows the teacher to see student work and passback grades.
getter/setter pair
teacherContext ↔ TeacherContext?
Add-on context corresponding to the requesting user's role as a teacher.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited