Assignment class

Additional details for assignments.

Constructors

Assignment({DriveFolder? studentWorkFolder})
Assignment.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
studentWorkFolder ↔ DriveFolder?
Drive folder where attachments from student submissions are placed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited