levels property

String? levels
getter/setter pair

Levels for the course.

Examples: "9th grade", "Middle school", "4th - 5th", "K-2", "3000". If set, this field must be a valid UTF-8 string and fewer than 1000 characters. This field can only be cleared using the PatchCourse method.

Optional.

Implementation

core.String? levels;