CourseMaterial class

A material attached to a course as part of a material set.

Constructors

CourseMaterial({DriveFile? driveFile, Form? form, Link? link, YouTubeVideo? youTubeVideo})
CourseMaterial.fromJson(Map json_)

Properties

driveFile ↔ DriveFile?
Google Drive file attachment.
getter/setter pair
form ↔ Form?
Google Forms attachment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Link atatchment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
youTubeVideo ↔ YouTubeVideo?
Youtube video attachment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited