CourseMaterialSet class

A set of materials that appears on the "About" page of the course.

These materials might include a syllabus, schedule, or other background information relating to the course as a whole.

Constructors

CourseMaterialSet({List<CourseMaterial>? materials, String? title})
CourseMaterialSet.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
materials ↔ List<CourseMaterial>?
Materials attached to this set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title for this set.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited