CourseWork class

Course work created by a teacher for students of the course.

Constructors

CourseWork({String? alternateLink, String? assigneeMode, Assignment? assignment, bool? associatedWithDeveloper, String? courseId, String? creationTime, String? creatorUserId, String? description, Date? dueDate, TimeOfDay? dueTime, GradeCategory? gradeCategory, String? gradingPeriodId, String? id, IndividualStudentsOptions? individualStudentsOptions, List<Material>? materials, double? maxPoints, MultipleChoiceQuestion? multipleChoiceQuestion, String? scheduledTime, String? state, String? submissionModificationMode, String? title, String? topicId, String? updateTime, String? workType})
CourseWork.fromJson(Map json_)

Properties

Absolute link to this course work in the Classroom web UI.
getter/setter pair
assigneeMode ↔ String?
Assignee mode of the coursework.
getter/setter pair
assignment ↔ Assignment?
Assignment details.
getter/setter pair
associatedWithDeveloper ↔ bool?
Whether this course work item is associated with the Developer Console project making the request.
getter/setter pair
courseId ↔ String?
Identifier of the course.
getter/setter pair
creationTime ↔ String?
Timestamp when this course work was created.
getter/setter pair
creatorUserId ↔ String?
Identifier for the user that created the coursework.
getter/setter pair
description ↔ String?
Optional description of this course work.
getter/setter pair
dueDate ↔ Date?
Optional date, in UTC, that submissions for this course work are due.
getter/setter pair
dueTime ↔ TimeOfDay?
Optional time of day, in UTC, that submissions for this course work are due.
getter/setter pair
gradeCategory ↔ GradeCategory?
The category that this coursework's grade contributes to.
getter/setter pair
gradingPeriodId ↔ String?
Identifier of the grading period associated with the coursework.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Classroom-assigned identifier of this course work, unique per course.
getter/setter pair
individualStudentsOptions ↔ IndividualStudentsOptions?
Identifiers of students with access to the coursework.
getter/setter pair
materials ↔ List<Material>?
Additional materials.
getter/setter pair
maxPoints ↔ double?
Maximum grade for this course work.
getter/setter pair
multipleChoiceQuestion ↔ MultipleChoiceQuestion?
Multiple choice question details.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledTime ↔ String?
Optional timestamp when this course work is scheduled to be published.
getter/setter pair
state ↔ String?
Status of this course work.
getter/setter pair
submissionModificationMode ↔ String?
Setting to determine when students are allowed to modify submissions.
getter/setter pair
title ↔ String?
Title of this course work.
getter/setter pair
topicId ↔ String?
Identifier for the topic that this coursework is associated with.
getter/setter pair
updateTime ↔ String?
Timestamp of the most recent change to this course work.
getter/setter pair
workType ↔ String?
Type of this course work.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited