CourseWorkMaterial class

Course work material created by a teacher for students of the course

Constructors

CourseWorkMaterial({String? alternateLink, String? assigneeMode, String? courseId, String? creationTime, String? creatorUserId, String? description, String? id, IndividualStudentsOptions? individualStudentsOptions, List<Material>? materials, String? scheduledTime, String? state, String? title, String? topicId, String? updateTime})
CourseWorkMaterial.fromJson(Map json_)

Properties

Absolute link to this course work material in the Classroom web UI.
getter/setter pair
assigneeMode ↔ String?
Assignee mode of the course work material.
getter/setter pair
courseId ↔ String?
Identifier of the course.
getter/setter pair
creationTime ↔ String?
Timestamp when this course work material was created.
getter/setter pair
creatorUserId ↔ String?
Identifier for the user that created the course work material.
getter/setter pair
description ↔ String?
Optional description of this course work material.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Classroom-assigned identifier of this course work material, unique per course.
getter/setter pair
individualStudentsOptions ↔ IndividualStudentsOptions?
Identifiers of students with access to the course work material.
getter/setter pair
materials ↔ List<Material>?
Additional materials.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledTime ↔ String?
Optional timestamp when this course work material is scheduled to be published.
getter/setter pair
state ↔ String?
Status of this course work material.
getter/setter pair
title ↔ String?
Title of this course work material.
getter/setter pair
topicId ↔ String?
Identifier for the topic that this course work material is associated with.
getter/setter pair
updateTime ↔ String?
Timestamp of the most recent change to this course work material.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited