Criterion class

A rubric criterion.

Each criterion is a dimension on which performance is rated.

Constructors

Criterion({String? description, String? id, List<Level>? levels, String? title})
Criterion.fromJson(Map json_)

Properties

description ↔ String?
The description of the criterion.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The criterion ID.
getter/setter pair
levels ↔ List<Level>?
The list of levels within this criterion.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The title of the criterion.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited