DriveFolder class

Representation of a Google Drive folder.

Constructors

DriveFolder({String? alternateLink, String? id, String? title})
DriveFolder.fromJson(Map json_)

Properties

URL that can be used to access the Drive folder.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Drive API resource ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title of the Drive folder.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited