Form class

Google Forms item.

Constructors

Form({String? formUrl, String? responseUrl, String? thumbnailUrl, String? title})
Form.fromJson(Map json_)

Properties

formUrl ↔ String?
URL of the form.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
responseUrl ↔ String?
URL of the form responses document.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl ↔ String?
URL of a thumbnail image of the Form.
getter/setter pair
title ↔ String?
Title of the Form.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited