GuardianInvitation class

An invitation to become the guardian of a specified user, sent to a specified email address.

Constructors

GuardianInvitation({String? creationTime, String? invitationId, String? invitedEmailAddress, String? state, String? studentId})
GuardianInvitation.fromJson(Map json_)

Properties

creationTime ↔ String?
The time that this invitation was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invitationId ↔ String?
Unique identifier for this invitation.
getter/setter pair
invitedEmailAddress ↔ String?
Email address that the invitation was sent to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state that this invitation is in. Possible string values are:
getter/setter pair
studentId ↔ String?
ID of the student (in standard format)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited