list method
Returns a list of invitations that the requesting user is permitted to view, restricted to those that match the list request.
Note: At least one of user_id or course_id must be supplied. Both
fields can be supplied. This method returns the following error codes: *
PERMISSION_DENIED for access errors.
Request parameters:
courseId - Restricts returned invitations to those for a course with the
specified identifier.
pageSize - Maximum number of items to return. The default is 500 if
unspecified or 0. The server may return fewer than the specified number
of results.
pageToken - nextPageToken value returned from a previous list call,
indicating that the subsequent page of results should be returned. The
list request must be otherwise identical to the one that resulted in this
token.
userId - Restricts returned invitations to those for a specific user.
The identifier can be one of the following: * the numeric identifier for
the user * the email address of the user * the string literal "me",
indicating the requesting user
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListInvitationsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListInvitationsResponse> list({
core.String? courseId,
core.int? pageSize,
core.String? pageToken,
core.String? userId,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'courseId': ?courseId == null ? null : [courseId],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'userId': ?userId == null ? null : [userId],
'fields': ?$fields == null ? null : [$fields],
};
const url_ = 'v1/invitations';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListInvitationsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}