Link class

URL item.

Constructors

Link({String? thumbnailUrl, String? title, String? url})
Link.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl ↔ String?
URL of a thumbnail image of the target URL.
getter/setter pair
title ↔ String?
Title of the target of the URL.
getter/setter pair
url ↔ String?
URL to link to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited