ListCourseAliasesResponse class

Response when listing course aliases.

Constructors

ListCourseAliasesResponse({List<CourseAlias>? aliases, String? nextPageToken})
ListCourseAliasesResponse.fromJson(Map json_)

Properties

aliases ↔ List<CourseAlias>?
The course aliases.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token identifying the next page of results to return.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited