ListTopicResponse class

Response when listing topics.

Constructors

ListTopicResponse({String? nextPageToken, List<Topic>? topic})
ListTopicResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token identifying the next page of results to return.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic ↔ List<Topic>?
Topic items that match the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited