Material class

Material attached to course work.

When creating attachments, setting the form, gem, or notebook field is not supported.

Constructors

Material({SharedDriveFile? driveFile, Form? form, GeminiGem? gem, Link? link, NotebookLmNotebook? notebook, YouTubeVideo? youtubeVideo})
Material.fromJson(Map json_)

Properties

driveFile ↔ SharedDriveFile?
Google Drive file material.
getter/setter pair
form ↔ Form?
Google Forms material.
getter/setter pair
gem ↔ GeminiGem?
Gemini Gem material.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Link material.
getter/setter pair
notebook ↔ NotebookLmNotebook?
NotebookLM Notebook material.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
youtubeVideo ↔ YouTubeVideo?
YouTube video material.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited