ModifyAnnouncementAssigneesRequest class

Request to modify assignee mode and options of an announcement.

Properties

assigneeMode ↔ String?
Mode of the announcement describing whether it is accessible by all students or specified individual students. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modifyIndividualStudentsOptions ↔ ModifyIndividualStudentsOptions?
Set which students can view or cannot view the announcement.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited