NotebookLmNotebook class

NotebookLM Notebook link.

Constructors

NotebookLmNotebook({String? id, String? title, String? url})
NotebookLmNotebook.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Notebook resource id.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title of the Notebook.
getter/setter pair
url ↔ String?
URL that can be used to access the Notebook.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited