Registration class

An instruction to Classroom to send notifications from the feed to the provided destination.

Constructors

Registration({CloudPubsubTopic? cloudPubsubTopic, String? expiryTime, Feed? feed, String? registrationId})
Registration.fromJson(Map json_)

Properties

cloudPubsubTopic ↔ CloudPubsubTopic?
The Cloud Pub/Sub topic that notifications are to be sent to.
getter/setter pair
expiryTime ↔ String?
The time until which the Registration is effective.
getter/setter pair
feed ↔ Feed?
Specification for the class of notifications that Classroom should deliver to the destination.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
registrationId ↔ String?
A server-generated unique identifier for this Registration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited