SharedDriveFile class

Drive file that is used as material for course work.

Constructors

SharedDriveFile({DriveFile? driveFile, String? shareMode})
SharedDriveFile.fromJson(Map json_)

Properties

driveFile ↔ DriveFile?
Drive file details.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareMode ↔ String?
Mechanism by which students access the Drive item. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited