StateHistory class

The history of each state this submission has been in.

Constructors

StateHistory({String? actorUserId, String? state, String? stateTimestamp})
StateHistory.fromJson(Map json_)

Properties

actorUserId ↔ String?
The teacher or student who made the change.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The workflow pipeline stage. Possible string values are:
getter/setter pair
stateTimestamp ↔ String?
When the submission entered this state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited