UserProfile class

Global information for a user.

Constructors

UserProfile({String? emailAddress, String? id, Name? name, List<GlobalPermission>? permissions, String? photoUrl, bool? verifiedTeacher})
UserProfile.fromJson(Map json_)

Properties

emailAddress ↔ String?
Email address of the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Identifier of the user.
getter/setter pair
name ↔ Name?
Name of the user.
getter/setter pair
permissions ↔ List<GlobalPermission>?
Global permissions of the user.
getter/setter pair
photoUrl ↔ String?
URL of user's profile photo.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verifiedTeacher ↔ bool?
Represents whether a Google Workspace for Education user's domain administrator has explicitly verified them as being a teacher.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited