UserProfilesGuardiansResource class

Constructors

UserProfilesGuardiansResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String studentId, String guardianId, {String? $fields}) → Future<Empty>
Deletes a guardian.
get(String studentId, String guardianId, {String? $fields}) → Future<Guardian>
Returns a specific guardian.
list(String studentId, {String? invitedEmailAddress, int? pageSize, String? pageToken, String? $fields}) → Future<ListGuardiansResponse>
Returns a list of guardians that the requesting user is permitted to view, restricted to those that match the request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited