UserProfilesResource class

Constructors

UserProfilesResource(ApiRequester client)

Properties

guardianInvitations → UserProfilesGuardianInvitationsResource
no setter
guardians → UserProfilesGuardiansResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String userId, {String? $fields}) → Future<UserProfile>
Returns a user profile.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited