YouTubeVideo class

YouTube video item.

Constructors

YouTubeVideo({String? alternateLink, String? id, String? thumbnailUrl, String? title})
YouTubeVideo.fromJson(Map json_)

Properties

URL that can be used to view the YouTube video.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
YouTube API resource ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailUrl ↔ String?
URL of a thumbnail image of the YouTube video.
getter/setter pair
title ↔ String?
Title of the YouTube video.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited