AnalyzeOrgPolicyGovernedContainersResponse class

The response message for AssetService.AnalyzeOrgPolicyGovernedContainers.

Properties

constraint ↔ AnalyzerOrgPolicyConstraint?
The definition of the constraint in the request.
getter/setter pair
governedContainers ↔ List<GoogleCloudAssetV1GovernedContainer>?
The list of the analyzed governed containers.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The page token to fetch the next page for AnalyzeOrgPolicyGovernedContainersResponse.governed_containers.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited