AnalyzerOrgPolicy class

This organization policy message is a modified version of the one defined in the Organization Policy system.

This message contains several fields defined in the original organization policy with some new fields for analysis purpose.

Constructors

AnalyzerOrgPolicy({String? appliedResource, String? attachedResource, bool? inheritFromParent, bool? reset, List<GoogleCloudAssetV1Rule>? rules})
AnalyzerOrgPolicy.fromJson(Map json_)

Properties

appliedResource ↔ String?
The full resource name of an organization/folder/project resource where this organization policy applies to.
getter/setter pair
attachedResource ↔ String?
The full resource name of an organization/folder/project resource where this organization policy is set.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inheritFromParent ↔ bool?
If inherit_from_parent is true, Rules set higher up in the hierarchy (up to the closest root) are inherited and present in the effective policy.
getter/setter pair
reset ↔ bool?
Ignores policies set above this resource and restores the default behavior of the constraint at this resource.
getter/setter pair
rules ↔ List<GoogleCloudAssetV1Rule>?
List of rules for this organization policy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited