AssetException class

An exception of an asset.

Constructors

AssetException({String? details, String? exceptionType})
AssetException.fromJson(Map json_)

Properties

details ↔ String?
The details of the exception.
getter/setter pair
exceptionType ↔ String?
The type of exception. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited