BigQueryDestination class

A BigQuery destination for exporting assets to.

Constructors

BigQueryDestination({String? dataset, bool? force, PartitionSpec? partitionSpec, bool? separateTablesPerAssetType, String? table})
BigQueryDestination.fromJson(Map json_)

Properties

dataset ↔ String?
The BigQuery dataset in format "projects/projectId/datasets/datasetId", to which the snapshot result should be exported.
getter/setter pair
force ↔ bool?
If the destination table already exists and this flag is TRUE, the table will be overwritten by the contents of assets snapshot.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partitionSpec ↔ PartitionSpec?
[partition_spec] determines whether to export to partitioned table(s) and how to partition the data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separateTablesPerAssetType ↔ bool?
If this flag is TRUE, the snapshot results will be written to one or multiple tables, each of which contains results of one asset type.
getter/setter pair
table ↔ String?
The BigQuery table to which the snapshot result should be written.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited