ExportAssetsRequest class

Export asset request.

Constructors

ExportAssetsRequest({List<String>? assetTypes, String? contentType, OutputConfig? outputConfig, String? readTime, List<String>? relationshipTypes})
ExportAssetsRequest.fromJson(Map json_)

Properties

assetTypes ↔ List<String>?
A list of asset types to take a snapshot for.
getter/setter pair
contentType ↔ String?
Asset content type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
outputConfig ↔ OutputConfig?
Output configuration indicating where the results will be output to.
getter/setter pair
readTime ↔ String?
Timestamp to take an asset snapshot.
getter/setter pair
relationshipTypes ↔ List<String>?
A list of relationship types to export, for example: INSTANCE_TO_INSTANCEGROUP.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited