GoogleCloudAssetV1QueryAssetsOutputConfigBigQueryDestination class

BigQuery destination.

Properties

dataset ↔ String?
The BigQuery dataset where the query results will be saved.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table ↔ String?
The BigQuery table where the query results will be saved.
getter/setter pair
writeDisposition ↔ String?
Specifies the action that occurs if the destination table or partition already exists.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited