GoogleIdentityAccesscontextmanagerV1BasicLevel class

BasicLevel is an AccessLevel using a set of recommended features.

Properties

combiningFunction ↔ String?
How the conditions list should be combined to determine if a request is granted this AccessLevel.
getter/setter pair
conditions ↔ List<GoogleIdentityAccesscontextmanagerV1Condition>?
A list of requirements for the AccessLevel to be granted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited