GoogleIdentityAccesscontextmanagerV1ServicePattern class
Service patterns used to allow access.
Constructors
-
GoogleIdentityAccesscontextmanagerV1ServicePattern({List<
GoogleIdentityAccesscontextmanagerV1Modifier> ? modifiers, String? pattern, String? service}) - GoogleIdentityAccesscontextmanagerV1ServicePattern.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
modifiers
↔ List<
GoogleIdentityAccesscontextmanagerV1Modifier> ? -
Modifiers to apply to the requests that match the URL pattern.
getter/setter pair
- pattern ↔ String?
-
URL pattern to allow.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service ↔ String?
-
Supported service to allow.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited