modifiers property
Modifiers to apply to the requests that match the URL pattern.
Implementation
core.List<GoogleIdentityAccesscontextmanagerV1Modifier>? modifiers;
Modifiers to apply to the requests that match the URL pattern.
core.List<GoogleIdentityAccesscontextmanagerV1Modifier>? modifiers;