pattern property
URL pattern to allow.
Only patterns of ".googleapis.com / * ", "www.googleapis.com/ / * " and "*.appspot.com / * forms are supported, where should be an alphanumeric name.
Implementation
core.String? pattern;
URL pattern to allow.
Only patterns of ".googleapis.com / * ", "www.googleapis.com/ / * " and "*.appspot.com / * forms are supported, where should be an alphanumeric name.
core.String? pattern;