IamPolicyAnalysisQuery class

IAM policy analysis query message.

Constructors

IamPolicyAnalysisQuery({AccessSelector? accessSelector, ConditionContext? conditionContext, IdentitySelector? identitySelector, Options? options, ResourceSelector? resourceSelector, String? scope})
IamPolicyAnalysisQuery.fromJson(Map json_)

Properties

accessSelector ↔ AccessSelector?
Specifies roles or permissions for analysis.
getter/setter pair
conditionContext ↔ ConditionContext?
The hypothetical context for IAM conditions evaluation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identitySelector ↔ IdentitySelector?
Specifies an identity for analysis.
getter/setter pair
options ↔ Options?
The query options.
getter/setter pair
resourceSelector ↔ ResourceSelector?
Specifies a resource for analysis.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
The relative name of the root asset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited