Item class

A single piece of inventory on a VM.

Constructors

Item({SoftwarePackage? availablePackage, String? createTime, String? id, SoftwarePackage? installedPackage, String? originType, String? type, String? updateTime})
Item.fromJson(Map json_)

Properties

availablePackage ↔ SoftwarePackage?
Software package available to be installed on the VM instance.
getter/setter pair
createTime ↔ String?
When this inventory item was first detected.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Identifier for this item, unique across items for this VM.
getter/setter pair
installedPackage ↔ SoftwarePackage?
Software package present on the VM instance.
getter/setter pair
originType ↔ String?
The origin of this inventory item. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The specific type of inventory, correlating to its specific details. Possible string values are:
getter/setter pair
updateTime ↔ String?
When this inventory item was last modified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited