ListAssetsResponse class

ListAssets response.

Constructors

ListAssetsResponse({List<Asset>? assets, String? nextPageToken, String? readTime})
ListAssetsResponse.fromJson(Map json_)

Properties

assets ↔ List<Asset>?
Assets.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to retrieve the next page of results.
getter/setter pair
readTime ↔ String?
Time the snapshot was taken.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited