Options class

Contains query options.

Constructors

Options({bool? analyzeServiceAccountImpersonation, bool? expandGroups, bool? expandResources, bool? expandRoles, bool? outputGroupEdges, bool? outputResourceEdges})
Options.fromJson(Map json_)

Properties

analyzeServiceAccountImpersonation ↔ bool?
If true, the response will include access analysis from identities to resources via service account impersonation.
getter/setter pair
expandGroups ↔ bool?
If true, the identities section of the result will expand any Google groups appearing in an IAM policy binding.
getter/setter pair
expandResources ↔ bool?
If true and IamPolicyAnalysisQuery.resource_selector is not specified, the resource section of the result will expand any resource attached to an IAM policy to include resources lower in the resource hierarchy.
getter/setter pair
expandRoles ↔ bool?
If true, the access section of result will expand any roles appearing in IAM policy bindings to include their permissions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
outputGroupEdges ↔ bool?
If true, the result will output the relevant membership relationships between groups and other groups, and between groups and principals.
getter/setter pair
outputResourceEdges ↔ bool?
If true, the result will output the relevant parent/child relationships between resources.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited