OrgPolicyResult class

The organization policy result to the query.

Constructors

OrgPolicyResult({AnalyzerOrgPolicy? consolidatedPolicy, List<String>? folders, String? organization, List<AnalyzerOrgPolicy>? policyBundle, String? project})
OrgPolicyResult.fromJson(Map json_)

Properties

consolidatedPolicy ↔ AnalyzerOrgPolicy?
The consolidated organization policy for the analyzed resource.
getter/setter pair
folders ↔ List<String>?
The folder(s) that this consolidated policy belongs to, in the format of folders/{FOLDER_NUMBER}.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
organization ↔ String?
The organization that this consolidated policy belongs to, in the format of organizations/{ORGANIZATION_NUMBER}.
getter/setter pair
policyBundle ↔ List<AnalyzerOrgPolicy>?
The ordered list of all organization policies from the consolidated_policy.attached_resource.
getter/setter pair
project ↔ String?
The project that this consolidated policy belongs to, in the format of projects/{PROJECT_NUMBER}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited