QueryAssetsRequest class

QueryAssets request.

Constructors

QueryAssetsRequest({String? jobReference, QueryAssetsOutputConfig? outputConfig, int? pageSize, String? pageToken, String? readTime, TimeWindow? readTimeWindow, String? statement, String? timeout})
QueryAssetsRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobReference ↔ String?
Reference to the query job, which is from the QueryAssetsResponse of previous QueryAssets call.
getter/setter pair
outputConfig ↔ QueryAssetsOutputConfig?
Destination where the query results will be saved.
getter/setter pair
pageSize ↔ int?
The maximum number of rows to return in the results.
getter/setter pair
pageToken ↔ String?
A page token received from previous QueryAssets.
getter/setter pair
readTime ↔ String?
Queries cloud assets as they appeared at the specified point in time.
getter/setter pair
readTimeWindow ↔ TimeWindow?
[start_time] is required.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statement ↔ String?
A SQL statement that's compatible with BigQuery SQL.
getter/setter pair
timeout ↔ String?
Specifies the maximum amount of time that the client is willing to wait for the query to complete.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited