QueryAssetsResponse class

QueryAssets response.

Constructors

QueryAssetsResponse({bool? done, Status? error, String? jobReference, QueryAssetsOutputConfig? outputConfig, QueryResult? queryResult})
QueryAssetsResponse.fromJson(Map json_)

Properties

done ↔ bool?
The query response, which can be either an error or a valid response.
getter/setter pair
error ↔ Status?
Error status.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobReference ↔ String?
Reference to a query job.
getter/setter pair
outputConfig ↔ QueryAssetsOutputConfig?
Output configuration, which indicates that instead of being returned in an API response on the fly, the query result will be saved in a specific output.
getter/setter pair
queryResult ↔ QueryResult?
Result of the query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited