RelationshipAttributes class

This message only presents for the purpose of backward-compatibility.

The server will never populate this message in responses. The relationship attributes which include type, source_resource_type, target_resource_type and action.

Deprecated.

Constructors

RelationshipAttributes({String? action, String? sourceResourceType, String? targetResourceType, String? type})
RelationshipAttributes.fromJson(Map json_)

Properties

action ↔ String?
The detail of the relationship, e.g. contains, attaches
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceResourceType ↔ String?
The source asset type.
getter/setter pair
targetResourceType ↔ String?
The target asset type.
getter/setter pair
type ↔ String?
The unique identifier of the relationship type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited