Resource class

A representation of a Google Cloud resource.

Constructors

Resource({Map<String, Object?>? data, String? discoveryDocumentUri, String? discoveryName, String? location, String? parent, String? resourceUrl, String? version})
Resource.fromJson(Map json_)

Properties

data ↔ Map<String, Object?>?
The content of the resource, in which some sensitive fields are removed and may not be present.
getter/setter pair
discoveryDocumentUri ↔ String?
The URL of the discovery document containing the resource's JSON schema.
getter/setter pair
discoveryName ↔ String?
The JSON schema name listed in the discovery document.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
The location of the resource in Google Cloud, such as its zone and region.
getter/setter pair
parent ↔ String?
The full name of the immediate parent of this resource.
getter/setter pair
resourceUrl ↔ String?
The REST URL for accessing the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
The API version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited