SavedQuery class

A saved query which can be shared with others or used later.

Constructors

SavedQuery({QueryContent? content, String? createTime, String? creator, String? description, Map<String, String>? labels, String? lastUpdateTime, String? lastUpdater, String? name})
SavedQuery.fromJson(Map json_)

Properties

content ↔ QueryContent?
The query content.
getter/setter pair
createTime ↔ String?
The create time of this saved query.
getter/setter pair
creator ↔ String?
The account's email address who has created this saved query.
getter/setter pair
description ↔ String?
The description of this saved query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels applied on the resource.
getter/setter pair
lastUpdater ↔ String?
The account's email address who has updated this saved query most recently.
getter/setter pair
lastUpdateTime ↔ String?
The last update time of this saved query.
getter/setter pair
name ↔ String?
The resource name of the saved query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited