TableSchema class

BigQuery Compatible table schema.

Constructors

TableSchema({List<TableFieldSchema>? fields})
TableSchema.fromJson(Map json_)

Properties

fields ↔ List<TableFieldSchema>?
Describes the fields in a table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited