TemporalAsset class

An asset in Google Cloud and its temporal metadata, including the time window when it was observed and its status during that window.

Constructors

TemporalAsset({Asset? asset, bool? deleted, Asset? priorAsset, String? priorAssetState, TimeWindow? window})
TemporalAsset.fromJson(Map json_)

Properties

asset ↔ Asset?
An asset in Google Cloud.
getter/setter pair
deleted ↔ bool?
Whether the asset has been deleted or not.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
priorAsset ↔ Asset?
Prior copy of the asset.
getter/setter pair
priorAssetState ↔ String?
State of prior_asset. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
window ↔ TimeWindow?
The time window when the asset data and state was observed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited