BillingAccount class

A billing account in the Google Cloud Console.

You can assign a billing account to one or more projects.

Constructors

BillingAccount({String? currencyCode, String? displayName, String? masterBillingAccount, String? name, bool? open, String? parent})
BillingAccount.fromJson(Map json_)

Properties

currencyCode ↔ String?
The currency in which the billing account is billed and charged, represented as an ISO 4217 code such as USD.
getter/setter pair
displayName ↔ String?
The display name given to the billing account, such as My Billing Account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
masterBillingAccount ↔ String?
If this account is a subaccount, then this will be the resource name of the parent billing account that it is being resold through.
getter/setter pair
name ↔ String?
The resource name of the billing account.
getter/setter pair
open ↔ bool?
True if the billing account is open, and will therefore be charged for any usage on associated projects.
getter/setter pair
parent ↔ String?
The billing account's parent resource identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited