Sku class

Encapsulates a single SKU in Google Cloud

Constructors

Sku({Category? category, String? description, GeoTaxonomy? geoTaxonomy, String? name, List<PricingInfo>? pricingInfo, String? serviceProviderName, List<String>? serviceRegions, String? skuId})
Sku.fromJson(Map json_)

Properties

category ↔ Category?
The category hierarchy of this SKU, purely for organizational purpose.
getter/setter pair
description ↔ String?
A human readable description of the SKU, has a maximum length of 256 characters.
getter/setter pair
geoTaxonomy ↔ GeoTaxonomy?
The geographic taxonomy for this sku.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name for the SKU.
getter/setter pair
pricingInfo ↔ List<PricingInfo>?
A timeline of pricing info for this SKU in chronological order.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceProviderName ↔ String?
Identifies the service provider.
getter/setter pair
serviceRegions ↔ List<String>?
List of service regions this SKU is offered at.
getter/setter pair
skuId ↔ String?
The identifier for the SKU.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited