ApprovalResult class

ApprovalResult describes the decision and associated metadata of a manual approval of a build.

Constructors

ApprovalResult({String? approvalTime, String? approverAccount, String? comment, String? decision, String? url})
ApprovalResult.fromJson(Map json_)

Properties

approvalTime ↔ String?
The time when the approval decision was made.
getter/setter pair
approverAccount ↔ String?
Email of the user that called the ApproveBuild API to approve or reject a build at the time that the API was called.
getter/setter pair
comment ↔ String?
An optional comment for this manual approval result.
getter/setter pair
decision ↔ String?
The decision of this manual approval.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
An optional URL tied to this manual approval result.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited