BitbucketServerConnectedRepository class

/ BitbucketServerConnectedRepository represents a connected Bitbucket Server / repository.

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent ↔ String?
The name of the BitbucketServerConfig that added connected repository.
getter/setter pair
repo ↔ BitbucketServerRepositoryId?
The Bitbucket Server repositories to connect.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ Status?
The status of the repo connection request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited