BitbucketServerRepository class

BitbucketServerRepository represents a repository hosted on a Bitbucket Server.

Constructors

BitbucketServerRepository({String? browseUri, String? description, String? displayName, String? name, BitbucketServerRepositoryId? repoId})
BitbucketServerRepository.fromJson(Map json_)

Properties

browseUri ↔ String?
Link to the browse repo page on the Bitbucket Server instance.
getter/setter pair
description ↔ String?
Description of the repository.
getter/setter pair
displayName ↔ String?
Display name of the repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the repository.
getter/setter pair
repoId ↔ BitbucketServerRepositoryId?
Identifier for a repository hosted on a Bitbucket Server.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited