BitbucketServerSecrets class

BitbucketServerSecrets represents the secrets in Secret Manager for a Bitbucket Server.

Constructors

BitbucketServerSecrets({String? adminAccessTokenVersionName, String? readAccessTokenVersionName, String? webhookSecretVersionName})
BitbucketServerSecrets.fromJson(Map json_)

Properties

adminAccessTokenVersionName ↔ String?
The resource name for the admin access token's secret version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readAccessTokenVersionName ↔ String?
The resource name for the read access token's secret version.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webhookSecretVersionName ↔ String?
The resource name for the webhook secret's secret version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited