BitbucketServerTriggerConfig class

BitbucketServerTriggerConfig describes the configuration of a trigger that creates a build whenever a Bitbucket Server event is received.

Constructors

BitbucketServerTriggerConfig({BitbucketServerConfig? bitbucketServerConfig, String? bitbucketServerConfigResource, String? projectKey, PullRequestFilter? pullRequest, PushFilter? push, String? repoSlug})
BitbucketServerTriggerConfig.fromJson(Map json_)

Properties

bitbucketServerConfig ↔ BitbucketServerConfig?
The BitbucketServerConfig specified in the bitbucket_server_config_resource field.
getter/setter pair
bitbucketServerConfigResource ↔ String?
The Bitbucket server config resource that this trigger config maps to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
projectKey ↔ String?
Key of the project that the repo is in.
getter/setter pair
pullRequest ↔ PullRequestFilter?
Filter to match changes in pull requests.
getter/setter pair
push ↔ PushFilter?
Filter to match changes in refs like branches, tags.
getter/setter pair
repoSlug ↔ String?
Slug of the repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited