Build class

A build resource in the Cloud Build API.

At a high level, a Build describes where to find source code, how to build it (for example, the builder image to run on the source), and where to store the built artifacts. Fields can include the following variables, which will be expanded when the build is created: - $PROJECT_ID: the project ID of the build. - $PROJECT_NUMBER: the project number of the build. - $LOCATION: the location/region of the build. - $BUILD_ID: the autogenerated ID of the build. - $REPO_NAME: the source repository name specified by RepoSource. - $BRANCH_NAME: the branch name specified by RepoSource. - $TAG_NAME: the tag name specified by RepoSource. - $REVISION_ID or $COMMIT_SHA: the commit SHA specified by RepoSource or resolved from the specified branch or tag. - $SHORT_SHA: first 7 characters of $REVISION_ID or $COMMIT_SHA.

Constructors

Build({BuildApproval? approval, Artifacts? artifacts, Secrets? availableSecrets, String? buildTriggerId, String? createTime, List<Dependency>? dependencies, FailureInfo? failureInfo, String? finishTime, GitConfig? gitConfig, String? id, List<String>? images, String? logUrl, String? logsBucket, String? name, BuildOptions? options, String? projectId, String? queueTtl, Results? results, List<Secret>? secrets, String? serviceAccount, Source? source, SourceProvenance? sourceProvenance, String? startTime, String? status, String? statusDetail, List<BuildStep>? steps, Map<String, String>? substitutions, List<String>? tags, String? timeout, Map<String, TimeSpan>? timing, List<Warning>? warnings})
Build.fromJson(Map json_)

Properties

approval ↔ BuildApproval?
Describes this build's approval configuration, status, and result.
getter/setter pair
artifacts ↔ Artifacts?
Artifacts produced by the build that should be uploaded upon successful completion of all build steps.
getter/setter pair
availableSecrets ↔ Secrets?
Secrets and secret environment variables.
getter/setter pair
buildTriggerId ↔ String?
The ID of the BuildTrigger that triggered this build, if it was triggered automatically.
getter/setter pair
createTime ↔ String?
Time at which the request to create the build was received.
getter/setter pair
dependencies ↔ List<Dependency>?
Dependencies that the Cloud Build worker will fetch before executing user steps.
getter/setter pair
failureInfo ↔ FailureInfo?
Contains information about the build when status=FAILURE.
getter/setter pair
finishTime ↔ String?
Time at which execution of the build was finished.
getter/setter pair
gitConfig ↔ GitConfig?
Configuration for git operations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique identifier of the build.
getter/setter pair
images ↔ List<String>?
A list of images to be pushed upon the successful completion of all build steps.
getter/setter pair
logsBucket ↔ String?
Cloud Storage bucket where logs should be written (see Bucket Name Requirements).
getter/setter pair
logUrl ↔ String?
URL to logs for this build in Google Cloud Console.
getter/setter pair
name ↔ String?
The 'Build' name with format: projects/{project}/locations/{location}/builds/{build}, where {build} is a unique identifier generated by the service.
getter/setter pair
options ↔ BuildOptions?
Special options for this build.
getter/setter pair
projectId ↔ String?
ID of the project.
getter/setter pair
queueTtl ↔ String?
TTL in queue for this build.
getter/setter pair
results ↔ Results?
Results of the build.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secrets ↔ List<Secret>?
Secrets to decrypt using Cloud Key Management Service.
getter/setter pair
serviceAccount ↔ String?
IAM service account whose credentials will be used at build runtime.
getter/setter pair
source ↔ Source?
The location of the source files to build.
getter/setter pair
sourceProvenance ↔ SourceProvenance?
A permanent fixed identifier for source.
getter/setter pair
startTime ↔ String?
Time at which execution of the build was started.
getter/setter pair
status ↔ String?
Status of the build.
getter/setter pair
statusDetail ↔ String?
Customer-readable message about the current status.
getter/setter pair
steps ↔ List<BuildStep>?
The operations to be performed on the workspace.
getter/setter pair
substitutions ↔ Map<String, String>?
Substitutions data for Build resource.
getter/setter pair
tags ↔ List<String>?
Tags for annotation of a Build.
getter/setter pair
timeout ↔ String?
Amount of time that this build should be allowed to run, to second granularity.
getter/setter pair
timing ↔ Map<String, TimeSpan>?
Stores timing information for phases of the build.
getter/setter pair
warnings ↔ List<Warning>?
Non-fatal problems encountered during the execution of the build.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited