BuildOptions class

Optional arguments to enable specific features of builds.

Constructors

BuildOptions({bool? automapSubstitutions, String? defaultLogsBucketBehavior, String? diskSizeGb, bool? dynamicSubstitutions, bool? enableStructuredLogging, List<String>? env, String? logStreamingOption, String? logging, String? machineType, PoolOption? pool, String? pubsubTopic, String? requestedVerifyOption, List<String>? secretEnv, List<String>? sourceProvenanceHash, String? substitutionOption, List<Volume>? volumes, String? workerPool})
BuildOptions.fromJson(Map json_)

Properties

automapSubstitutions ↔ bool?
Option to include built-in and custom substitutions as env variables for all build steps.
getter/setter pair
defaultLogsBucketBehavior ↔ String?
Option to specify how default logs buckets are setup.
getter/setter pair
diskSizeGb ↔ String?
Requested disk size for the VM that runs the build.
getter/setter pair
dynamicSubstitutions ↔ bool?
Option to specify whether or not to apply bash style string operations to the substitutions.
getter/setter pair
enableStructuredLogging ↔ bool?
Option to specify whether structured logging is enabled.
getter/setter pair
env ↔ List<String>?
A list of global environment variable definitions that will exist for all build steps in this build.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
logging ↔ String?
Option to specify the logging mode, which determines if and where build logs are stored. Possible string values are:
getter/setter pair
logStreamingOption ↔ String?
Option to define build log streaming behavior to Cloud Storage. Possible string values are:
getter/setter pair
machineType ↔ String?
Compute Engine machine type on which to run the build. Possible string values are:
getter/setter pair
pool ↔ PoolOption?
Specification for execution on a WorkerPool.
getter/setter pair
pubsubTopic ↔ String?
Option to specify the Pub/Sub topic to receive build status updates.
getter/setter pair
requestedVerifyOption ↔ String?
Requested verifiability options. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretEnv ↔ List<String>?
A list of global environment variables, which are encrypted using a Cloud Key Management Service crypto key.
getter/setter pair
sourceProvenanceHash ↔ List<String>?
Requested hash for SourceProvenance.
getter/setter pair
substitutionOption ↔ String?
Option to specify behavior when there is an error in the substitution checks.
getter/setter pair
volumes ↔ List<Volume>?
Global list of volumes to mount for ALL build steps Each volume is created as an empty volume prior to starting the build process.
getter/setter pair
workerPool ↔ String?
This field deprecated; please use pool.name instead.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited