BuildStep class

A step in the build pipeline.

Constructors

BuildStep({List<int>? allowExitCodes, bool? allowFailure, List<String>? args, bool? automapSubstitutions, String? dir, String? entrypoint, List<String>? env, int? exitCode, String? id, String? name, TimeSpan? pullTiming, List<StepResult>? results, String? script, List<String>? secretEnv, String? status, String? timeout, TimeSpan? timing, List<Volume>? volumes, List<String>? waitFor})
BuildStep.fromJson(Map json_)

Properties

allowExitCodes ↔ List<int>?
Allow this build step to fail without failing the entire build if and only if the exit code is one of the specified codes.
getter/setter pair
allowFailure ↔ bool?
Allow this build step to fail without failing the entire build.
getter/setter pair
args ↔ List<String>?
A list of arguments that will be presented to the step when it is started.
getter/setter pair
automapSubstitutions ↔ bool?
Option to include built-in and custom substitutions as env variables for this build step.
getter/setter pair
dir ↔ String?
Working directory to use when running this step's container.
getter/setter pair
entrypoint ↔ String?
Entrypoint to be used instead of the build step image's default entrypoint.
getter/setter pair
env ↔ List<String>?
A list of environment variable definitions to be used when running a step.
getter/setter pair
exitCode ↔ int?
Return code from running the step.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique identifier for this build step, used in wait_for to reference this build step as a dependency.
getter/setter pair
name ↔ String?
The name of the container image that will run this particular build step.
getter/setter pair
pullTiming ↔ TimeSpan?
Stores timing information for pulling this build step's builder image only.
getter/setter pair
results ↔ List<StepResult>?
Declaration of results for this build step.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script ↔ String?
A shell script to be executed in the step.
getter/setter pair
secretEnv ↔ List<String>?
A list of environment variables which are encrypted using a Cloud Key Management Service crypto key.
getter/setter pair
status ↔ String?
Status of the build step.
getter/setter pair
timeout ↔ String?
Time limit for executing this build step.
getter/setter pair
timing ↔ TimeSpan?
Stores timing information for executing this build step.
getter/setter pair
volumes ↔ List<Volume>?
List of volumes to mount into the build step.
getter/setter pair
waitFor ↔ List<String>?
The ID(s) of the step(s) that this build step depends on.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited