ociMediaType property

String? ociMediaType
getter/setter pair

The OCI media type of the artifact.

Non-OCI images, such as Docker images, will have an unspecified value.

Output only. Possible string values are:

  • "OCI_MEDIA_TYPE_UNSPECIFIED" : Default value.
  • "IMAGE_MANIFEST" : The artifact is an image manifest, which represents a single image with all its layers.
  • "IMAGE_INDEX" : The artifact is an image index, which can contain a list of image manifests.

Implementation

core.String? ociMediaType;