CloudBuildApi class

Creates and manages builds on Google Cloud Platform.

Constructors

CloudBuildApi(Client client, {String rootUrl = 'https://cloudbuild.googleapis.com/', String servicePath = ''})

Properties

githubDotComWebhook → GithubDotComWebhookResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
locations → LocationsResource
no setter
operations → OperationsResource
no setter
projects → ProjectsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
v1 → V1Resource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

cloudPlatformScope → const String
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.