ConnectedRepository class

Location of the source in a 2nd-gen Google Cloud Build repository resource.

Constructors

ConnectedRepository({String? dir, String? repository, String? revision})
ConnectedRepository.fromJson(Map json_)

Properties

dir ↔ String?
Directory, relative to the source root, in which to run the build.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
repository ↔ String?
Name of the Google Cloud Build repository, formatted as projects / * /locations / * /connections / * /repositories / * .
getter/setter pair
revision ↔ String?
The revision to fetch from the Git repository such as a branch, a tag, a commit SHA, or any Git ref.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited