CreateBitbucketServerConnectedRepositoryRequest class

Request to connect a repository from a connected Bitbucket Server host.

Properties

bitbucketServerConnectedRepository ↔ BitbucketServerConnectedRepository?
The Bitbucket Server repository to connect.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parent ↔ String?
The name of the BitbucketServerConfig that added connected repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited