DefaultServiceAccount class

The default service account used for Builds.

Constructors

DefaultServiceAccount({String? name, String? serviceAccountEmail})
DefaultServiceAccount.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountEmail ↔ String?
The email address of the service account identity that will be used for a build by default.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited