Dependency class

A dependency that the Cloud Build worker will fetch before executing user steps.

Constructors

Dependency({bool? empty, GenericArtifactDependency? genericArtifact, GitSourceDependency? gitSource})
Dependency.fromJson(Map json_)

Properties

empty ↔ bool?
If set to true disable all dependency fetching (ignoring the default source as well).
getter/setter pair
genericArtifact ↔ GenericArtifactDependency?
Represents a generic artifact as a build dependency.
getter/setter pair
gitSource ↔ GitSourceDependency?
Represents a git repository as a build dependency.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited