FailureInfo class

A fatal problem encountered during the execution of the build.

Constructors

FailureInfo({String? detail, String? type})
FailureInfo.fromJson(Map json_)

Properties

detail ↔ String?
Explains the failure issue in more detail using hard-coded text.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The name of the failure. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited