GenericArtifactDependency class

Represents a generic artifact as a build dependency.

Constructors

GenericArtifactDependency({String? destPath, String? resource})
GenericArtifactDependency.fromJson(Map json_)

Properties

destPath String?
Where the artifact files should be placed on the worker.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
resource String?
The location to download the artifact files from.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited