GitFileSource class

GitFileSource describes a file within a (possibly remote) code repository.

Constructors

GitFileSource({String? bitbucketServerConfig, String? githubEnterpriseConfig, String? path, String? repoType, String? repository, String? revision, String? uri})
GitFileSource.fromJson(Map json_)

Properties

bitbucketServerConfig ↔ String?
The full resource name of the bitbucket server config.
getter/setter pair
githubEnterpriseConfig ↔ String?
The full resource name of the github enterprise config.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
path ↔ String?
The path of the file, with the repo root as the root of the path.
getter/setter pair
repository ↔ String?
The fully qualified resource name of the Repos API repository.
getter/setter pair
repoType ↔ String?
See RepoType above. Possible string values are:
getter/setter pair
revision ↔ String?
The branch, tag, arbitrary ref, or SHA version of the repo to use when resolving the filename (optional).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
The URI of the repo.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited