GitHubEventsConfig class

GitHubEventsConfig describes the configuration of a trigger that creates a build whenever a GitHub event is received.

Constructors

GitHubEventsConfig({String? enterpriseConfigResourceName, String? installationId, String? name, String? owner, PullRequestFilter? pullRequest, PushFilter? push})
GitHubEventsConfig.fromJson(Map json_)

Properties

enterpriseConfigResourceName ↔ String?
The resource name of the github enterprise config that should be applied to this installation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installationId ↔ String?
The installationID that emits the GitHub event.
getter/setter pair
name ↔ String?
Name of the repository.
getter/setter pair
owner ↔ String?
Owner of the repository.
getter/setter pair
pullRequest ↔ PullRequestFilter?
filter to match changes in pull requests.
getter/setter pair
push ↔ PushFilter?
filter to match changes in refs like branches, tags.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited