GitSourceDependency class

Represents a git repository as a build dependency.

Constructors

GitSourceDependency({String? depth, String? destPath, bool? fetchTags, bool? recurseSubmodules, GitSourceRepository? repository, String? revision})
GitSourceDependency.fromJson(Map json_)

Properties

depth ↔ String?
How much history should be fetched for the build (default 1, -1 for all history).
getter/setter pair
destPath ↔ String?
Where should the files be placed on the worker.
getter/setter pair
fetchTags ↔ bool?
True if remote tags should be fetched too (default false).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
recurseSubmodules ↔ bool?
True if submodules should be fetched too (default false).
getter/setter pair
repository ↔ GitSourceRepository?
The kind of repo (url or dev connect).
getter/setter pair
revision ↔ String?
The revision that we will fetch the repo at.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited