GitSourceRepository class

A repository for a git source.

Constructors

GitSourceRepository({String? developerConnect, String? url})
GitSourceRepository.fromJson(Map json_)

Properties

developerConnect ↔ String?
The Developer Connect Git repository link formatted as projects / * /locations / * /connections / * /gitRepositoryLink / *
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
Location of the Git repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited