HttpConfig class

HttpConfig is a configuration for HTTP related git operations.

Constructors

HttpConfig({String? proxySecretVersionName})
HttpConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
proxySecretVersionName ↔ String?
SecretVersion resource of the HTTP proxy URL.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited