ListGitLabConfigsResponse class

RPC response object returned by ListGitLabConfigs RPC method.

Constructors

ListGitLabConfigsResponse({List<GitLabConfig>? gitlabConfigs, String? nextPageToken})
ListGitLabConfigsResponse.fromJson(Map json_)

Properties

gitlabConfigs ↔ List<GitLabConfig>?
A list of GitLabConfigs
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token that can be sent as page_token to retrieve the next page If this field is omitted, there are no subsequent pages.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited