LocationsResource class

Constructors

LocationsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
regionalWebhook(HttpBody request, String location, {String? webhookKey, String? $fields}) → Future<Empty>
ReceiveRegionalWebhook is called when the API receives a regional GitHub webhook.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited