NetworkConfig class

Defines the network configuration for the pool.

Constructors

NetworkConfig({String? egressOption, String? peeredNetwork, String? peeredNetworkIpRange})
NetworkConfig.fromJson(Map json_)

Properties

egressOption ↔ String?
Option to configure network egress for the workers. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
peeredNetwork ↔ String?
The network definition that the workers are peered to.
getter/setter pair
peeredNetworkIpRange ↔ String?
Subnet IP range within the peered network.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited