Oci class

OCI image to upload to Artifact Registry upon successful completion of all build steps.

Constructors

Oci({String? file, String? registryPath, List<String>? tags})
Oci.fromJson(Map json_)

Properties

file String?
Path on the local file system where to find the container to upload.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
registryPath String?
Registry path to upload the container to.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>?
Tags to apply to the uploaded image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited