file property
Path on the local file system where to find the container to upload.
e.g. /workspace/my-image.tar
Required.
Implementation
core.String? file;
Path on the local file system where to find the container to upload.
e.g. /workspace/my-image.tar
Required.
core.String? file;