PrivatePoolV1Config class

Configuration for a V1 PrivatePool.

Constructors

PrivatePoolV1Config({NetworkConfig? networkConfig, PrivateServiceConnect? privateServiceConnect, WorkerConfig? workerConfig})
PrivatePoolV1Config.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkConfig ↔ NetworkConfig?
Network configuration for the pool.
getter/setter pair
privateServiceConnect ↔ PrivateServiceConnect?
Private Service Connect(PSC) Network configuration for the pool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workerConfig ↔ WorkerConfig?
Machine configuration for the workers in the pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited