PrivateServiceConnect class

Defines the Private Service Connect network configuration for the pool.

Constructors

PrivateServiceConnect({String? networkAttachment, bool? publicIpAddressDisabled, bool? routeAllTraffic})
PrivateServiceConnect.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkAttachment ↔ String?
The network attachment that the worker network interface is peered to.
getter/setter pair
publicIpAddressDisabled ↔ bool?
Disable public IP on the primary network interface.
getter/setter pair
routeAllTraffic ↔ bool?
Route all traffic through PSC interface.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited