ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

bitbucketServerConfigs ProjectsLocationsBitbucketServerConfigsResource
no setter
builds ProjectsLocationsBuildsResource
no setter
githubEnterpriseConfigs ProjectsLocationsGithubEnterpriseConfigsResource
no setter
hashCode int
The hash code for this object.
no setterinherited
operations ProjectsLocationsOperationsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
triggers ProjectsLocationsTriggersResource
no setter
workerPools ProjectsLocationsWorkerPoolsResource
no setter

Methods

getDefaultServiceAccount(String name, {String? $fields}) Future<DefaultServiceAccount>
Returns the DefaultServiceAccount used by the project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited