PullRequestFilter class

PullRequestFilter contains filter properties for matching GitHub Pull Requests.

Constructors

PullRequestFilter({String? branch, String? commentControl, bool? invertRegex})
PullRequestFilter.fromJson(Map json_)

Properties

branch ↔ String?
Regex of branches to match.
getter/setter pair
commentControl ↔ String?
If CommentControl is enabled, depending on the setting, builds may not fire until a repository writer comments /gcbrun on a pull request or /gcbrun is in the pull request description.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invertRegex ↔ bool?
If true, branches that do NOT match the git_ref will trigger a build.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited