RepositoryEventConfig class

The configuration of a trigger that creates a build whenever an event from Repo API is received.

Constructors

RepositoryEventConfig({PullRequestFilter? pullRequest, PushFilter? push, String? repository, String? repositoryType})
RepositoryEventConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pullRequest ↔ PullRequestFilter?
Filter to match changes in pull requests.
getter/setter pair
push ↔ PushFilter?
Filter to match changes in refs like branches, tags.
getter/setter pair
repository ↔ String?
The resource name of the Repo API resource.
getter/setter pair
repositoryType ↔ String?
The type of the SCM vendor the repository points to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited