SecretManagerSecret class

Pairs a secret environment variable with a SecretVersion in Secret Manager.

Constructors

SecretManagerSecret({String? env, String? versionName})
SecretManagerSecret.fromJson(Map json_)

Properties

env ↔ String?
Environment variable name to associate with the secret.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionName ↔ String?
Resource name of the SecretVersion.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited