Source class

Location of the source in a supported storage service.

Constructors

Source({ConnectedRepository? connectedRepository, DeveloperConnectConfig? developerConnectConfig, GitSource? gitSource, RepoSource? repoSource, StorageSource? storageSource, StorageSourceManifest? storageSourceManifest})
Source.fromJson(Map json_)

Properties

connectedRepository ↔ ConnectedRepository?
If provided, get the source from this 2nd-gen Google Cloud Build repository resource.
getter/setter pair
developerConnectConfig ↔ DeveloperConnectConfig?
If provided, get the source from this Developer Connect config.
getter/setter pair
gitSource ↔ GitSource?
If provided, get the source from this Git repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
repoSource ↔ RepoSource?
If provided, get the source from this location in a Cloud Source Repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageSource ↔ StorageSource?
If provided, get the source from this location in Cloud Storage.
getter/setter pair
storageSourceManifest ↔ StorageSourceManifest?
If provided, get the source from this manifest in Cloud Storage.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited