SourceProvenance class

Provenance of the source.

Ways to find the original source, or verify that some source was used for this build.

Constructors

SourceProvenance({Map<String, FileHashes>? fileHashes, ConnectedRepository? resolvedConnectedRepository, GitSource? resolvedGitSource, RepoSource? resolvedRepoSource, StorageSource? resolvedStorageSource, StorageSourceManifest? resolvedStorageSourceManifest})
SourceProvenance.fromJson(Map json_)

Properties

fileHashes ↔ Map<String, FileHashes>?
Hash(es) of the build source, which can be used to verify that the original source integrity was maintained in the build.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resolvedConnectedRepository ↔ ConnectedRepository?
A copy of the build's source.connected_repository, if exists, with any revisions resolved.
getter/setter pair
resolvedGitSource ↔ GitSource?
A copy of the build's source.git_source, if exists, with any revisions resolved.
getter/setter pair
resolvedRepoSource ↔ RepoSource?
A copy of the build's source.repo_source, if exists, with any revisions resolved.
getter/setter pair
resolvedStorageSource ↔ StorageSource?
A copy of the build's source.storage_source, if exists, with any generations resolved.
getter/setter pair
resolvedStorageSourceManifest ↔ StorageSourceManifest?
A copy of the build's source.storage_source_manifest, if exists, with any revisions resolved.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited