StorageSource class

Location of the source in an archive file in Cloud Storage.

Constructors

StorageSource({String? bucket, String? generation, String? object, String? sourceFetcher})
StorageSource.fromJson(Map json_)

Properties

bucket ↔ String?
Cloud Storage bucket containing the source (see Bucket Name Requirements).
getter/setter pair
generation ↔ String?
Cloud Storage generation for the object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
object ↔ String?
Cloud Storage object containing the source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFetcher ↔ String?
Option to specify the tool to fetch the source file for the build.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited