fileHashes property
The file hashes that make up the generic artifact.
Output only.
Implementation
core.Map<core.String, FileHashes>? fileHashes;
The file hashes that make up the generic artifact.
Output only.
core.Map<core.String, FileHashes>? fileHashes;