Warning class

A non-fatal problem encountered during the execution of the build.

Constructors

Warning({String? priority, String? text})
Warning.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
priority ↔ String?
The priority for this warning. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
Explanation of the warning generated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited