WorkerConfig class

Defines the configuration to be used for creating workers in the pool.

Constructors

WorkerConfig({String? diskSizeGb, bool? enableNestedVirtualization, String? machineType})
WorkerConfig.fromJson(Map json_)

Properties

diskSizeGb ↔ String?
Size of the disk attached to the worker, in GB.
getter/setter pair
enableNestedVirtualization ↔ bool?
Enable nested virtualization on the worker, if supported by the machine type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
machineType ↔ String?
Machine type of a worker, such as e2-medium.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited