GitHubConfig class

Configuration for connections to github.com.

Constructors

GitHubConfig({String? appInstallationId, OAuthCredential? authorizerCredential})
GitHubConfig.fromJson(Map json_)

Properties

appInstallationId ↔ String?
GitHub App installation id.
getter/setter pair
authorizerCredential ↔ OAuthCredential?
OAuth credential of the account that authorized the Cloud Build GitHub App.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited