Repository class

A repository associated to a parent connection.

Constructors

Repository({Map<String, String>? annotations, String? createTime, String? etag, String? name, String? remoteUri, String? updateTime, String? webhookId})
Repository.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Allows clients to store small amounts of arbitrary data.
getter/setter pair
createTime ↔ String?
Server assigned timestamp for when the connection was created.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of the repository, in the format `projects / * /locations /
getter/setter pair
remoteUri ↔ String?
Git Clone HTTPS URI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Server assigned timestamp for when the connection was updated.
getter/setter pair
webhookId ↔ String?
External ID of the webhook created for the repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited