UserCredential class

Represents a personal access token that authorized the Connection, and associated metadata.

Constructors

UserCredential({String? userTokenSecretVersion, String? username})
UserCredential.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String?
The username associated to this token.
getter/setter pair
userTokenSecretVersion ↔ String?
A SecretManager resource containing the user token that authorizes the Cloud Build connection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited