AccountsResource class

Constructors

AccountsResource(ApiRequester client)

Properties

no setter
customers → AccountsCustomersResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
offers → AccountsOffersResource
no setter
reportJobs → AccountsReportJobsResource
no setter
reports → AccountsReportsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skuGroups → AccountsSkuGroupsResource
no setter

Methods

checkCloudIdentityAccountsExist(GoogleCloudChannelV1CheckCloudIdentityAccountsExistRequest request, String parent, {String? $fields}) → Future<GoogleCloudChannelV1CheckCloudIdentityAccountsExistResponse>
Confirms the existence of Cloud Identity accounts based on the domain and if the Cloud Identity accounts are owned by the reseller.
listSubscribers(String account, {String? integrator, int? pageSize, String? pageToken, String? $fields}) → Future<GoogleCloudChannelV1ListSubscribersResponse>
Lists service accounts with subscriber privileges on the Pub/Sub topic created for this Channel Services account or integrator.
listTransferableOffers(GoogleCloudChannelV1ListTransferableOffersRequest request, String parent, {String? $fields}) → Future<GoogleCloudChannelV1ListTransferableOffersResponse>
List TransferableOffers of a customer based on Cloud Identity ID or Customer Name in the request.
listTransferableSkus(GoogleCloudChannelV1ListTransferableSkusRequest request, String parent, {String? $fields}) → Future<GoogleCloudChannelV1ListTransferableSkusResponse>
List TransferableSkus of a customer based on the Cloud Identity ID or Customer Name in the request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(GoogleCloudChannelV1RegisterSubscriberRequest request, String account, {String? $fields}) → Future<GoogleCloudChannelV1RegisterSubscriberResponse>
Registers a service account with subscriber privileges on the Pub/Sub topic for this Channel Services account or integrator.
toString() → String
A string representation of this object.
inherited
unregister(GoogleCloudChannelV1UnregisterSubscriberRequest request, String account, {String? $fields}) → Future<GoogleCloudChannelV1UnregisterSubscriberResponse>
Unregisters a service account with subscriber privileges on the Pub/Sub topic created for this Channel Services account or integrator.

Operators

operator ==(Object other) → bool
The equality operator.
inherited