GoogleCloudChannelV1ChannelPartnerRepricingConfig class

Configuration for how a distributor will rebill a channel partner (also known as a distributor-authorized reseller).

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of the ChannelPartnerRepricingConfig.
getter/setter pair
repricingConfig ↔ GoogleCloudChannelV1RepricingConfig?
The configuration for bill modifications made by a reseller before sending it to ChannelPartner.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Timestamp of an update to the repricing rule.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited