GoogleCloudChannelV1ConditionalOverride class

Specifies the override to conditionally apply.

Properties

adjustment ↔ GoogleCloudChannelV1RepricingAdjustment?
Information about the applied override's adjustment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rebillingBasis ↔ String?
The RebillingBasis to use for the applied override.
getter/setter pair
repricingCondition ↔ GoogleCloudChannelV1RepricingCondition?
Specifies the condition which, if met, will apply the override.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited