GoogleCloudChannelV1DiscountComponent class

Represents a single component of the total discount applicable on a Price.

Constructors

GoogleCloudChannelV1DiscountComponent({GoogleTypeMoney? discountAbsolute, double? discountPercentage, String? discountType})
GoogleCloudChannelV1DiscountComponent.fromJson(Map json_)

Properties

discountAbsolute ↔ GoogleTypeMoney?
Fixed value discount.
getter/setter pair
discountPercentage ↔ double?
Discount percentage, represented as decimal.
getter/setter pair
discountType ↔ String?
Type of the discount. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited