GoogleCloudChannelV1ProvisionCloudIdentityRequest class

Request message for CloudChannelService.ProvisionCloudIdentity

Properties

cloudIdentityInfo ↔ GoogleCloudChannelV1CloudIdentityInfo?
CloudIdentity-specific customer information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user ↔ GoogleCloudChannelV1AdminUser?
Admin user information.
getter/setter pair
validateOnly ↔ bool?
Validate the request and preview the review, but do not post it.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited