GoogleCloudChannelV1RepricingAdjustment class

A type that represents the various adjustments you can apply to a bill.

Properties

hashCode → int
The hash code for this object.
no setterinherited
percentageAdjustment ↔ GoogleCloudChannelV1PercentageAdjustment?
Flat markup or markdown on an entire bill.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited