GoogleCloudChannelV1Row class

A row of report values.

Properties

hashCode → int
The hash code for this object.
no setterinherited
partitionKey ↔ String?
The key for the partition this row belongs to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<GoogleCloudChannelV1ReportValue>?
The list of values in the row.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited