GoogleCloudChannelV1RunReportJobRequest class

Request message for CloudChannelReportsService.RunReportJob.

Properties

dateRange ↔ GoogleCloudChannelV1DateRange?
The range of usage or invoice dates to include in the result.
getter/setter pair
filter ↔ String?
A structured string that defines conditions on dimension columns to restrict the report output.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The BCP-47 language code, such as "en-US".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited