Account class

Represents an account that was established by the customer on the service provider's system.

Constructors

Account({List<Approval>? approvals, String? createTime, Map<String, Object?>? inputProperties, String? name, String? provider, String? resellerParentBillingAccount, String? state, String? updateTime})
Account.fromJson(Map json_)

Properties

approvals ↔ List<Approval>?
The approvals for this account.
getter/setter pair
createTime ↔ String?
The creation timestamp.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputProperties ↔ Map<String, Object?>?
The custom properties that were collected from the user to create this account.
getter/setter pair
name ↔ String?
The resource name of the account.
getter/setter pair
provider ↔ String?
The identifier of the service provider that this account was created against.
getter/setter pair
resellerParentBillingAccount ↔ String?
The reseller parent billing account of the account's corresponding billing account, applicable only when the corresponding billing account is a subaccount of a reseller.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the account.
getter/setter pair
updateTime ↔ String?
The last update timestamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited