ConnectionError class

Information around the error that occurred if the connection state is anything other than available or unspecified

Constructors

ConnectionError({String? errorDomain, String? errorMessage})
ConnectionError.fromJson(Map json_)

Properties

errorDomain ↔ String?
The error domain for the error
getter/setter pair
errorMessage ↔ String?
The error message for the error
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited