CustomerOnboardingStep class

Container for customer onboarding information

Constructors

CustomerOnboardingStep({String? completionState, String? completionTime, String? startTime, String? step})
CustomerOnboardingStep.fromJson(Map json_)

Properties

completionState ↔ String?
Current state of the step
getter/setter pair
completionTime ↔ String?
The completion time of the onboarding step
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The starting time of the onboarding step
getter/setter pair
step ↔ String?
The onboarding step Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited