EkmConnection class

Details about the EKM connection

Constructors

EkmConnection({ConnectionError? connectionError, String? connectionName, String? connectionState})
EkmConnection.fromJson(Map json_)

Properties

connectionError ↔ ConnectionError?
The connection error that occurred if any
getter/setter pair
connectionName ↔ String?
Resource name of the EKM connection in the format: projects/{project}/locations/{location}/ekmConnections/{ekm_connection}
getter/setter pair
connectionState ↔ String?
The connection state
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited