ListViolationsResponse class

Response message for list customer violation requests

Constructors

ListViolationsResponse({String? nextPageToken, List<String>? unreachable, List<Violation>? violations})
ListViolationsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token that can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Workloads that could not be reached due to permission errors or any other error.
getter/setter pair
violations ↔ List<Violation>?
List of violation
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited