Partner class

Message describing Partner resource

Constructors

Partner({String? createTime, List<EkmMetadata>? ekmSolutions, String? name, List<String>? operatedCloudRegions, String? partnerProjectId, List<Sku>? skus, String? updateTime})
Partner.fromJson(Map json_)

Properties

createTime ↔ String?
Time the resource was created
getter/setter pair
ekmSolutions ↔ List<EkmMetadata>?
List of Google Cloud supported EKM partners supported by the partner
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
operatedCloudRegions ↔ List<String>?
List of Google Cloud regions that the partner sells services to customers.
getter/setter pair
partnerProjectId ↔ String?
Google Cloud project ID in the partner's Google Cloud organization for receiving enhanced Logs for Partners.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skus ↔ List<Sku>?
List of SKUs the partner is offering
getter/setter pair
updateTime ↔ String?
The last time the resource was updated
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited