Remediation class

Represents remediation guidance to resolve compliance violation for AssuredWorkload

Constructors

Remediation({List<String>? compliantValues, Instructions? instructions, String? remediationType})
Remediation.fromJson(Map json_)

Properties

compliantValues ↔ List<String>?
Values that can resolve the violation For example: for list org policy violations, this will either be the list of allowed or denied values
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instructions ↔ Instructions?
Remediation instructions to resolve violations
getter/setter pair
remediationType ↔ String?
Remediation type based on the type of org policy values violated
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited