Violation class

Details of resource Violation

Constructors

Violation({String? beginTime, String? category, String? description, String? folderId, String? name, String? nonCompliantOrgPolicy, Remediation? remediation, String? resolveTime, String? state, String? updateTime})
Violation.fromJson(Map json_)

Properties

beginTime ↔ String?
Time of the event which triggered the Violation.
getter/setter pair
category ↔ String?
Category under which this violation is mapped.
getter/setter pair
description ↔ String?
Description for the Violation.
getter/setter pair
folderId ↔ String?
The folder_id of the violation
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
nonCompliantOrgPolicy ↔ String?
Name of the OrgPolicy which was modified with non-compliant change and resulted this violation.
getter/setter pair
remediation ↔ Remediation?
Compliance violation remediation
getter/setter pair
resolveTime ↔ String?
Time of the event which fixed the Violation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the violation
getter/setter pair
updateTime ↔ String?
The last time when the Violation record was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited