Workload class

Contains metadata around the Workload resource in the Assured Workloads API.

Constructors

Workload({String? createTime, String? folder, String? folderId, bool? isOnboarded, String? keyManagementProjectId, String? location, String? name, String? partner, WorkloadOnboardingState? workloadOnboardingState})
Workload.fromJson(Map json_)

Properties

createTime ↔ String?
Time the resource was created.
getter/setter pair
folder ↔ String?
The name of container folder of the assured workload
getter/setter pair
folderId ↔ String?
Folder id this workload is associated with
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isOnboarded ↔ bool?
Indicates whether a workload is fully onboarded.
getter/setter pair
keyManagementProjectId ↔ String?
The project id of the key management project for the workload
getter/setter pair
location ↔ String?
The Google Cloud location of the workload
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
partner ↔ String?
Partner associated with this workload. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workloadOnboardingState ↔ WorkloadOnboardingState?
Container for workload onboarding steps.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited