AlertPolicyCheckStatus class

AlertPolicyCheckStatus contains information specific to a single run of an alert policy check.

Constructors

AlertPolicyCheckStatus({List<String>? alertPolicies, List<FailedAlertPolicy>? failedAlertPolicies, String? failureMessage, String? id, Map<String, String>? labels})
AlertPolicyCheckStatus.fromJson(Map json_)

Properties

alertPolicies List<String>?
The alert policies that this analysis monitors.
getter/setter pair
failedAlertPolicies List<FailedAlertPolicy>?
The alert policies that were found to be firing during this check.
getter/setter pair
failureMessage String?
Additional information about the alert policy check failure, if available.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The ID of this analysis.
getter/setter pair
labels Map<String, String>?
The resolved labels used to filter for specific incidents.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited