failureMessage property
Additional information about the alert policy check failure, if available.
This will be empty if the alert policy check succeeded.
Output only.
Implementation
core.String? failureMessage;
Additional information about the alert policy check failure, if available.
This will be empty if the alert policy check succeeded.
Output only.
core.String? failureMessage;