duration property

String? duration
getter/setter pair

The amount of time in minutes the analysis on the target will last.

If all analysis checks have successfully completed before the specified duration, the analysis is successful. If a check is still running while the specified duration passes, it will wait for that check to complete to determine if the analysis is successful. The maximum duration is 48 hours.

Required.

Implementation

core.String? duration;