AnalysisJob class
An analysis Job.
Constructors
-
AnalysisJob({List<
CustomCheck> ? customChecks, String? duration, GoogleCloudAnalysis? googleCloud}) - AnalysisJob.fromJson(Map json_)
Properties
-
customChecks
↔ List<
CustomCheck> ? -
Custom analysis checks from 3P metric providers that are run as part of
the analysis Job.
getter/setter pair
- duration ↔ String?
-
The amount of time in minutes the analysis Job will run, up to a maximum
of 48 hours.
getter/setter pair
- googleCloud ↔ GoogleCloudAnalysis?
-
Google Cloud - based analysis checks that are run as part of the analysis
Job.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited