customChecks property
Custom analysis checks from 3P metric providers that are run as part of the analysis Job.
Output only.
Implementation
core.List<CustomCheck>? customChecks;
Custom analysis checks from 3P metric providers that are run as part of the analysis Job.
Output only.
core.List<CustomCheck>? customChecks;