duration property

String? duration
getter/setter pair

The amount of time in minutes the analysis Job will run, up to a maximum of 48 hours.

If any check in this Job is still running when the duration ends, the Job keeps running until that check completes.

Output only.

Implementation

core.String? duration;