googleCloud property
Google Cloud - based analysis checks that are run as part of the analysis Job.
Output only.
Implementation
GoogleCloudAnalysis? googleCloud;
Google Cloud - based analysis checks that are run as part of the analysis Job.
Output only.
GoogleCloudAnalysis? googleCloud;