customCheckAnalyses property
The status of the running custom checks configured for this analysis.
Output only.
Implementation
core.List<CustomCheckStatus>? customCheckAnalyses;
The status of the running custom checks configured for this analysis.
Output only.
core.List<CustomCheckStatus>? customCheckAnalyses;