failedCheckId property
The ID of the configured check that failed.
This will always be blank while the analysis is in progress or if it succeeded.
Output only.
Implementation
core.String? failedCheckId;
The ID of the configured check that failed.
This will always be blank while the analysis is in progress or if it succeeded.
Output only.
core.String? failedCheckId;