AssociatedEntities class

Information about entities associated with a Target.

Constructors

AssociatedEntities({List<AnthosCluster>? anthosClusters, List<GkeCluster>? gkeClusters})
AssociatedEntities.fromJson(Map json_)

Properties

anthosClusters ↔ List<AnthosCluster>?
Information specifying Anthos clusters as associated entities.
getter/setter pair
gkeClusters ↔ List<GkeCluster>?
Information specifying GKE clusters as associated entities.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited