Automation class

An Automation resource in the Cloud Deploy API.

An Automation enables the automation of manually driven actions for a Delivery Pipeline, which includes Release promotion among Targets, Rollout repair and Rollout deployment strategy advancement. The intention of Automation is to reduce manual intervention in the continuous delivery process.

Constructors

Automation({Map<String, String>? annotations, String? createTime, String? description, String? etag, Map<String, String>? labels, String? name, List<AutomationRule>? rules, AutomationResourceSelector? selector, String? serviceAccount, bool? suspended, String? uid, String? updateTime})
Automation.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
User annotations.
getter/setter pair
createTime ↔ String?
Time at which the automation was created.
getter/setter pair
description ↔ String?
Description of the Automation.
getter/setter pair
etag ↔ String?
The weak etag of the Automation resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels are attributes that can be set and used by both the user and by Cloud Deploy.
getter/setter pair
name ↔ String?
Name of the Automation.
getter/setter pair
rules ↔ List<AutomationRule>?
List of Automation rules associated with the Automation resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector ↔ AutomationResourceSelector?
Selected resources to which the automation will be applied.
getter/setter pair
serviceAccount ↔ String?
Email address of the user-managed IAM service account that creates Cloud Deploy release and rollout resources.
getter/setter pair
suspended ↔ bool?
When Suspended, automation is deactivated from execution.
getter/setter pair
uid ↔ String?
Unique identifier of the Automation.
getter/setter pair
updateTime ↔ String?
Time at which the automation was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited