AutomationRolloutMetadata class

AutomationRolloutMetadata contains Automation-related actions that were performed on a rollout.

Constructors

AutomationRolloutMetadata({List<String>? advanceAutomationRuns, String? promoteAutomationRun, List<String>? repairAutomationRuns})
AutomationRolloutMetadata.fromJson(Map json_)

Properties

advanceAutomationRuns ↔ List<String>?
The names of the AutomationRuns initiated by an advance rollout rule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
promoteAutomationRun ↔ String?
The name of the AutomationRun initiated by a promote release rule.
getter/setter pair
repairAutomationRuns ↔ List<String>?
The names of the AutomationRuns initiated by a repair rollout rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited