AutomationRule class

AutomationRule defines the automation activities.

Constructors

AutomationRule({AdvanceRolloutRule? advanceRolloutRule, PromoteReleaseRule? promoteReleaseRule, RepairRolloutRule? repairRolloutRule, TimedPromoteReleaseRule? timedPromoteReleaseRule})
AutomationRule.fromJson(Map json_)

Properties

advanceRolloutRule ↔ AdvanceRolloutRule?
The AdvanceRolloutRule will automatically advance a successful Rollout.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
promoteReleaseRule ↔ PromoteReleaseRule?
PromoteReleaseRule will automatically promote a release from the current target to a specified target.
getter/setter pair
repairRolloutRule ↔ RepairRolloutRule?
The RepairRolloutRule will automatically repair a failed rollout.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timedPromoteReleaseRule ↔ TimedPromoteReleaseRule?
The TimedPromoteReleaseRule will automatically promote a release from the current target(s) to the specified target(s) on a configured schedule.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited