AutomationRuleCondition class

AutomationRuleCondition contains conditions relevant to an Automation rule.

Constructors

AutomationRuleCondition({TargetsPresentCondition? targetsPresentCondition, TimedPromoteReleaseCondition? timedPromoteReleaseCondition})
AutomationRuleCondition.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetsPresentCondition ↔ TargetsPresentCondition?
Details around targets enumerated in the rule.
getter/setter pair
timedPromoteReleaseCondition ↔ TimedPromoteReleaseCondition?
TimedPromoteReleaseCondition contains rule conditions specific to a an Automation with a timed promote release rule defined.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited