Canary class

Canary represents the canary deployment strategy.

Constructors

Canary({CanaryDeployment? canaryDeployment, CustomCanaryDeployment? customCanaryDeployment, RuntimeConfig? runtimeConfig})
Canary.fromJson(Map json_)

Properties

canaryDeployment ↔ CanaryDeployment?
Configures the progressive based deployment for a Target.
getter/setter pair
customCanaryDeployment ↔ CustomCanaryDeployment?
Configures the progressive based deployment for a Target, but allows customizing at the phase level where a phase represents each of the percentage deployments.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeConfig ↔ RuntimeConfig?
Runtime specific configurations for the deployment strategy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited