analysis property
Configuration for the analysis job.
If configured, the analysis will run after each percentage deployment.
Optional.
Implementation
Analysis? analysis;
Configuration for the analysis job.
If configured, the analysis will run after each percentage deployment.
Optional.
Analysis? analysis;