CloudRunMetadata class

CloudRunMetadata contains information from a Cloud Run deployment.

Constructors

CloudRunMetadata({String? job, String? previousRevision, String? revision, String? service, List<String>? serviceUrls, String? workerPool})
CloudRunMetadata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
job ↔ String?
The name of the Cloud Run job that is associated with a Rollout.
getter/setter pair
previousRevision ↔ String?
The previous Cloud Run Revision name associated with a Rollout.
getter/setter pair
revision ↔ String?
The Cloud Run Revision id associated with a Rollout.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
The name of the Cloud Run Service that is associated with a Rollout.
getter/setter pair
serviceUrls ↔ List<String>?
The Cloud Run Service urls that are associated with a Rollout.
getter/setter pair
workerPool ↔ String?
The Cloud Run worker pool associated with a Rollout.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited