previousRevision property

String? previousRevision
getter/setter pair

The previous Cloud Run Revision name associated with a Rollout.

Only set when a canary deployment strategy is configured. Format for service is projects/{project}/locations/{location}/services/{service}/revisions/{revision}. Format for worker pool is projects/{project}/locations/{location}/workerPools/{workerpool}/revisions/{revision}.

Output only.

Implementation

core.String? previousRevision;