workerPool property
The Cloud Run worker pool associated with a Rollout.
Format is
projects/{project}/locations/{location}/workerPools/{worker_pool}.
Output only.
Implementation
core.String? workerPool;
The Cloud Run worker pool associated with a Rollout.
Format is
projects/{project}/locations/{location}/workerPools/{worker_pool}.
Output only.
core.String? workerPool;