job property
The name of the Cloud Run Job in the rendered manifest.
Format is projects/{project}/locations/{location}/jobs/{job}.
Output only.
Implementation
core.String? job;
The name of the Cloud Run Job in the rendered manifest.
Format is projects/{project}/locations/{location}/jobs/{job}.
Output only.
core.String? job;