revision property
The name of the Cloud Run Revision in the rendered manifest.
Format is
projects/{project}/locations/{location}/services/{service}/revisions/{revision}.
Output only.
Implementation
core.String? revision;
The name of the Cloud Run Revision in the rendered manifest.
Format is
projects/{project}/locations/{location}/services/{service}/revisions/{revision}.
Output only.
core.String? revision;