workerPool property
The name of the Cloud Run Worker Pool in the rendered manifest.
Format is
projects/{project}/locations/{location}/workerPools/{worker_pool}.
Output only.
Implementation
core.String? workerPool;
The name of the Cloud Run Worker Pool in the rendered manifest.
Format is
projects/{project}/locations/{location}/workerPools/{worker_pool}.
Output only.
core.String? workerPool;