Config class

Service-wide configuration.

Constructors

Config({String? defaultSkaffoldVersion, ToolVersions? defaultToolVersions, String? name, List<SkaffoldVersion>? supportedVersions})
Config.fromJson(Map json_)

Properties

defaultSkaffoldVersion ↔ String?
Default Skaffold version that is assigned when a Release is created without specifying a Skaffold version.
getter/setter pair
defaultToolVersions ↔ ToolVersions?
Default tool versions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedVersions ↔ List<SkaffoldVersion>?
All supported versions of Skaffold.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited