frequency property
The frequency at which the custom check will be run, with a minimum and default of 5 minutes.
Optional.
Implementation
core.String? frequency;
The frequency at which the custom check will be run, with a minimum and default of 5 minutes.
Optional.
core.String? frequency;