failureCause property

String? failureCause
getter/setter pair

The reason the analysis failed.

This will always be unspecified while the analysis is in progress or if it succeeded.

Output only. Possible string values are:

  • "FAILURE_CAUSE_UNSPECIFIED" : No reason for failure is specified.
  • "CLOUD_BUILD_UNAVAILABLE" : Cloud Build is not available, either because it is not enabled or because Cloud Deploy has insufficient permissions. See required permission.
  • "EXECUTION_FAILED" : The analysis operation did not complete successfully; check Cloud Build logs.
  • "DEADLINE_EXCEEDED" : The analysis job run did not complete within the alloted time defined in the target's execution environment configuration.
  • "CLOUD_BUILD_REQUEST_FAILED" : Cloud Build failed to fulfill Cloud Deploy's request. See failure_message for additional details.

Implementation

core.String? failureCause;