latestBuild property

String? latestBuild
getter/setter pair

The resource name of the Cloud Build Build object that was used to execute the latest run of this custom action check.

Format is projects/{project}/locations/{location}/builds/{build}.

Output only.

Implementation

core.String? latestBuild;