CustomTargetTasks class
CustomTargetTasks represents the CustomTargetType configuration using
tasks.
Constructors
- CustomTargetTasks({Task? deploy, Task? render})
- CustomTargetTasks.fromJson(Map json_)
Properties
- deploy ↔ Task?
-
The task responsible for deploy operations.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- render ↔ Task?
-
The task responsible for render operations.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited