DefaultPool class

Execution using the default Cloud Build pool.

Constructors

DefaultPool({String? artifactStorage, String? serviceAccount})
DefaultPool.fromJson(Map json_)

Properties

artifactStorage ↔ String?
Cloud Storage location where execution outputs should be stored.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Google service account to use for execution.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited