DeployJobRun class

DeployJobRun contains information specific to a deploy JobRun.

Constructors

DeployJobRun({DeployArtifact? artifact, String? build, String? failureCause, String? failureMessage, DeployJobRunMetadata? metadata})
DeployJobRun.fromJson(Map json_)

Properties

artifact ↔ DeployArtifact?
The artifact of a deploy job run, if available.
getter/setter pair
build ↔ String?
The resource name of the Cloud Build Build object that is used to deploy.
getter/setter pair
failureCause ↔ String?
The reason the deploy failed.
getter/setter pair
failureMessage ↔ String?
Additional information about the deploy failure, if available.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ DeployJobRunMetadata?
Metadata containing information about the deploy job run.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited