DeployJobRunMetadata class

DeployJobRunMetadata surfaces information associated with a DeployJobRun to the user.

Properties

cloudRun ↔ CloudRunMetadata?
The name of the Cloud Run Service that is associated with a DeployJobRun.
getter/setter pair
custom ↔ CustomMetadata?
Custom metadata provided by user-defined deploy operation.
getter/setter pair
customTarget ↔ CustomTargetDeployMetadata?
Custom Target metadata associated with a DeployJobRun.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited