DeployParameters class

DeployParameters contains deploy parameters information.

Constructors

DeployParameters({Map<String, String>? matchTargetLabels, Map<String, String>? values})
DeployParameters.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchTargetLabels ↔ Map<String, String>?
Deploy parameters are applied to targets with match labels.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ Map<String, String>?
Values are deploy parameters in key-value pairs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited