DeployPolicy class

A DeployPolicy resource in the Cloud Deploy API.

A DeployPolicy inhibits manual or automation-driven actions within a Delivery Pipeline or Target.

Constructors

DeployPolicy({Map<String, String>? annotations, String? createTime, String? description, String? etag, Map<String, String>? labels, String? name, List<PolicyRule>? rules, List<DeployPolicyResourceSelector>? selectors, bool? suspended, String? uid, String? updateTime})
DeployPolicy.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
User annotations.
getter/setter pair
createTime ↔ String?
Time at which the deploy policy was created.
getter/setter pair
description ↔ String?
Description of the DeployPolicy.
getter/setter pair
etag ↔ String?
The weak etag of the DeployPolicy resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels are attributes that can be set and used by both the user and by Cloud Deploy.
getter/setter pair
name ↔ String?
Name of the DeployPolicy.
getter/setter pair
rules ↔ List<PolicyRule>?
Rules to apply.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectors ↔ List<DeployPolicyResourceSelector>?
Selected resources to which the policy will be applied.
getter/setter pair
suspended ↔ bool?
When suspended, the policy will not prevent actions from occurring, even if the action violates the policy.
getter/setter pair
uid ↔ String?
Unique identifier of the DeployPolicy.
getter/setter pair
updateTime ↔ String?
Most recent time at which the deploy policy was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited