analysisJob property
The analysis Job.
Runs after a verify if there is a verify job and the verify job succeeds.
Output only.
Implementation
Job? analysisJob;
The analysis Job.
Runs after a verify if there is a verify job and the verify job succeeds.
Output only.
Job? analysisJob;