alertPolicy property
The name of the alert policy that was found to be firing.
Format is
projects/{project}/locations/{location}/alertPolicies/{alertPolicy}.
Output only.
Implementation
core.String? alertPolicy;
The name of the alert policy that was found to be firing.
Format is
projects/{project}/locations/{location}/alertPolicies/{alertPolicy}.
Output only.
core.String? alertPolicy;