GatewayServiceMesh class

Information about the Kubernetes Gateway API service mesh configuration.

Constructors

GatewayServiceMesh({String? deployment, String? httpRoute, String? podSelectorLabel, RouteDestinations? routeDestinations, String? routeUpdateWaitTime, String? service, String? stableCutbackDuration})
GatewayServiceMesh.fromJson(Map json_)

Properties

deployment ↔ String?
Name of the Kubernetes Deployment whose traffic is managed by the specified HTTPRoute and Service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpRoute ↔ String?
Name of the Gateway API HTTPRoute.
getter/setter pair
podSelectorLabel ↔ String?
The label to use when selecting Pods for the Deployment and Service resources.
getter/setter pair
routeDestinations ↔ RouteDestinations?
Route destinations allow configuring the Gateway API HTTPRoute to be deployed to additional clusters.
getter/setter pair
routeUpdateWaitTime ↔ String?
The time to wait for route updates to propagate.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
Name of the Kubernetes Service.
getter/setter pair
stableCutbackDuration ↔ String?
The amount of time to migrate traffic back from the canary Service to the original Service during the stable phase deployment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited