GoogleCloudAnalysis class
GoogleCloudAnalysis is a set of Google Cloud-based checks to perform on the deployment.
Constructors
-
GoogleCloudAnalysis({List<
AlertPolicyCheck> ? alertPolicyChecks}) - GoogleCloudAnalysis.fromJson(Map json_)
Properties
-
alertPolicyChecks
↔ List<
AlertPolicyCheck> ? -
A list of Cloud Monitoring Alert Policy checks to perform as part of the
analysis.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited