Job class

Job represents an operation for a Rollout.

Constructors

Job({AdvanceChildRolloutJob? advanceChildRolloutJob, AnalysisJob? analysisJob, CreateChildRolloutJob? createChildRolloutJob, DeployJob? deployJob, String? id, String? jobRun, PostdeployJob? postdeployJob, PredeployJob? predeployJob, String? skipMessage, String? state, VerifyJob? verifyJob})
Job.fromJson(Map json_)

Properties

advanceChildRolloutJob ↔ AdvanceChildRolloutJob?
An advanceChildRollout Job.
getter/setter pair
analysisJob ↔ AnalysisJob?
An analysis Job.
getter/setter pair
createChildRolloutJob ↔ AdvanceChildRolloutJob?
A createChildRollout Job.
getter/setter pair
deployJob ↔ AdvanceChildRolloutJob?
A deploy Job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the Job.
getter/setter pair
jobRun ↔ String?
The name of the JobRun responsible for the most recent invocation of this Job.
getter/setter pair
postdeployJob ↔ PostdeployJob?
A postdeploy Job.
getter/setter pair
predeployJob ↔ PredeployJob?
A predeploy Job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipMessage ↔ String?
Additional information on why the Job was skipped, if available.
getter/setter pair
state ↔ String?
The current state of the Job.
getter/setter pair
verifyJob ↔ VerifyJob?
A verify Job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited