JobRun class

A JobRun resource in the Cloud Deploy API.

A JobRun contains information of a single Rollout job evaluation.

Constructors

JobRun({AdvanceChildRolloutJobRun? advanceChildRolloutJobRun, AnalysisJobRun? analysisJobRun, CreateChildRolloutJobRun? createChildRolloutJobRun, String? createTime, DeployJobRun? deployJobRun, String? endTime, String? etag, String? jobId, String? name, String? phaseId, PostdeployJobRun? postdeployJobRun, PredeployJobRun? predeployJobRun, String? startTime, String? state, String? uid, VerifyJobRun? verifyJobRun})
JobRun.fromJson(Map json_)

Properties

advanceChildRolloutJobRun ↔ AdvanceChildRolloutJobRun?
Information specific to an advanceChildRollout JobRun
getter/setter pair
analysisJobRun ↔ AnalysisJobRun?
Information specific to an analysis JobRun.
getter/setter pair
createChildRolloutJobRun ↔ CreateChildRolloutJobRun?
Information specific to a createChildRollout JobRun.
getter/setter pair
createTime ↔ String?
Time at which the JobRun was created.
getter/setter pair
deployJobRun ↔ DeployJobRun?
Information specific to a deploy JobRun.
getter/setter pair
endTime ↔ String?
Time at which the JobRun ended.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobId ↔ String?
ID of the Rollout job this JobRun corresponds to.
getter/setter pair
name ↔ String?
Name of the JobRun.
getter/setter pair
phaseId ↔ String?
ID of the Rollout phase this JobRun belongs in.
getter/setter pair
postdeployJobRun ↔ PostdeployJobRun?
Information specific to a postdeploy JobRun.
getter/setter pair
predeployJobRun ↔ PredeployJobRun?
Information specific to a predeploy JobRun.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Time at which the JobRun was started.
getter/setter pair
state ↔ String?
The current state of the JobRun.
getter/setter pair
uid ↔ String?
Unique identifier of the JobRun.
getter/setter pair
verifyJobRun ↔ VerifyJobRun?
Information specific to a verify JobRun.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited