KubernetesRenderMetadata class

KubernetesRenderMetadata contains Kubernetes information associated with a Release render.

Constructors

KubernetesRenderMetadata({String? canaryDeployment, String? deployment, String? kubernetesNamespace})
KubernetesRenderMetadata.fromJson(Map json_)

Properties

canaryDeployment ↔ String?
Name of the canary version of the Kubernetes Deployment that will be applied to the GKE cluster.
getter/setter pair
deployment ↔ String?
Name of the Kubernetes Deployment that will be applied to the GKE cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kubernetesNamespace ↔ String?
Namespace the Kubernetes resources will be applied to in the GKE cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited