kubernetesNamespace property

String? kubernetesNamespace
getter/setter pair

Namespace the Kubernetes resources will be applied to in the GKE cluster.

Only set if applying resources to a single namespace.

Output only.

Implementation

core.String? kubernetesNamespace;