OneTimeWindow class

One-time window within which actions are restricted.

For example, blocking actions over New Year's Eve from December 31st at 5pm to January 1st at 9am.

Constructors

OneTimeWindow({Date? endDate, TimeOfDay? endTime, Date? startDate, TimeOfDay? startTime})
OneTimeWindow.fromJson(Map json_)

Properties

endDate ↔ Date?
End date.
getter/setter pair
endTime ↔ TimeOfDay?
End time (exclusive).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ Date?
Start date.
getter/setter pair
startTime ↔ TimeOfDay?
Start time (inclusive).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited