Phase class

Phase represents a collection of jobs that are logically grouped together for a Rollout.

Constructors

Phase({ChildRolloutJobs? childRolloutJobs, DeploymentJobs? deploymentJobs, String? id, String? skipMessage, String? state})
Phase.fromJson(Map json_)

Properties

childRolloutJobs ↔ ChildRolloutJobs?
ChildRollout job composition.
getter/setter pair
deploymentJobs ↔ DeploymentJobs?
Deployment job composition.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the Phase.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipMessage ↔ String?
Additional information on why the Phase was skipped, if available.
getter/setter pair
state ↔ String?
Current state of the Phase.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited