analysis property
Configuration for the analysis job of this phase.
If this is not configured, there will be no analysis job for this phase.
Optional.
Implementation
Analysis? analysis;
Configuration for the analysis job of this phase.
If this is not configured, there will be no analysis job for this phase.
Optional.
Analysis? analysis;