Postdeploy class
Postdeploy contains the postdeploy job configuration information.
Constructors
-
Postdeploy({List<
String> ? actions, List<Task> ? tasks}) - Postdeploy.fromJson(Map json_)
Properties
-
actions
↔ List<
String> ? -
A sequence of Skaffold custom actions to invoke during execution of the
postdeploy job.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tasks
↔ List<
Task> ? -
The tasks that will run as a part of the postdeploy job.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited