The tasks that will run as a part of the postdeploy job.
The tasks are executed sequentially in the order specified. Only one of actions or tasks can be specified.
actions
tasks
Optional.
core.List<Task>? tasks;