tasks property

List<Task>? tasks
getter/setter pair

The tasks that will run as a part of the predeploy job.

The tasks are executed sequentially in the order specified. Only one of actions or tasks can be specified.

Optional.

Implementation

core.List<Task>? tasks;