PredeployJob class
A predeploy Job.
Constructors
-
PredeployJob({List<
String> ? actions, List<Task> ? tasks}) - PredeployJob.fromJson(Map json_)
Properties
-
actions
↔ List<
String> ? -
The custom actions that the predeploy Job executes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tasks
↔ List<
Task> ? -
The tasks that are executed as part of the predeploy Job.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited