PromoteReleaseOperation class

Contains the information of an automated promote-release operation.

Constructors

PromoteReleaseOperation({String? phase, String? rollout, String? targetId, String? wait})
PromoteReleaseOperation.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
phase ↔ String?
The starting phase of the rollout created by this operation.
getter/setter pair
rollout ↔ String?
The name of the rollout that initiates the AutomationRun.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetId ↔ String?
The ID of the target that represents the promotion stage to which the release will be promoted.
getter/setter pair
wait ↔ String?
How long the operation will be paused.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited