Release class

A Release resource in the Cloud Deploy API.

A Release defines a specific Skaffold configuration instance that can be deployed.

Constructors

Release({bool? abandoned, Map<String, String>? annotations, List<BuildArtifact>? buildArtifacts, ReleaseCondition? condition, String? createTime, List<CustomTargetType>? customTargetTypeSnapshots, DeliveryPipeline? deliveryPipelineSnapshot, Map<String, String>? deployParameters, String? description, String? etag, Map<String, String>? labels, String? name, String? renderEndTime, String? renderStartTime, String? renderState, String? skaffoldConfigPath, String? skaffoldConfigUri, String? skaffoldVersion, Map<String, TargetArtifact>? targetArtifacts, Map<String, TargetRender>? targetRenders, List<Target>? targetSnapshots, ToolVersions? toolVersions, String? uid})
Release.fromJson(Map json_)

Properties

abandoned ↔ bool?
Indicates whether this is an abandoned release.
getter/setter pair
annotations ↔ Map<String, String>?
User annotations.
getter/setter pair
buildArtifacts ↔ List<BuildArtifact>?
List of artifacts to pass through to Skaffold command.
getter/setter pair
condition ↔ ReleaseCondition?
Information around the state of the Release.
getter/setter pair
createTime ↔ String?
Time at which the Release was created.
getter/setter pair
customTargetTypeSnapshots ↔ List<CustomTargetType>?
Snapshot of the custom target types referenced by the targets taken at release creation time.
getter/setter pair
deliveryPipelineSnapshot ↔ DeliveryPipeline?
Snapshot of the parent pipeline taken at release creation time.
getter/setter pair
deployParameters ↔ Map<String, String>?
The deploy parameters to use for all targets in this release.
getter/setter pair
description ↔ String?
Description of the Release.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels are attributes that can be set and used by both the user and by Cloud Deploy.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
renderEndTime ↔ String?
Time at which the render completed.
getter/setter pair
renderStartTime ↔ String?
Time at which the render began.
getter/setter pair
renderState ↔ String?
Current state of the render operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skaffoldConfigPath ↔ String?
Filepath of the Skaffold config inside of the config URI.
getter/setter pair
skaffoldConfigUri ↔ String?
Cloud Storage URI of tar.gz archive containing Skaffold configuration.
getter/setter pair
skaffoldVersion ↔ String?
The Skaffold version to use when operating on this release, such as "1.20.0".
getter/setter pair
targetArtifacts ↔ Map<String, TargetArtifact>?
Map from target ID to the target artifacts created during the render operation.
getter/setter pair
targetRenders ↔ Map<String, TargetRender>?
Map from target ID to details of the render operation for that target.
getter/setter pair
targetSnapshots ↔ List<Target>?
Snapshot of the targets taken at release creation time.
getter/setter pair
toolVersions ↔ ToolVersions?
The tool versions to use for this release and all subsequent operations involving this release.
getter/setter pair
uid ↔ String?
Unique identifier of the Release.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited