ReleaseCondition class

ReleaseCondition contains all conditions relevant to a Release.

Constructors

ReleaseCondition({ToolVersionSupportedCondition? dockerVersionSupportedCondition, ToolVersionSupportedCondition? helmVersionSupportedCondition, ToolVersionSupportedCondition? kptVersionSupportedCondition, ToolVersionSupportedCondition? kubectlVersionSupportedCondition, ToolVersionSupportedCondition? kustomizeVersionSupportedCondition, ReleaseReadyCondition? releaseReadyCondition, SkaffoldSupportedCondition? skaffoldSupportedCondition, ToolVersionSupportedCondition? skaffoldVersionSupportedCondition})
ReleaseCondition.fromJson(Map json_)

Properties

dockerVersionSupportedCondition ↔ ToolVersionSupportedCondition?
Details around the support state of the release's Docker version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
helmVersionSupportedCondition ↔ ToolVersionSupportedCondition?
Details around the support state of the release's Helm version.
getter/setter pair
kptVersionSupportedCondition ↔ ToolVersionSupportedCondition?
Details around the support state of the release's kpt version.
getter/setter pair
kubectlVersionSupportedCondition ↔ ToolVersionSupportedCondition?
Details around the support state of the release's Kubectl version.
getter/setter pair
kustomizeVersionSupportedCondition ↔ ToolVersionSupportedCondition?
Details around the support state of the release's Kustomize version.
getter/setter pair
releaseReadyCondition ↔ ReleaseReadyCondition?
Details around the Releases's overall status.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skaffoldSupportedCondition ↔ SkaffoldSupportedCondition?
Details around the support state of the release's Skaffold version.
getter/setter pair
skaffoldVersionSupportedCondition ↔ ToolVersionSupportedCondition?
Details around the support state of the release's Skaffold version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited