RetryAttempt class

RetryAttempt represents an action of retrying the failed Cloud Deploy job.

Constructors

RetryAttempt({String? attempt, String? state, String? stateDesc, String? wait})
RetryAttempt.fromJson(Map json_)

Properties

attempt ↔ String?
The index of this retry attempt.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Valid state of this retry action.
getter/setter pair
stateDesc ↔ String?
Description of the state of the Retry.
getter/setter pair
wait ↔ String?
How long the operation will be paused.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited