RetryJobRequest class

RetryJobRequest is the request object used by RetryJob.

Constructors

RetryJobRequest({String? jobId, List<String>? overrideDeployPolicy, String? phaseId})
RetryJobRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobId ↔ String?
The job ID for the Job to retry.
getter/setter pair
overrideDeployPolicy ↔ List<String>?
Deploy policies to override.
getter/setter pair
phaseId ↔ String?
The phase ID the Job to retry belongs to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited