RetryPhase class

RetryPhase contains the retry attempts and the metadata for initiating a new attempt.

Constructors

RetryPhase({List<RetryAttempt>? attempts, String? backoffMode, String? totalAttempts})
RetryPhase.fromJson(Map json_)

Properties

attempts ↔ List<RetryAttempt>?
Detail of a retry action.
getter/setter pair
backoffMode ↔ String?
The pattern of how the wait time of the retry attempt is calculated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAttempts ↔ String?
The number of attempts that have been made.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited