Rollback class

Rolls back a Rollout.

Constructors

Rollback({String? destinationPhase, bool? disableRollbackIfRolloutPending})
Rollback.fromJson(Map json_)

Properties

destinationPhase ↔ String?
The starting phase ID for the Rollout.
getter/setter pair
disableRollbackIfRolloutPending ↔ bool?
If pending rollout exists on the target, the rollback operation will be aborted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited