RollbackTargetConfig class

Configs for the Rollback rollout.

Constructors

RollbackTargetConfig({Rollout? rollout, String? startingPhaseId})
RollbackTargetConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
rollout ↔ Rollout?
The rollback Rollout to create.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startingPhaseId ↔ String?
The starting phase ID for the Rollout.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited