RollbackTargetRequest class

The request object for RollbackTarget.

Constructors

RollbackTargetRequest({List<String>? overrideDeployPolicy, String? releaseId, RollbackTargetConfig? rollbackConfig, String? rolloutId, String? rolloutToRollBack, String? targetId, bool? validateOnly})
RollbackTargetRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
overrideDeployPolicy ↔ List<String>?
Deploy policies to override.
getter/setter pair
releaseId ↔ String?
ID of the Release to roll back to.
getter/setter pair
rollbackConfig ↔ RollbackTargetConfig?
Configs for the rollback Rollout.
getter/setter pair
rolloutId ↔ String?
ID of the rollback Rollout to create.
getter/setter pair
rolloutToRollBack ↔ String?
If provided, this must be the latest Rollout that is on the Target.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetId ↔ String?
ID of the Target that is being rolled back.
getter/setter pair
validateOnly ↔ bool?
If set to true, the request is validated and the user is provided with a RollbackTargetResponse.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited