RouteDestinations class

Information about route destinations for the Gateway API service mesh.

Constructors

RouteDestinations({List<String>? destinationIds, bool? propagateService})
RouteDestinations.fromJson(Map json_)

Properties

destinationIds ↔ List<String>?
The clusters where the Gateway API HTTPRoute resource will be deployed to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
propagateService ↔ bool?
Whether to propagate the Kubernetes Service to the route destination clusters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited