SerialPipeline class

SerialPipeline defines a sequential set of stages for a DeliveryPipeline.

Constructors

SerialPipeline({List<Stage>? stages})
SerialPipeline.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stages ↔ List<Stage>?
Each stage specifies configuration for a Target.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited