ServiceNetworking class

Information about the Kubernetes Service networking configuration.

Constructors

ServiceNetworking({String? deployment, bool? disablePodOverprovisioning, String? podSelectorLabel, String? service})
ServiceNetworking.fromJson(Map json_)

Properties

deployment ↔ String?
Name of the Kubernetes Deployment whose traffic is managed by the specified Service.
getter/setter pair
disablePodOverprovisioning ↔ bool?
Whether to disable Pod overprovisioning.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
podSelectorLabel ↔ String?
The label to use when selecting Pods for the Deployment resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
Name of the Kubernetes Service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited