SkaffoldModules class

Skaffold Config modules and their remote source.

Constructors

SkaffoldModules({List<String>? configs, SkaffoldGitSource? git, SkaffoldGCBRepoSource? googleCloudBuildRepo, SkaffoldGCSSource? googleCloudStorage})
SkaffoldModules.fromJson(Map json_)

Properties

configs ↔ List<String>?
The Skaffold Config modules to use from the specified source.
getter/setter pair
git ↔ SkaffoldGitSource?
Remote git repository containing the Skaffold Config modules.
getter/setter pair
googleCloudBuildRepo ↔ SkaffoldGCBRepoSource?
Cloud Build V2 repository containing the Skaffold Config modules.
getter/setter pair
googleCloudStorage ↔ SkaffoldGCSSource?
Cloud Storage bucket containing the Skaffold Config modules.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited