SkaffoldVersion class

Details of a supported Skaffold version.

Constructors

SkaffoldVersion({String? maintenanceModeTime, Date? supportEndDate, String? supportExpirationTime, String? version})
SkaffoldVersion.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maintenanceModeTime ↔ String?
The time at which this version of Skaffold will enter maintenance mode.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportEndDate ↔ Date?
Date when this version is expected to no longer be supported.
getter/setter pair
supportExpirationTime ↔ String?
The time at which this version of Skaffold will no longer be supported.
getter/setter pair
version ↔ String?
Release version number.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited