Standard class

Standard represents the standard deployment strategy.

Constructors

Standard({Analysis? analysis, Postdeploy? postdeploy, Predeploy? predeploy, bool? verify, Verify? verifyConfig})
Standard.fromJson(Map json_)

Properties

analysis ↔ Analysis?
Configuration for the analysis job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postdeploy ↔ Postdeploy?
Configuration for the postdeploy job.
getter/setter pair
predeploy ↔ Predeploy?
Configuration for the predeploy job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verify ↔ bool?
Whether to verify a deployment via skaffold verify.
getter/setter pair
verifyConfig ↔ Verify?
Configuration for the verify job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited