analysis property
Configuration for the analysis job.
If this is not configured, the analysis job will not be present.
Optional.
Implementation
Analysis? analysis;
Configuration for the analysis job.
If this is not configured, the analysis job will not be present.
Optional.
Analysis? analysis;