Target class

A Target resource in the Cloud Deploy API.

A Target defines a location to which a Skaffold configuration can be deployed.

Constructors

Target({Map<String, String>? annotations, AnthosCluster? anthosCluster, Map<String, AssociatedEntities>? associatedEntities, String? createTime, CustomTarget? customTarget, Map<String, String>? deployParameters, String? description, String? etag, List<ExecutionConfig>? executionConfigs, GkeCluster? gke, Map<String, String>? labels, MultiTarget? multiTarget, String? name, bool? requireApproval, CloudRunLocation? run, String? targetId, String? uid, String? updateTime})
Target.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
User annotations.
getter/setter pair
anthosCluster ↔ AnthosCluster?
Information specifying an Anthos Cluster.
getter/setter pair
associatedEntities ↔ Map<String, AssociatedEntities>?
Map of entity IDs to their associated entities.
getter/setter pair
createTime ↔ String?
Time at which the Target was created.
getter/setter pair
customTarget ↔ CustomTarget?
Information specifying a Custom Target.
getter/setter pair
deployParameters ↔ Map<String, String>?
The deploy parameters to use for this target.
getter/setter pair
description ↔ String?
Description of the Target.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
executionConfigs ↔ List<ExecutionConfig>?
Configurations for all execution that relates to this Target.
getter/setter pair
gke ↔ GkeCluster?
Information specifying a GKE Cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels are attributes that can be set and used by both the user and by Cloud Deploy.
getter/setter pair
multiTarget ↔ MultiTarget?
Information specifying a multiTarget.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
requireApproval ↔ bool?
Whether or not the Target requires approval.
getter/setter pair
run ↔ CloudRunLocation?
Information specifying a Cloud Run deployment target.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetId ↔ String?
Resource id of the Target.
getter/setter pair
uid ↔ String?
Unique identifier of the Target.
getter/setter pair
updateTime ↔ String?
Most recent time at which the Target was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited