TargetAttribute class

Contains criteria for selecting Targets.

This could be used to select targets for a Deploy Policy or for an Automation.

Constructors

TargetAttribute({String? id, Map<String, String>? labels})
TargetAttribute.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of the Target.
getter/setter pair
labels ↔ Map<String, String>?
Target labels.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited