TargetsTypeCondition class

TargetsTypeCondition contains information on whether the Targets defined in the Delivery Pipeline are of the same type.

Constructors

TargetsTypeCondition({String? errorDetails, bool? status})
TargetsTypeCondition.fromJson(Map json_)

Properties

errorDetails ↔ String?
Human readable error message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ bool?
True if the targets are all a comparable type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited