container property
This task is represented by a container that is executed in the Cloud Build execution environment.
Optional.
Implementation
ContainerTask? container;
This task is represented by a container that is executed in the Cloud Build execution environment.
Optional.
ContainerTask? container;