TimeWindows class

Time windows within which actions are restricted.

See the documentation for more information on how to configure dates/times.

Constructors

TimeWindows({List<OneTimeWindow>? oneTimeWindows, String? timeZone, List<WeeklyWindow>? weeklyWindows})
TimeWindows.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
oneTimeWindows ↔ List<OneTimeWindow>?
One-time windows within which actions are restricted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone ↔ String?
The time zone in IANA format IANA Time Zone Database (e.g. America/New_York).
getter/setter pair
weeklyWindows ↔ List<WeeklyWindow>?
Recurring weekly windows within which actions are restricted.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited