TimedPromoteReleaseCondition class

TimedPromoteReleaseCondition contains conditions specific to an Automation with a Timed Promote Release rule defined.

Constructors

TimedPromoteReleaseCondition({String? nextPromotionTime, List<Targets>? targetsList})
TimedPromoteReleaseCondition.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPromotionTime ↔ String?
When the next scheduled promotion(s) will occur.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetsList ↔ List<Targets>?
A list of targets involved in the upcoming timed promotion(s).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited