ToolVersions class

Details of ToolVersions for the release.

Constructors

ToolVersions({String? docker, String? helm, String? kpt, String? kubectl, String? kustomize, String? skaffold})
ToolVersions.fromJson(Map json_)

Properties

docker ↔ String?
The Docker version to use for Cloud Deploy operations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
helm ↔ String?
The Helm version to use for Cloud Deploy operations.
getter/setter pair
kpt ↔ String?
The kpt version to use for Cloud Deploy operations.
getter/setter pair
kubectl ↔ String?
The Kubectl version to use for Cloud Deploy operations.
getter/setter pair
kustomize ↔ String?
The Kustomize version to use for Cloud Deploy operations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skaffold ↔ String?
The Skaffold version to use for Cloud Deploy operations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited