tasks property

List<Task>? tasks
getter/setter pair

The tasks that will run as a part of the verify job.

The tasks are executed sequentially in the order specified.

Optional.

Implementation

core.List<Task>? tasks;