WeeklyWindow class

Weekly windows.

For example, blocking actions every Saturday and Sunday. Another example would be blocking actions every weekday from 5pm to midnight.

Constructors

WeeklyWindow({List<String>? daysOfWeek, TimeOfDay? endTime, TimeOfDay? startTime})
WeeklyWindow.fromJson(Map json_)

Properties

daysOfWeek ↔ List<String>?
Days of week.
getter/setter pair
endTime ↔ TimeOfDay?
End time (exclusive).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ TimeOfDay?
Start time (inclusive).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited