CallFunctionResponse class

Response of CallFunction method.

Constructors

CallFunctionResponse({String? error, String? executionId, String? result})
CallFunctionResponse.fromJson(Map json_)

Properties

error ↔ String?
Either system or user-function generated error.
getter/setter pair
executionId ↔ String?
Execution id of function invocation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
result ↔ String?
Result populated for successful execution of synchronous function.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited