network property

String? network
getter/setter pair

The name of the VPC network to which the function will be connected.

Specify either a VPC network or a subnet, or both. If you specify only a network, the subnet uses the same name as the network.

Optional.

Implementation

core.String? network;