subnetwork property
The name of the VPC subnetwork that the Cloud Function resource will get IPs from.
Specify either a VPC network or a subnet, or both. If both network and subnetwork are specified, the given VPC subnetwork must belong to the given VPC network. If subnetwork is not specified, the subnetwork with the same name with the network will be used.
Optional.
Implementation
core.String? subnetwork;