EventFilter class

Filters events based on exact matches on the CloudEvents attributes.

Constructors

EventFilter({String? attribute, String? operator, String? value})
EventFilter.fromJson(Map json_)

Properties

attribute ↔ String?
The name of a CloudEvents attribute.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
operator ↔ String?
The operator used for matching the events with the value of the filter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The value for the attribute.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited