EventTrigger class

Describes EventTrigger, used to request events to be sent from another service.

Constructors

EventTrigger({String? channel, List<EventFilter>? eventFilters, String? eventType, String? pubsubTopic, String? retryPolicy, String? service, String? serviceAccountEmail, String? trigger, String? triggerRegion})
EventTrigger.fromJson(Map json_)

Properties

channel ↔ String?
The name of the channel associated with the trigger in projects/{project}/locations/{location}/channels/{channel} format.
getter/setter pair
eventFilters ↔ List<EventFilter>?
Criteria used to filter events.
getter/setter pair
eventType ↔ String?
The type of event to observe.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pubsubTopic ↔ String?
The name of a Pub/Sub topic in the same project that will be used as the transport topic for the event delivery.
getter/setter pair
retryPolicy ↔ String?
If unset, then defaults to ignoring failures (i.e. not retrying them).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
The hostname of the service that 1st Gen function should be observed.
getter/setter pair
serviceAccountEmail ↔ String?
The email of the trigger's service account.
getter/setter pair
trigger ↔ String?
The resource name of the Eventarc trigger.
getter/setter pair
triggerRegion ↔ String?
The region that the trigger will be in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited