GoogleCloudFunctionsV2StateMessage class

Informational messages about the state of the Cloud Function or Operation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
The message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Severity of the state message. Possible string values are:
getter/setter pair
type ↔ String?
One-word CamelCase type of the state message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited