RepoSource class

Location of the source in a Google Cloud Source Repository.

Constructors

RepoSource({String? branchName, String? commitSha, String? dir, String? projectId, String? repoName, String? tagName})
RepoSource.fromJson(Map json_)

Properties

branchName ↔ String?
Regex matching branches to build.
getter/setter pair
commitSha ↔ String?
Explicit commit SHA to build.
getter/setter pair
dir ↔ String?
Directory, relative to the source root, in which to run the build.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
projectId ↔ String?
ID of the project that owns the Cloud Source Repository.
getter/setter pair
repoName ↔ String?
Name of the Cloud Source Repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagName ↔ String?
Regex matching tags to build.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited