ServiceConfig class

Describes the Service being deployed.

Currently Supported : Cloud Run (fully managed).

Constructors

ServiceConfig({bool? allTrafficOnLatestRevision, String? availableCpu, String? availableMemory, String? binaryAuthorizationPolicy, String? directVpcEgress, List<DirectVpcNetworkInterface>? directVpcNetworkInterface, Map<String, String>? environmentVariables, String? ingressSettings, int? maxInstanceCount, int? maxInstanceRequestConcurrency, int? minInstanceCount, String? revision, List<SecretEnvVar>? secretEnvironmentVariables, List<SecretVolume>? secretVolumes, String? securityLevel, String? service, String? serviceAccountEmail, int? timeoutSeconds, String? uri, String? vpcConnector, String? vpcConnectorEgressSettings})
ServiceConfig.fromJson(Map json_)

Properties

allTrafficOnLatestRevision ↔ bool?
Whether 100% of traffic is routed to the latest revision.
getter/setter pair
availableCpu ↔ String?
The number of CPUs used in a single container instance.
getter/setter pair
availableMemory ↔ String?
The amount of memory available for a function.
getter/setter pair
binaryAuthorizationPolicy ↔ String?
The binary authorization policy to be checked when deploying the Cloud Run service.
getter/setter pair
directVpcEgress ↔ String?
Egress settings for direct VPC.
getter/setter pair
directVpcNetworkInterface ↔ List<DirectVpcNetworkInterface>?
The Direct VPC network interface for the Cloud Function.
getter/setter pair
environmentVariables ↔ Map<String, String>?
Environment variables that shall be available during function execution.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ingressSettings ↔ String?
The ingress settings for the function, controlling what traffic can reach it. Possible string values are:
getter/setter pair
maxInstanceCount ↔ int?
The limit on the maximum number of function instances that may coexist at a given time.
getter/setter pair
maxInstanceRequestConcurrency ↔ int?
Sets the maximum number of concurrent requests that each instance can receive.
getter/setter pair
minInstanceCount ↔ int?
The limit on the minimum number of function instances that may coexist at a given time.
getter/setter pair
revision ↔ String?
The name of service revision.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretEnvironmentVariables ↔ List<SecretEnvVar>?
Secret environment variables configuration.
getter/setter pair
secretVolumes ↔ List<SecretVolume>?
Secret volumes configuration.
getter/setter pair
securityLevel ↔ String?
Security level configure whether the function only accepts https.
getter/setter pair
service ↔ String?
Name of the service associated with a Function.
getter/setter pair
serviceAccountEmail ↔ String?
The email of the service's service account.
getter/setter pair
timeoutSeconds ↔ int?
The function execution timeout.
getter/setter pair
uri ↔ String?
URI of the Service deployed.
getter/setter pair
vpcConnector ↔ String?
The Serverless VPC Access connector that this cloud function can connect to.
getter/setter pair
vpcConnectorEgressSettings ↔ String?
The egress settings for the connector, controlling what traffic is diverted through it. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited