AllowlistedDomain class

This resource object defines a domain that has been designated as allowlisted.

Constructors

AllowlistedDomain({String? domain, String? name})
AllowlistedDomain.fromJson(Map json_)

Properties

domain String?
Name of the domain that is in the allowlist.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited