Group class

A group within the Cloud Identity Groups API.

A Group is a collection of entities, where each entity is either a user, another group, or a service account.

Constructors

Group({List<EntityKey>? additionalGroupKeys, String? createTime, String? description, String? displayName, DynamicGroupMetadata? dynamicGroupMetadata, EntityKey? groupKey, Map<String, String>? labels, String? name, String? parent, String? updateTime})
Group.fromJson(Map json_)

Properties

additionalGroupKeys ↔ List<EntityKey>?
Additional group keys associated with the Group.
getter/setter pair
createTime ↔ String?
The time when the Group was created.
getter/setter pair
description ↔ String?
An extended description to help users determine the purpose of a Group.
getter/setter pair
displayName ↔ String?
The display name of the Group.
getter/setter pair
dynamicGroupMetadata ↔ DynamicGroupMetadata?
Dynamic group metadata like queries and status.
getter/setter pair
groupKey ↔ EntityKey?
The EntityKey of the Group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
One or more label entries that apply to the Group.
getter/setter pair
name ↔ String?
The resource name of the Group.
getter/setter pair
parent ↔ String?
The resource name of the entity under which this Group resides in the Cloud Identity resource hierarchy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The time when the Group was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited