GroupRelation class

Message representing a transitive group of a user or a group.

Constructors

GroupRelation({String? displayName, String? group, EntityKey? groupKey, Map<String, String>? labels, String? relationType, List<TransitiveMembershipRole>? roles})
GroupRelation.fromJson(Map json_)

Properties

displayName ↔ String?
Display name for this group.
getter/setter pair
group ↔ String?
Resource name for this group.
getter/setter pair
groupKey ↔ EntityKey?
Entity key has an id and a namespace.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels for Group resource.
getter/setter pair
relationType ↔ String?
The relation between the member and the transitive group. Possible string values are:
getter/setter pair
roles ↔ List<TransitiveMembershipRole>?
Membership roles of the member for the group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited