InboundSamlSsoProfile class

A SAML 2.0 federation between a Google enterprise customer and a SAML identity provider.

Constructors

InboundSamlSsoProfile({String? customer, String? displayName, SamlIdpConfig? idpConfig, String? name, SamlSpConfig? spConfig})
InboundSamlSsoProfile.fromJson(Map json_)

Properties

customer ↔ String?
The customer.
getter/setter pair
displayName ↔ String?
Human-readable name of the SAML SSO profile.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idpConfig ↔ SamlIdpConfig?
SAML identity provider configuration.
getter/setter pair
name ↔ String?
Resource name of the SAML SSO profile.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spConfig ↔ SamlSpConfig?
SAML service provider configuration for this SAML SSO profile.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited