InboundSsoAssignment class

Targets with "set" SSO assignments and their respective assignments.

Constructors

InboundSsoAssignment({String? customer, String? name, OidcSsoInfo? oidcSsoInfo, int? rank, SamlSsoInfo? samlSsoInfo, SignInBehavior? signInBehavior, String? ssoMode, String? targetGroup, String? targetOrgUnit})
InboundSsoAssignment.fromJson(Map json_)

Properties

customer ↔ String?
The customer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of the Inbound SSO Assignment.
getter/setter pair
oidcSsoInfo ↔ OidcSsoInfo?
OpenID Connect SSO details.
getter/setter pair
rank ↔ int?
Must be zero (which is the default value so it can be omitted) for assignments with target_org_unit set and must be greater-than-or-equal-to one for assignments with target_group set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samlSsoInfo ↔ SamlSsoInfo?
SAML SSO details.
getter/setter pair
signInBehavior ↔ SignInBehavior?
Assertions about users assigned to an IdP will always be accepted from that IdP.
getter/setter pair
ssoMode ↔ String?
Inbound SSO behavior. Possible string values are:
getter/setter pair
targetGroup ↔ String?
Must be of the form groups/{group}.
getter/setter pair
targetOrgUnit ↔ String?
Must be of the form orgUnits/{org_unit}.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited