ListUserInvitationsResponse class

Response message for UserInvitation listing request.

Constructors

ListUserInvitationsResponse({String? nextPageToken, List<UserInvitation>? userInvitations})
ListUserInvitationsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The token for the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInvitations ↔ List<UserInvitation>?
The list of UserInvitation resources.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited