MemberRelation class

Message representing a transitive membership of a group.

Constructors

MemberRelation({String? member, List<EntityKey>? preferredMemberKey, String? relationType, List<TransitiveMembershipRole>? roles})
MemberRelation.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
member ↔ String?
Resource name for this member.
getter/setter pair
preferredMemberKey ↔ List<EntityKey>?
Entity key has an id and a namespace.
getter/setter pair
relationType ↔ String?
The relation between the group and the transitive member. Possible string values are:
getter/setter pair
roles ↔ List<TransitiveMembershipRole>?
The membership role details (i.e name of role and expiry time).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited