MemberRestriction class

The definition of MemberRestriction

Constructors

MemberRestriction({RestrictionEvaluation? evaluation, String? query})
MemberRestriction.fromJson(Map json_)

Properties

evaluation ↔ RestrictionEvaluation?
The evaluated state of this restriction on a group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
query ↔ String?
Member Restriction as defined by CEL expression.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited