Membership class

A membership within the Cloud Identity Groups API.

A Membership defines a relationship between a Group and an entity belonging to that Group, referred to as a "member".

Constructors

Membership({String? createTime, String? deliverySetting, String? name, EntityKey? preferredMemberKey, List<MembershipRole>? roles, String? type, String? updateTime})
Membership.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the Membership was created.
getter/setter pair
deliverySetting ↔ String?
Delivery setting associated with the membership.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the Membership.
getter/setter pair
preferredMemberKey ↔ EntityKey?
The EntityKey of the member.
getter/setter pair
roles ↔ List<MembershipRole>?
The MembershipRoles that apply to the Membership.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the membership.
getter/setter pair
updateTime ↔ String?
The time when the Membership was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited