MembershipRole class

A membership role within the Cloud Identity Groups API.

A MembershipRole defines the privileges granted to a Membership.

Constructors

MembershipRole({ExpiryDetail? expiryDetail, String? name, RestrictionEvaluations? restrictionEvaluations})
MembershipRole.fromJson(Map json_)

Properties

expiryDetail ↔ ExpiryDetail?
The expiry details of the MembershipRole.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the MembershipRole.
getter/setter pair
restrictionEvaluations ↔ RestrictionEvaluations?
Evaluations of restrictions applied to parent group on this membership.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited