Policy class

A Policy resource binds an instance of a single Setting with the scope of a PolicyQuery.

The Setting instance will be applied to all entities that satisfy the query.

Constructors

Policy({String? customer, String? name, PolicyQuery? policyQuery, Setting? setting, String? type})
Policy.fromJson(Map json_)

Properties

customer ↔ String?
Customer that the Policy belongs to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
policyQuery ↔ PolicyQuery?
The PolicyQuery the Setting applies to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setting ↔ Setting?
The Setting configured by this Policy.
getter/setter pair
type ↔ String?
The type of the policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited