SamlIdpConfig class

SAML IDP (identity provider) configuration.

Constructors

SamlIdpConfig({String? changePasswordUri, String? entityId, String? logoutRedirectUri, String? singleSignOnServiceUri})
SamlIdpConfig.fromJson(Map json_)

Properties

changePasswordUri ↔ String?
The Change Password URL of the identity provider.
getter/setter pair
entityId ↔ String?
The SAML Entity ID of the identity provider.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
logoutRedirectUri ↔ String?
The Logout Redirect URL (sign-out page URL) of the identity provider.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleSignOnServiceUri ↔ String?
The SingleSignOnService endpoint location (sign-in page URL) of the identity provider.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited