AsymmetricSignResponse class

Response message for KeyManagementService.AsymmetricSign.

Constructors

AsymmetricSignResponse({String? name, String? protectionLevel, String? signature, String? signatureCrc32c, bool? verifiedDataCrc32c, bool? verifiedDigestCrc32c})
AsymmetricSignResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the CryptoKeyVersion used for signing.
getter/setter pair
protectionLevel ↔ String?
The ProtectionLevel of the CryptoKeyVersion used for signing. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature ↔ String?
The created signature.
getter/setter pair
signatureAsBytes ↔ List<int>
getter/setter pair
signatureCrc32c ↔ String?
Integrity verification field.
getter/setter pair
verifiedDataCrc32c ↔ bool?
Integrity verification field.
getter/setter pair
verifiedDigestCrc32c ↔ bool?
Integrity verification field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited