ChecksummedData class

Data with integrity verification field.

Constructors

ChecksummedData({String? crc32cChecksum, String? data})
ChecksummedData.fromJson(Map json_)

Properties

crc32cChecksum ↔ String?
Integrity verification field.
getter/setter pair
data ↔ String?
Raw Data.
getter/setter pair
dataAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited