CryptoKey class

A CryptoKey represents a logical key that can be used for cryptographic operations.

A CryptoKey is made up of zero or more versions, which represent the actual key material used in cryptographic operations.

Constructors

CryptoKey({String? createTime, String? cryptoKeyBackend, String? destroyScheduledDuration, bool? importOnly, KeyAccessJustificationsPolicy? keyAccessJustificationsPolicy, Map<String, String>? labels, String? name, String? nextRotationTime, CryptoKeyVersion? primary, String? purpose, String? rotationPeriod, CryptoKeyVersionTemplate? versionTemplate})
CryptoKey.fromJson(Map json_)

Properties

createTime ↔ String?
The time at which this CryptoKey was created.
getter/setter pair
cryptoKeyBackend ↔ String?
The resource name of the backend environment where the key material for all CryptoKeyVersions associated with this CryptoKey reside and where all related cryptographic operations are performed.
getter/setter pair
destroyScheduledDuration ↔ String?
The period of time that versions of this key spend in the DESTROY_SCHEDULED state before transitioning to DESTROYED.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importOnly ↔ bool?
Whether this key may contain imported versions only.
getter/setter pair
keyAccessJustificationsPolicy ↔ KeyAccessJustificationsPolicy?
The policy used for Key Access Justifications Policy Enforcement.
getter/setter pair
labels ↔ Map<String, String>?
Labels with user-defined metadata.
getter/setter pair
name ↔ String?
The resource name for this CryptoKey in the format projects / * /locations / * /keyRings / * /cryptoKeys / * .
getter/setter pair
nextRotationTime ↔ String?
At next_rotation_time, the Key Management Service will automatically: 1.
getter/setter pair
primary ↔ CryptoKeyVersion?
A copy of the "primary" CryptoKeyVersion that will be used by Encrypt when this CryptoKey is given in EncryptRequest.name.
getter/setter pair
purpose ↔ String?
The immutable purpose of this CryptoKey.
getter/setter pair
rotationPeriod ↔ String?
next_rotation_time will be advanced by this period when the service automatically rotates a key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionTemplate ↔ CryptoKeyVersionTemplate?
A template describing settings for new CryptoKeyVersion instances.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited