trustedWrappingEnabled property

bool? trustedWrappingEnabled
getter/setter pair

Field indicating that the key may be wrapped by a trusted key.

This field can be set for all key purposes except ENCRYPT_DECRYPT, and is only valid for keys with protection level HSM_SINGLE_TENANT. This field can only be set at creation or import time via CreateCryptoKeyVersion, or ImportCryptoKeyVersion.

Immutable.

Implementation

core.bool? trustedWrappingEnabled;