DecryptRequest class

Request message for KeyManagementService.Decrypt.

Constructors

DecryptRequest({String? additionalAuthenticatedData, String? additionalAuthenticatedDataCrc32c, String? ciphertext, String? ciphertextCrc32c})
DecryptRequest.fromJson(Map json_)

Properties

additionalAuthenticatedData ↔ String?
Optional data that must match the data originally supplied in EncryptRequest.additional_authenticated_data.
getter/setter pair
additionalAuthenticatedDataAsBytes ↔ List<int>
getter/setter pair
additionalAuthenticatedDataCrc32c ↔ String?
An optional CRC32C checksum of the DecryptRequest.additional_authenticated_data.
getter/setter pair
ciphertext ↔ String?
The encrypted data originally returned in EncryptResponse.ciphertext.
getter/setter pair
ciphertextAsBytes ↔ List<int>
getter/setter pair
ciphertextCrc32c ↔ String?
An optional CRC32C checksum of the DecryptRequest.ciphertext.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited