DecryptResponse class

Response message for KeyManagementService.Decrypt.

Constructors

DecryptResponse({String? plaintext, String? plaintextCrc32c, String? protectionLevel, bool? usedPrimary})
DecryptResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
plaintext ↔ String?
The decrypted data originally supplied in EncryptRequest.plaintext.
getter/setter pair
plaintextAsBytes ↔ List<int>
getter/setter pair
plaintextCrc32c ↔ String?
Integrity verification field.
getter/setter pair
protectionLevel ↔ String?
The ProtectionLevel of the CryptoKeyVersion used in decryption. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedPrimary ↔ bool?
Whether the Decryption was performed using the primary key version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited