Digest class

A Digest holds a cryptographic message digest.

Constructors

Digest({String? externalMu, String? sha256, String? sha384, String? sha512})
Digest.fromJson(Map json_)

Properties

externalMu ↔ String?
A message digest produced with SHAKE-256, to be used with ML-DSA external-μ algorithms only.
getter/setter pair
externalMuAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256 ↔ String?
A message digest produced with the SHA-256 algorithm.
getter/setter pair
sha256AsBytes ↔ List<int>
getter/setter pair
sha384 ↔ String?
A message digest produced with the SHA-384 algorithm.
getter/setter pair
sha384AsBytes ↔ List<int>
getter/setter pair
sha512 ↔ String?
A message digest produced with the SHA-512 algorithm.
getter/setter pair
sha512AsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited