EncryptResponse class

Response message for KeyManagementService.Encrypt.

Constructors

EncryptResponse({String? ciphertext, String? ciphertextCrc32c, String? name, String? protectionLevel, bool? verifiedAdditionalAuthenticatedDataCrc32c, bool? verifiedPlaintextCrc32c})
EncryptResponse.fromJson(Map json_)

Properties

ciphertext ↔ String?
The encrypted data.
getter/setter pair
ciphertextAsBytes ↔ List<int>
getter/setter pair
ciphertextCrc32c ↔ String?
Integrity verification field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the CryptoKeyVersion used in encryption.
getter/setter pair
protectionLevel ↔ String?
The ProtectionLevel of the CryptoKeyVersion used in encryption. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verifiedAdditionalAuthenticatedDataCrc32c ↔ bool?
Integrity verification field.
getter/setter pair
verifiedPlaintextCrc32c ↔ bool?
Integrity verification field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited