ImportTrustedKeyWrappedCryptoKeyVersionRequest class

Request message for KeyManagementService.ImportTrustedKeyWrappedCryptoKeyVersion.

Constructors

ImportTrustedKeyWrappedCryptoKeyVersionRequest({String? algorithm, String? cryptoKeyVersion, String? importingKey, String? wrappedKey})
ImportTrustedKeyWrappedCryptoKeyVersionRequest.fromJson(Map json_)

Properties

algorithm String?
Required - The algorithm of the key being imported.
getter/setter pair
cryptoKeyVersion String?
The optional name of an existing CryptoKeyVersion to target for an import operation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
importingKey String?
Required - the CKV of the trusted key used to import.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wrappedKey String?
The target key pre-wrapped on premises.
getter/setter pair
wrappedKeyAsBytes List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited