KeyAccessJustificationsPolicyConfig class
Represents a singleton configuration for Key Access Justifications policies.
Constructors
- KeyAccessJustificationsPolicyConfig({KeyAccessJustificationsPolicy? defaultKeyAccessJustificationPolicy, bool? defaultPolicyAvailable, String? name})
- KeyAccessJustificationsPolicyConfig.fromJson(Map json_)
Properties
- defaultKeyAccessJustificationPolicy ↔ KeyAccessJustificationsPolicy?
-
Specifies the default key access justifications (KAJ) policy used when a
CryptoKey is created in this folder.
getter/setter pair
- defaultPolicyAvailable ↔ bool?
-
Indicates whether this parent resource is available to default policy
feature.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited