defaultKeyAccessJustificationPolicy property
Specifies the default key access justifications (KAJ) policy used when a CryptoKey is created in this folder.
This is only used when a Key Access Justifications policy is not provided in the CreateCryptoKeyRequest. This overrides any default policies in its ancestry. If this field is unset, or is set but contains an empty allowed_access_reasons list, no default Key Access Justifications (KAJ) policy configuration is active. In this scenario, all newly created keys will default to an "allow-all" policy.
Optional.
Implementation
KeyAccessJustificationsPolicy? defaultKeyAccessJustificationPolicy;