defaultPolicyAvailable property
Indicates whether this parent resource is available to default policy feature.
Please consult the prerequisite of default policy feature for more details.
Output only.
Implementation
core.bool? defaultPolicyAvailable;
Indicates whether this parent resource is available to default policy feature.
Please consult the prerequisite of default policy feature for more details.
Output only.
core.bool? defaultPolicyAvailable;