KeyRing class

A KeyRing is a toplevel logical grouping of CryptoKeys.

Constructors

KeyRing({String? createTime, String? name})
KeyRing.fromJson(Map json_)

Properties

createTime ↔ String?
The time at which this KeyRing was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name for the KeyRing in the format `projects / * /locations /
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited