ListCryptoKeyVersionsResponse class

Response message for KeyManagementService.ListCryptoKeyVersions.

Constructors

ListCryptoKeyVersionsResponse({List<CryptoKeyVersion>? cryptoKeyVersions, String? nextPageToken, int? totalSize})
ListCryptoKeyVersionsResponse.fromJson(Map json_)

Properties

cryptoKeyVersions ↔ List<CryptoKeyVersion>?
The list of CryptoKeyVersions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to retrieve next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize ↔ int?
The total number of CryptoKeyVersions that matched the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited