ListCryptoKeysResponse class

Response message for KeyManagementService.ListCryptoKeys.

Constructors

ListCryptoKeysResponse({List<CryptoKey>? cryptoKeys, String? nextPageToken, int? totalSize})
ListCryptoKeysResponse.fromJson(Map json_)

Properties

cryptoKeys ↔ List<CryptoKey>?
The list of CryptoKeys.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to retrieve next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize ↔ int?
The total number of CryptoKeys that matched the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited