ListKeyRingsResponse class

Response message for KeyManagementService.ListKeyRings.

Constructors

ListKeyRingsResponse({List<KeyRing>? keyRings, String? nextPageToken, int? totalSize})
ListKeyRingsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyRings ↔ List<KeyRing>?
The list of KeyRings.
getter/setter pair
nextPageToken ↔ String?
A token to retrieve next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize ↔ int?
The total number of KeyRings that matched the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited