ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

ekmConfig → ProjectsLocationsEkmConfigResource
no setter
ekmConnections → ProjectsLocationsEkmConnectionsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
keyHandles → ProjectsLocationsKeyHandlesResource
no setter
keyRings → ProjectsLocationsKeyRingsResource
no setter
operations → ProjectsLocationsOperationsResource
no setter
retiredResources → ProjectsLocationsRetiredResourcesResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleTenantHsmInstances → ProjectsLocationsSingleTenantHsmInstancesResource
no setter

Methods

generateRandomBytes(GenerateRandomBytesRequest request, String location, {String? $fields}) → Future<GenerateRandomBytesResponse>
Generate random bytes using the Cloud KMS randomness source in the provided location.
get(String name, {String? $fields}) → Future<Location>
Gets information about a location.
getEkmConfig(String name, {String? $fields}) → Future<EkmConfig>
Returns the EkmConfig singleton resource for a given project and location.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateEkmConfig(EkmConfig request, String name, {String? updateMask, String? $fields}) → Future<EkmConfig>
Updates the EkmConfig singleton resource for a given project and location.

Operators

operator ==(Object other) → bool
The equality operator.
inherited