list method

Future<ListRetiredResourcesResponse> list(
  1. String parent, {
  2. int? pageSize,
  3. String? pageToken,
  4. String? $fields,
})

Lists the RetiredResources which are the records of deleted CryptoKeys.

RetiredResources prevent the reuse of these resource names after deletion.

Request parameters:

parent - Required. The project-specific location holding the RetiredResources, in the format projects / * /locations / * . Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.

pageSize - Optional. Optional limit on the number of RetiredResources to be included in the response. Further RetiredResources can subsequently be obtained by including the ListRetiredResourcesResponse.next_page_token in a subsequent request. If unspecified, the server will pick an appropriate default.

pageToken - Optional. Optional pagination token, returned earlier via ListRetiredResourcesResponse.next_page_token.

$fields - Selector specifying which fields to include in a partial response.

Completes with a ListRetiredResourcesResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<ListRetiredResourcesResponse> list(
  core.String parent, {
  core.int? pageSize,
  core.String? pageToken,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'pageSize': ?pageSize == null ? null : ['${pageSize}'],
    'pageToken': ?pageToken == null ? null : [pageToken],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/retiredResources';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return ListRetiredResourcesResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}