QuorumReply class

The reply to QuorumParameters for approving the proposal.

Constructors

QuorumReply({List<ChallengeReply>? challengeReplies})
QuorumReply.fromJson(Map json_)

Properties

challengeReplies ↔ List<ChallengeReply>?
The challenge replies to approve the proposal.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited