RequiredActionQuorumReply class

The reply to RequiredActionQuorumParameters for approving the proposal.

Constructors

RequiredActionQuorumReply({List<ChallengeReply>? quorumChallengeReplies, List<ChallengeReply>? requiredChallengeReplies})
RequiredActionQuorumReply.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
quorumChallengeReplies ↔ List<ChallengeReply>?
Quorum members' signed challenge replies.
getter/setter pair
requiredChallengeReplies ↔ List<ChallengeReply>?
All required challenges must be signed for the proposal to be approved.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited