RetiredResource class

A RetiredResource resource represents the record of a deleted CryptoKey.

Its purpose is to provide visibility into retained user data and to prevent reuse of these names for new CryptoKeys.

Constructors

RetiredResource({String? deleteTime, String? name, String? originalResource, String? resourceType})
RetiredResource.fromJson(Map json_)

Properties

deleteTime String?
The time at which the original resource was deleted and this RetiredResource record was created.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
originalResource String?
The full resource name of the original CryptoKey that was deleted in the format projects / * /locations / * /keyRings / * /cryptoKeys / * .
getter/setter pair
resourceType String?
The resource type of the original deleted resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited