deleteTime property
The time at which the original resource was deleted and this RetiredResource record was created.
Output only.
Implementation
core.String? deleteTime;
The time at which the original resource was deleted and this RetiredResource record was created.
Output only.
core.String? deleteTime;