ShowEffectiveAutokeyConfigResponse class

Response message for ShowEffectiveAutokeyConfig

Constructors

ShowEffectiveAutokeyConfigResponse({String? keyProject, String? keyProjectResolutionMode, Source? source})
ShowEffectiveAutokeyConfigResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
keyProject String?
Name of the key project configured in the ancestry of the project or folder.
getter/setter pair
keyProjectResolutionMode String?
The KeyProjectResolutionMode for the AutokeyConfig. Possible string values are:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Source?
Source of the effective AutokeyConfig.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited