keyProjectResolutionMode property

String? keyProjectResolutionMode
getter/setter pair

The KeyProjectResolutionMode for the AutokeyConfig. Possible string values are:

  • "KEY_PROJECT_RESOLUTION_MODE_UNSPECIFIED" : Default value. When KeyProjectResolutionMode is set to KEY_PROJECT_RESOLUTION_MODE_UNSPECIFIED for a folder and that folder has a key_project set, the folder acts like its KeyProjectResolutionMode is DEDICATED_KEY_PROJECT.
  • "DEDICATED_KEY_PROJECT" : Keys are created in a dedicated project specified by key_project.
  • "RESOURCE_PROJECT" : Keys are created in the same project as the resource requesting the key. The key_project must not be set when this mode is used.
  • "DISABLED" : Disables the AutokeyConfig. When this mode is set, any AutokeyConfig from higher levels in the resource hierarchy are ignored for this resource and its descendants. This setting can be overridden by a more specific configuration at a lower level. For example, if Autokey is disabled on a folder, it can be re-enabled on a sub-folder or project within that folder by setting a different mode (e.g., DEDICATED_KEY_PROJECT or RESOURCE_PROJECT).

Implementation

core.String? keyProjectResolutionMode;