SingleTenantHsmInstance class

A SingleTenantHsmInstance represents a single-tenant HSM instance.

It can be used for creating CryptoKeys with a ProtectionLevel of HSM_SINGLE_TENANT, as well as performing cryptographic operations using keys created within the SingleTenantHsmInstance.

Constructors

SingleTenantHsmInstance({String? createTime, String? deleteTime, String? disableTime, bool? keyPortabilityEnabled, String? name, QuorumAuth? quorumAuth, String? state, String? unrefreshedDurationUntilDisable})
SingleTenantHsmInstance.fromJson(Map json_)

Properties

createTime ↔ String?
The time at which the SingleTenantHsmInstance was created.
getter/setter pair
deleteTime ↔ String?
The time at which the SingleTenantHsmInstance was deleted.
getter/setter pair
disableTime ↔ String?
The time at which the instance will be automatically disabled if not refreshed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyPortabilityEnabled ↔ bool?
Indicates whether key portability is enabled for the SingleTenantHsmInstance.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
quorumAuth ↔ QuorumAuth?
The quorum auth configuration for the SingleTenantHsmInstance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the SingleTenantHsmInstance.
getter/setter pair
unrefreshedDurationUntilDisable ↔ String?
The system-defined duration that an instance can remain unrefreshed until it is automatically disabled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited