Source class
Source of the effective AutokeyConfig.
Constructors
- Source({String? name})
- Source.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Contains the resource name of the AutokeyConfig that is effective, for
example,
folders/{FOLDER_NUMBER}orprojects/{PROJECT_NUMBER}ororganizations/{ORGANIZATION_NUMBER}.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited