twoFactorPublicKeyPem property
The public key associated with the 2FA key that will sign the login nonce for this operation.
Required.
Implementation
core.String? twoFactorPublicKeyPem;
The public key associated with the 2FA key that will sign the login nonce for this operation.
Required.
core.String? twoFactorPublicKeyPem;