pem property
The public key, encoded in PEM format.
For more information, see the RFC 7468 sections for General Considerations and Textual Encoding of Subject Public Key Info. This field gets populated by default for RSA-based import methods, if no public_key_format is specified in the request. If you want to retrieve the wrapping key of an ImportJob in some other format, use KeyManagementService.GetImportJob and set the public_key_format to the desired public key format.
Implementation
core.String? pem;