LogicalProduct class
Represents an independent service offering that can be provisioned by a customer.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lifecycleState ↔ String?
-
Current Lifecycle state of the logical product.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- productSuite ↔ String?
-
Product suite associated with the logical product.
getter/setter pair
- replaced ↔ bool?
-
Indicates whether the logical product has been replaced.
getter/setter pair
- replacement ↔ String?
-
The resource name of the Logical Entity that the logical product is
replaced by.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
Display name of the LogicalProduct.
getter/setter pair
-
variants
↔ List<
String> ? -
Child variant resource references.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited