lifecycleState property
Current Lifecycle state of the logical product variant.
Output only. Possible string values are:
- "LIFECYCLE_STATE_UNSPECIFIED" : The default value. This value is used if the lifecycle state is not set.
- "LIFECYCLE_STATE_PUBLIC_PREVIEW" : The entity is in Public Preview. It is available to all customers, but may not be feature-complete or have full support guarantees.
- "LIFECYCLE_STATE_PRIVATE_GA" : The entity is in Private General Availability. It is fully supported and stable, but only available to a select group of customers.
- "LIFECYCLE_STATE_GA" : The entity is Generally Available. It is fully supported, stable, and available to all customers.
- "LIFECYCLE_STATE_DEPRECATED" : The entity is deprecated. It is no longer recommended for use and may be removed in a future version.
Implementation
core.String? lifecycleState;