LookupEntityResponse class

Response message for LookupEntity.

Constructors

LookupEntityResponse({LogicalProduct? logicalProduct, LogicalProductVariant? logicalProductVariant, ProductSuite? productSuite})
LookupEntityResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
logicalProduct LogicalProduct?
Matched LogicalProduct.
getter/setter pair
logicalProductVariant LogicalProductVariant?
Matched LogicalProductVariant.
getter/setter pair
productSuite ProductSuite?
Matched ProductSuite.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited