ListConstraint class

A Constraint that allows or disallows a list of string values, which are configured by an Organization's policy administrator with a Policy.

Constructors

ListConstraint({String? suggestedValue, bool? supportsUnder})
ListConstraint.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedValue ↔ String?
The Google Cloud Console will try to default to a configuration that matches the value specified in this Constraint.
getter/setter pair
supportsUnder ↔ bool?
Indicates whether subtrees of Cloud Resource Manager resource hierarchy can be used in Policy.allowed_values and Policy.denied_values.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited