ListLiensResponse class

The response message for Liens.ListLiens.

Constructors

ListLiensResponse({List<Lien>? liens, String? nextPageToken})
ListLiensResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
liens ↔ List<Lien>?
A list of Liens.
getter/setter pair
nextPageToken ↔ String?
Token to retrieve the next page of results, or empty if there are no more results in the list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited