Project class

A Project is a high-level Google Cloud Platform entity.

It is a container for ACLs, APIs, App Engine Apps, VMs, and other Google Cloud Platform resources.

Constructors

Project({List<String>? configuredCapabilities, String? createTime, Map<String, String>? labels, String? lifecycleState, String? name, ResourceId? parent, String? projectId, String? projectNumber, Map<String, String>? tags})
Project.fromJson(Map json_)

Properties

configuredCapabilities ↔ List<String>?
If this project is a Management Project, list of capabilities configured on the parent folder.
getter/setter pair
createTime ↔ String?
Creation time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels associated with this Project.
getter/setter pair
lifecycleState ↔ String?
The Project lifecycle state.
getter/setter pair
name ↔ String?
The optional user-assigned display name of the Project.
getter/setter pair
parent ↔ ResourceId?
An optional reference to a parent Resource.
getter/setter pair
projectId ↔ String?
The unique, user-assigned ID of the Project.
getter/setter pair
projectNumber ↔ String?
The number uniquely identifying the project.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ Map<String, String>?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited