FetchResourceSemanticsResponse class

Response message for FetchResourceSemantics.

Constructors

FetchResourceSemanticsResponse({String? fullResourceName, Map<String, String>? semantics})
FetchResourceSemanticsResponse.fromJson(Map json_)

Properties

fullResourceName String?
The full resource name for which semantics are returned.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semantics Map<String, String>?
Map of resource semantics (e.g., "ENVIRONMENT": "PRODUCTION").
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited