ListTagBindingsResponse class

The ListTagBindings response.

Constructors

ListTagBindingsResponse({String? nextPageToken, List<TagBinding>? tagBindings})
ListTagBindingsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Pagination token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagBindings ↔ List<TagBinding>?
A possibly paginated list of TagBindings for the specified resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited