ListTagHoldsResponse class

The ListTagHolds response.

Constructors

ListTagHoldsResponse({String? nextPageToken, List<TagHold>? tagHolds})
ListTagHoldsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Pagination token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagHolds ↔ List<TagHold>?
A possibly paginated list of TagHolds.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited