ListTagValuesResponse class

The ListTagValues response.

Constructors

ListTagValuesResponse({String? nextPageToken, List<TagValue>? tagValues})
ListTagValuesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A pagination token returned from a previous call to ListTagValues that indicates from where listing should continue.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagValues ↔ List<TagValue>?
A possibly paginated list of TagValues that are direct descendants of the specified parent TagKey.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited