MoveFolderRequest class

The MoveFolder request message.

Constructors

MoveFolderRequest({String? destinationParent})
MoveFolderRequest.fromJson(Map json_)

Properties

destinationParent ↔ String?
The resource name of the folder or organization which should be the folder's new parent.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited