SearchProjectsResponse class

A page of the response received from the SearchProjects method.

A paginated response where more pages are available has next_page_token set. This token can be used in a subsequent request to retrieve the next request page.

Constructors

SearchProjectsResponse({String? nextPageToken, List<Project>? projects})
SearchProjectsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Pagination token.
getter/setter pair
projects ↔ List<Project>?
The list of Projects that matched the list filter query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited