TagBindingCollection class

Represents a collection of tags directly bound to a GCP resource.

Constructors

TagBindingCollection({String? etag, String? fullResourceName, String? name, Map<String, String>? tags})
TagBindingCollection.fromJson(Map json_)

Properties

etag ↔ String?
A checksum based on the current bindings which can be passed to prevent race conditions.
getter/setter pair
fullResourceName ↔ String?
The full resource name of the resource the TagBindings are bound to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ Map<String, String>?
Tag keys/values directly bound to this resource, specified in namespaced format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited