TagKey class

A TagKey, used to group a set of TagValues.

Constructors

TagKey({String? allowedValuesRegex, String? createTime, String? description, String? etag, String? name, String? namespacedName, String? parent, String? purpose, Map<String, String>? purposeData, String? shortName, String? updateTime})
TagKey.fromJson(Map json_)

Properties

allowedValuesRegex ↔ String?
Regular expression constraint for freeform tag values.
getter/setter pair
createTime ↔ String?
Creation time.
getter/setter pair
description ↔ String?
User-assigned description of the TagKey.
getter/setter pair
etag ↔ String?
Entity tag which users can pass to prevent race conditions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name for a TagKey.
getter/setter pair
namespacedName ↔ String?
Namespaced name of the TagKey.
getter/setter pair
parent ↔ String?
The resource name of the TagKey's parent.
getter/setter pair
purpose ↔ String?
A purpose denotes that this Tag is intended for use in policies of a specific policy engine, and will involve that policy engine in management operations involving this Tag.
getter/setter pair
purposeData ↔ Map<String, String>?
Purpose data corresponds to the policy system that the tag is intended for.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName ↔ String?
The user friendly name for a TagKey.
getter/setter pair
updateTime ↔ String?
Update time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited