TagValuesTagHoldsResource class

Constructors

TagValuesTagHoldsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(TagHold request, String parent, {bool? validateOnly, String? $fields}) → Future<Operation>
Creates a TagHold.
delete(String name, {bool? validateOnly, String? $fields}) → Future<Operation>
Deletes a TagHold.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListTagHoldsResponse>
Lists TagHolds under a TagValue.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited