HttpTarget class

Http target.

The job will be pushed to the job handler by means of an HTTP request via an http_method such as HTTP POST, HTTP GET, etc. The job is acknowledged by means of an HTTP response code in the range [200 - 299]. A failure to receive a response constitutes a failed execution. For a redirected request, the response returned by the redirected request is considered.

Constructors

HttpTarget({String? body, Map<String, String>? headers, String? httpMethod, OAuthToken? oauthToken, OidcToken? oidcToken, String? uri})
HttpTarget.fromJson(Map json_)

Properties

body ↔ String?
HTTP request body.
getter/setter pair
bodyAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
HTTP request headers.
getter/setter pair
httpMethod ↔ String?
Which HTTP method to use for the request. Possible string values are:
getter/setter pair
oauthToken ↔ OAuthToken?
If specified, an OAuth token will be generated and attached as an Authorization header in the HTTP request.
getter/setter pair
oidcToken ↔ OidcToken?
If specified, an OIDC token will be generated and attached as an Authorization header in the HTTP request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
The full URI path that the request will be sent to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited