headers property
HTTP request headers.
This map contains the header field names and values. The user can specify
HTTP request headers to send with the job's HTTP request. Repeated headers
are not supported, but a header value can contain commas. The following
headers represent a subset of the headers that accompany the job's HTTP
request. Some HTTP request headers are ignored or replaced. A partial list
of headers that are ignored or replaced is below: * Host: This will be
computed by Cloud Scheduler and derived from uri. * Content-Length: This
will be computed by Cloud Scheduler. * User-Agent: This will be set to
"Google-Cloud-Scheduler". * X-Google-*: Used internally by Google. If
present in an external user request, it is replaced by the internal
header. * X-AppEngine-*: Used internally by Google. If present in an
external user request, it is replaced by the internal header. *
X-CloudScheduler: This header will be set to true. *
X-CloudScheduler-JobName: This header will contain the job name. *
X-CloudScheduler-ScheduleTime: For Cloud Scheduler jobs specified in the
unix-cron format, this header will contain the job schedule as an offset
of UTC parsed according to RFC3339. Remains constant across retries and
can be used for
job request deduplication.
If the job has a body and the following headers are not set by the user,
Cloud Scheduler sets default values: * Content-Type: This will be set to
"application/octet-stream". You can override this default by explicitly
setting Content-Type to a particular media type when creating the job.
For example, you can set Content-Type to "application/json". The total
size of headers must be less than 80KB.
Implementation
core.Map<core.String, core.String>? headers;