PubsubTarget class

Pub/Sub target.

The job will be delivered by publishing a message to the given Pub/Sub topic.

Constructors

PubsubTarget({Map<String, String>? attributes, String? data, String? topicName})
PubsubTarget.fromJson(Map json_)

Properties

attributes ↔ Map<String, String>?
Attributes for PubsubMessage.
getter/setter pair
data ↔ String?
The message payload for PubsubMessage.
getter/setter pair
dataAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topicName ↔ String?
The name of the Cloud Pub/Sub topic to which messages will be published when a job is delivered.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited