CompositeFilter class

Constructors

CompositeFilter({String? logicOperator, List<Filter>? subFilters})
CompositeFilter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logicOperator ↔ String?
The logic operator of the sub filter. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subFilters ↔ List<Filter>?
Sub filters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited