CustomerQueryStats class

Constructors

CustomerQueryStats({Date? date, List<QueryCountByStatus>? queryCountByStatus})
CustomerQueryStats.fromJson(Map json_)

Properties

date ↔ Date?
The date for which query stats were calculated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
queryCountByStatus ↔ List<QueryCountByStatus>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited