CustomerSearchApplicationStats class

Search application stats for a customer for the given date.

Properties

count ↔ String?
The count of search applications for the date.
getter/setter pair
date ↔ Date?
The date for which search application stats were calculated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited