DataSource class

Datasource is a logical namespace for items to be indexed.

All items must belong to a datasource. This is the prerequisite before items can be indexed into Cloud Search.

Constructors

DataSource({bool? disableModifications, bool? disableServing, String? displayName, List<String>? indexingServiceAccounts, List<GSuitePrincipal>? itemsVisibility, String? name, List<String>? operationIds, bool? returnThumbnailUrls, String? shortName})
DataSource.fromJson(Map json_)

Properties

disableModifications ↔ bool?
If true, sets the datasource to read-only mode.
getter/setter pair
disableServing ↔ bool?
Disable serving any search or assist results.
getter/setter pair
displayName ↔ String?
Display name of the datasource The maximum length is 300 characters.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indexingServiceAccounts ↔ List<String>?
List of service accounts that have indexing access.
getter/setter pair
itemsVisibility ↔ List<GSuitePrincipal>?
This field restricts visibility to items at the datasource level.
getter/setter pair
name ↔ String?
The name of the datasource resource.
getter/setter pair
operationIds ↔ List<String>?
IDs of the Long Running Operations (LROs) currently running for this schema.
getter/setter pair
returnThumbnailUrls ↔ bool?
Can a user request to get thumbnail URI for Items indexed in this data source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName ↔ String?
A short name or alias for the source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited