DateOperatorOptions class

Provides a search operator for date properties.

Search operators let users restrict the query to specific fields relevant to the type of item being searched.

Optional.

Constructors

DateOperatorOptions({String? greaterThanOperatorName, String? lessThanOperatorName, String? operatorName})
DateOperatorOptions.fromJson(Map json_)

Properties

greaterThanOperatorName ↔ String?
Indicates the operator name required in the query in order to isolate the date property using the greater-than operator.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lessThanOperatorName ↔ String?
Indicates the operator name required in the query in order to isolate the date property using the less-than operator.
getter/setter pair
operatorName ↔ String?
Indicates the actual string required in the query in order to isolate the date property.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited