DebugResponse class

Debug Search Response.

Constructors

DebugResponse({String? gsrRequest, String? gsrResponse, SearchResponse? searchResponse})
DebugResponse.fromJson(Map json_)

Properties

gsrRequest ↔ String?
Serialized string of GenericSearchRequest.
getter/setter pair
gsrRequestAsBytes ↔ List<int>
getter/setter pair
gsrResponse ↔ String?
Serialized string of GenericSearchResponse.
getter/setter pair
gsrResponseAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchResponse ↔ SearchResponse?
Search response.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited