DeleteQueueItemsRequest class

Constructors

DeleteQueueItemsRequest({String? connectorName, DebugOptions? debugOptions, String? queue})
DeleteQueueItemsRequest.fromJson(Map json_)

Properties

connectorName ↔ String?
The name of connector making this call.
getter/setter pair
debugOptions ↔ DebugOptions?
Common debug options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
queue ↔ String?
The name of a queue to delete items from.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited