DoubleOperatorOptions class

Used to provide a search operator for double properties.

This is optional. Search operators let users restrict the query to specific fields relevant to the type of item being searched.

Constructors

DoubleOperatorOptions({String? operatorName})
DoubleOperatorOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operatorName ↔ String?
Indicates the operator name required in the query in order to use the double property in sorting or as a facet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited