EmailAddress class

A person's email address.

Constructors

EmailAddress({String? customType, String? emailAddress, String? emailUrl, bool? primary, String? type})
EmailAddress.fromJson(Map json_)

Properties

customType ↔ String?
If the value of type is custom, this property contains the custom type string.
getter/setter pair
emailAddress ↔ String?
The email address.
getter/setter pair
emailUrl ↔ String?
The URL to send email.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
primary ↔ bool?
Indicates if this is the user's primary email.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the email account.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited