FacetOptions class

Specifies operators to return facet results for.

There will be one FacetResult for every source_name/object_type/operator_name combination.

Constructors

FacetOptions({IntegerFacetingOptions? integerFacetingOptions, int? numFacetBuckets, String? objectType, String? operatorName, String? sourceName})
FacetOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
integerFacetingOptions ↔ IntegerFacetingOptions?
If set, describes integer faceting options for the given integer property.
getter/setter pair
numFacetBuckets ↔ int?
Maximum number of facet buckets that should be returned for this facet.
getter/setter pair
objectType ↔ String?
If object_type is set, only those objects of that type will be used to compute facets.
getter/setter pair
operatorName ↔ String?
The name of the operator chosen for faceting.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceName ↔ String?
Source name to facet on.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited