FieldViolation class

Constructors

FieldViolation({String? description, String? field})
FieldViolation.fromJson(Map json_)

Properties

description ↔ String?
The description of the error.
getter/setter pair
field ↔ String?
Path of field with violation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited