FilterOptions class

Filter options to be applied on query.

Constructors

FilterOptions({Filter? filter, String? objectType})
FilterOptions.fromJson(Map json_)

Properties

filter ↔ Filter?
Generic filter to restrict the search, such as lang:en, site:xyz.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectType ↔ String?
If object_type is set, only objects of that type are returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited