IndexItemRequest class

Constructors

IndexItemRequest({String? connectorName, DebugOptions? debugOptions, IndexItemOptions? indexItemOptions, Item? item, String? mode})
IndexItemRequest.fromJson(Map json_)

Properties

connectorName ↔ String?
The name of connector making this call.
getter/setter pair
debugOptions ↔ DebugOptions?
Common debug options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indexItemOptions ↔ IndexItemOptions?
getter/setter pair
item ↔ Item?
The name of the item.
getter/setter pair
mode ↔ String?
The RequestMode for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited