IndexingDatasourcesResource class

Constructors

IndexingDatasourcesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items → IndexingDatasourcesItemsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteSchema(String name, {bool? debugOptions_enableDebugging, String? $fields}) → Future<Operation>
Deletes the schema of a data source.
getSchema(String name, {bool? debugOptions_enableDebugging, String? $fields}) → Future<Schema>
Gets the schema of a data source.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateSchema(UpdateSchemaRequest request, String name, {String? $fields}) → Future<Operation>
Updates the schema of a data source.

Operators

operator ==(Object other) → bool
The equality operator.
inherited