IntegerPropertyOptions class

The options for integer properties.

Constructors

IntegerPropertyOptions({IntegerFacetingOptions? integerFacetingOptions, String? maximumValue, String? minimumValue, IntegerOperatorOptions? operatorOptions, String? orderedRanking})
IntegerPropertyOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
integerFacetingOptions ↔ IntegerFacetingOptions?
If set, describes integer faceting options for the given integer property.
getter/setter pair
maximumValue ↔ String?
The maximum value of the property.
getter/setter pair
minimumValue ↔ String?
The minimum value of the property.
getter/setter pair
operatorOptions ↔ IntegerOperatorOptions?
If set, describes how the integer should be used as a search operator.
getter/setter pair
orderedRanking ↔ String?
Used to specify the ordered ranking for the integer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited