Item class

Represents a single object that is an item in the search index, such as a file, folder, or a database record.

Constructors

Item({ItemAcl? acl, ItemContent? content, String? itemType, ItemMetadata? metadata, String? name, String? payload, String? queue, ItemStatus? status, ItemStructuredData? structuredData, String? version})
Item.fromJson(Map json_)

Properties

acl ↔ ItemAcl?
Access control list for this item.
getter/setter pair
content ↔ ItemContent?
Item content to be indexed and made text searchable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemType ↔ String?
The type for this item. Possible string values are:
getter/setter pair
metadata ↔ ItemMetadata?
The metadata information.
getter/setter pair
name ↔ String?
The name of the Item.
getter/setter pair
payload ↔ String?
Additional state connector can store for this item.
getter/setter pair
payloadAsBytes ↔ List<int>
getter/setter pair
queue ↔ String?
Queue this item belongs to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ItemStatus?
Status of the item.
getter/setter pair
structuredData ↔ ItemStructuredData?
The structured data for the item that should conform to a registered object definition in the schema for the data source.
getter/setter pair
version ↔ String?
The indexing system stores the version from the datasource as a byte string and compares the Item version in the index to the version of the queued Item using lexical ordering.
getter/setter pair
versionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited