ItemContent class

Content of an item to be indexed and surfaced by Cloud Search.

Only UTF-8 encoded strings are allowed as inlineContent. If the content is uploaded and not binary, it must be UTF-8 encoded.

Constructors

ItemContent({UploadItemRef? contentDataRef, String? contentFormat, String? hash, String? inlineContent})
ItemContent.fromJson(Map json_)

Properties

contentDataRef ↔ UploadItemRef?
Upload reference ID of a previously uploaded content via write method.
getter/setter pair
contentFormat ↔ String?
Possible string values are:
getter/setter pair
hash ↔ String?
Hashing info calculated and provided by the API client for content.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inlineContent ↔ String?
Content that is supplied inlined within the update method.
getter/setter pair
inlineContentAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited