MatchRange class

Matched range of a snippet [start, end).

Constructors

MatchRange({int? end, int? start})
MatchRange.fromJson(Map json_)

Properties

end ↔ int?
End of the match in the snippet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ int?
Starting position of the match in the snippet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited