Metadata class

Metadata of a matched search result.

Constructors

Metadata({String? createTime, ResultDisplayMetadata? displayOptions, List<NamedProperty>? fields, String? mimeType, String? objectType, Person? owner, Source? source, String? thumbnailUrl, String? updateTime})
Metadata.fromJson(Map json_)

Properties

createTime ↔ String?
The creation time for this document or object in the search result.
getter/setter pair
displayOptions ↔ ResultDisplayMetadata?
Options that specify how to display a structured data search result.
getter/setter pair
fields ↔ List<NamedProperty>?
Indexed fields in structured data, returned as a generic named property.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mimeType ↔ String?
Mime type of the search result.
getter/setter pair
objectType ↔ String?
Object type of the search result.
getter/setter pair
owner ↔ Person?
Owner (usually creator) of the document or object of the search result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Source?
The named source for the result, such as Gmail.
getter/setter pair
thumbnailUrl ↔ String?
The thumbnail URL of the result.
getter/setter pair
updateTime ↔ String?
The last modified date for the object in the search result.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited