ObjectOptions class

The options for an object.

Constructors

ObjectOptions({ObjectDisplayOptions? displayOptions, FreshnessOptions? freshnessOptions, List<String>? suggestionFilteringOperators})
ObjectOptions.fromJson(Map json_)

Properties

displayOptions ↔ ObjectDisplayOptions?
The options that determine how the object is displayed in the Cloud Search results page.
getter/setter pair
freshnessOptions ↔ FreshnessOptions?
The freshness options for an object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestionFilteringOperators ↔ List<String>?
Operators that can be used to filter suggestions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited