ObjectPropertyOptions class

The options for object properties.

Constructors

ObjectPropertyOptions({List<PropertyDefinition>? subobjectProperties})
ObjectPropertyOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subobjectProperties ↔ List<PropertyDefinition>?
The properties of the sub-object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited