Principal class

Reference to a user, group, or domain.

Constructors

Principal({String? groupResourceName, GSuitePrincipal? gsuitePrincipal, String? userResourceName})
Principal.fromJson(Map json_)

Properties

groupResourceName ↔ String?
This principal is a group identified using an external identity.
getter/setter pair
gsuitePrincipal ↔ GSuitePrincipal?
This principal is a Google Workspace user, group or domain.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userResourceName ↔ String?
This principal is a user identified using an external identity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited