ProcessingError class

Constructors

ProcessingError({String? code, String? errorMessage, List<FieldViolation>? fieldViolations})
ProcessingError.fromJson(Map json_)

Properties

code ↔ String?
Error code indicating the nature of the error. Possible string values are:
getter/setter pair
errorMessage ↔ String?
The description of the error.
getter/setter pair
fieldViolations ↔ List<FieldViolation>?
In case the item fields are invalid, this field contains the details about the validation errors.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited