PropertyDefinition class

The definition of a property within an object.

Constructors

PropertyDefinition({BooleanPropertyOptions? booleanPropertyOptions, DatePropertyOptions? datePropertyOptions, PropertyDisplayOptions? displayOptions, DoublePropertyOptions? doublePropertyOptions, EnumPropertyOptions? enumPropertyOptions, HtmlPropertyOptions? htmlPropertyOptions, IntegerPropertyOptions? integerPropertyOptions, bool? isFacetable, bool? isRepeatable, bool? isReturnable, bool? isSortable, bool? isSuggestable, bool? isWildcardSearchable, String? name, ObjectPropertyOptions? objectPropertyOptions, TextPropertyOptions? textPropertyOptions, TimestampPropertyOptions? timestampPropertyOptions})
PropertyDefinition.fromJson(Map json_)

Properties

booleanPropertyOptions ↔ BooleanPropertyOptions?
getter/setter pair
datePropertyOptions ↔ DatePropertyOptions?
getter/setter pair
displayOptions ↔ PropertyDisplayOptions?
The options that determine how the property is displayed in the Cloud Search results page if it's specified to be displayed in the object's display options.
getter/setter pair
doublePropertyOptions ↔ DoublePropertyOptions?
getter/setter pair
enumPropertyOptions ↔ EnumPropertyOptions?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
htmlPropertyOptions ↔ HtmlPropertyOptions?
getter/setter pair
integerPropertyOptions ↔ IntegerPropertyOptions?
getter/setter pair
isFacetable ↔ bool?
Indicates that the property can be used for generating facets.
getter/setter pair
isRepeatable ↔ bool?
Indicates that multiple values are allowed for the property.
getter/setter pair
isReturnable ↔ bool?
Indicates that the property identifies data that should be returned in search results via the Query API.
getter/setter pair
isSortable ↔ bool?
Indicates that the property can be used for sorting.
getter/setter pair
isSuggestable ↔ bool?
Indicates that the property can be used for generating query suggestions.
getter/setter pair
isWildcardSearchable ↔ bool?
Indicates that users can perform wildcard search for this property.
getter/setter pair
name ↔ String?
The name of the property.
getter/setter pair
objectPropertyOptions ↔ ObjectPropertyOptions?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textPropertyOptions ↔ TextPropertyOptions?
getter/setter pair
timestampPropertyOptions ↔ TimestampPropertyOptions?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited