PushItem class

Represents an item to be pushed to the indexing queue.

Constructors

PushItem({String? contentHash, String? metadataHash, String? payload, String? queue, RepositoryError? repositoryError, String? structuredDataHash, String? type})
PushItem.fromJson(Map json_)

Properties

contentHash ↔ String?
Content hash of the item according to the repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadataHash ↔ String?
The metadata hash of the item according to the repository.
getter/setter pair
payload ↔ String?
Provides additional document state information for the connector, such as an alternate repository ID and other metadata.
getter/setter pair
payloadAsBytes ↔ List<int>
getter/setter pair
queue ↔ String?
Queue to which this item belongs.
getter/setter pair
repositoryError ↔ RepositoryError?
Populate this field to store Connector or repository error details.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredDataHash ↔ String?
Structured data hash of the item according to the repository.
getter/setter pair
type ↔ String?
The type of the push operation that defines the push behavior. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited