QueryInterpretationConfig class

Default options to interpret user query.

Constructors

QueryInterpretationConfig({bool? forceDisableSupplementalResults, bool? forceVerbatimMode})
QueryInterpretationConfig.fromJson(Map json_)

Properties

forceDisableSupplementalResults ↔ bool?
Set this flag to disable supplemental results retrieval, setting a flag here will not retrieve supplemental results for queries associated with a given search application.
getter/setter pair
forceVerbatimMode ↔ bool?
Enable this flag to turn off all internal optimizations like natural language (NL) interpretation of queries, supplemental results retrieval, and usage of synonyms including custom ones.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited