QueryInterpretationOptions class

Options to interpret user query.

Constructors

QueryInterpretationOptions({bool? disableNlInterpretation, bool? disableSupplementalResults, bool? enableVerbatimMode})
QueryInterpretationOptions.fromJson(Map json_)

Properties

disableNlInterpretation ↔ bool?
Flag to disable natural language (NL) interpretation of queries.
getter/setter pair
disableSupplementalResults ↔ bool?
Use this flag to disable supplemental results for a query.
getter/setter pair
enableVerbatimMode ↔ bool?
Enable this flag to turn off all internal optimizations like natural language (NL) interpretation of queries, supplemental result retrieval, and usage of synonyms including custom ones.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited