QueryOperator class

The definition of a operator that can be used in a Search/Suggest request.

Constructors

QueryOperator({String? displayName, List<String>? enumValues, String? greaterThanOperatorName, bool? isFacetable, bool? isRepeatable, bool? isReturnable, bool? isSortable, bool? isSuggestable, String? lessThanOperatorName, String? objectType, String? operatorName, String? type})
QueryOperator.fromJson(Map json_)

Properties

displayName ↔ String?
Display name of the operator
getter/setter pair
enumValues ↔ List<String>?
Potential list of values for the opeatror field.
getter/setter pair
greaterThanOperatorName ↔ String?
Indicates the operator name that can be used to isolate the property using the greater-than operator.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isFacetable ↔ bool?
Can this operator be used to get facets.
getter/setter pair
isRepeatable ↔ bool?
Indicates if multiple values can be set for this property.
getter/setter pair
isReturnable ↔ bool?
Will the property associated with this facet be returned as part of search results.
getter/setter pair
isSortable ↔ bool?
Can this operator be used to sort results.
getter/setter pair
isSuggestable ↔ bool?
Can get suggestions for this field.
getter/setter pair
lessThanOperatorName ↔ String?
Indicates the operator name that can be used to isolate the property using the less-than operator.
getter/setter pair
objectType ↔ String?
The name of the object corresponding to the operator.
getter/setter pair
operatorName ↔ String?
The name of the operator.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the operator. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited