QuerySourcesResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
list({String? pageToken, String? requestOptions_clientDisplayLanguageCode, String? requestOptions_countryCode, bool? requestOptions_debugOptions_enableDebugging, String? requestOptions_languageCode, String? requestOptions_searchApplicationId, String? requestOptions_timeZone, String? $fields})
→ Future<ListQuerySourcesResponse>
-
Returns list of sources that user can use for Search and Suggest APIs.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited