RepositoryError class

Errors when the connector is communicating to the source repository.

Constructors

RepositoryError({String? errorMessage, int? httpStatusCode, String? type})
RepositoryError.fromJson(Map json_)

Properties

errorMessage ↔ String?
Message that describes the error.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpStatusCode ↔ int?
Error codes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of error. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited