RequestOptions class

Shared request options for all RPC methods.

Constructors

RequestOptions({String? clientDisplayLanguageCode, String? countryCode, DebugOptions? debugOptions, String? languageCode, String? searchApplicationId, String? timeZone})
RequestOptions.fromJson(Map json_)

Properties

clientDisplayLanguageCode String?
The BCP-47 language code, such as "pt" or "en".
getter/setter pair
countryCode String?
Specifies the country/region where the query originated, as a lowercase ISO 3166-1 alpha-2 region code (using 'uk' instead of 'gb' for the United Kingdom).
getter/setter pair
debugOptions DebugOptions?
Debug options of the request
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
languageCode String?
The BCP-47 language code, such as "en-US" or "sr-Latn".
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchApplicationId String?
The ID generated when you create a search application using the admin console.
getter/setter pair
timeZone String?
Current user's time zone id, such as "America/Los_Angeles" or "Australia/Sydney".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited