ResultDisplayField class

Display Fields for Search Results

Constructors

ResultDisplayField({String? label, String? operatorName, NamedProperty? property})
ResultDisplayField.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
The display label for the property.
getter/setter pair
operatorName ↔ String?
The operator name of the property.
getter/setter pair
property ↔ NamedProperty?
The name value pair for the property.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited