ScoringConfig class

Scoring configurations for a source while processing a Search or Suggest request.

Constructors

ScoringConfig({bool? disableFreshness, bool? disablePersonalization})
ScoringConfig.fromJson(Map json_)

Properties

disableFreshness ↔ bool?
Whether to use freshness as a ranking signal.
getter/setter pair
disablePersonalization ↔ bool?
Whether to personalize the results.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited