SearchApplicationSessionStats class

Constructors

SearchApplicationSessionStats({Date? date, String? searchSessionsCount})
SearchApplicationSessionStats.fromJson(Map json_)

Properties

date ↔ Date?
The date for which session stats were calculated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchSessionsCount ↔ String?
The count of search sessions on the day
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited