SearchQualityMetadata class

Additional search quality metadata of the item.

Properties

hashCode → int
The hash code for this object.
no setterinherited
quality ↔ double?
An indication of the quality of the item, used to influence search quality.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited