SearchRequest class

The search API request.

NEXT ID: 26

Constructors

SearchRequest({List<ContextAttribute>? contextAttributes, List<DataSourceRestriction>? dataSourceRestrictions, List<FacetOptions>? facetOptions, int? pageSize, String? query, QueryInterpretationOptions? queryInterpretationOptions, RequestOptions? requestOptions, SortOptions? sortOptions, int? start})
SearchRequest.fromJson(Map json_)

Properties

contextAttributes ↔ List<ContextAttribute>?
Context attributes for the request which will be used to adjust ranking of search results.
getter/setter pair
dataSourceRestrictions ↔ List<DataSourceRestriction>?
The sources to use for querying.
getter/setter pair
facetOptions ↔ List<FacetOptions>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int?
Maximum number of search results to return in one page.
getter/setter pair
query ↔ String?
The raw query string.
getter/setter pair
queryInterpretationOptions ↔ QueryInterpretationOptions?
Options to interpret the user query.
getter/setter pair
requestOptions ↔ RequestOptions?
Request options, such as the search application and user timezone.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortOptions ↔ SortOptions?
The options for sorting the search results
getter/setter pair
start ↔ int?
Starting index of the results.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited