SourceConfig class

Configurations for a source while processing a Search or Suggest request.

Constructors

SourceConfig({SourceCrowdingConfig? crowdingConfig, SourceScoringConfig? scoringConfig, Source? source})
SourceConfig.fromJson(Map json_)

Properties

crowdingConfig ↔ SourceCrowdingConfig?
The crowding configuration for the source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scoringConfig ↔ SourceScoringConfig?
The scoring configuration for the source.
getter/setter pair
source ↔ Source?
The source for which this configuration is to be used.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited