SuggestRequest class

Request of suggest API.

Constructors

SuggestRequest({List<DataSourceRestriction>? dataSourceRestrictions, String? query, RequestOptions? requestOptions})
SuggestRequest.fromJson(Map json_)

Properties

dataSourceRestrictions ↔ List<DataSourceRestriction>?
The sources to use for suggestions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
query ↔ String?
Partial query for which autocomplete suggestions will be shown.
getter/setter pair
requestOptions ↔ RequestOptions?
Request options, such as the search application and user timezone.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited