SuggestResult class

One suggestion result.

Constructors

SuggestResult({PeopleSuggestion? peopleSuggestion, QuerySuggestion? querySuggestion, Source? source, String? suggestedQuery})
SuggestResult.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
peopleSuggestion ↔ PeopleSuggestion?
This is present when the suggestion indicates a person.
getter/setter pair
querySuggestion ↔ QuerySuggestion?
This field will be present if the suggested query is a word/phrase completion.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Source?
The source of the suggestion.
getter/setter pair
suggestedQuery ↔ String?
The suggested query that will be used for search, when the user clicks on the suggestion
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited