TextPropertyOptions class

The options for text properties.

Constructors

TextPropertyOptions({TextOperatorOptions? operatorOptions, RetrievalImportance? retrievalImportance})
TextPropertyOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operatorOptions ↔ TextOperatorOptions?
If set, describes how the property should be used as a search operator.
getter/setter pair
retrievalImportance ↔ RetrievalImportance?
Indicates the search quality importance of the tokens within the field when used for retrieval.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited