UpdateDataSourceRequest class

Constructors

UpdateDataSourceRequest({DebugOptions? debugOptions, DataSource? source, String? updateMask})
UpdateDataSourceRequest.fromJson(Map json_)

Properties

debugOptions ↔ DebugOptions?
Common debug options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ DataSource?
getter/setter pair
updateMask ↔ String?
Only applies to [settings.datasources.patch](https://developers.google.com/workspace/cloud-search/docs/reference/rest/v1/settings.datasources/patch).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited