UpdateSchemaRequest class

Constructors

UpdateSchemaRequest({DebugOptions? debugOptions, Schema? schema, bool? validateOnly})
UpdateSchemaRequest.fromJson(Map json_)

Properties

debugOptions ↔ DebugOptions?
Common debug options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ Schema?
The new schema for the source.
getter/setter pair
validateOnly ↔ bool?
If true, the schema will be checked for validity, but will not be registered with the data source, even if valid.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited