Value class

Definition of a single value with generic type.

Constructors

Value({bool? booleanValue, Date? dateValue, double? doubleValue, String? integerValue, String? stringValue, String? timestampValue})
Value.fromJson(Map json_)

Properties

booleanValue ↔ bool?
getter/setter pair
dateValue ↔ Date?
getter/setter pair
doubleValue ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integerValue ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue ↔ String?
getter/setter pair
timestampValue ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited