ValueFilter class

Constructors

ValueFilter({String? operatorName, Value? value})
ValueFilter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operatorName ↔ String?
The operator_name applied to the query, such as price_greater_than.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Value?
The value to be compared with.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited