cloudsupport/v2 library

Google Cloud Support API - v2

Manages Google Cloud technical support cases for Customer Care support offerings.

For more information, see cloud.google.com/support/docs/apis

Create an instance of CloudSupportApi to access these resources:

Classes

Actor
An Actor represents an entity that performed an action.
Attachment
An Attachment contains metadata about a file that was uploaded to a case - it is NOT a file itself.
Blobstore2Info
gdata.* are outside protos with mising documentation
ByteRange
Specifies a range of media.
Case
A Case is an object that contains the details of a support case.
CaseClassification
A Case Classification represents the topic that a case is about.
CaseClassificationsResource
CasesAttachmentsResource
CasesCommentsResource
CasesResource
CloudSupportApi
Manages Google Cloud technical support cases for Customer Care support offerings.
Comment
A comment associated with a support case.
CompositeMedia
gdata.* are outside protos with mising documentation
ContentTypeInfo
gdata.* are outside protos with mising documentation
CreateAttachmentRequest
The request message for the CreateAttachment endpoint.
DiffChecksumsResponse
gdata.* are outside protos with mising documentation
DiffDownloadResponse
gdata.* are outside protos with mising documentation
DiffUploadRequest
gdata.* are outside protos with mising documentation
DiffUploadResponse
gdata.* are outside protos with mising documentation
DiffVersionResponse
gdata.* are outside protos with mising documentation
DownloadOptions
Represents options for downloading media.
DownloadParameters
gdata.* are outside protos with mising documentation
EscalateCaseRequest
The request message for the EscalateCase endpoint.
Escalation
An escalation of a support case.
ListAttachmentsResponse
The response message for the ListAttachments endpoint.
ListCasesResponse
The response message for the ListCases endpoint.
ListCommentsResponse
The response message for the ListComments endpoint.
ListSupportEventSubscriptionsResponse
Response message for ListSupportEventSubscriptions.
Media
gdata.* are outside protos with mising documentation
MediaResource
ObjectId
gdata.* are outside protos with mising documentation
OrganizationsResource
OrganizationsSupportEventSubscriptionsResource
PartialDownloadOptions
Options for downloading a Media.
ResumableUploadOptions
Specifies options for resumable uploads.
SearchCaseClassificationsResponse
The response message for SearchCaseClassifications endpoint.
SearchCasesResponse
The response message for the SearchCases endpoint.
SupportEventSubscription
A support event subscription.
UploadOptions
Represents options for uploading a Media.

Typedefs

CloseCaseRequest = $Empty
The request message for the CloseCase endpoint.
Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
ExpungeSupportEventSubscriptionRequest = $Empty
Request message for ExpungeSupportEventSubscription.
UndeleteSupportEventSubscriptionRequest = $Empty
Request message for UndeleteSupportEventSubscription.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.