Blobstore2Info class

gdata.* are outside protos with mising documentation

Constructors

Blobstore2Info({String? blobGeneration, String? blobId, String? downloadExternalReadToken, String? downloadReadHandle, String? readToken, String? uploadFragmentListCreationInfo, String? uploadMetadataContainer})
Blobstore2Info.fromJson(Map json_)

Properties

blobGeneration ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
blobId ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
downloadExternalReadToken ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
downloadExternalReadTokenAsBytes ↔ List<int>
getter/setter pair
downloadReadHandle ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
downloadReadHandleAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readToken ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uploadFragmentListCreationInfo ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
uploadFragmentListCreationInfoAsBytes ↔ List<int>
getter/setter pair
uploadMetadataContainer ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
uploadMetadataContainerAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited