CloudSupportApi class

Manages Google Cloud technical support cases for Customer Care support offerings.

Constructors

CloudSupportApi(Client client, {String rootUrl = 'https://cloudsupport.googleapis.com/', String servicePath = ''})

Properties

caseClassifications → CaseClassificationsResource
no setter
cases → CasesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
media → MediaResource
no setter
organizations → OrganizationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

cloudPlatformScope → const String
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.