CompositeMedia class

gdata.* are outside protos with mising documentation

Constructors

CompositeMedia({String? blobRef, Blobstore2Info? blobstore2Info, String? cosmoBinaryReference, int? crc32cHash, String? inline, String? length, String? md5Hash, ObjectId? objectId, String? path, String? referenceType, String? sha1Hash})
CompositeMedia.fromJson(Map json_)

Properties

blobRef ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
blobRefAsBytes ↔ List<int>
getter/setter pair
blobstore2Info ↔ Blobstore2Info?
gdata.* are outside protos with mising documentation
getter/setter pair
cosmoBinaryReference ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
cosmoBinaryReferenceAsBytes ↔ List<int>
getter/setter pair
crc32cHash ↔ int?
gdata.* are outside protos with mising documentation
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inline ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
inlineAsBytes ↔ List<int>
getter/setter pair
length ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
md5Hash ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
md5HashAsBytes ↔ List<int>
getter/setter pair
objectId ↔ ObjectId?
gdata.* are outside protos with mising documentation
getter/setter pair
path ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
referenceType ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1Hash ↔ String?
gdata.* are outside protos with mising documentation
getter/setter pair
sha1HashAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited