EscalateCaseRequest class

The request message for the EscalateCase endpoint.

Constructors

EscalateCaseRequest({Escalation? escalation})
EscalateCaseRequest.fromJson(Map json_)

Properties

escalation ↔ Escalation?
The escalation information to be sent with the escalation request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited