Escalation class

An escalation of a support case.

Constructors

Escalation({String? justification, String? reason})
Escalation.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
justification ↔ String?
A free text description to accompany the reason field above.
getter/setter pair
reason ↔ String?
The reason why the Case is being escalated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited