MediaResource class

Constructors

MediaResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

download(String name, {String? $fields, DownloadOptions downloadOptions = commons.DownloadOptions.metadata}) → Future<Object>
Download a file attached to a case.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upload(CreateAttachmentRequest request, String parent, {String? $fields, Media? uploadMedia}) → Future<Attachment>
Create a file attachment on a case or Cloud resource.

Operators

operator ==(Object other) → bool
The equality operator.
inherited