OrganizationsSupportEventSubscriptionsResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(SupportEventSubscription request, String parent, {String? $fields})
→ Future<SupportEventSubscription>
-
Creates a support event subscription for an organization.
-
delete(String name, {String? $fields})
→ Future<SupportEventSubscription>
-
Soft deletes a support event subscription.
-
expunge(ExpungeSupportEventSubscriptionRequest request, String name, {String? $fields})
→ Future<Empty>
-
Expunges a support event subscription.
-
get(String name, {String? $fields})
→ Future<SupportEventSubscription>
-
Gets a support event subscription.
-
list(String parent, {String? filter, int? pageSize, String? pageToken, bool? showDeleted, String? $fields})
→ Future<ListSupportEventSubscriptionsResponse>
-
Lists support event subscriptions.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(SupportEventSubscription request, String name, {String? updateMask, String? $fields})
→ Future<SupportEventSubscription>
-
Updates a support event subscription.
-
toString()
→ String
-
A string representation of this object.
inherited
-
undelete(UndeleteSupportEventSubscriptionRequest request, String name, {String? $fields})
→ Future<SupportEventSubscription>
-
Undeletes a support event subscription.