SupportEventSubscription class

A support event subscription.

You can also manage support event subscriptions using other tools: * [gcloud support support-event-subscriptions](/sdk/gcloud/reference/support/support-event-subscriptions) (or [gcloud beta](/sdk/gcloud/reference/beta/support/support-event-subscriptions) for beta) * [Terraform google_cloud_support_support_event_subscription](https://registry.terraform.io/providers/hashicorp/google/latest/docs/resources/cloud_support_support_event_subscription) (or [google-beta provider](https://registry.terraform.io/providers/hashicorp/google-beta/latest/docs/resources/cloud_support_support_event_subscription) for beta)

Constructors

SupportEventSubscription({String? createTime, String? deleteTime, String? failureReason, String? name, String? pubSubTopic, String? purgeTime, String? state, String? updateTime})
SupportEventSubscription.fromJson(Map json_)

Properties

createTime String?
The time at which the subscription was created.
getter/setter pair
deleteTime String?
The time at which the subscription was deleted.
getter/setter pair
failureReason String?
Reason why subscription is failing.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
pubSubTopic String?
The name of the Pub/Sub topic to publish notifications to.
getter/setter pair
purgeTime String?
The time at which the subscription will be purged.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The state of the subscription.
getter/setter pair
updateTime String?
The time at which the subscription was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited