HttpTarget class

HTTP target.

When specified as a Queue, all the tasks with [HttpRequest] will be overridden according to the target.

Constructors

HttpTarget({List<HeaderOverride>? headerOverrides, String? httpMethod, OAuthToken? oauthToken, OidcToken? oidcToken, UriOverride? uriOverride})
HttpTarget.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerOverrides ↔ List<HeaderOverride>?
HTTP target headers.
getter/setter pair
httpMethod ↔ String?
The HTTP method to use for the request.
getter/setter pair
oauthToken ↔ OAuthToken?
If specified, an OAuth token is generated and attached as the Authorization header in the HTTP request.
getter/setter pair
oidcToken ↔ OidcToken?
If specified, an OIDC token is generated and attached as an Authorization header in the HTTP request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uriOverride ↔ UriOverride?
URI override.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited