maxBackoff property

String? maxBackoff
getter/setter pair

A task will be scheduled for retry between min_backoff and max_backoff duration after it fails, if the queue's RetryConfig specifies that the task should be retried.

The value must be given as a string that indicates the length of time (in seconds) followed by s (for "seconds"). For more information on the format, see the documentation for Duration. max_backoff will be truncated to the nearest second. If unspecified when the queue is created, Cloud Tasks will pick the default. This field has the same meaning as max_backoff_seconds in queue.yaml/xml.

Implementation

core.String? maxBackoff;