maxRetryDuration property

String? maxRetryDuration
getter/setter pair

If positive, max_retry_duration specifies the time limit for retrying a failed task, measured from when the task was first attempted.

Once max_retry_duration time has passed and the task has been attempted max_attempts times, no further attempts are made and the task is deleted. A zero (0) indicates an unlimited duration, up to the maximum task retention limit. The value must be given as a string that indicates the length of time (in seconds) followed by s (for "seconds"). For the maximum possible value or the format, see the documentation for Duration. max_retry_duration will be truncated to the nearest second. If unspecified when the queue is created, Cloud Tasks will pick the default. This field has the same meaning as task_age_limit in queue.yaml/xml.

Implementation

core.String? maxRetryDuration;