RunTaskRequest class

Request message for forcing a task to run now using RunTask.

Constructors

RunTaskRequest({String? responseView})
RunTaskRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
responseView ↔ String?
The response_view specifies which subset of the Task will be returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited