name property
Identifier.
The resource name of the span in the following format: *
projects/[PROJECT_ID]/traces/[TRACE_ID]/spans/[SPAN_ID] [TRACE_ID] is
a unique identifier for a trace within a project; it is a 32-character
hexadecimal encoding of a 16-byte array. It should not be zero.
[SPAN_ID] is a unique identifier for a span within a trace; it is a
16-character hexadecimal encoding of an 8-byte array. It should not be
zero. .
Implementation
core.String? name;