functionName property
The fully-qualified name that uniquely identifies the function or method that is active in this frame (up to 1024 bytes).
Optional.
Implementation
TruncatableString? functionName;
The fully-qualified name that uniquely identifies the function or method that is active in this frame (up to 1024 bytes).
Optional.
TruncatableString? functionName;