truncatedByteCount property
The number of bytes removed from the original string.
If this value is 0, then the string was not shortened.
Optional.
Implementation
core.int? truncatedByteCount;
The number of bytes removed from the original string.
If this value is 0, then the string was not shortened.
Optional.
core.int? truncatedByteCount;