AirflowMetadataRetentionPolicyConfig class

The policy for airflow metadata database retention.

Properties

hashCode → int
The hash code for this object.
no setterinherited
retentionDays ↔ int?
How many days data should be retained for.
getter/setter pair
retentionMode ↔ String?
Retention can be either enabled or disabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited