ComposerWorkload class

Information about a single workload.

Constructors

ComposerWorkload({String? name, ComposerWorkloadStatus? status, String? type})
ComposerWorkload.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of a workload.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ComposerWorkloadStatus?
Status of a workload.
getter/setter pair
type ↔ String?
Type of a workload. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited