ComposerWorkloadStatus class

Workload status.

Constructors

ComposerWorkloadStatus({String? detailedStatusMessage, String? state, String? statusMessage})
ComposerWorkloadStatus.fromJson(Map json_)

Properties

detailedStatusMessage ↔ String?
Detailed message of the status.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Workload state.
getter/setter pair
statusMessage ↔ String?
Text to provide more descriptive status.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited