DagProcessorResource class

Configuration for resources used by Airflow DAG processors.

This field is supported for Cloud Composer environments in versions composer-3-airflow-..-build. and newer.

Constructors

DagProcessorResource({int? count, double? cpu, double? memoryGb, double? storageGb})
DagProcessorResource.fromJson(Map json_)

Properties

count ↔ int?
The number of DAG processors.
getter/setter pair
cpu ↔ double?
CPU request and limit for a single Airflow DAG processor replica.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memoryGb ↔ double?
Memory (GB) request and limit for a single Airflow DAG processor replica.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageGb ↔ double?
Storage (GB) request and limit for a single Airflow DAG processor replica.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited