DatabaseConfig class

The configuration of Cloud SQL instance that is used by the Apache Airflow software.

Constructors

DatabaseConfig({String? machineType, String? zone})
DatabaseConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
machineType ↔ String?
Cloud SQL machine type used by Airflow database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zone ↔ String?
The Compute Engine zone where the Airflow database is created.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited