EnvironmentConfig class

Configuration information for an environment.

Constructors

EnvironmentConfig({String? airflowByoidUri, String? airflowUri, String? dagGcsPrefix, DataRetentionConfig? dataRetentionConfig, DatabaseConfig? databaseConfig, EncryptionConfig? encryptionConfig, String? environmentSize, String? gkeCluster, MaintenanceWindow? maintenanceWindow, MasterAuthorizedNetworksConfig? masterAuthorizedNetworksConfig, NodeConfig? nodeConfig, int? nodeCount, PrivateEnvironmentConfig? privateEnvironmentConfig, RecoveryConfig? recoveryConfig, String? resilienceMode, SoftwareConfig? softwareConfig, WebServerConfig? webServerConfig, WebServerNetworkAccessControl? webServerNetworkAccessControl, WorkloadsConfig? workloadsConfig})
EnvironmentConfig.fromJson(Map json_)

Properties

airflowByoidUri ↔ String?
The 'bring your own identity' variant of the URI of the Apache Airflow Web UI hosted within this environment, to be accessed with external identities using workforce identity federation (see [Access environments with workforce identity federation](/composer/docs/composer-2/access-environments-with-workforce-identity-federation)).
getter/setter pair
airflowUri ↔ String?
The URI of the Apache Airflow Web UI hosted within this environment (see [Airflow web interface](/composer/docs/how-to/accessing/airflow-web-interface)).
getter/setter pair
dagGcsPrefix ↔ String?
The Cloud Storage prefix of the DAGs for this environment.
getter/setter pair
databaseConfig ↔ DatabaseConfig?
The configuration settings for Cloud SQL instance used internally by Apache Airflow software.
getter/setter pair
dataRetentionConfig ↔ DataRetentionConfig?
The configuration setting for Airflow database data retention mechanism.
getter/setter pair
encryptionConfig ↔ EncryptionConfig?
The encryption options for the Cloud Composer environment and its dependencies.
getter/setter pair
environmentSize ↔ String?
The size of the Cloud Composer environment.
getter/setter pair
gkeCluster ↔ String?
The Kubernetes Engine cluster used to run this environment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maintenanceWindow ↔ MaintenanceWindow?
The maintenance window is the period when Cloud Composer components may undergo maintenance.
getter/setter pair
masterAuthorizedNetworksConfig ↔ MasterAuthorizedNetworksConfig?
The configuration options for GKE cluster master authorized networks.
getter/setter pair
nodeConfig ↔ NodeConfig?
The configuration used for the Kubernetes Engine cluster.
getter/setter pair
nodeCount ↔ int?
The number of nodes in the Kubernetes Engine cluster that will be used to run this environment.
getter/setter pair
privateEnvironmentConfig ↔ PrivateEnvironmentConfig?
The configuration used for the Private IP Cloud Composer environment.
getter/setter pair
recoveryConfig ↔ RecoveryConfig?
The Recovery settings configuration of an environment.
getter/setter pair
resilienceMode ↔ String?
Resilience mode of the Cloud Composer Environment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softwareConfig ↔ SoftwareConfig?
The configuration settings for software inside the environment.
getter/setter pair
webServerConfig ↔ WebServerConfig?
The configuration settings for the Airflow web server App Engine instance.
getter/setter pair
webServerNetworkAccessControl ↔ WebServerNetworkAccessControl?
The network-level access control policy for the Airflow web server.
getter/setter pair
workloadsConfig ↔ WorkloadsConfig?
The workloads configuration settings for the GKE cluster associated with the Cloud Composer environment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited