ExecuteAirflowCommandRequest class

Execute Airflow Command request.

Constructors

ExecuteAirflowCommandRequest({String? command, List<String>? parameters, String? subcommand})
ExecuteAirflowCommandRequest.fromJson(Map json_)

Properties

command ↔ String?
Airflow command.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parameters ↔ List<String>?
Parameters for the Airflow command/subcommand as an array of arguments.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subcommand ↔ String?
Airflow subcommand.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited