IPAllocationPolicy class

Configuration for controlling how IPs are allocated in the GKE cluster running the Apache Airflow software.

Constructors

IPAllocationPolicy({String? clusterIpv4CidrBlock, String? clusterSecondaryRangeName, String? servicesIpv4CidrBlock, String? servicesSecondaryRangeName, bool? useIpAliases})
IPAllocationPolicy.fromJson(Map json_)

Properties

clusterIpv4CidrBlock ↔ String?
The IP address range used to allocate IP addresses to pods in the GKE cluster.
getter/setter pair
clusterSecondaryRangeName ↔ String?
The name of the GKE cluster's secondary range used to allocate IP addresses to pods.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servicesIpv4CidrBlock ↔ String?
The IP address range of the services IP addresses in this GKE cluster.
getter/setter pair
servicesSecondaryRangeName ↔ String?
The name of the services' secondary range used to allocate IP addresses to the GKE cluster.
getter/setter pair
useIpAliases ↔ bool?
Whether or not to enable Alias IPs in the GKE cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited