ImageVersion class

ImageVersion information

Constructors

ImageVersion({bool? creationDisabled, String? imageVersionId, bool? isDefault, Date? releaseDate, List<String>? supportedPythonVersions, bool? upgradeDisabled})
ImageVersion.fromJson(Map json_)

Properties

creationDisabled ↔ bool?
Whether it is impossible to create an environment with the image version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageVersionId ↔ String?
The string identifier of the ImageVersion, in the form: "composer-x.y.z-airflow-a.b.c"
getter/setter pair
isDefault ↔ bool?
Whether this is the default ImageVersion used by Composer during environment creation if no input ImageVersion is specified.
getter/setter pair
releaseDate ↔ Date?
The date of the version release.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedPythonVersions ↔ List<String>?
supported python versions
getter/setter pair
upgradeDisabled ↔ bool?
Whether it is impossible to upgrade an environment running with the image version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited