ListEnvironmentsResponse class

The environments in a project and location.

Constructors

ListEnvironmentsResponse({List<Environment>? environments, String? nextPageToken})
ListEnvironmentsResponse.fromJson(Map json_)

Properties

environments ↔ List<Environment>?
The list of environments returned by a ListEnvironmentsRequest.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The page token used to query for the next page if one exists.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited