ListWorkloadsResponse class

Response to ListWorkloadsRequest.

Constructors

ListWorkloadsResponse({String? nextPageToken, List<ComposerWorkload>? workloads})
ListWorkloadsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The page token used to query for the next page if one exists.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workloads ↔ List<ComposerWorkload>?
The list of environment workloads.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited