NodeConfig class

The configuration information for the Kubernetes Engine nodes running the Apache Airflow software.

Constructors

NodeConfig({String? composerInternalIpv4CidrBlock, String? composerNetworkAttachment, int? diskSizeGb, bool? enableIpMasqAgent, IPAllocationPolicy? ipAllocationPolicy, String? location, String? machineType, String? network, List<String>? oauthScopes, String? serviceAccount, String? subnetwork, List<String>? tags})
NodeConfig.fromJson(Map json_)

Properties

composerInternalIpv4CidrBlock ↔ String?
The IP range in CIDR notation to use internally by Cloud Composer.
getter/setter pair
composerNetworkAttachment ↔ String?
Network Attachment that Cloud Composer environment is connected to, which provides connectivity with a user's VPC network.
getter/setter pair
diskSizeGb ↔ int?
The disk size in GB used for node VMs.
getter/setter pair
enableIpMasqAgent ↔ bool?
Deploys 'ip-masq-agent' daemon set in the GKE cluster and defines nonMasqueradeCIDRs equals to pod IP range so IP masquerading is used for all destination addresses, except between pods traffic.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipAllocationPolicy ↔ IPAllocationPolicy?
The configuration for controlling how IPs are allocated in the GKE cluster.
getter/setter pair
location ↔ String?
The Compute Engine [zone](/compute/docs/regions-zones) in which to deploy the VMs used to run the Apache Airflow software, specified as a [relative resource name](/apis/design/resource_names#relative_resource_name).
getter/setter pair
machineType ↔ String?
The Compute Engine [machine type](/compute/docs/machine-types) used for cluster instances, specified as a [relative resource name](/apis/design/resource_names#relative_resource_name).
getter/setter pair
network ↔ String?
The Compute Engine network to be used for machine communications, specified as a [relative resource name](/apis/design/resource_names#relative_resource_name).
getter/setter pair
oauthScopes ↔ List<String>?
The set of Google API scopes to be made available on all node VMs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
The Google Cloud Platform Service Account to be used by the node VMs.
getter/setter pair
subnetwork ↔ String?
The Compute Engine subnetwork to be used for machine communications, specified as a [relative resource name](/apis/design/resource_names#relative_resource_name).
getter/setter pair
tags ↔ List<String>?
The list of instance tags applied to all node VMs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited