PollAirflowCommandRequest class

Poll Airflow Command request.

Constructors

PollAirflowCommandRequest({String? executionId, int? nextLineNumber, String? pod, String? podNamespace})
PollAirflowCommandRequest.fromJson(Map json_)

Properties

executionId ↔ String?
The unique ID of the command execution.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextLineNumber ↔ int?
Line number from which new logs should be fetched.
getter/setter pair
pod ↔ String?
The name of the pod where the command is executed.
getter/setter pair
podNamespace ↔ String?
The namespace of the pod where the command is executed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited