PollAirflowCommandResponse class

Response to PollAirflowCommandRequest.

Constructors

PollAirflowCommandResponse({ExitInfo? exitInfo, List<Line>? output, bool? outputEnd})
PollAirflowCommandResponse.fromJson(Map json_)

Properties

exitInfo ↔ ExitInfo?
The result exit status of the command.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
output ↔ List<Line>?
Output from the command execution.
getter/setter pair
outputEnd ↔ bool?
Whether the command execution has finished and there is no more output.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited