StopAirflowCommandResponse class

Response to StopAirflowCommandRequest.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isDone ↔ bool?
Whether the execution is still running.
getter/setter pair
output ↔ List<String>?
Output message from stopping execution request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited