UserWorkloadsConfigMap class

User workloads ConfigMap used by Airflow tasks that run with Kubernetes executor or KubernetesPodOperator.

Properties

data ↔ Map<String, String>?
The "data" field of Kubernetes ConfigMap, organized in key-value pairs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited