WorkloadsConfig class

The Kubernetes workloads configuration for GKE cluster associated with the Cloud Composer environment.

Supported for Cloud Composer environments in versions composer-2..-airflow-..* and newer.

Constructors

WorkloadsConfig({DagProcessorResource? dagProcessor, SchedulerResource? scheduler, TriggererResource? triggerer, WebServerResource? webServer, WorkerResource? worker})
WorkloadsConfig.fromJson(Map json_)

Properties

dagProcessor ↔ DagProcessorResource?
Resources used by Airflow DAG processors.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduler ↔ SchedulerResource?
Resources used by Airflow schedulers.
getter/setter pair
triggerer ↔ TriggererResource?
Resources used by Airflow triggerers.
getter/setter pair
webServer ↔ WebServerResource?
Resources used by Airflow web server.
getter/setter pair
worker ↔ WorkerResource?
Resources used by Airflow workers.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited