AcceleratorTopologiesInfoAcceleratorTopologyInfo class

Info for a slice of a given topology.

Properties

acceleratorTopology String?
The accelerator topology.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
infoPerTopologyStates List<AcceleratorTopologiesInfoAcceleratorTopologyInfoInfoPerTopologyState>?
Info for each topology state.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited