AccessConfig class

An access configuration attached to an instance's network interface. Only one access config per instance is supported.

Constructors

AccessConfig({String? externalIpv6, int? externalIpv6PrefixLength, String? kind, String? name, String? natIP, String? networkTier, String? publicPtrDomainName, String? securityPolicy, bool? setPublicPtr, String? type})
AccessConfig.fromJson(Map json_)

Properties

externalIpv6 ↔ String?
Applies to ipv6AccessConfigs only. The first IPv6 address of the external IPv6 range associated with this instance, prefix length is stored inexternalIpv6PrefixLength in ipv6AccessConfig.
getter/setter pair
externalIpv6PrefixLength ↔ int?
Applies to ipv6AccessConfigs only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
The name of this access configuration.
getter/setter pair
natIP ↔ String?
Applies to accessConfigs (IPv4) only.
getter/setter pair
networkTier ↔ String?
This signifies the networking tier used for configuring this access configuration and can only take the following values: PREMIUM,STANDARD.
getter/setter pair
publicPtrDomainName ↔ String?
The DNS domain name for the public PTR record.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityPolicy ↔ String?
The resource URL for the security policy associated with this access config.
getter/setter pair
setPublicPtr ↔ bool?
Specifies whether a public DNS 'PTR' record should be created to map the external IP address of the instance to a DNS domain name.
getter/setter pair
type ↔ String?
The type of configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited