AllocationResourceStatusSpecificSKUAllocation class

Contains Properties set for the reservation.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceInstanceTemplateId ↔ String?
ID of the instance template used to populate reservation properties.
getter/setter pair
utilizations ↔ Map<String, String>?
Per service utilization breakdown.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited