AllocationSpecificSKUAllocationReservedInstanceProperties class

Properties of the SKU instances being reserved.

Next ID: 9

Properties

guestAccelerators ↔ List<AcceleratorConfig>?
Specifies accelerator type and count.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localSsds ↔ List<AllocationSpecificSKUAllocationAllocatedInstancePropertiesReservedDisk>?
Specifies amount of local ssd to reserve with each instance.
getter/setter pair
locationHint ↔ String?
An opaque location hint used to place the allocation close to other resources.
getter/setter pair
machineType ↔ String?
Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory.
getter/setter pair
minCpuPlatform ↔ String?
Minimum cpu platform the reservation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited