AttachedDisk class

An instance-attached disk resource.

Constructors

AttachedDisk({String? architecture, bool? autoDelete, bool? boot, String? deviceName, CustomerEncryptionKey? diskEncryptionKey, String? diskSizeGb, bool? forceAttach, List<GuestOsFeature>? guestOsFeatures, int? index, AttachedDiskInitializeParams? initializeParams, String? interface, String? kind, List<String>? licenses, String? mode, String? savedState, InitialStateConfig? shieldedInstanceInitialState, String? source, String? type})
AttachedDisk.fromJson(Map json_)

Properties

architecture ↔ String?
The architecture of the attached disk.
getter/setter pair
autoDelete ↔ bool?
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
getter/setter pair
boot ↔ bool?
Indicates that this is a boot disk.
getter/setter pair
deviceName ↔ String?
Specifies a unique device name of your choice that is reflected into the/dev/disk/by-id/google-* tree of a Linux operating system running within the instance.
getter/setter pair
diskEncryptionKey ↔ CustomerEncryptionKey?
Encrypts or decrypts a disk using acustomer-supplied encryption key.
getter/setter pair
diskSizeGb ↔ String?
The size of the disk in GB.
getter/setter pair
forceAttach ↔ bool?
[Input Only] Whether to force attach the regional disk even if it's currently attached to another instance.
getter/setter pair
guestOsFeatures ↔ List<GuestOsFeature>?
A list of features to enable on the guest operating system.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int?
A zero-based index to this disk, where 0 is reserved for the boot disk.
getter/setter pair
initializeParams ↔ AttachedDiskInitializeParams?
[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance.
getter/setter pair
interface ↔ String?
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
licenses ↔ List<String>?
Any valid publicly visible licenses.
getter/setter pair
mode ↔ String?
The mode in which to attach this disk, either READ_WRITE orREAD_ONLY.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedState ↔ String?
For LocalSSD disks on VM Instances in STOPPED or SUSPENDED state, this field is set to PRESERVED if the LocalSSD data has been saved to a persistent location by customer request.
getter/setter pair
shieldedInstanceInitialState ↔ InitialStateConfig?
shielded vm initial state stored on disk
getter/setter pair
source ↔ String?
Specifies a valid partial or full URL to an existing Persistent Disk resource.
getter/setter pair
type ↔ String?
Specifies the type of the disk, either SCRATCH orPERSISTENT.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited