region property
URL of theregion where the instance group resides (for autoscalers living in regional scope).
Output only.
Implementation
core.String? region;
URL of theregion where the instance group resides (for autoscalers living in regional scope).
Output only.
core.String? region;