AutoscalingPolicyScaleInControl class

Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.

Constructors

AutoscalingPolicyScaleInControl({FixedOrPercent? maxScaledInReplicas, int? timeWindowSec})
AutoscalingPolicyScaleInControl.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxScaledInReplicas ↔ FixedOrPercent?
Maximum allowed number (or %) of VMs that can be deducted from the peak recommendation during the window autoscaler looks at when computing recommendations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeWindowSec ↔ int?
How far back autoscaling looks when computing recommendations to include directives regarding slower scale in, as described above.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited