AutoscalingPolicyScalingSchedule class
Scaling based on user-defined schedule.
The message describes a single scaling schedule. A scaling schedule changes the minimum number of VM instances an autoscaler can recommend, which can trigger scaling out.
Constructors
- AutoscalingPolicyScalingSchedule({String? description, bool? disabled, int? durationSec, int? minRequiredReplicas, String? schedule, String? timeZone})
- AutoscalingPolicyScalingSchedule.fromJson(Map json_)
Properties
- description ↔ String?
-
A description of a scaling schedule.
getter/setter pair
- disabled ↔ bool?
-
A boolean value that specifies whether a scaling schedule can influence
autoscaler recommendations.
getter/setter pair
- durationSec ↔ int?
-
The duration of time intervals, in seconds, for which this
scaling schedule is to run.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- minRequiredReplicas ↔ int?
-
The minimum number of VM instances that the autoscaler will
recommend in time intervals starting according to schedule.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedule ↔ String?
-
The start timestamps of time intervals when this scaling
schedule is to provide a scaling signal.
getter/setter pair
- timeZone ↔ String?
-
The time zone to use when interpreting the schedule.
The value of this field must be a time zone name from the tz database:
https://en.wikipedia.org/wiki/Tz_database.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited