Backend class

Message containing information of one individual backend.

Constructors

Backend({String? balancingMode, double? capacityScaler, List<BackendCustomMetric>? customMetrics, String? description, bool? failover, String? group, int? maxConnections, int? maxConnectionsPerEndpoint, int? maxConnectionsPerInstance, int? maxInFlightRequests, int? maxInFlightRequestsPerEndpoint, int? maxInFlightRequestsPerInstance, int? maxRate, double? maxRatePerEndpoint, double? maxRatePerInstance, double? maxUtilization, BackendBackendOrchestrationInfo? orchestrationInfo, String? preference, String? trafficDuration})
Backend.fromJson(Map json_)

Properties

balancingMode ↔ String?
Specifies how to determine whether the backend of a load balancer can handle additional traffic or is fully loaded.
getter/setter pair
capacityScaler ↔ double?
A multiplier applied to the backend's target capacity of its balancing mode. The default value is 1, which means the group serves up to 100% of its configured capacity (depending onbalancingMode).
getter/setter pair
customMetrics ↔ List<BackendCustomMetric>?
List of custom metrics that are used for CUSTOM_METRICS BalancingMode.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
failover ↔ bool?
This field designates whether this is a failover backend.
getter/setter pair
group ↔ String?
The fully-qualified URL of aninstance group or network endpoint group (NEG) resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxConnections ↔ int?
Defines a target maximum number of simultaneous connections.
getter/setter pair
maxConnectionsPerEndpoint ↔ int?
Defines a target maximum number of simultaneous connections.
getter/setter pair
maxConnectionsPerInstance ↔ int?
Defines a target maximum number of simultaneous connections. For usage guidelines, seeConnection balancing mode and Utilization balancing mode.
getter/setter pair
maxInFlightRequests ↔ int?
Defines a maximum number of in-flight requests for the whole NEG or instance group.
getter/setter pair
maxInFlightRequestsPerEndpoint ↔ int?
Defines a maximum number of in-flight requests for a single endpoint. Not available if backend's balancingMode is RATE or CONNECTION.
getter/setter pair
maxInFlightRequestsPerInstance ↔ int?
Defines a maximum number of in-flight requests for a single VM. Not available if backend's balancingMode is RATE or CONNECTION.
getter/setter pair
maxRate ↔ int?
Defines a maximum number of HTTP requests per second (RPS).
getter/setter pair
maxRatePerEndpoint ↔ double?
Defines a maximum target for requests per second (RPS).
getter/setter pair
maxRatePerInstance ↔ double?
Defines a maximum target for requests per second (RPS).
getter/setter pair
maxUtilization ↔ double?
Optional parameter to define a target capacity for theUTILIZATION balancing mode.
getter/setter pair
orchestrationInfo ↔ BackendBackendOrchestrationInfo?
Information about the resource or system that manages the backend.
getter/setter pair
preference ↔ String?
This field indicates whether this backend should be fully utilized before sending traffic to backends with default preference.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficDuration ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited