failover property

bool? failover
getter/setter pair

This field designates whether this is a failover backend.

More than one failover backend can be configured for a given BackendService.

This field can only be used for a regional external Passthrough Network Load Balancer or a regional internal Passthrough Network Load Balancer.

Implementation

core.bool? failover;