orchestrationInfo property
Information about the resource or system that manages the backend.
Implementation
BackendBackendOrchestrationInfo? orchestrationInfo;
Information about the resource or system that manages the backend.
BackendBackendOrchestrationInfo? orchestrationInfo;