trafficDuration property

String? trafficDuration
getter/setter pair

Possible string values are:

  • "LONG" : Most of the requests are expected to take more than multiple seconds to finish.
  • "SHORT" : Most requests are expected to finish with a sub-second latency.
  • "TRAFFIC_DURATION_UNSPECIFIED" : Traffic duration is unspecified.

Implementation

core.String? trafficDuration;