region property
URL of the region where the regional backend bucket resides.
This field is not applicable to global backend buckets. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body.
Output only.
Implementation
core.String? region;