BackendBucketCdnPolicyCacheKeyPolicy class

Message containing what to include in the cache key for a request for Cloud CDN.

Constructors

BackendBucketCdnPolicyCacheKeyPolicy({List<String>? includeHttpHeaders, List<String>? queryStringWhitelist})
BackendBucketCdnPolicyCacheKeyPolicy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeHttpHeaders ↔ List<String>?
Allows HTTP request headers (by name) to be used in the cache key.
getter/setter pair
queryStringWhitelist ↔ List<String>?
Names of query string parameters to include in cache keys.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited