BackendCustomMetric class

Custom Metrics are used for CUSTOM_METRICS balancing_mode.

Constructors

BackendCustomMetric({bool? dryRun, double? maxUtilization, String? name})
BackendCustomMetric.fromJson(Map json_)

Properties

dryRun ↔ bool?
If true, the metric data is collected and reported to Cloud Monitoring, but is not used for load balancing.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxUtilization ↔ double?
Optional parameter to define a target utilization for the Custom Metrics balancing mode.
getter/setter pair
name ↔ String?
Name of a custom utilization signal.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited