localityLbPolicies property

List<BackendServiceLocalityLoadBalancingPolicyConfig>? localityLbPolicies
getter/setter pair

A list of locality load-balancing policies to be used in order of preference.

When you use localityLbPolicies, you must set at least one value for either the localityLbPolicies[].policy or the localityLbPolicies[].customPolicy field. localityLbPolicies overrides any value set in the localityLbPolicy field.

For an example of how to use this field, seeDefine a list of preferred policies.

Caution: This field and its children are intended for use in a service mesh that includes gRPC clients only. Envoy proxies can't use backend services that have this configuration.

Implementation

core.List<BackendServiceLocalityLoadBalancingPolicyConfig>?
localityLbPolicies;