orchestrationInfo property
Information about the resource or system that manages the backend service.
Implementation
BackendServiceOrchestrationInfo? orchestrationInfo;
Information about the resource or system that manages the backend service.
BackendServiceOrchestrationInfo? orchestrationInfo;