BackendServiceCdnPolicy class

Message containing Cloud CDN configuration for a backend service.

Constructors

BackendServiceCdnPolicy({List<BackendBucketCdnPolicyBypassCacheOnRequestHeader>? bypassCacheOnRequestHeaders, CacheKeyPolicy? cacheKeyPolicy, String? cacheMode, int? clientTtl, int? defaultTtl, int? maxTtl, bool? negativeCaching, List<BackendBucketCdnPolicyNegativeCachingPolicy>? negativeCachingPolicy, bool? requestCoalescing, int? serveWhileStale, String? signedUrlCacheMaxAgeSec, List<String>? signedUrlKeyNames})
BackendServiceCdnPolicy.fromJson(Map json_)

Properties

bypassCacheOnRequestHeaders ↔ List<BackendBucketCdnPolicyBypassCacheOnRequestHeader>?
Bypass the cache when the specified request headers are matched - e.g. Pragma or Authorization headers.
getter/setter pair
cacheKeyPolicy ↔ CacheKeyPolicy?
The CacheKeyPolicy for this CdnPolicy.
getter/setter pair
cacheMode ↔ String?
Specifies the cache setting for all responses from this backend.
getter/setter pair
clientTtl ↔ int?
Specifies a separate client (e.g. browser client) maximum TTL.
getter/setter pair
defaultTtl ↔ int?
Specifies the default TTL for cached content served by this origin for responses that do not have an existing valid TTL (max-age or s-maxage).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxTtl ↔ int?
Specifies the maximum allowed TTL for cached content served by this origin.
getter/setter pair
negativeCaching ↔ bool?
Negative caching allows per-status code TTLs to be set, in order to apply fine-grained caching for common errors or redirects.
getter/setter pair
negativeCachingPolicy ↔ List<BackendBucketCdnPolicyNegativeCachingPolicy>?
Sets a cache TTL for the specified HTTP status code.
getter/setter pair
requestCoalescing ↔ bool?
If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serveWhileStale ↔ int?
Serve existing content from the cache (if available) when revalidating content with the origin, or when an error is encountered when refreshing the cache.
getter/setter pair
signedUrlCacheMaxAgeSec ↔ String?
Maximum number of seconds the response to a signed URL request will be considered fresh.
getter/setter pair
signedUrlKeyNames ↔ List<String>?
Names of the keys for signing request URLs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited