BackendServiceGroupHealth class

Constructors

BackendServiceGroupHealth({Map<String, String>? annotations, List<HealthStatus>? healthStatus, String? kind})
BackendServiceGroupHealth.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Metadata defined as annotations on the network endpoint group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthStatus ↔ List<HealthStatus>?
Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.
getter/setter pair
kind ↔ String?
Type of resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited