BackendServiceHAPolicy class

Properties

fastIPMove ↔ String?
Specifies whether fast IP move is enabled, and if so, the mechanism to achieve it.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
leader ↔ BackendServiceHAPolicyLeader?
Selects one of the network endpoints attached to the backend NEGs of this service as the active endpoint (the leader) that receives all traffic.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited