BackendServiceIAP class

Identity-Aware Proxy

Constructors

BackendServiceIAP({bool? enabled, String? oauth2ClientId, String? oauth2ClientSecret, String? oauth2ClientSecretSha256})
BackendServiceIAP.fromJson(Map json_)

Properties

enabled ↔ bool?
Whether the serving infrastructure will authenticate and authorize all incoming requests.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oauth2ClientId ↔ String?
OAuth2 client ID to use for the authentication flow.
getter/setter pair
oauth2ClientSecret ↔ String?
OAuth2 client secret to use for the authentication flow. For security reasons, this value cannot be retrieved via the API. Instead, the SHA-256 hash of the value is returned in the oauth2ClientSecretSha256 field.
getter/setter pair
oauth2ClientSecretSha256 ↔ String?
SHA256 hash value for the field oauth2_client_secret above.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited