BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy class

The configuration for a custom policy implemented by the user and deployed with the client.

Properties

data ↔ String?
An optional, arbitrary JSON object with configuration data, understood by a locally installed custom policy implementation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifies the custom policy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited