BackendServiceLogConfig class

The available logging options for the load balancer traffic served by this backend service.

Constructors

BackendServiceLogConfig({bool? enable, List<BackendServiceLogConfigLoggingHttpHeader>? loggingHttpRequestHeaders, List<BackendServiceLogConfigLoggingHttpHeader>? loggingHttpResponseHeaders, List<String>? optionalFields, String? optionalMode, double? sampleRate})
BackendServiceLogConfig.fromJson(Map json_)

Properties

enable bool?
Denotes whether to enable logging for the load balancer traffic served by this backend service.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loggingHttpRequestHeaders List<BackendServiceLogConfigLoggingHttpHeader>?
The list of request headers that will be logged to Stackdriver.
getter/setter pair
loggingHttpResponseHeaders List<BackendServiceLogConfigLoggingHttpHeader>?
The list of response headers that will be logged to Stackdriver.
getter/setter pair
optionalFields List<String>?
This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM.
getter/setter pair
optionalMode String?
This field can only be specified if logging is enabled for this backend service.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate double?
This field can only be specified if logging is enabled for this backend service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited