loggingHttpResponseHeaders property
The list of response headers that will be logged to Stackdriver.
Implementation
core.List<BackendServiceLogConfigLoggingHttpHeader>?
loggingHttpResponseHeaders;
The list of response headers that will be logged to Stackdriver.
core.List<BackendServiceLogConfigLoggingHttpHeader>?
loggingHttpResponseHeaders;