BackendServiceTlsSettings class

Constructors

BackendServiceTlsSettings({String? authenticationConfig, String? identity, String? sni, List<BackendServiceTlsSettingsSubjectAltName>? subjectAltNames})
BackendServiceTlsSettings.fromJson(Map json_)

Properties

authenticationConfig ↔ String?
Reference to the BackendAuthenticationConfig resource from the networksecurity.googleapis.com namespace.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identity ↔ String?
Assigns the Managed Identity for the BackendService Workload.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sni ↔ String?
Server Name Indication - see RFC3546 section 3.1.
getter/setter pair
subjectAltNames ↔ List<BackendServiceTlsSettingsSubjectAltName>?
A list of Subject Alternative Names (SANs) that the Load Balancer verifies during a TLS handshake with the backend.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited