BackendServicesResource class

Constructors

BackendServicesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addSignedUrlKey(SignedUrlKey request, String project, String backendService, {String? requestId, String? $fields}) Future<Operation>
Adds a key for validating requests with signed URLs for this backend service.
aggregatedList(String project, {String? filter, bool? includeAllScopes, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? serviceProjectNumber, String? $fields}) Future<BackendServiceAggregatedList>
Retrieves the list of all BackendService resources, regional and global, available to the specified project.
delete(String project, String backendService, {String? requestId, String? $fields}) Future<Operation>
Deletes the specified BackendService resource.
deleteSignedUrlKey(String project, String backendService, String keyName, {String? requestId, String? $fields}) Future<Operation>
Deletes a key for validating requests with signed URLs for this backend service.
get(String project, String backendService, {String? $fields}) Future<BackendService>
Returns the specified BackendService resource.
getEffectiveSecurityPolicies(String project, String backendService, {String? $fields}) Future<void>
Returns effective security policies applied to this backend service.
getHealth(ResourceGroupReference request, String project, String backendService, {String? $fields}) Future<BackendServiceGroupHealth>
Gets the most recent health check results for this BackendService.
getIamPolicy(String project, String resource, {int? optionsRequestedPolicyVersion, String? $fields}) Future<Policy>
Gets the access control policy for a resource.
insert(BackendService request, String project, {String? requestId, String? $fields}) Future<Operation>
Creates a BackendService resource in the specified project using the data included in the request.
list(String project, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<BackendServiceList>
Retrieves the list of BackendService resources available to the specified project.
listUsable(String project, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<BackendServiceListUsable>
Retrieves a list of all usable backend services for Application Load Balancers and Proxy Network Load Balancers in the specified project. Backend services for external and internal passthrough Network Load Balancers are not included in the response.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(BackendService request, String project, String backendService, {String? requestId, String? $fields}) Future<Operation>
Patches the specified BackendService resource with the data included in the request.
setEdgeSecurityPolicy(SecurityPolicyReference request, String project, String backendService, {String? requestId, String? $fields}) Future<Operation>
Sets the edge security policy for the specified backend service.
setIamPolicy(GlobalSetPolicyRequest request, String project, String resource, {String? $fields}) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
setSecurityPolicy(SecurityPolicyReference request, String project, String backendService, {String? requestId, String? $fields}) Future<Operation>
Sets the Google Cloud Armor security policy for the specified backend service.
testIamPermissions(TestPermissionsRequest request, String project, String resource, {String? $fields}) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited
update(BackendService request, String project, String backendService, {String? requestId, String? $fields}) Future<Operation>
Updates the specified BackendService resource with the data included in the request.

Operators

operator ==(Object other) bool
The equality operator.
inherited