BfdPacket class

Constructors

BfdPacket({bool? authenticationPresent, bool? controlPlaneIndependent, bool? demand, String? diagnostic, bool? final_, int? length, int? minEchoRxIntervalMs, int? minRxIntervalMs, int? minTxIntervalMs, int? multiplier, bool? multipoint, int? myDiscriminator, bool? poll, String? state, int? version, int? yourDiscriminator})
BfdPacket.fromJson(Map json_)

Properties

authenticationPresent ↔ bool?
The Authentication Present bit of the BFD packet.
getter/setter pair
controlPlaneIndependent ↔ bool?
The Control Plane Independent bit of the BFD packet.
getter/setter pair
demand ↔ bool?
The demand bit of the BFD packet.
getter/setter pair
diagnostic ↔ String?
The diagnostic code specifies the local system's reason for the last change in session state.
getter/setter pair
final_ ↔ bool?
The Final bit of the BFD packet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ int?
The length of the BFD Control packet in bytes.
getter/setter pair
minEchoRxIntervalMs ↔ int?
The Required Min Echo RX Interval value in the BFD packet.
getter/setter pair
minRxIntervalMs ↔ int?
The Required Min RX Interval value in the BFD packet.
getter/setter pair
minTxIntervalMs ↔ int?
The Desired Min TX Interval value in the BFD packet.
getter/setter pair
multiplier ↔ int?
The detection time multiplier of the BFD packet.
getter/setter pair
multipoint ↔ bool?
The multipoint bit of the BFD packet.
getter/setter pair
myDiscriminator ↔ int?
The My Discriminator value in the BFD packet.
getter/setter pair
poll ↔ bool?
The Poll bit of the BFD packet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current BFD session state as seen by the transmitting system.
getter/setter pair
version ↔ int?
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
getter/setter pair
yourDiscriminator ↔ int?
The Your Discriminator value in the BFD packet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited