BfdStatusPacketCounts class

Constructors

BfdStatusPacketCounts({int? numRx, int? numRxRejected, int? numRxSuccessful, int? numTx})
BfdStatusPacketCounts.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
numRx ↔ int?
Number of packets received since the beginning of the current BFD session.
getter/setter pair
numRxRejected ↔ int?
Number of packets received that were rejected because of errors since the beginning of the current BFD session.
getter/setter pair
numRxSuccessful ↔ int?
Number of packets received that were successfully processed since the beginning of the current BFD session.
getter/setter pair
numTx ↔ int?
Number of packets transmitted since the beginning of the current BFD session.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited