BulkInsertInstanceResourcePerInstanceProperties class

Per-instance properties to be set on individual instances. To be extended in the future.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
Specifies the hostname of the instance.
getter/setter pair
name ↔ String?
This field is only temporary.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited