BulkInsertOperationStatus class

Constructors

BulkInsertOperationStatus({int? createdVmCount, int? deletedVmCount, int? failedToCreateVmCount, String? status, int? targetVmCount})
BulkInsertOperationStatus.fromJson(Map json_)

Properties

createdVmCount ↔ int?
Count of VMs successfully created so far.
getter/setter pair
deletedVmCount ↔ int?
Count of VMs that got deleted during rollback.
getter/setter pair
failedToCreateVmCount ↔ int?
Count of VMs that started creating but encountered an error.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Creation status of BulkInsert operation - information if the flow is rolling forward or rolling back.
getter/setter pair
targetVmCount ↔ int?
Count of VMs originally planned to be created.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited