CacheKeyPolicy class

Message containing what to include in the cache key for a request for Cloud CDN.

Constructors

CacheKeyPolicy({bool? includeHost, List<String>? includeHttpHeaders, List<String>? includeNamedCookies, bool? includeProtocol, bool? includeQueryString, List<String>? queryStringBlacklist, List<String>? queryStringWhitelist})
CacheKeyPolicy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeHost ↔ bool?
If true, requests to different hosts will be cached separately.
getter/setter pair
includeHttpHeaders ↔ List<String>?
Allows HTTP request headers (by name) to be used in the cache key.
getter/setter pair
includeNamedCookies ↔ List<String>?
Allows HTTP cookies (by name) to be used in the cache key. The name=value pair will be used in the cache key Cloud CDN generates.
getter/setter pair
includeProtocol ↔ bool?
If true, http and https requests will be cached separately.
getter/setter pair
includeQueryString ↔ bool?
If true, include query string parameters in the cache key according to query_string_whitelist and query_string_blacklist.
getter/setter pair
queryStringBlacklist ↔ List<String>?
Names of query string parameters to exclude in cache keys.
getter/setter pair
queryStringWhitelist ↔ List<String>?
Names of query string parameters to include in cache keys.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited