defaultTtl property

Duration? defaultTtl
getter/setter pair

Specifies the default TTL for cached content for responses that do not have an existing valid TTL (max-age or s-maxage).

Setting a TTL of "0" means "always revalidate". The value of defaultTtl cannot be set to a value greater than that of maxTtl. When the cacheMode is set to FORCE_CACHE_ALL, the defaultTtl will overwrite the TTL set in all responses. The maximum allowed value is 31,622,400s (1 year). Infrequently accessed objects may be evicted from the cache before the defined TTL. If not specified, Cloud CDN uses 3600s (1 hour) for CACHE_ALL_STATIC and FORCE_CACHE_ALL modes. Cannot be specified when cacheMode is USE_ORIGIN_HEADERS.

Implementation

Duration? defaultTtl;