negativeCaching property

bool? negativeCaching
getter/setter pair

Negative caching allows per-status code TTLs to be set, in order to apply fine-grained caching for common errors or redirects. This can reduce the load on your origin and improve end-user experience by reducing response latency. When the cacheMode is set to CACHE_ALL_STATIC or USE_ORIGIN_HEADERS, negative caching applies to responses with the specified response code that lack any Cache-Control, Expires, or Pragma: no-cache directives.

When the cacheMode is set to FORCE_CACHE_ALL, negative caching applies to all responses with the specified response code, and overrides any caching headers. By default, Cloud CDN applies the following TTLs to these HTTP status codes:

  • 300 (Multiple Choice), 301, 308 (Permanent Redirects): 10m
  • 404 (Not Found), 410 (Gone), 451 (Unavailable For Legal Reasons): 120s
  • 405 (Method Not Found), 501 (Not Implemented): 60s

These defaults can be overridden in negativeCachingPolicy. If not specified, Cloud CDN applies negative caching by default.

Implementation

core.bool? negativeCaching;