negativeCachingPolicy property

List<CachePolicyNegativeCachingPolicy>? negativeCachingPolicy
getter/setter pair

Sets a cache TTL for the specified HTTP status code. negativeCaching must be enabled to configure negativeCachingPolicy. Omitting the policy and leaving negativeCaching enabled will use Cloud CDN's default cache TTLs.

Note that when specifying an explicit negativeCachingPolicy, you should take care to specify a cache TTL for all response codes that you wish to cache. Cloud CDN will not apply any default negative caching when a policy exists.

Implementation

core.List<CachePolicyNegativeCachingPolicy>? negativeCachingPolicy;