requestCoalescing property
If true then Cloud CDN will combine multiple concurrent cache fill requests into a small number of requests to the origin.
If not specified, Cloud CDN applies request coalescing by default.
Implementation
core.bool? requestCoalescing;