excludedQueryParameters property

List<String>? excludedQueryParameters
getter/setter pair

Names of query string parameters to exclude in cache keys.

All other parameters will be included. Either specify excludedQueryParameters or includedQueryParameters, not both. '&' and '=' will be percent encoded and not treated as delimiters.

Note: This field applies to routes that use backend services. Attempting to set it on a route that points exclusively to Backend Buckets will result in a configuration error. For routes that point to a Backend Bucket, use includedQueryParameters to define which parameters should be part of the cache key.

Implementation

core.List<core.String>? excludedQueryParameters;