includeProtocol property
If true, http and https requests will be cached separately.
Note: This setting is only applicable to routes that use a Backend Service.
It does not affect requests served by a Backend Bucket, as the protocol is never included in a Backend Bucket's cache key. Attempting to set on a route that points exclusively to Backend Buckets will result in a configuration error.
Implementation
core.bool? includeProtocol;