includedCookieNames property

List<String>? includedCookieNames
getter/setter pair

Allows HTTP cookies (by name) to be used in the cache key. The name=value pair will be used in the cache key Cloud CDN generates.

Note: This setting is only applicable to routes that use a Backend Service.

It does not affect requests served by a Backend Bucket. Attempting to set it on a route that points exclusively to Backend Buckets will result in a configuration error. Up to 5 cookie names can be specified.

Implementation

core.List<core.String>? includedCookieNames;