includedQueryParameters property

List<String>? includedQueryParameters
getter/setter pair

Names of query string parameters to include in cache keys.

All other parameters will be excluded. Either specify includedQueryParameters or excludedQueryParameters, not both. '&' and '=' will be percent encoded and not treated as delimiters.

Implementation

core.List<core.String>? includedQueryParameters;