ttl property

Duration? ttl
getter/setter pair

The TTL (in seconds) for which to cache responses with the corresponding status code. The maximum allowed value is 1800s (30 minutes).

Infrequently accessed objects may be evicted from the cache before the defined TTL.

Implementation

Duration? ttl;