Commitment class

Represents a regional resource-based commitment resource.

Creating this commitment resource means that you are purchasing a resource-based committed use contract, with an explicit start and end time. You can purchase resource-based commitments for both hardware and software resources.

For more information, read Resource-based committed use discounts

Constructors

Commitment({bool? autoRenew, String? category, String? creationTimestamp, String? customEndTimestamp, String? description, String? endTimestamp, List<String>? existingReservations, String? id, String? kind, LicenseResourceCommitment? licenseResource, List<String>? mergeSourceCommitments, String? name, CommitmentParams? params, String? plan, String? region, List<Reservation>? reservations, CommitmentResourceStatus? resourceStatus, List<ResourceCommitment>? resources, String? selfLink, String? splitSourceCommitment, String? startTimestamp, String? status, String? statusMessage, String? type})
Commitment.fromJson(Map json_)

Properties

autoRenew ↔ bool?
Specifies whether to automatically renew the commitment at the end of its current term.
getter/setter pair
category ↔ String?
The category of the commitment; specifies whether the commitment is for hardware or software resources.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
customEndTimestamp ↔ String?
[Input Only] Optional, specifies the requested commitment end time inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of the commitment.
getter/setter pair
endTimestamp ↔ String?
Commitment end time inRFC3339 text format.
getter/setter pair
existingReservations ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
licenseResource ↔ LicenseResourceCommitment?
The license specification required as part of a license commitment.
getter/setter pair
mergeSourceCommitments ↔ List<String>?
The list of source commitments that you are merging to create the new merged commitment.
getter/setter pair
name ↔ String?
Name of the commitment.
getter/setter pair
params ↔ CommitmentParams?
Input only.
getter/setter pair
plan ↔ String?
The minimum time duration that you commit to purchasing resources. The plan that you choose determines the preset term length of the commitment (which is 1 year or 3 years) and affects the discount rate that you receive for your resources.
getter/setter pair
region ↔ String?
URL of the region where the commitment and committed resources are located.
getter/setter pair
reservations ↔ List<Reservation>?
The list of new reservations that you want to create and attach to this commitment.
getter/setter pair
resources ↔ List<ResourceCommitment>?
The list of all the hardware resources, with their types and amounts, that you want to commit to.
getter/setter pair
resourceStatus ↔ CommitmentResourceStatus?
Status information for Commitment resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
splitSourceCommitment ↔ String?
The source commitment from which you are transferring resources to create the new split commitment.
getter/setter pair
startTimestamp ↔ String?
Commitment start time inRFC3339 text format.
getter/setter pair
status ↔ String?
Status of the commitment with regards to eventual expiration (each commitment has an end date defined).
getter/setter pair
statusMessage ↔ String?
An optional, human-readable explanation of the status.
getter/setter pair
type ↔ String?
The type of commitment; specifies the machine series for which you want to commit to purchasing resources. The choice of machine series affects the discount rate and the eligible resource types.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited