CompositeHealthCheck class

Represents a composite health check.

A composite health check resource specifies the health source resources and the health destination resource to which the aggregated health result from the health source resources is delivered.

Constructors

CompositeHealthCheck({String? creationTimestamp, String? description, String? fingerprint, String? healthDestination, List<String>? healthSources, String? id, String? kind, String? name, String? region, String? selfLink, String? selfLinkWithId})
CompositeHealthCheck.fromJson(Map json_)

Properties

creationTimestamp String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description String?
An optional description of this resource.
getter/setter pair
fingerprint String?
Fingerprint of this resource.
getter/setter pair
fingerprintAsBytes List<int>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
healthDestination String?
URL to the destination resource.
getter/setter pair
healthSources List<String>?
URLs to the HealthSource resources whose results are AND'ed. I.e. he aggregated result is is HEALTHY only if all sources are HEALTHY.
getter/setter pair
id String?
A unique identifier for this resource type.
getter/setter pair
kind String?
Type of the resource.
getter/setter pair
name String?
Name of the resource.
getter/setter pair
region String?
URL of the region where the composite health check resides. This field applies only to the regional resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId String?
Server-defined URL with id for the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited