CompositeHealthChecksGetHealthResponseHealthSourceHealth class
Constructors
- CompositeHealthChecksGetHealthResponseHealthSourceHealth({String? healthState, String? source})
- CompositeHealthChecksGetHealthResponseHealthSourceHealth.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthState ↔ String?
-
Health state of the associated HealthSource resource.
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ String?
-
Fully qualified URL of the associated HealthSource resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited