CompositeHealthChecksScopedList class
Constructors
-
CompositeHealthChecksScopedList({List<
CompositeHealthCheck> ? compositeHealthChecks, CompositeHealthChecksScopedListWarning? warning}) - CompositeHealthChecksScopedList.fromJson(Map json_)
Properties
-
compositeHealthChecks
↔ List<
CompositeHealthCheck> ? -
A list of CompositeHealthChecks contained in this scope.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warning ↔ CompositeHealthChecksScopedListWarning?
-
Informational warning which replaces the list of composite health checks
when the list is empty.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited