warning property
Informational warning which replaces the list of composite health checks when the list is empty.
Implementation
CompositeHealthChecksScopedListWarning? warning;
Informational warning which replaces the list of composite health checks when the list is empty.
CompositeHealthChecksScopedListWarning? warning;