ConnectionDraining class

Message containing connection draining configuration.

Constructors

ConnectionDraining({int? drainingTimeoutSec})
ConnectionDraining.fromJson(Map json_)

Properties

drainingTimeoutSec ↔ int?
Configures a duration timeout for existing requests on a removed backend instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited