ConsistentHashLoadBalancerSettings class

This message defines settings for a consistent hash style load balancer.

Properties

hashCode → int
The hash code for this object.
no setterinherited
httpCookie ↔ ConsistentHashLoadBalancerSettingsHttpCookie?
Hash is based on HTTP Cookie.
getter/setter pair
httpHeaderName ↔ String?
The hash based on the value of the specified header field.
getter/setter pair
minimumRingSize ↔ String?
The minimum number of virtual nodes to use for the hash ring.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited