ConsistentHashLoadBalancerSettingsHttpCookie class

The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the cookie.
getter/setter pair
path ↔ String?
Path to set for the cookie.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl ↔ Duration?
Lifetime of the cookie.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited