allowOrigins property

List<String>? allowOrigins
getter/setter pair

Specifies the list of origins that is allowed to do CORS requests.

An origin is allowed if it matches either an item inallowOrigins or an item inallowOriginRegexes.

Implementation

core.List<core.String>? allowOrigins;