CustomErrorResponsePolicy class

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.

Properties

errorResponseRules ↔ List<CustomErrorResponsePolicyCustomErrorResponseRule>?
Specifies rules for returning error responses.
getter/setter pair
errorService ↔ String?
The full or partial URL to the BackendBucket resource that contains the custom error content.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited