CustomErrorResponsePolicyCustomErrorResponseRule class

Specifies the mapping between the response code that will be returned along with the custom error content and the response code returned by the backend service.

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchResponseCodes ↔ List<String>?
Valid values include:
getter/setter pair
overrideResponseCode ↔ int?
The HTTP status code returned with the response containing the custom error content.
getter/setter pair
path ↔ String?
The full path to a file within backendBucket .
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited