CustomerEncryptionKey class

Constructors

CustomerEncryptionKey({String? kmsKeyName, String? kmsKeyServiceAccount, String? rawKey, String? rsaEncryptedKey, String? sha256})
CustomerEncryptionKey.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
kmsKeyName String?
The name of the encryption key that is stored in Google Cloud KMS. For example:
getter/setter pair
kmsKeyServiceAccount String?
The service account being used for the encryption request for the given KMS key.
getter/setter pair
rawKey String?
CSEK is no longer supported.
getter/setter pair
rsaEncryptedKey String?
CSEK is no longer supported.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String?
CSEK is no longer supported.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited