CustomerEncryptionKeyProtectedDisk class

Properties

diskEncryptionKey ↔ CustomerEncryptionKey?
Decrypts data associated with the disk with acustomer-supplied encryption key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
Specifies a valid partial or full URL to an existing Persistent Disk resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited