DateTime class

Represents civil time (or occasionally physical time).

This type can represent a civil time in one of a few possible ways:

  • When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
  • When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
  • When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time.

The date is relative to the Proleptic Gregorian Calendar.

If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively.

This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead.

If your use case also would like to store the user's timezone, that can be done in another field.

This type is more flexible than some applications may want. Make sure to document and validate your application's limitations.

Constructors

DateTime({int? day, int? hours, int? minutes, int? month, int? nanos, int? seconds, TimeZone? timeZone, String? utcOffset, int? year})
DateTime.fromJson(Map json_)

Properties

day ↔ int?
Day of month.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hours ↔ int?
Hours of day in 24 hour format.
getter/setter pair
minutes ↔ int?
Minutes of hour of day.
getter/setter pair
month ↔ int?
Month of year.
getter/setter pair
nanos ↔ int?
Fractions of seconds in nanoseconds.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds ↔ int?
Seconds of minutes of the time.
getter/setter pair
timeZone ↔ TimeZone?
Time zone.
getter/setter pair
utcOffset ↔ String?
UTC offset.
getter/setter pair
year ↔ int?
Year of date.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited