DeprecationStatus class

Deprecation status for a public resource.

Constructors

DeprecationStatus({String? deleted, String? deprecated, String? obsolete, String? replacement, String? state})
DeprecationStatus.fromJson(Map json_)

Properties

deleted ↔ String?
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
getter/setter pair
deprecated ↔ String?
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
obsolete ↔ String?
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
getter/setter pair
replacement ↔ String?
The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The deprecation state of this resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited