DiskAsyncReplication class

Constructors

DiskAsyncReplication({String? consistencyGroupPolicy, String? consistencyGroupPolicyId, String? disk, String? diskId})
DiskAsyncReplication.fromJson(Map json_)

Properties

consistencyGroupPolicy ↔ String?
URL of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group.
getter/setter pair
consistencyGroupPolicyId ↔ String?
ID of the DiskConsistencyGroupPolicy if replication was started on the disk as a member of a group.
getter/setter pair
disk ↔ String?
The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
getter/setter pair
diskId ↔ String?
The unique ID of the other disk asynchronously replicated to or from the current disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited