DisksStopGroupAsyncReplicationResource class

A transient resource used in compute.disks.stopGroupAsyncReplication and compute.regionDisks.stopGroupAsyncReplication.

It is only used to process requests and is not persisted.

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourcePolicy ↔ String?
The URL of the DiskConsistencyGroupPolicy for the group of disks to stop. This may be a full or partial URL, such as:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited