ExchangedPeeringRoute class

Constructors

ExchangedPeeringRoute({String? destRange, bool? imported, String? nextHopRegion, int? priority, String? type})
ExchangedPeeringRoute.fromJson(Map json_)

Properties

destRange ↔ String?
The destination range of the route.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imported ↔ bool?
True if the peering route has been imported from a peer.
getter/setter pair
nextHopRegion ↔ String?
The region of peering route next hop, only applies to dynamic routes.
getter/setter pair
priority ↔ int?
The priority of the peering route.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the peering route. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited