ExternalVpnGatewayInterface class

The interface for the external VPN gateway.

Constructors

ExternalVpnGatewayInterface({int? id, String? ipAddress, String? ipv6Address})
ExternalVpnGatewayInterface.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The numeric ID of this interface. The allowed input values for this id for different redundancy types of external VPN gateway:
getter/setter pair
ipAddress ↔ String?
IP address of the interface in the external VPN gateway.
getter/setter pair
ipv6Address ↔ String?
IPv6 address of the interface in the external VPN gateway.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited