Firewall class

Represents a Firewall Rule resource.

Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, read Firewall rules.

Constructors

Firewall({List<FirewallAllowed>? allowed, String? creationTimestamp, List<FirewallDenied>? denied, String? description, List<String>? destinationRanges, String? direction, bool? disabled, String? id, String? kind, FirewallLogConfig? logConfig, String? name, String? network, FirewallParams? params, int? priority, String? selfLink, List<String>? sourceRanges, List<String>? sourceServiceAccounts, List<String>? sourceTags, List<String>? targetServiceAccounts, List<String>? targetTags})
Firewall.fromJson(Map json_)

Properties

allowed ↔ List<FirewallAllowed>?
The list of ALLOW rules specified by this firewall.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp in RFC3339 text format.
getter/setter pair
denied ↔ List<FirewallDenied>?
The list of DENY rules specified by this firewall.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
destinationRanges ↔ List<String>?
If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges.
getter/setter pair
direction ↔ String?
Direction of traffic to which this firewall applies, either INGRESS or EGRESS.
getter/setter pair
disabled ↔ bool?
Denotes whether the firewall rule is disabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
logConfig ↔ FirewallLogConfig?
This field denotes the logging options for a particular firewall rule.
getter/setter pair
name ↔ String?
Name of the resource; provided by the client when the resource is created.
getter/setter pair
network ↔ String?
URL of the network resource for this firewall rule.
getter/setter pair
params ↔ BackendBucketParams?
Input only.
getter/setter pair
priority ↔ int?
Priority for this rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
sourceRanges ↔ List<String>?
If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges.
getter/setter pair
sourceServiceAccounts ↔ List<String>?
If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list.
getter/setter pair
sourceTags ↔ List<String>?
If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network.
getter/setter pair
targetServiceAccounts ↔ List<String>?
A list of service accounts indicating sets of instances located in the network that may make network connections as specified in allowed[].
getter/setter pair
targetTags ↔ List<String>?
A list of tags that controls which instances the firewall rule applies to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited