FirewallLogConfig class

The available logging options for a firewall rule.

Constructors

FirewallLogConfig({bool? enable, String? metadata})
FirewallLogConfig.fromJson(Map json_)

Properties

enable ↔ bool?
This field denotes whether to enable logging for a particular firewall rule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ String?
This field can only be specified for a particular firewall rule if logging is enabled for that rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited