FirewallPolicy class

Represents a Firewall Policy resource.

Constructors

FirewallPolicy({List<FirewallPolicyAssociation>? associations, String? creationTimestamp, String? description, String? displayName, String? fingerprint, String? id, String? kind, String? name, List<FirewallPolicyRule>? packetMirroringRules, String? parent, String? policyType, String? region, int? ruleTupleCount, List<FirewallPolicyRule>? rules, String? selfLink, String? selfLinkWithId, String? shortName})
FirewallPolicy.fromJson(Map json_)

Properties

associations ↔ List<FirewallPolicyAssociation>?
A list of associations that belong to this firewall policy.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
displayName ↔ String?
Deprecated, please use short name instead.
getter/setter pair
fingerprint ↔ String?
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
packetMirroringRules ↔ List<FirewallPolicyRule>?
A list of packet mirroring rules that belong to this policy.
getter/setter pair
parent ↔ String?
The parent of the firewall policy. This field is not applicable to network firewall policies.
getter/setter pair
policyType ↔ String?
The type of the firewall policy.
getter/setter pair
region ↔ String?
URL of the region where the regional firewall policy resides. This field is not applicable to global firewall policies. You must specify this field as part of the HTTP request URL.
getter/setter pair
rules ↔ List<FirewallPolicyRule>?
A list of rules that belong to this policy. There must always be a default rule (rule with priority 2147483647 and match "*").
getter/setter pair
ruleTupleCount ↔ int?
Total count of all firewall policy rule tuples.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId ↔ String?
Server-defined URL for this resource with the resource id.
getter/setter pair
shortName ↔ String?
User-provided name of the Organization firewall policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited