FirewallPolicyAssociation class

Constructors

FirewallPolicyAssociation({String? attachmentTarget, String? displayName, String? firewallPolicyId, String? name, String? shortName})
FirewallPolicyAssociation.fromJson(Map json_)

Properties

attachmentTarget ↔ String?
The target that the firewall policy is attached to.
getter/setter pair
displayName ↔ String?
Deprecated, please use short name instead.
getter/setter pair
firewallPolicyId ↔ String?
The firewall policy ID of the association.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name for an association.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName ↔ String?
The short name of the firewall policy of the association.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited