securityProfileGroup property
A fully-qualified URL of a SecurityProfileGroup resource instance. Example: https://networksecurity.googleapis.com/v1/projects/{project}/locations/{location}/securityProfileGroups/my-security-profile-group Must be specified if action is one of 'apply_security_profile_group' or 'mirror'.
Cannot be specified for other actions. Can be specified only for global network firewall policies or hierarchical firewall policies.
Implementation
core.String? securityProfileGroup;