FirewallPolicyRuleMatcher class

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.

Constructors

FirewallPolicyRuleMatcher({List<String>? destAddressGroups, List<String>? destFqdns, List<String>? destIpRanges, String? destNetworkContext, String? destNetworkType, List<String>? destRegionCodes, List<String>? destThreatIntelligences, List<FirewallPolicyRuleMatcherLayer4Config>? layer4Configs, List<String>? srcAddressGroups, List<String>? srcFqdns, List<String>? srcIpRanges, String? srcNetworkContext, String? srcNetworkType, List<String>? srcNetworks, List<String>? srcRegionCodes, List<FirewallPolicyRuleSecureTag>? srcSecureTags, List<String>? srcThreatIntelligences})
FirewallPolicyRuleMatcher.fromJson(Map json_)

Properties

destAddressGroups ↔ List<String>?
Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10.
getter/setter pair
destFqdns ↔ List<String>?
Fully Qualified Domain Name (FQDN) which should be matched against traffic destination. Maximum number of destination fqdn allowed is 100.
getter/setter pair
destIpRanges ↔ List<String>?
CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.
getter/setter pair
destNetworkContext ↔ String?
Network context of the traffic destination.
getter/setter pair
destNetworkType ↔ String?
Network type of the traffic destination.
getter/setter pair
destRegionCodes ↔ List<String>?
Region codes whose IP addresses will be used to match for destination of traffic.
getter/setter pair
destThreatIntelligences ↔ List<String>?
Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic destination.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
layer4Configs ↔ List<FirewallPolicyRuleMatcherLayer4Config>?
Pairs of IP protocols and ports that the rule should match.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcAddressGroups ↔ List<String>?
Address groups which should be matched against the traffic source. Maximum number of source address groups is 10.
getter/setter pair
srcFqdns ↔ List<String>?
Fully Qualified Domain Name (FQDN) which should be matched against traffic source. Maximum number of source fqdn allowed is 100.
getter/setter pair
srcIpRanges ↔ List<String>?
CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.
getter/setter pair
srcNetworkContext ↔ String?
Network context of the traffic source.
getter/setter pair
srcNetworks ↔ List<String>?
Networks of the traffic source.
getter/setter pair
srcNetworkType ↔ String?
Network type of the traffic source.
getter/setter pair
srcRegionCodes ↔ List<String>?
Region codes whose IP addresses will be used to match for source of traffic.
getter/setter pair
srcSecureTags ↔ List<FirewallPolicyRuleSecureTag>?
List of secure tag values, which should be matched at the source of the traffic. For INGRESS rule, if all the srcSecureTag are INEFFECTIVE, and there is no srcIpRange, this rule will be ignored. Maximum number of source tag values allowed is 256.
getter/setter pair
srcThreatIntelligences ↔ List<String>?
Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited