ForwardingRule class

Represents a Forwarding Rule resource.

Forwarding rule resources in Google Cloud can be either regional or global in scope: * Global * Regional A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud load balancer. Forwarding rules can also reference target instances and Cloud VPN Classic gateways (targetVpnGateway). For more information, read Forwarding rule concepts and Using protocol forwarding.

Constructors

ForwardingRule({String? IPAddress, String? IPProtocol, bool? allPorts, bool? allowGlobalAccess, bool? allowPscGlobalAccess, String? backendService, String? baseForwardingRule, String? creationTimestamp, String? description, String? externalManagedBackendBucketMigrationState, double? externalManagedBackendBucketMigrationTestingPercentage, String? fingerprint, String? id, String? ipCollection, String? ipVersion, bool? isMirroringCollector, String? kind, String? labelFingerprint, Map<String, String>? labels, String? loadBalancingScheme, List<MetadataFilter>? metadataFilters, String? name, String? network, String? networkTier, bool? noAutomateDnsZone, String? portRange, List<String>? ports, String? pscConnectionId, String? pscConnectionStatus, String? region, String? selfLink, String? selfLinkWithId, List<ForwardingRuleServiceDirectoryRegistration>? serviceDirectoryRegistrations, String? serviceLabel, String? serviceName, List<String>? sourceIpRanges, String? subnetwork, String? target})
ForwardingRule.fromJson(Map json_)

Properties

allowGlobalAccess ↔ bool?
If set to true, clients can access the internal passthrough Network Load Balancers, the regional internal Application Load Balancer, and the regional internal proxy Network Load Balancer from all regions.
getter/setter pair
allowPscGlobalAccess ↔ bool?
This is used in PSC consumer ForwardingRule to control whether the PSC endpoint can be accessed from another region.
getter/setter pair
allPorts ↔ bool?
The ports, portRange, and allPorts fields are mutually exclusive.
getter/setter pair
backendService ↔ String?
Identifies the backend service to which the forwarding rule sends traffic.
getter/setter pair
baseForwardingRule ↔ String?
The URL for the corresponding base forwarding rule.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp in RFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
externalManagedBackendBucketMigrationState ↔ String?
Specifies the canary migration state for the backend buckets attached to this forwarding rule.
getter/setter pair
externalManagedBackendBucketMigrationTestingPercentage ↔ double?
Determines the fraction of requests to backend buckets that should be processed by the global external Application Load Balancer.
getter/setter pair
fingerprint ↔ String?
Fingerprint of this resource.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
IPAddress ↔ String?
IP address for which this forwarding rule accepts traffic.
getter/setter pair
ipCollection ↔ String?
Resource reference of a PublicDelegatedPrefix.
getter/setter pair
IPProtocol ↔ String?
The IP protocol to which this rule applies.
getter/setter pair
ipVersion ↔ String?
The IP Version that will be used by this forwarding rule.
getter/setter pair
isMirroringCollector ↔ bool?
Indicates whether or not this load balancer can be used as a collector for packet mirroring.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
labelFingerprint ↔ String?
A fingerprint for the labels being applied to this resource, which is essentially a hash of the labels set used for optimistic locking.
getter/setter pair
labelFingerprintAsBytes ↔ List<int>
getter/setter pair
labels ↔ Map<String, String>?
Labels for this resource.
getter/setter pair
loadBalancingScheme ↔ String?
Specifies the forwarding rule type.
getter/setter pair
metadataFilters ↔ List<MetadataFilter>?
Opaque filter criteria used by load balancer to restrict routing configuration to a limited set of xDS compliant clients.
getter/setter pair
name ↔ String?
Name of the resource; provided by the client when the resource is created.
getter/setter pair
network ↔ String?
This field is not used for global external load balancing.
getter/setter pair
networkTier ↔ String?
This signifies the networking tier used for configuring this load balancer and can only take the following values: PREMIUM, STANDARD.
getter/setter pair
noAutomateDnsZone ↔ bool?
This is used in PSC consumer ForwardingRule to control whether it should try to auto-generate a DNS zone or not.
getter/setter pair
portRange ↔ String?
The ports, portRange, and allPorts fields are mutually exclusive.
getter/setter pair
ports ↔ List<String>?
The ports, portRange, and allPorts fields are mutually exclusive.
getter/setter pair
pscConnectionId ↔ String?
The PSC connection id of the PSC forwarding rule.
getter/setter pair
pscConnectionStatus ↔ String?
Possible string values are:
getter/setter pair
region ↔ String?
URL of the region where the regional forwarding rule resides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId ↔ String?
Server-defined URL for this resource with the resource id.
getter/setter pair
serviceDirectoryRegistrations ↔ List<ForwardingRuleServiceDirectoryRegistration>?
Service Directory resources to register this forwarding rule with.
getter/setter pair
serviceLabel ↔ String?
An optional prefix to the service name for this forwarding rule.
getter/setter pair
serviceName ↔ String?
The internal fully qualified service name for this forwarding rule.
getter/setter pair
sourceIpRanges ↔ List<String>?
If not empty, this forwarding rule will only forward the traffic when the source IP address matches one of the IP addresses or CIDR ranges set here.
getter/setter pair
subnetwork ↔ String?
This field identifies the subnetwork that the load balanced IP should belong to for this forwarding rule, used with internal load balancers and external passthrough Network Load Balancers with IPv6.
getter/setter pair
target ↔ String?
The URL of the target resource to receive the matched traffic.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited