name property

String? name
getter/setter pair

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.

For Private Service Connect forwarding rules that forward traffic to Google APIs, the forwarding rule name must be a 1-20 characters string with lowercase letters and numbers and must start with a letter.

For global external Passthrough Network Load Balancer forwarding rules, the forwarding rule name must be 1-43 characters long.

For each global external Passthrough Network Load Balancer forwarding rule (a parent forwarding rule) that you create, Google Cloud generates two output-only child forwarding rules that are named by concatenating the parent forwarding rule name with the -ag0 and -ag1 suffixes, respectively. Refer to theavailabilityGroup field for further details.

Implementation

core.String? name;