resourceName property
Name of the resource intended to be delivered.
Name should conform to RFC1035. This will be the name of storage pool or Exapool for persistent disk FRs.
Implementation
core.String? resourceName;
Name of the resource intended to be delivered.
Name should conform to RFC1035. This will be the name of storage pool or Exapool for persistent disk FRs.
core.String? resourceName;