FutureReservationStatusExistingMatchingUsageInfo class

Represents the existing matching usage for the future reservation.

Output only.

Properties

count ↔ String?
Count to represent min(FR total_count, matching_reserved_capacity+matching_unreserved_instances)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ String?
Timestamp when the matching usage was calculated
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited