FutureReservationTimeWindow class

Constructors

FutureReservationTimeWindow({Duration? duration, String? endTime, String? startTime})
FutureReservationTimeWindow.fromJson(Map json_)

Properties

duration ↔ Duration?
getter/setter pair
endTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Start time of the Future Reservation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited