GRPCHealthCheck class

Constructors

GRPCHealthCheck({String? grpcServiceName, int? port, String? portName, String? portSpecification})
GRPCHealthCheck.fromJson(Map json_)

Properties

grpcServiceName ↔ String?
The gRPC service name for the health check.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
port ↔ int?
The TCP port number to which the health check prober sends packets.
getter/setter pair
portName ↔ String?
Not supported.
getter/setter pair
portSpecification ↔ String?
Specifies how a port is selected for health checking.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited