GetVersionOperationMetadataSbomInfo class

Constructors

GetVersionOperationMetadataSbomInfo({Map<String, String>? currentComponentVersions, Map<String, String>? targetComponentVersions})
GetVersionOperationMetadataSbomInfo.fromJson(Map json_)

Properties

currentComponentVersions ↔ Map<String, String>?
A mapping of components to their currently-applied versions or other appropriate identifiers.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetComponentVersions ↔ Map<String, String>?
A mapping of components to their target versions or other appropriate identifiers.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited