GlobalVmExtensionPoliciesResource class

Constructors

GlobalVmExtensionPoliciesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

aggregatedList(String project, {String? filter, bool? includeAllScopes, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? serviceProjectNumber, String? $fields}) Future<VmExtensionPolicyAggregatedListResponse>
Retrieves the list of all VM Extension Policy resources available to the specified project.
delete(GlobalVmExtensionPolicyRolloutOperationRolloutInput request, String project, String globalVmExtensionPolicy, {String? requestId, String? $fields}) Future<Operation>
Purge scoped resources (zonal policies) from a global VM extension policy, and then delete the global VM extension policy.
get(String project, String globalVmExtensionPolicy, {String? $fields}) Future<GlobalVmExtensionPolicy>
Gets details of a global VM extension policy.
insert(GlobalVmExtensionPolicy request, String project, {String? requestId, String? $fields}) Future<Operation>
Creates a new project level GlobalVmExtensionPolicy.
list(String project, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<GlobalVmExtensionPolicyList>
Lists global VM extension policies.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
update(GlobalVmExtensionPolicy request, String project, String globalVmExtensionPolicy, {String? requestId, String? $fields}) Future<Operation>
Updates a global VM extension policy.

Operators

operator ==(Object other) bool
The equality operator.
inherited