delete method

Future<Operation> delete(
  1. GlobalVmExtensionPolicyRolloutOperationRolloutInput request,
  2. String project,
  3. String globalVmExtensionPolicy, {
  4. String? requestId,
  5. String? $fields,
})

Purge scoped resources (zonal policies) from a global VM extension policy, and then delete the global VM extension policy.

Purge of the scoped resources is a pre-condition of the global VM extension policy deletion. The deletion of the global VM extension policy happens after the purge rollout is done, so it's not a part of the LRO. It's an automatic process that triggers in the backend.

request - The metadata request object.

Request parameters:

project - Project ID for this request. Value must have pattern (?:(?:\[-a-z0-9\]{1,63}\.)*(?:\[a-z\](?:\[-a-z0-9\]{0,61}\[a-z0-9\])?):)?(?:\[0-9\]{1,19}|(?:\[a-z0-9\](?:\[-a-z0-9\]{0,61}\[a-z0-9\])?)).

globalVmExtensionPolicy - Name of the global VM extension policy to purge scoped resources for.

requestId - An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.

The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).

$fields - Selector specifying which fields to include in a partial response.

Completes with a Operation.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Operation> delete(
  GlobalVmExtensionPolicyRolloutOperationRolloutInput request,
  core.String project,
  core.String globalVmExtensionPolicy, {
  core.String? requestId,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'requestId': ?requestId == null ? null : [requestId],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'projects/' +
      commons.escapeVariable('$project') +
      '/global/vmExtensionPolicies/' +
      commons.escapeVariable('$globalVmExtensionPolicy') +
      '/delete';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}