priority property

int? priority
getter/setter pair

Used to resolve conflicts when multiple policies are active for the same extension.

Defaults to 0.

Larger the number, higher the priority. When the priority is the same, the policy with the newer create time has higher priority.

Optional.

Implementation

core.int? priority;