pinnedVersion property
The version pinning for the extension. If empty, the extension will be installed with the latest version released by the extension producer.
Optional.
Implementation
core.String? pinnedVersion;
The version pinning for the extension. If empty, the extension will be installed with the latest version released by the extension producer.
Optional.
core.String? pinnedVersion;