inclusionLabels property
Labels as key value pairs. A VM should contain all the pairs specified in this map to be selected; Labels within the LabelSelector are OR'ed.
Optional.
Implementation
core.Map<core.String, core.String>? inclusionLabels;
Labels as key value pairs. A VM should contain all the pairs specified in this map to be selected; Labels within the LabelSelector are OR'ed.
Optional.
core.Map<core.String, core.String>? inclusionLabels;