GlobalVmExtensionPolicyRolloutOperationRolloutInput class
Properties
-
conflictBehavior
↔ String?
-
Specifies the behavior of the rollout if a conflict is detected in a
project during a rollout.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
name
↔ String?
-
The name of the rollout plan.
Ex.
projects//locations/global/rolloutPlans/.
getter/setter pair
-
predefinedRolloutPlan
↔ String?
-
Specifies the predefined rollout plan for the policy.
getter/setter pair
-
retryUuid
↔ String?
-
The UUID that identifies a policy rollout retry attempt for update and
delete operations.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited