GroupMaintenanceInfo class

Maintenance Info for ReservationBlocks.

Constructors

GroupMaintenanceInfo({int? instanceMaintenanceOngoingCount, int? instanceMaintenancePendingCount, int? maintenanceOngoingCount, int? maintenancePendingCount, String? schedulingType, int? subblockInfraMaintenanceOngoingCount, int? subblockInfraMaintenancePendingCount, UpcomingMaintenance? upcomingGroupMaintenance})
GroupMaintenanceInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceMaintenanceOngoingCount ↔ int?
Describes number of instances that have ongoing maintenance.
getter/setter pair
instanceMaintenancePendingCount ↔ int?
Describes number of instances that have pending maintenance.
getter/setter pair
maintenanceOngoingCount ↔ int?
Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have ongoing maintenance.
getter/setter pair
maintenancePendingCount ↔ int?
Progress for ongoing maintenance for this group of VMs/hosts. Describes number of hosts in the block that have pending maintenance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulingType ↔ String?
The type of maintenance for the reservation. Possible string values are:
getter/setter pair
subblockInfraMaintenanceOngoingCount ↔ int?
Describes number of subblock Infrastructure that has ongoing maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family(e.g. NVLink Domains).
getter/setter pair
subblockInfraMaintenancePendingCount ↔ int?
Describes number of subblock Infrastructure that has pending maintenance. Here, Subblock Infrastructure Maintenance pertains to upstream hardware contained in the Subblock that is necessary for a VM Family (e.g. NVLink Domains).
getter/setter pair
upcomingGroupMaintenance ↔ UpcomingMaintenance?
Maintenance information on this group of VMs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited