GuestAttributesValue class

Array of guest attribute namespace/key/value tuples.

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<GuestAttributesEntry>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited