minHealthyThreshold property

int? minHealthyThreshold
getter/setter pair

Can only be set if the policyType field isBACKEND_SERVICE_POLICY.

Specifies the minimum number of healthy endpoints required in order to consider the aggregated health result HEALTHY. Defaults to 1. Must be positive. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated. This field is optional, and will be set to the default if unspecified. Note that both this threshold and healthyPercentThreshold must be satisfied in order for HEALTHY to be the aggregated result. "Endpoints" refers to network endpoints within a Network Endpoint Group or instances within an Instance Group.

Implementation

core.int? minHealthyThreshold;