policyType property

String? policyType
getter/setter pair

Specifies the type of the healthAggregationPolicy.

The only allowed value for global resources is DNS_PUBLIC_IP_POLICY. The only allowed value for regional resources is BACKEND_SERVICE_POLICY. Must be specified when the healthAggregationPolicy is created, and cannot be mutated. Possible string values are:

  • "BACKEND_SERVICE_POLICY"
  • "DNS_PUBLIC_IP_POLICY"

Implementation

core.String? policyType;