HealthCheckService class

Represents a Health-Check as a Service resource.

Constructors

HealthCheckService({String? creationTimestamp, String? description, String? fingerprint, List<String>? healthChecks, String? healthStatusAggregationPolicy, String? id, String? kind, String? name, List<String>? networkEndpointGroups, List<String>? notificationEndpoints, String? region, String? selfLink})
HealthCheckService.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
fingerprint ↔ String?
Fingerprint of this resource.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthChecks ↔ List<String>?
A list of URLs to the HealthCheck resources.
getter/setter pair
healthStatusAggregationPolicy ↔ String?
Policy for how the results from multiple health checks for the same endpoint are aggregated.
getter/setter pair
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
networkEndpointGroups ↔ List<String>?
A list of URLs to the NetworkEndpointGroup resources.
getter/setter pair
notificationEndpoints ↔ List<String>?
A list of URLs to the NotificationEndpoint resources.
getter/setter pair
region ↔ String?
URL of the region where the health check service resides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited