warning property
Informational warning which replaces the list of backend services when the list is empty.
Implementation
HealthCheckServicesScopedListWarning? warning;
Informational warning which replaces the list of backend services when the list is empty.
HealthCheckServicesScopedListWarning? warning;