HealthSource class

Represents a health source.

A health source resource specifies the source resources and the health aggregation policy applied to the source resources to determine the aggregated health status.

Constructors

HealthSource({String? creationTimestamp, String? description, String? fingerprint, String? healthAggregationPolicy, String? id, String? kind, String? name, String? region, String? selfLink, String? selfLinkWithId, String? sourceType, List<String>? sources})
HealthSource.fromJson(Map json_)

Properties

creationTimestamp String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description String?
An optional description of this resource.
getter/setter pair
fingerprint String?
Fingerprint of this resource.
getter/setter pair
fingerprintAsBytes List<int>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
healthAggregationPolicy String?
URL to the HealthAggregationPolicy resource.
getter/setter pair
id String?
A unique identifier for this resource type.
getter/setter pair
kind String?
Type of the resource.
getter/setter pair
name String?
Name of the resource.
getter/setter pair
region String?
URL of the region where the health source resides. This field applies only to the regional resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId String?
Server-defined URL with id for the resource.
getter/setter pair
sources List<String>?
URLs to the source resources.
getter/setter pair
sourceType String?
Specifies the type of the HealthSource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited