healthAggregationPolicy property
URL to the HealthAggregationPolicy resource.
Must be set. Must be regional and in the same region as the HealthSource. Can be mutated.
Implementation
core.String? healthAggregationPolicy;
URL to the HealthAggregationPolicy resource.
Must be set. Must be regional and in the same region as the HealthSource. Can be mutated.
core.String? healthAggregationPolicy;