HealthSourcesGetHealthResponseSourceInfo class

Properties

backends List<HealthSourcesGetHealthResponseSourceInfoBackendInfo>?
Represents an instance group or network endpoint group behind the source backend service.
getter/setter pair
forwardingRule String?
Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
Fully qualified URL of the associated source resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited