HealthSourcesGetHealthResponseSourceInfoBackendInfo class

Properties

endpointCount ↔ int?
Total number of endpoints when determining the health of the regionHealthSource.
getter/setter pair
group ↔ String?
Fully qualified URL of an instance group or network endpoint group behind the source backend service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthyEndpointCount ↔ int?
Number of endpoints considered healthy when determining health of the regionHealthSource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited