endpointCount property
Total number of endpoints when determining the health of the regionHealthSource.
Implementation
core.int? endpointCount;
Total number of endpoints when determining the health of the regionHealthSource.
core.int? endpointCount;