group property
Fully qualified URL of an instance group or network endpoint group behind the source backend service.
Implementation
core.String? group;
Fully qualified URL of an instance group or network endpoint group behind the source backend service.
core.String? group;