warning property
Informational warning which replaces the list of health sources when the list is empty.
Implementation
HealthSourcesScopedListWarning? warning;
Informational warning which replaces the list of health sources when the list is empty.
HealthSourcesScopedListWarning? warning;