HealthStatus class

Constructors

HealthStatus({Map<String, String>? annotations, String? forwardingRule, String? forwardingRuleIp, String? healthState, String? instance, String? ipAddress, String? ipv6Address, String? ipv6HealthState, int? port, String? weight, String? weightError})
HealthStatus.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Metadata defined as annotations for network endpoint.
getter/setter pair
forwardingRule ↔ String?
URL of the forwarding rule associated with the health status of the instance.
getter/setter pair
forwardingRuleIp ↔ String?
A forwarding rule IP address assigned to this instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthState ↔ String?
Health state of the IPv4 address of the instance. Possible string values are:
getter/setter pair
instance ↔ String?
URL of the instance resource.
getter/setter pair
ipAddress ↔ String?
For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance.
getter/setter pair
ipv6Address ↔ String?
getter/setter pair
ipv6HealthState ↔ String?
Health state of the IPv6 address of the instance. Possible string values are:
getter/setter pair
port ↔ int?
The named port of the instance group, not necessarily the port that is health-checked.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight ↔ String?
getter/setter pair
weightError ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited