HealthStatusForNetworkEndpoint class

Constructors

HealthStatusForNetworkEndpoint({BackendServiceReference? backendService, ForwardingRuleReference? forwardingRule, HealthCheckReference? healthCheck, HealthCheckServiceReference? healthCheckService, String? healthState, String? ipv6HealthState})
HealthStatusForNetworkEndpoint.fromJson(Map json_)

Properties

backendService ↔ BackendServiceReference?
URL of the backend service associated with the health state of the network endpoint.
getter/setter pair
forwardingRule ↔ ForwardingRuleReference?
URL of the forwarding rule associated with the health state of the network endpoint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthCheck ↔ HealthCheckReference?
URL of the health check associated with the health state of the network endpoint.
getter/setter pair
healthCheckService ↔ HealthCheckServiceReference?
URL of the health check service associated with the health state of the network endpoint.
getter/setter pair
healthState ↔ String?
Health state of the network endpoint determined based on the health checks configured. Possible string values are:
getter/setter pair
ipv6HealthState ↔ String?
Health state of the ipv6 network endpoint determined based on the health checks configured. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited