Host class

Represents a host resource.

Constructors

Host({List<String>? aliasLinks, String? creationTimestamp, String? description, String? id, String? kind, String? name, String? selfLink, String? selfLinkWithId, String? state, HostStatus? status, String? zone})
Host.fromJson(Map json_)

Properties

All aliases for this resource. e.g. projects/123/zones/us-centra1-a/reservation/r1/reservationBlock/b1/hosts/h1
getter/setter pair
creationTimestamp String?
The creation timestamp, formatted asRFC3339 text.
getter/setter pair
description String?
An optional description of this resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier for this resource.
getter/setter pair
kind String?
The type of resource.
getter/setter pair
name String?
The name of the host.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
The self link of the host.
getter/setter pair
selfLinkWithId String?
The self link with id of the host.
getter/setter pair
state String?
The state of the host.
getter/setter pair
status HostStatus?
The status of the host
getter/setter pair
zone String?
The zone in which the host resides.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited