HostsListResponse class

Constructors

HostsListResponse({String? etag, String? id, List<Host>? items, String? kind, String? nextPageToken, String? selfLink, List<String>? unreachables, HostsListResponseWarning? warning})
HostsListResponse.fromJson(Map json_)

Properties

etag ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource; defined by the server.
getter/setter pair
items ↔ List<Host>?
A list of host resources.
getter/setter pair
kind ↔ String?
The type of resource.
getter/setter pair
nextPageToken ↔ String?
This token allows you to get the next page of results for list requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The server-defined URL for this resource.
getter/setter pair
unreachables ↔ List<String>?
Unreachable resources. end_interface: MixerListResponseWithEtagBuilder
getter/setter pair
warning ↔ HostsListResponseWarning?
An informational warning message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited