HostsResource class

Constructors

HostsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String project, String zone, String association, String host, {String? $fields}) Future<Host>
Retrieves information about the specified host.
getVersion(HostsGetVersionRequest request, String project, String zone, String association, String host, {String? requestId, String? $fields}) Future<Operation>
Allows customers to get SBOM versions of a host.
list(String project, String zone, String association, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<HostsListResponse>
Retrieves a list of hosts.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited