getVersion method

Future<Operation> getVersion(
  1. HostsGetVersionRequest request,
  2. String project,
  3. String zone,
  4. String association,
  5. String host, {
  6. String? requestId,
  7. String? $fields,
})

Allows customers to get SBOM versions of a host.

request - The metadata request object.

Request parameters:

project - Project ID for this request.

zone - Name of the zone for this request. Zone name should conform to RFC1035.

association - The parent resource association for the Host. This field specifies the hierarchical context (e.g., reservation, block, sub-block) when accessing the host.

host - The name of the host, formatted as RFC1035 or a resource ID number.

requestId - An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Operation.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Operation> getVersion(
  HostsGetVersionRequest request,
  core.String project,
  core.String zone,
  core.String association,
  core.String host, {
  core.String? requestId,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'requestId': ?requestId == null ? null : [requestId],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'projects/' +
      commons.escapeVariable('$project') +
      '/zones/' +
      commons.escapeVariable('$zone') +
      '/' +
      commons.escapeVariable('$association') +
      '/hosts/' +
      commons.escapeVariable('$host') +
      '/getVersion';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}