HttpFaultInjection class

The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure.

As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.

Properties

abort ↔ HttpFaultAbort?
The specification for how client requests are aborted as part of fault injection.
getter/setter pair
delay ↔ HttpFaultDelay?
The specification for how client requests are delayed as part of fault injection, before being sent to a backend service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited