HttpHeaderAction class

The request and response header transformations that take effect before the request is passed along to the selected backendService.

Constructors

HttpHeaderAction({List<HttpHeaderOption>? requestHeadersToAdd, List<String>? requestHeadersToRemove, List<HttpHeaderOption>? responseHeadersToAdd, List<String>? responseHeadersToRemove})
HttpHeaderAction.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestHeadersToAdd ↔ List<HttpHeaderOption>?
Headers to add to a matching request before forwarding the request to thebackendService.
getter/setter pair
requestHeadersToRemove ↔ List<String>?
A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.
getter/setter pair
responseHeadersToAdd ↔ List<HttpHeaderOption>?
Headers to add the response before sending the response back to the client.
getter/setter pair
responseHeadersToRemove ↔ List<String>?
A list of header names for headers that need to be removed from the response before sending the response back to the client.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited