HttpHeaderOption class

Specification determining how headers are added to requests or responses.

Constructors

HttpHeaderOption({String? headerName, String? headerValue, bool? replace})
HttpHeaderOption.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
headerName ↔ String?
The name of the header.
getter/setter pair
headerValue ↔ String?
The value of the header to add.
getter/setter pair
replace ↔ bool?
If false, headerValue is appended to any values that already exist for the header.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited