HttpRouteRule class

The HttpRouteRule setting specifies how to match an HTTP request and the corresponding routing action that load balancing proxies perform.

Constructors

HttpRouteRule({CustomErrorResponsePolicy? customErrorResponsePolicy, String? description, HttpHeaderAction? headerAction, List<HttpRouteRuleMatch>? matchRules, int? priority, HttpRouteAction? routeAction, String? service, HttpRedirectAction? urlRedirect})
HttpRouteRule.fromJson(Map json_)

Properties

customErrorResponsePolicy ↔ CustomErrorResponsePolicy?
customErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceorBackendBucket responds with an error.
getter/setter pair
description ↔ String?
The short description conveying the intent of this routeRule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headerAction ↔ HttpHeaderAction?
Specifies changes to request and response headers that need to take effect for the selected backendService.
getter/setter pair
matchRules ↔ List<HttpRouteRuleMatch>?
The list of criteria for matching attributes of a request to thisrouteRule.
getter/setter pair
priority ↔ int?
For routeRules within a given pathMatcher, priority determines the order in which a load balancer interpretsrouteRules.
getter/setter pair
routeAction ↔ HttpRouteAction?
In response to a matching matchRule, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
The full or partial URL of the backend service resource to which traffic is directed if this rule is matched.
getter/setter pair
urlRedirect ↔ HttpRedirectAction?
When this rule is matched, the request is redirected to a URL specified by urlRedirect.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited