ImageFamilyView class

Constructors

ImageFamilyView({Image? image})
ImageFamilyView.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
image ↔ Image?
The latest image that is part of the specified image family in the requested location, and that is not deprecated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited