ImageRawDisk class

The parameters of the raw disk image.

Constructors

ImageRawDisk({String? containerType, String? sha1Checksum, String? source})
ImageRawDisk.fromJson(Map json_)

Properties

containerType ↔ String?
The format used to encode and transmit the block device, which should beTAR.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1Checksum ↔ String?
This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created.
getter/setter pair
source ↔ String?
The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited