InitialStateConfig class

Initial State for shielded instance, these are public keys which are safe to store in public

Properties

dbs ↔ List<FileContentBuffer>?
The Key Database (db).
getter/setter pair
dbxs ↔ List<FileContentBuffer>?
The forbidden key database (dbx).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keks ↔ List<FileContentBuffer>?
The Key Exchange Key (KEK).
getter/setter pair
pk ↔ FileContentBuffer?
The Platform Key (PK).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited