minCpuPlatform property
Name of the minimum CPU platform to be used by this instance selection. e.g. 'Intel Ice Lake'.
Implementation
core.String? minCpuPlatform;
Name of the minimum CPU platform to be used by this instance selection. e.g. 'Intel Ice Lake'.
core.String? minCpuPlatform;