InstanceGroupManagerActionsSummary class

Constructors

InstanceGroupManagerActionsSummary({int? abandoning, int? creating, int? creatingWithoutRetries, int? deleting, int? none, int? recreating, int? refreshing, int? restarting, int? resuming, int? starting, int? stopping, int? suspending, int? verifying})
InstanceGroupManagerActionsSummary.fromJson(Map json_)

Properties

abandoning ↔ int?
The total number of instances in the managed instance group that are scheduled to be abandoned.
getter/setter pair
creating ↔ int?
The number of instances in the managed instance group that are scheduled to be created or are currently being created.
getter/setter pair
creatingWithoutRetries ↔ int?
The number of instances that the managed instance group will attempt to create.
getter/setter pair
deleting ↔ int?
The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
none ↔ int?
The number of instances in the managed instance group that are running and have no scheduled actions.
getter/setter pair
recreating ↔ int?
The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated.
getter/setter pair
refreshing ↔ int?
The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action.
getter/setter pair
restarting ↔ int?
The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted.
getter/setter pair
resuming ↔ int?
The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
starting ↔ int?
The number of instances in the managed instance group that are scheduled to be started or are currently being started.
getter/setter pair
stopping ↔ int?
The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped.
getter/setter pair
suspending ↔ int?
The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended.
getter/setter pair
verifying ↔ int?
The number of instances in the managed instance group that are being verified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited