InstanceGroupManagerAutoHealingPolicy class

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthCheck ↔ String?
The URL for the health check that signals autohealing.
getter/setter pair
initialDelaySec ↔ int?
The initial delay is the number of seconds that a new VM takes to initialize and run its startup script.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited