defaultActionOnFailure property

String? defaultActionOnFailure
getter/setter pair

The action that a MIG performs on a failed VM.

If the value of the onFailedHealthCheck field is DEFAULT_ACTION, then the same action also applies to the VMs on which your application fails a health check. Valid values are

  • REPAIR (default): MIG automatically repairs a failed VM by recreating it. For more information, see About repairing VMs in a MIG.
  • DO_NOTHING: MIG does not repair a failed VM. Possible string values are:
  • "DO_NOTHING" : MIG does not repair a failed VM.
  • "REPAIR" : (default): MIG automatically repairs a failed VM by recreating it. For more information, see About repairing VMs in a MIG.

Implementation

core.String? defaultActionOnFailure;