InstanceGroupManagerResizeRequest class

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time.

This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Constructors

InstanceGroupManagerResizeRequest({String? creationTimestamp, String? description, String? id, List<PerInstanceConfig>? instances, String? kind, String? name, String? region, Duration? requestedRunDuration, int? resizeBy, String? selfLink, String? selfLinkWithId, String? state, InstanceGroupManagerResizeRequestStatus? status, String? zone})
InstanceGroupManagerResizeRequest.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
The creation timestamp for this resize request inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
A unique identifier for this resource type.
getter/setter pair
instances ↔ List<PerInstanceConfig>?
The names of instances to be created by this resize request.
getter/setter pair
kind ↔ String?
The resource type, which is alwayscompute#instanceGroupManagerResizeRequest for resize requests.
getter/setter pair
name ↔ String?
The name of this resize request.
getter/setter pair
region ↔ String?
The URL of a region where the resize request is located.
getter/setter pair
requestedRunDuration ↔ Duration?
Requested run duration for instances that will be created by this request. At the end of the run duration instance will be deleted.
getter/setter pair
resizeBy ↔ int?
The number of instances to be created by this resize request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The URL for this resize request.
getter/setter pair
selfLinkWithId ↔ String?
Server-defined URL for this resource with the resource id.
getter/setter pair
state ↔ String?
Current state of the request.
getter/setter pair
status ↔ InstanceGroupManagerResizeRequestStatus?
Status of the request.
getter/setter pair
zone ↔ String?
The URL of a zone where the resize request is located.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited