instances property

List<PerInstanceConfig>? instances
getter/setter pair

The names of instances to be created by this resize request.

The number of names specified determines the number of instances to create. The group's target size will be increased by this number. This field cannot be used together with 'resize_by'.

Implementation

core.List<PerInstanceConfig>? instances;