region property
The URL of a region where the resize request is located.
Populated only for regional resize requests.
Output only.
Implementation
core.String? region;
The URL of a region where the resize request is located.
Populated only for regional resize requests.
Output only.
core.String? region;