InstanceGroupManagerResizeRequestStatusErrorErrorsErrorDetails class
Container for structured error details providing additional context specific to the encountered error code.
Constructors
- InstanceGroupManagerResizeRequestStatusErrorErrorsErrorDetails({ErrorInfo? errorInfo, Help? help, LocalizedMessage? localizedMessage, QuotaExceededInfo? quotaInfo})
- InstanceGroupManagerResizeRequestStatusErrorErrorsErrorDetails.fromJson(Map json_)
Properties
- errorInfo ↔ ErrorInfo?
-
Error information containing structured domain, reason, and metadata.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- help ↔ Help?
-
Links and information to help the user resolve the error.
getter/setter pair
- localizedMessage ↔ LocalizedMessage?
-
A localized human-readable error message intended for end users.
getter/setter pair
- quotaInfo ↔ QuotaExceededInfo?
-
Details about quota limits and metrics when a quota is exceeded.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited