InstanceGroupManagerStandbyPolicy class

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialDelaySec ↔ int?
Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created.
getter/setter pair
mode ↔ String?
Defines how a MIG resumes or starts VMs from a standby pool when the group scales out.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited