InstanceGroupManagerStatus class

Properties

allInstancesConfig ↔ InstanceGroupManagerStatusAllInstancesConfig?
Status of all-instances configuration on the group.
getter/setter pair
appliedAcceleratorTopologies ↔ List<InstanceGroupManagerStatusAcceleratorTopology>?
The accelerator topology applied to this MIG. Currently only one accelerator topology is supported.
getter/setter pair
autoscaler ↔ String?
The URL of theAutoscaler that targets this instance group manager.
getter/setter pair
bulkInstanceOperation ↔ InstanceGroupManagerStatusBulkInstanceOperation?
The status of bulk instance operation.
getter/setter pair
currentInstanceStatuses ↔ InstanceGroupManagerStatusInstanceStatusSummary?
The list of instance statuses and the number of instances in this managed instance group that have the status.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isStable ↔ bool?
A bit indicating whether the managed instance group is in a stable state.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateful ↔ InstanceGroupManagerStatusStateful?
Stateful status of the given Instance Group Manager.
getter/setter pair
versionTarget ↔ InstanceGroupManagerStatusVersionTarget?
A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited