InstanceGroupManagerStatusAcceleratorTopology class

Properties

acceleratorTopology String?
Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The state of the accelerator topology.
getter/setter pair
stateDetails InstanceGroupManagerStatusAcceleratorTopologyAcceleratorTopologyStateDetails?
The result of the latest accelerator topology state check.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited