acceleratorTopology property
Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.
Output only.
Implementation
core.String? acceleratorTopology;
Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy.
Output only.
core.String? acceleratorTopology;