state property

String? state
getter/setter pair

The state of the accelerator topology.

Output only. Possible string values are:

  • "ACTIVATING" : The accelerator topology is being activated.
  • "ACTIVE" : The accelerator topology is active.
  • "DEACTIVATING" : The accelerator topology is being deactivated.
  • "FAILED" : The accelerator topology failed.
  • "INCOMPLETE" : The configuration is incomplete and the accelerator topology cannot be activated due to insufficient number of running VMs.
  • "REACTIVATING" : The accelerator topology is being reactivated.

Implementation

core.String? state;