InstanceGroupManagerStatusAllInstancesConfig class

Properties

currentRevision ↔ String?
Current all-instances configuration revision. This value is in RFC3339 text format.
getter/setter pair
effective ↔ bool?
A bit indicating whether this configuration has been applied to all managed instances in the group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited