InstanceGroupManagerStatusBulkInstanceOperation class

Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK.

Properties

hashCode → int
The hash code for this object.
no setterinherited
inProgress ↔ bool?
Informs whether bulk instance operation is in progress.
getter/setter pair
lastProgressCheck ↔ InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck?
Information from the last progress check of bulk instance operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited