timestamp property
Timestamp of the last progress check of bulk instance operation.
Timestamp is in RFC3339 text format.
Output only.
Implementation
core.String? timestamp;
Timestamp of the last progress check of bulk instance operation.
Timestamp is in RFC3339 text format.
Output only.
core.String? timestamp;