deprovisioning property
The number of instances in the managed instance group that have DEPROVISIONING status.
Output only.
Implementation
core.int? deprovisioning;
The number of instances in the managed instance group that have DEPROVISIONING status.
Output only.
core.int? deprovisioning;