nonExistent property

int? nonExistent
getter/setter pair

The number of instances that have not been created yet or have been deleted.

Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'.

Output only.

Implementation

core.int? nonExistent;