pending property
The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources.
Instances that do not exist because of the other reasons are counted as 'non_existent'.
Output only.
Implementation
core.int? pending;