pendingStop property
The number of instances in the managed instance group that have PENDING_STOP status.
Output only.
Implementation
core.int? pendingStop;
The number of instances in the managed instance group that have PENDING_STOP status.
Output only.
core.int? pendingStop;