provisioning property
The number of instances in the managed instance group that have PROVISIONING status.
Output only.
Implementation
core.int? provisioning;
The number of instances in the managed instance group that have PROVISIONING status.
Output only.
core.int? provisioning;