repairing property
The number of instances in the managed instance group that have REPAIRING status.
Output only.
Implementation
core.int? repairing;
The number of instances in the managed instance group that have REPAIRING status.
Output only.
core.int? repairing;