staging property
The number of instances in the managed instance group that have STAGING status.
Output only.
Implementation
core.int? staging;
The number of instances in the managed instance group that have STAGING status.
Output only.
core.int? staging;