stopped property
The number of instances in the managed instance group that have STOPPED status.
Output only.
Implementation
core.int? stopped;
The number of instances in the managed instance group that have STOPPED status.
Output only.
core.int? stopped;