stopping property
The number of instances in the managed instance group that have STOPPING status.
Output only.
Implementation
core.int? stopping;
The number of instances in the managed instance group that have STOPPING status.
Output only.
core.int? stopping;