suspended property
The number of instances in the managed instance group that have SUSPENDED status.
Output only.
Implementation
core.int? suspended;
The number of instances in the managed instance group that have SUSPENDED status.
Output only.
core.int? suspended;