suspending property
The number of instances in the managed instance group that have SUSPENDING status.
Output only.
Implementation
core.int? suspending;
The number of instances in the managed instance group that have SUSPENDING status.
Output only.
core.int? suspending;