terminated property
The number of instances in the managed instance group that have TERMINATED status.
Output only.
Implementation
core.int? terminated;
The number of instances in the managed instance group that have TERMINATED status.
Output only.
core.int? terminated;