InstanceGroupManagerStatusVersionTarget class

Properties

hashCode → int
The hash code for this object.
no setterinherited
isReached ↔ bool?
A bit indicating whether version target has been reached in this managed instance group, i.e. all instances are in their target version.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited