InstanceGroupManagerUpdatePolicy class

Constructors

InstanceGroupManagerUpdatePolicy({String? instanceRedistributionType, FixedOrPercent? maxSurge, FixedOrPercent? maxUnavailable, String? minimalAction, String? mostDisruptiveAllowedAction, String? replacementMethod, String? type})
InstanceGroupManagerUpdatePolicy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceRedistributionType ↔ String?
The instance redistribution policy for regional managed instance groups. Valid values are:
getter/setter pair
maxSurge ↔ FixedOrPercent?
The maximum number of instances that can be created above the specifiedtargetSize during the update process.
getter/setter pair
maxUnavailable ↔ FixedOrPercent?
The maximum number of instances that can be unavailable during the update process.
getter/setter pair
minimalAction ↔ String?
Minimal action to be taken on an instance.
getter/setter pair
mostDisruptiveAllowedAction ↔ String?
Most disruptive action that is allowed to be taken on an instance. You can specify either NONE to forbid any actions,REFRESH to avoid restarting the VM and to limit disruption as much as possible.
getter/setter pair
replacementMethod ↔ String?
What action should be used to replace instances. See minimal_action.REPLACE Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of update process.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited