InstanceGroupManagerVersion class

Constructors

InstanceGroupManagerVersion({String? instanceTemplate, String? name, FixedOrPercent? targetSize})
InstanceGroupManagerVersion.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceTemplate ↔ String?
The URL of the instance template that is specified for this managed instance group.
getter/setter pair
name ↔ String?
Name of the version.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetSize ↔ FixedOrPercent?
Specifies the intended number of instances to be created from theinstanceTemplate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited