InstanceManagedByIgmError class

Properties

error ↔ InstanceManagedByIgmErrorManagedInstanceError?
Contents of the error.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceActionDetails ↔ InstanceManagedByIgmErrorInstanceActionDetails?
Details of the instance action that triggered this error. May be null, if the error was not caused by an action on an instance. This field is optional.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ String?
The time that this error occurred.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited