InstanceMoveRequest class

Constructors

InstanceMoveRequest({String? destinationZone, String? targetInstance})
InstanceMoveRequest.fromJson(Map json_)

Properties

destinationZone ↔ String?
The URL of the destination zone to move the instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetInstance ↔ String?
The URL of the target instance to move.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited