InstanceProperties class

Constructors

InstanceProperties({AdvancedMachineFeatures? advancedMachineFeatures, bool? canIpForward, ConfidentialInstanceConfig? confidentialInstanceConfig, String? description, List<AttachedDisk>? disks, List<AcceleratorConfig>? guestAccelerators, String? keyRevocationActionType, Map<String, String>? labels, String? localSsdEncryptionMode, String? machineType, Metadata? metadata, String? minCpuPlatform, List<NetworkInterface>? networkInterfaces, NetworkPerformanceConfig? networkPerformanceConfig, String? privateIpv6GoogleAccess, ReservationAffinity? reservationAffinity, Map<String, String>? resourceManagerTags, List<String>? resourcePolicies, Scheduling? scheduling, List<ServiceAccount>? serviceAccounts, ShieldedInstanceConfig? shieldedInstanceConfig, Tags? tags, WorkloadIdentityConfig? workloadIdentityConfig})
InstanceProperties.fromJson(Map json_)

Properties

advancedMachineFeatures ↔ AdvancedMachineFeatures?
Controls for advanced machine-related behavior features. Note that for MachineImage, this is not supported yet.
getter/setter pair
canIpForward ↔ bool?
Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
getter/setter pair
confidentialInstanceConfig ↔ ConfidentialInstanceConfig?
Specifies the Confidential Instance options. Note that for MachineImage, this is not supported yet.
getter/setter pair
description ↔ String?
An optional text description for the instances that are created from these properties.
getter/setter pair
disks ↔ List<AttachedDisk>?
An array of disks that are associated with the instances that are created from these properties.
getter/setter pair
guestAccelerators ↔ List<AcceleratorConfig>?
A list of guest accelerator cards' type and count to use for instances created from these properties.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyRevocationActionType ↔ String?
KeyRevocationActionType of the instance.
getter/setter pair
labels ↔ Map<String, String>?
Labels to apply to instances that are created from these properties.
getter/setter pair
localSsdEncryptionMode ↔ String?
Specifies which method should be used for encrypting the Local SSDs attached to the VM. Possible string values are:
getter/setter pair
machineType ↔ String?
The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR.
getter/setter pair
metadata ↔ Metadata?
The metadata key/value pairs to assign to instances that are created from these properties.
getter/setter pair
minCpuPlatform ↔ String?
Minimum cpu/platform to be used by instances.
getter/setter pair
networkInterfaces ↔ List<NetworkInterface>?
An array of network access configurations for this interface.
getter/setter pair
networkPerformanceConfig ↔ NetworkPerformanceConfig?
Note that for MachineImage, this is not supported yet.
getter/setter pair
privateIpv6GoogleAccess ↔ String?
The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Possible string values are:
getter/setter pair
reservationAffinity ↔ ReservationAffinity?
Specifies the reservations that instances can consume from. Note that for MachineImage, this is not supported yet.
getter/setter pair
resourceManagerTags ↔ Map<String, String>?
Input only.
getter/setter pair
resourcePolicies ↔ List<String>?
Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduling ↔ Scheduling?
Specifies the scheduling options for the instances that are created from these properties.
getter/setter pair
serviceAccounts ↔ List<ServiceAccount>?
A list of service accounts with specified scopes.
getter/setter pair
shieldedInstanceConfig ↔ ShieldedInstanceConfig?
Note that for MachineImage, this is not supported yet.
getter/setter pair
tags ↔ Tags?
A list of tags to apply to the instances that are created from these properties.
getter/setter pair
workloadIdentityConfig ↔ WorkloadIdentityConfig?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited