InstanceSettingsMetadata class

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ Map<String, String>?
A metadata key/value items map. The total size of all keys and values must be less than 512KB.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited