InstanceWithNamedPorts class

Constructors

InstanceWithNamedPorts({String? instance, List<NamedPort>? namedPorts, String? status})
InstanceWithNamedPorts.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instance ↔ String?
The URL of the instance.
getter/setter pair
namedPorts ↔ List<NamedPort>?
The named ports that belong to this instance group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status of the instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited