InstancesBulkInsertOperationMetadata class

Properties

hashCode → int
The hash code for this object.
no setterinherited
perLocationStatus ↔ Map<String, BulkInsertOperationStatus>?
Status information per location (location name is key). Example key: zones/us-central1-a
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited