InstantSnapshot class

Represents a InstantSnapshot resource.

You can use instant snapshots to create disk rollback points quickly..

Constructors

InstantSnapshot({String? architecture, String? creationTimestamp, String? description, String? diskSizeGb, String? id, String? kind, String? labelFingerprint, Map<String, String>? labels, String? name, InstantSnapshotParams? params, String? region, InstantSnapshotResourceStatus? resourceStatus, bool? satisfiesPzi, bool? satisfiesPzs, String? selfLink, String? selfLinkWithId, String? sourceDisk, String? sourceDiskId, String? sourceInstantSnapshotGroup, String? sourceInstantSnapshotGroupId, String? status, String? zone})
InstantSnapshot.fromJson(Map json_)

Properties

architecture ↔ String?
The architecture of the instant snapshot.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
diskSizeGb ↔ String?
Size of the source disk, specified in GB.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
labelFingerprint ↔ String?
A fingerprint for the labels being applied to this InstantSnapshot, which is essentially a hash of the labels set used for optimistic locking.
getter/setter pair
labelFingerprintAsBytes ↔ List<int>
getter/setter pair
labels ↔ Map<String, String>?
Labels to apply to this InstantSnapshot.
getter/setter pair
name ↔ String?
Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
getter/setter pair
params ↔ InstantSnapshotParams?
Input only.
getter/setter pair
region ↔ String?
URL of the region where the instant snapshot resides. You must specify this field as part of the HTTP request URL.
getter/setter pair
resourceStatus ↔ InstantSnapshotResourceStatus?
Status information for the instant snapshot resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId ↔ String?
Server-defined URL for this resource's resource id.
getter/setter pair
sourceDisk ↔ String?
URL of the source disk used to create this instant snapshot. Note that the source disk must be in the same zone/region as the instant snapshot to be created.
getter/setter pair
sourceDiskId ↔ String?
The ID value of the disk used to create this InstantSnapshot. This value may be used to determine whether the InstantSnapshot was taken from the current or a previous instance of a given disk name.
getter/setter pair
sourceInstantSnapshotGroup ↔ String?
URL of the source instant snapshot this instant snapshot is part of.
getter/setter pair
sourceInstantSnapshotGroupId ↔ String?
The ID value of the source instant snapshot group this InstantSnapshot is part of.
getter/setter pair
status ↔ String?
The status of the instantSnapshot.
getter/setter pair
zone ↔ String?
URL of the zone where the instant snapshot resides. You must specify this field as part of the HTTP request URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited