sourceInstantSnapshotGroup property

String? sourceInstantSnapshotGroup
getter/setter pair

URL of the source instant snapshot this instant snapshot is part of.

Note that the source instant snapshot group must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL.

Output only.

Implementation

core.String? sourceInstantSnapshotGroup;