sourceInstantSnapshotGroupId property

String? sourceInstantSnapshotGroupId
getter/setter pair

The ID value of the source instant snapshot group this InstantSnapshot is part of.

This value may be used to determine whether the InstantSnapshot was created as part of an InstantSnapshotGroup creation.

Output only.

Implementation

core.String? sourceInstantSnapshotGroupId;