InstantSnapshotGroup class

Represents an InstantSnapshotGroup resource.

An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.

Constructors

InstantSnapshotGroup({String? creationTimestamp, String? description, String? id, String? kind, String? name, String? region, InstantSnapshotGroupResourceStatus? resourceStatus, String? selfLink, String? selfLinkWithId, String? sourceConsistencyGroup, String? status, String? zone})
InstantSnapshotGroup.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
region ↔ String?
URL of the region where the instant snapshot group resides. You must specify this field as part of the HTTP request URL.
getter/setter pair
resourceStatus ↔ InstantSnapshotGroupResourceStatus?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId ↔ String?
Server-defined URL for this resource's resource id.
getter/setter pair
sourceConsistencyGroup ↔ String?
getter/setter pair
status ↔ String?
[Output Only]
getter/setter pair
zone ↔ String?
URL of the zone where the instant snapshot group resides. You must specify this field as part of the HTTP request URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited