InstantSnapshotGroupResourceStatus class

Constructors

InstantSnapshotGroupResourceStatus({String? consistencyMembershipResolutionTime, InstantSnapshotGroupSourceInfo? sourceInfo})
InstantSnapshotGroupResourceStatus.fromJson(Map json_)

Properties

consistencyMembershipResolutionTime ↔ String?
[Output Only]
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceInfo ↔ InstantSnapshotGroupSourceInfo?
[Output Only]
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited