Interconnect class

Represents an Interconnect resource.

An Interconnect resource is a dedicated connection between the Google Cloud network and your on-premises network.

For more information, read the Dedicated Interconnect Overview.

Constructors

Interconnect({bool? aaiEnabled, bool? adminEnabled, InterconnectApplicationAwareInterconnect? applicationAwareInterconnect, List<String>? availableFeatures, List<InterconnectCircuitInfo>? circuitInfos, String? creationTimestamp, String? customerName, String? description, String? effectiveLocation, List<InterconnectOutageNotification>? expectedOutages, String? googleIpAddress, String? googleReferenceId, String? id, List<String>? interconnectAttachments, List<String>? interconnectGroups, String? interconnectType, String? kind, String? labelFingerprint, Map<String, String>? labels, String? linkType, String? location, InterconnectMacsec? macsec, bool? macsecEnabled, String? name, String? nocContactEmail, String? operationalStatus, InterconnectParams? params, String? peerIpAddress, int? provisionedLinkCount, String? remoteLocation, List<String>? requestedFeatures, int? requestedLinkCount, bool? satisfiesPzs, String? selfLink, String? state, String? subzone, List<String>? wireGroups})
Interconnect.fromJson(Map json_)

Properties

aaiEnabled ↔ bool?
Enable or disable the application awareness feature on this Cloud Interconnect.
getter/setter pair
adminEnabled ↔ bool?
Administrative status of the interconnect.
getter/setter pair
applicationAwareInterconnect ↔ InterconnectApplicationAwareInterconnect?
Configuration information for application awareness on this Cloud Interconnect.
getter/setter pair
availableFeatures ↔ List<String>?
List of features available for this Interconnect connection, which can take one of the following values:
getter/setter pair
circuitInfos ↔ List<InterconnectCircuitInfo>?
A list of CircuitInfo objects, that describe the individual circuits in this LAG.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
customerName ↔ String?
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
effectiveLocation ↔ String?
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
getter/setter pair
expectedOutages ↔ List<InterconnectOutageNotification>?
A list of outages expected for this Interconnect.
getter/setter pair
googleIpAddress ↔ String?
IP address configured on the Google side of the Interconnect link.
getter/setter pair
googleReferenceId ↔ String?
Google reference ID to be used when raising support tickets with Google or otherwise to debug backend connectivity issues.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
interconnectAttachments ↔ List<String>?
A list of the URLs of all InterconnectAttachments configured to use this Interconnect.
getter/setter pair
interconnectGroups ↔ List<String>?
URLs of InterconnectGroups that include this Interconnect. Order is arbitrary and items are unique.
getter/setter pair
interconnectType ↔ String?
Type of interconnect, which can take one of the following values:
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
labelFingerprint ↔ String?
A fingerprint for the labels being applied to this Interconnect, which is essentially a hash of the labels set used for optimistic locking.
getter/setter pair
labelFingerprintAsBytes ↔ List<int>
getter/setter pair
labels ↔ Map<String, String>?
Labels for this resource.
getter/setter pair
linkType ↔ String?
Type of link requested, which can take one of the following values:
getter/setter pair
location ↔ String?
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
getter/setter pair
macsec ↔ InterconnectMacsec?
Configuration that enables Media Access Control security (MACsec) on the Cloud Interconnect connection between Google and your on-premises router.
getter/setter pair
macsecEnabled ↔ bool?
Enable or disable MACsec on this Interconnect connection.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
nocContactEmail ↔ String?
Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect.
getter/setter pair
operationalStatus ↔ String?
The current status of this Interconnect's functionality, which can take one of the following values:
getter/setter pair
params ↔ ExternalVpnGatewayParams?
Input only.
getter/setter pair
peerIpAddress ↔ String?
IP address configured on the customer side of the Interconnect link.
getter/setter pair
provisionedLinkCount ↔ int?
Number of links actually provisioned in this interconnect.
getter/setter pair
remoteLocation ↔ String?
Indicates that this is a Cross-Cloud Interconnect.
getter/setter pair
requestedFeatures ↔ List<String>?
This parameter can be provided only with Interconnect INSERT.
getter/setter pair
requestedLinkCount ↔ int?
Target number of physical links in the link bundle, as requested by the customer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
Server-defined URL for the resource.
getter/setter pair
state ↔ String?
The current state of Interconnect functionality, which can take one of the following values:
getter/setter pair
subzone ↔ String?
To be deprecated. Possible string values are:
getter/setter pair
wireGroups ↔ List<String>?
A list of the URLs of all CrossSiteNetwork WireGroups configured to use this Interconnect.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited