InterconnectApplicationAwareInterconnect class

Configuration information for application awareness on this Cloud Interconnect.

Properties

bandwidthPercentagePolicy ↔ InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
profileDescription ↔ String?
Description for the application awareness profile on this Cloud Interconnect.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeAveragePercentages ↔ List<InterconnectApplicationAwareInterconnectBandwidthPercentage>?
Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy.
getter/setter pair
strictPriorityPolicy ↔ InterconnectApplicationAwareInterconnectStrictPriorityPolicy?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited