candidateCloudRouterIpv6Address property

String? candidateCloudRouterIpv6Address
getter/setter pair

Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address must be the same.
  • Max prefix length is 126.

Implementation

core.String? candidateCloudRouterIpv6Address;