candidateCustomerRouterIpv6Address property
Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment.
Implementation
core.String? candidateCustomerRouterIpv6Address;
Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment.
core.String? candidateCustomerRouterIpv6Address;