InterconnectAttachmentGroupsOperationalStatus class

Properties

attachmentStatuses ↔ List<InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>?
getter/setter pair
configured ↔ InterconnectAttachmentGroupConfigured?
getter/setter pair
groupStatus ↔ String?
Summarizes the status of the group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intent ↔ InterconnectAttachmentGroupIntent?
getter/setter pair
operational ↔ InterconnectAttachmentGroupConfigured?
The operational state of the group, including only active Attachments.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited