InterconnectAttachmentGroupsOperationalStatusAttachmentStatus class

The status of one Attachment in the group.

List order is arbitrary.

Properties

adminEnabled ↔ bool?
Whether this Attachment is enabled.
getter/setter pair
attachment ↔ String?
The URL of the Attachment being described.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isActive ↔ String?
Whether this Attachment is participating in the redundant configuration. This will be ACTIVE if and only if the status below is CONNECTION_UP. Any INACTIVE Attachments are excluded from the analysis that generates operational.availabilitySLA.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Whether this Attachment is active, and if so, whether BGP is up.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited