applianceMappings property

Map<String, InterconnectAttachmentL2ForwardingApplianceMapping>? applianceMappings
getter/setter pair

A map of VLAN tags to appliances and optional inner mapping rules.

If VLANs are not explicitly mapped to any appliance, the defaultApplianceIpAddress is used.

Each VLAN tag can be a single number or a range of numbers in the range of 1 to 4094, e.g., "1" or "4001-4094". Non-empty and non-overlapping VLAN tag ranges are enforced, and violating operations will be rejected.

The VLAN tags in the Ethernet header must use an ethertype value of 0x88A8 or 0x8100.

Optional.

Implementation

core.Map<core.String, InterconnectAttachmentL2ForwardingApplianceMapping>?
applianceMappings;