InterconnectAttachmentL2ForwardingApplianceMapping class

Two-level VLAN-to-Appliance mapping rule.

Properties

applianceIpAddress String?
A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on a VLAN tag, but do not match a more specific inner VLAN tag.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
innerVlanToApplianceMappings List<InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping>?
Used to match against the inner VLAN when the packet contains two VLAN tags.
getter/setter pair
name String?
The name of this appliance mapping rule.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited