InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping class
The inner VLAN-to-Appliance mapping.
Constructors
-
InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping({String? innerApplianceIpAddress, List<
String> ? innerVlanTags}) - InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- innerApplianceIpAddress ↔ String?
-
Required in this object.
getter/setter pair
-
innerVlanTags
↔ List<
String> ? -
Required in this object.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited