InterconnectAttachmentPartnerMetadata class

Informational metadata about Partner attachments from Partners to display to customers.

These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments.

Constructors

InterconnectAttachmentPartnerMetadata({String? interconnectName, String? partnerName, String? portalUrl})
InterconnectAttachmentPartnerMetadata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
interconnectName ↔ String?
Plain text name of the Interconnect this attachment is connected to, as displayed in the Partner's portal.
getter/setter pair
partnerName ↔ String?
Plain text name of the Partner providing this attachment. This value may be validated to match approved Partner values.
getter/setter pair
portalUrl ↔ String?
URL of the Partner's portal for this Attachment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited