InterconnectDiagnosticsLinkStatus class

Properties

arpCaches ↔ List<InterconnectDiagnosticsARPEntry>?
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled
getter/setter pair
circuitId ↔ String?
The unique ID for this link assigned during turn up by Google.
getter/setter pair
googleDemarc ↔ String?
The Demarc address assigned by Google and provided in the LoA.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lacpStatus ↔ InterconnectDiagnosticsLinkLACPStatus?
getter/setter pair
macsec ↔ InterconnectDiagnosticsMacsecStatus?
Describes the status of MACsec encryption on this link.
getter/setter pair
operationalStatus ↔ String?
The operational status of the link. Possible string values are:
getter/setter pair
receivingOpticalPower ↔ InterconnectDiagnosticsLinkOpticalPower?
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transmittingOpticalPower ↔ InterconnectDiagnosticsLinkOpticalPower?
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited