arpCaches property
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled
Implementation
core.List<InterconnectDiagnosticsARPEntry>? arpCaches;
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled
core.List<InterconnectDiagnosticsARPEntry>? arpCaches;