InterconnectGroupPhysicalStructureMetrosFacilitiesZones class

The zones that Interconnects in this facility are present in.

Output only.

Properties

hashCode int
The hash code for this object.
no setterinherited
interconnects List<String>?
URLs of Interconnects in this redundancy group in the given metro, facility, and zone.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zone String?
The name of the zone, either "zone1" or "zone2". This is the second component of the location of Interconnects in this facility.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited