InterconnectGroupsCreateMembers class

Properties

hashCode → int
The hash code for this object.
no setterinherited
intentMismatchBehavior ↔ String?
How to behave when configured.topologyCapability.supportedSLA would not equal intent.topologyCapability after this call. Possible string values are:
getter/setter pair
interconnects ↔ List<InterconnectGroupsCreateMembersInterconnectInput>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateInterconnect ↔ InterconnectGroupsCreateMembersInterconnectInput?
Parameters for the Interconnects to create.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited