InterconnectGroupsCreateMembersInterconnectInput class
Constructors
-
InterconnectGroupsCreateMembersInterconnectInput({bool? adminEnabled, String? customerName, String? description, String? facility, String? interconnectType, String? linkType, String? name, String? nocContactEmail, String? remoteLocation, List<String>? requestedFeatures, int? requestedLinkCount})
-
-
InterconnectGroupsCreateMembersInterconnectInput.fromJson(Map json_)
-
Properties
-
adminEnabled
↔ bool?
-
Administrative status of the interconnect.
getter/setter pair
-
customerName
↔ String?
-
Customer name, to put in the Letter of Authorization as the party
authorized to request a crossconnect.
getter/setter pair
-
description
↔ String?
-
An optional description of this resource.
getter/setter pair
-
facility
↔ String?
-
A zone-free location to use for all Interconnects created in this call,
like "iad-1234".
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
interconnectType
↔ String?
-
Type of interconnect, which can take one of the following values:
getter/setter pair
-
linkType
↔ String?
-
Type of link requested, which can take one of the following values:
getter/setter pair
-
name
↔ String?
-
Name of the Interconnects to be created.
getter/setter pair
-
nocContactEmail
↔ String?
-
Email address to contact the customer NOC for operations and maintenance
notifications regarding this Interconnect.
getter/setter pair
-
remoteLocation
↔ String?
-
Indicates that this is a Cross-Cloud Interconnect.
getter/setter pair
-
requestedFeatures
↔ List<String>?
-
List of features requested for this Interconnect connection,
which can take one of the following values:
getter/setter pair
-
requestedLinkCount
↔ int?
-
Target number of physical links in the link bundle, as requested by the
customer.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited