InterconnectGroupsOperationalStatus class

Request to get the status of the interconnect group with extra detail.

Properties

configured ↔ InterconnectGroupConfigured?
The configuration analysis, as returned by Get.
getter/setter pair
groupStatus ↔ String?
Summarizes the status of the group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intent ↔ InterconnectGroupIntent?
The intent of the resource, as returned by Get.
getter/setter pair
interconnectStatuses ↔ List<InterconnectGroupsOperationalStatusInterconnectStatus>?
getter/setter pair
operational ↔ InterconnectGroupConfigured?
The operational state of the group, including only active Interconnects.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited