InterconnectLocation class

Represents an Interconnect Attachment (VLAN) Location resource.

You can use this resource to find location details about an Interconnect attachment (VLAN).

For more information about interconnect attachments, read Creating VLAN Attachments.

Constructors

InterconnectLocation({String? address, String? availabilityZone, List<String>? availableFeatures, List<String>? availableLinkTypes, String? city, String? continent, String? creationTimestamp, List<InterconnectLocationCrossSiteInterconnectInfo>? crossSiteInterconnectInfos, String? description, String? facilityProvider, String? facilityProviderFacilityId, String? id, String? kind, String? name, String? peeringdbFacilityId, List<InterconnectLocationRegionInfo>? regionInfos, String? selfLink, List<String>? singleRegionProductionCriticalPeerLocations, String? status, bool? supportsPzs})
InterconnectLocation.fromJson(Map json_)

Properties

address ↔ String?
The postal address of the Point of Presence, each line in the address is separated by a newline character.
getter/setter pair
availabilityZone ↔ String?
Availability zone for this InterconnectLocation.
getter/setter pair
availableFeatures ↔ List<String>?
List of features available at this InterconnectLocation, which can take one of the following values:
getter/setter pair
availableLinkTypes ↔ List<String>?
List of link types available at this InterconnectLocation, which can take one of the following values:
getter/setter pair
city ↔ String?
Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".
getter/setter pair
continent ↔ String?
Continent for this location, which can take one of the following values:
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
crossSiteInterconnectInfos ↔ List<InterconnectLocationCrossSiteInterconnectInfo>?
A list of InterconnectLocation.CrossSiteInterconnectInfo objects, that describe where Cross-Site Interconnect wires may connect to from this location and associated connection parameters.
getter/setter pair
description ↔ String?
An optional description of the resource.
getter/setter pair
facilityProvider ↔ String?
The name of the provider for this facility (e.g., EQUINIX).
getter/setter pair
facilityProviderFacilityId ↔ String?
A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
peeringdbFacilityId ↔ String?
The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).
getter/setter pair
regionInfos ↔ List<InterconnectLocationRegionInfo>?
A list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
singleRegionProductionCriticalPeerLocations ↔ List<String>?
URLs of the other locations that can pair up with this location to support Single-Region 99.99% SLA.
getter/setter pair
status ↔ String?
The status of this InterconnectLocation, which can take one of the following values:
getter/setter pair
supportsPzs ↔ bool?
Reserved for future use.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited