InterconnectLocationRegionInfo class

Information about any potential InterconnectAttachments between an Interconnect at a specific InterconnectLocation, and a specific Cloud Region.

Constructors

InterconnectLocationRegionInfo({String? expectedRttMs, bool? l2ForwardingEnabled, String? locationPresence, String? region})
InterconnectLocationRegionInfo.fromJson(Map json_)

Properties

expectedRttMs ↔ String?
Expected round-trip time in milliseconds, from this InterconnectLocation to a VM in this region.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
l2ForwardingEnabled ↔ bool?
Identifies whether L2 Interconnect Attachments can be created in this region for interconnects that are in this location.
getter/setter pair
locationPresence ↔ String?
Identifies the network presence of this location.
getter/setter pair
region ↔ String?
URL for the region of this location.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited