InterconnectMacsecConfig class

MACsec configuration information for the Interconnect connection.

Contains the generated Connectivity Association Key Name (CKN) and the key (CAK) for this Interconnect connection.

Properties

hashCode → int
The hash code for this object.
no setterinherited
preSharedKeys ↔ List<InterconnectMacsecConfigPreSharedKey>?
A keychain placeholder describing a set of named key objects along with their start times.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited