InterconnectMacsecConfigPreSharedKey class

Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.

Properties

cak ↔ String?
An auto-generated Connectivity Association Key (CAK) for this key.
getter/setter pair
ckn ↔ String?
An auto-generated Connectivity Association Key Name (CKN) for this key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
User provided name for this pre-shared key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
User provided timestamp on or after which this key is valid.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited