InterconnectRemoteLocation class

Represents a Cross-Cloud Interconnect Remote Location resource.

You can use this resource to find remote location details about an Interconnect attachment (VLAN).

Constructors

InterconnectRemoteLocation({String? address, InterconnectAttachmentConfigurationConstraints? attachmentConfigurationConstraints, String? city, InterconnectRemoteLocationConstraints? constraints, String? continent, String? creationTimestamp, String? description, String? facilityProvider, String? facilityProviderFacilityId, String? id, String? kind, String? lacp, int? maxLagSize100Gbps, int? maxLagSize10Gbps, int? maxLagSize400Gbps, String? name, String? peeringdbFacilityId, List<InterconnectRemoteLocationPermittedConnections>? permittedConnections, String? remoteService, String? selfLink, String? status})
InterconnectRemoteLocation.fromJson(Map json_)

Properties

address ↔ String?
The postal address of the Point of Presence, each line in the address is separated by a newline character.
getter/setter pair
attachmentConfigurationConstraints ↔ InterconnectAttachmentConfigurationConstraints?
Subset of fields from InterconnectAttachment's |configurationConstraints| field that apply to all attachments for this remote location.
getter/setter pair
city ↔ String?
Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands".
getter/setter pair
constraints ↔ InterconnectRemoteLocationConstraints?
Constraints on the parameters for creating Cross-Cloud Interconnect and associated InterconnectAttachments.
getter/setter pair
continent ↔ String?
Continent for this location, which can take one of the following values:
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of the resource.
getter/setter pair
facilityProvider ↔ String?
The name of the provider for this facility (e.g., EQUINIX).
getter/setter pair
facilityProviderFacilityId ↔ String?
A provider-assigned Identifier for this facility (e.g., Ashburn-DC1).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
lacp ↔ String?
Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
getter/setter pair
maxLagSize100Gbps ↔ int?
[Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG).
getter/setter pair
maxLagSize10Gbps ↔ int?
[Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG).
getter/setter pair
maxLagSize400Gbps ↔ int?
[Output Only] The maximum number of 400 Gbps ports supported in a link aggregation group (LAG).
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
peeringdbFacilityId ↔ String?
The peeringdb identifier for this facility (corresponding with a netfac type in peeringdb).
getter/setter pair
permittedConnections ↔ List<InterconnectRemoteLocationPermittedConnections>?
Permitted connections.
getter/setter pair
remoteService ↔ String?
Indicates the service provider present at the remote location.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
status ↔ String?
The status of this InterconnectRemoteLocation, which can take one of the following values:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited