LicenseCodesResource class

Constructors

LicenseCodesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String project, String licenseCode, {String? $fields}) Future<LicenseCode>
Return a specified license code.
getIamPolicy(String project, String resource, {int? optionsRequestedPolicyVersion, String? $fields}) Future<Policy>
Gets the access control policy for a resource.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(GlobalSetPolicyRequest request, String project, String resource, {String? $fields}) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
testIamPermissions(TestPermissionsRequest request, String project, String resource, {String? $fields}) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited