LicenseResourceCommitment class

Commitment for a particular license resource.

Constructors

LicenseResourceCommitment({String? amount, String? coresPerLicense, String? license})
LicenseResourceCommitment.fromJson(Map json_)

Properties

amount ↔ String?
The number of licenses you plan to purchase.
getter/setter pair
coresPerLicense ↔ String?
The number of cores per license.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
license ↔ String?
The applicable license URI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited