LicensesResource class

Constructors

LicensesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String project, String license, {String? requestId, String? $fields}) Future<Operation>
Deletes the specified license. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
get(String project, String license, {String? $fields}) Future<License>
Returns the specified License resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
getIamPolicy(String project, String resource, {int? optionsRequestedPolicyVersion, String? $fields}) Future<Policy>
Gets the access control policy for a resource.
insert(License request, String project, {String? requestId, String? $fields}) Future<Operation>
Create a License resource in the specified project. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
list(String project, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<LicensesListResponse>
Retrieves the list of licenses available in the specified project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(GlobalSetPolicyRequest request, String project, String resource, {String? $fields}) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
testIamPermissions(TestPermissionsRequest request, String project, String resource, {String? $fields}) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
toString() String
A string representation of this object.
inherited
update(License request, String project, String license, {String? requestId, String? updateMask, String? $fields}) Future<Operation>
Updates a License resource in the specified project. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Operators

operator ==(Object other) bool
The equality operator.
inherited