LocalDisk class

Constructors

LocalDisk({int? diskCount, int? diskSizeGb, String? diskType})
LocalDisk.fromJson(Map json_)

Properties

diskCount ↔ int?
Specifies the number of such disks.
getter/setter pair
diskSizeGb ↔ int?
Specifies the size of the disk in base-2 GB.
getter/setter pair
diskType ↔ String?
Specifies the desired disk type on the node.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited