zones property

List<LocationPolicyZoneConfiguration>? zones
getter/setter pair

The bulkInsert operation applies any preferences set in the locations field to the specific zones listed in the zones field if the same zones are specified in both fields.

Implementation

core.List<LocationPolicyZoneConfiguration>? zones;