MachineType class

Represents a Machine Type resource.

You can use specific machine types for your VM instances based on performance and pricing requirements.

For more information, readMachine Types.

Constructors

MachineType({List<MachineTypeAccelerators>? accelerators, String? architecture, BundledLocalSsds? bundledLocalSsds, String? creationTimestamp, DeprecationStatus? deprecated, String? description, int? guestCpus, String? id, int? imageSpaceGb, bool? isSharedCpu, String? kind, int? maximumPersistentDisks, String? maximumPersistentDisksSizeGb, int? memoryMb, String? name, String? selfLink, String? zone})
MachineType.fromJson(Map json_)

Properties

accelerators ↔ List<MachineTypeAccelerators>?
A list of accelerator configurations assigned to this machine type.
getter/setter pair
architecture ↔ String?
The architecture of the machine type.
getter/setter pair
bundledLocalSsds ↔ BundledLocalSsds?
The configuration of bundled local SSD for the machine type.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
deprecated ↔ DeprecationStatus?
The deprecation status associated with this machine type. Only applicable if the machine type is unavailable.
getter/setter pair
description ↔ String?
An optional textual description of the resource.
getter/setter pair
guestCpus ↔ int?
The number of virtual CPUs that are available to the instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
imageSpaceGb ↔ int?
This property is deprecated and will never be populated with any relevant values.
getter/setter pair
isSharedCpu ↔ bool?
Whether this machine type has a shared CPU.
getter/setter pair
kind ↔ String?
The type of the resource.
getter/setter pair
maximumPersistentDisks ↔ int?
Maximum persistent disks allowed.
getter/setter pair
maximumPersistentDisksSizeGb ↔ String?
Maximum total persistent disks size (GB) allowed.
getter/setter pair
memoryMb ↔ int?
The amount of physical memory available to the instance, defined in MB.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
zone ↔ String?
The name of the zone where the machine type resides, such as us-central1-a.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited