MachineTypeAccelerators class

Constructors

MachineTypeAccelerators({int? guestAcceleratorCount, String? guestAcceleratorType})
MachineTypeAccelerators.fromJson(Map json_)

Properties

guestAcceleratorCount ↔ int?
Number of accelerator cards exposed to the guest.
getter/setter pair
guestAcceleratorType ↔ String?
The accelerator type resource name, not a full URL, e.g.nvidia-tesla-t4.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited