MachineTypesScopedList class

Properties

hashCode → int
The hash code for this object.
no setterinherited
machineTypes ↔ List<MachineType>?
A list of machine types contained in this scope.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warning ↔ MachineTypesScopedListWarning?
An informational warning that appears when the machine types list is empty.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited