scheduling property
Information about the termination timestamp of the instance, if applicable.
Output only.
Implementation
ManagedInstanceScheduling? scheduling;
Information about the termination timestamp of the instance, if applicable.
Output only.
ManagedInstanceScheduling? scheduling;