shutdownDetails property

ManagedInstanceShutdownDetails? shutdownDetails
getter/setter pair

Specifies the graceful shutdown details if the instance is in PENDING_STOP state or there is a programmed stop scheduled.

Output only.

Implementation

ManagedInstanceShutdownDetails? shutdownDetails;