ManagedInstanceScheduling class

Constructors

ManagedInstanceScheduling({String? gracefulShutdownTimestamp, String? terminationTimestamp})
ManagedInstanceScheduling.fromJson(Map json_)

Properties

gracefulShutdownTimestamp ↔ String?
The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terminationTimestamp ↔ String?
The timestamp at which the managed instance will be terminated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited