terminationTimestamp property
The timestamp at which the managed instance will be terminated.
This is in RFC3339 text format.
Output only.
Implementation
core.String? terminationTimestamp;
The timestamp at which the managed instance will be terminated.
This is in RFC3339 text format.
Output only.
core.String? terminationTimestamp;