MetadataFilter class

Opaque filter criteria used by load balancers to restrict routing configuration to a limited set of load balancing proxies.

Proxies and sidecars involved in load balancing would typically present metadata to the load balancers that need to match criteria specified here. If a match takes place, the relevant configuration is made available to those proxies.

For each metadataFilter in this list, if itsfilterMatchCriteria is set to MATCH_ANY, at least one of thefilterLabels must match the corresponding label provided in the metadata. If its filterMatchCriteria is set to MATCH_ALL, then all of its filterLabels must match with corresponding labels provided in the metadata.

An example for using metadataFilters would be: if load balancing involves Envoys, they receive routing configuration when values inmetadataFilters match values supplied in of their XDS requests to loadbalancers.

Constructors

MetadataFilter({List<MetadataFilterLabelMatch>? filterLabels, String? filterMatchCriteria})
MetadataFilter.fromJson(Map json_)

Properties

filterLabels ↔ List<MetadataFilterLabelMatch>?
The list of label value pairs that must match labels in the provided metadata based on filterMatchCriteria
getter/setter pair
filterMatchCriteria ↔ String?
Specifies how individual filter label matches within the list of filterLabels and contributes toward the overall metadataFilter match.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited