NamedSet class

Constructors

NamedSet({String? description, List<Expr>? elements, String? fingerprint, String? name, String? type})
NamedSet.fromJson(Map json_)

Properties

description String?
An optional description of named set.
getter/setter pair
elements List<Expr>?
CEL expressions that are comparable to constructs of this set's type (see Policy Language).
getter/setter pair
fingerprint String?
A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set.
getter/setter pair
fingerprintAsBytes List<int>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
This named set's type Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited