fingerprint property

String? fingerprint
getter/setter pair

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set.

You must always provide an up-to-date fingerprint hash in order to update or change labels.

To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set.

Implementation

core.String? fingerprint;