name property
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router.
Name should conform to RFC1035.
Implementation
core.String? name;
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router.
Name should conform to RFC1035.
core.String? name;