NetworkEndpointGroup class

Represents a collection of network endpoints.

A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs for different use cases, seeNetwork endpoint groups overview.

Note: Use the following APIs to manage network endpoint groups:

To manage NEGs with zonal scope (such as zonal NEGs, hybrid connectivity NEGs): zonal API

To manage NEGs with regional scope (such as regional internet NEGs, serverless NEGs, Private Service Connect NEGs): regional API

To manage NEGs with global scope (such as global internet NEGs):global API

Constructors

NetworkEndpointGroup({Map<String, String>? annotations, NetworkEndpointGroupAppEngine? appEngine, NetworkEndpointGroupCloudFunction? cloudFunction, NetworkEndpointGroupCloudRun? cloudRun, String? creationTimestamp, int? defaultPort, String? description, String? id, String? kind, String? name, String? network, String? networkEndpointType, NetworkEndpointGroupPscData? pscData, String? pscTargetService, String? region, String? selfLink, int? size, String? subnetwork, String? zone})
NetworkEndpointGroup.fromJson(Map json_)

Properties

annotations Map<String, String>?
Metadata defined as annotations on the network endpoint group.
getter/setter pair
appEngine NetworkEndpointGroupAppEngine?
Only valid when networkEndpointType isSERVERLESS.
getter/setter pair
cloudFunction NetworkEndpointGroupCloudFunction?
Only valid when networkEndpointType isSERVERLESS.
getter/setter pair
cloudRun NetworkEndpointGroupCloudRun?
Only valid when networkEndpointType isSERVERLESS.
getter/setter pair
creationTimestamp String?
Creation timestamp inRFC3339 text format.
getter/setter pair
defaultPort int?
The default port used if the port number is not specified in the network endpoint.
getter/setter pair
description String?
An optional description of this resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier for the resource.
getter/setter pair
kind String?
Type of the resource.
getter/setter pair
name String?
Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash.
getter/setter pair
network String?
The URL of the network to which all network endpoints in the NEG belong. For networkEndpointType GCE_VM_IP_PORT,GCE_VM_IP_PORTMAP or NON_GCP_PRIVATE_IP_PORT, if this field is not specified, a default network will be used. This field cannot be set for NEGs with networkEndpointType set toSERVERLESS or PRIVATE_SERVICE_CONNECT and for global NEGs. For all other network endpoint types, this field is required.
getter/setter pair
networkEndpointType String?
Type of network endpoints in this network endpoint group.
getter/setter pair
pscData NetworkEndpointGroupPscData?
Only valid when networkEndpointType isPRIVATE_SERVICE_CONNECT.
getter/setter pair
pscTargetService String?
The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment. An example value is: asia-northeast3-cloudkms.googleapis.com.
getter/setter pair
region String?
The URL of theregion where the network endpoint group is located.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
size int?
Number of network endpoints in the network endpoint group.
getter/setter pair
subnetwork String?
Optional URL of the subnetwork to which all network endpoints in the NEG belong.
getter/setter pair
zone String?
The URL of thezone where the network endpoint group is located.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited