NetworkEndpointGroupCloudFunction class

Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask.

Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG.

Properties

function ↔ String?
A user-defined name of the Cloud Function.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlMask ↔ String?
An URL mask is one of the main components of the Cloud Function.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited