NetworkEndpointGroupPscData class

All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.

Constructors

NetworkEndpointGroupPscData({String? consumerPscAddress, int? producerPort, String? pscConnectionId, String? pscConnectionStatus})
NetworkEndpointGroupPscData.fromJson(Map json_)

Properties

consumerPscAddress ↔ String?
Address allocated from given subnetwork for PSC.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
producerPort ↔ int?
The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type
getter/setter pair
pscConnectionId ↔ String?
The PSC connection id of the PSC Network Endpoint Group Consumer.
getter/setter pair
pscConnectionStatus ↔ String?
The connection status of the PSC Forwarding Rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited