NetworkPeeringConnectionStatusTrafficConfiguration class

Constructors

NetworkPeeringConnectionStatusTrafficConfiguration({bool? exportCustomRoutesToPeer, bool? exportSubnetRoutesWithPublicIpToPeer, bool? importCustomRoutesFromPeer, bool? importSubnetRoutesWithPublicIpFromPeer, String? stackType})
NetworkPeeringConnectionStatusTrafficConfiguration.fromJson(Map json_)

Properties

exportCustomRoutesToPeer ↔ bool?
Whether custom routes are being exported to the peer network.
getter/setter pair
exportSubnetRoutesWithPublicIpToPeer ↔ bool?
Whether subnet routes with public IP ranges are being exported to the peer network.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importCustomRoutesFromPeer ↔ bool?
Whether custom routes are being imported from the peer network.
getter/setter pair
importSubnetRoutesWithPublicIpFromPeer ↔ bool?
Whether subnet routes with public IP ranges are being imported from the peer network.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackType ↔ String?
Which IP version(s) of traffic and routes are being imported or exported between peer networks. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited