NetworkProfileNetworkFeatures class

Constructors

NetworkProfileNetworkFeatures({List<String>? addressPurposes, String? allowAddressCreation, String? allowAliasIpRanges, String? allowAutoModeSubnet, String? allowClassDFirewalls, String? allowCloudNat, String? allowCloudRouter, String? allowDefaultNicAttachment, String? allowExternalIpAccess, String? allowFirewallPolicy, String? allowInterconnect, String? allowIpForwarding, String? allowLoadBalancing, String? allowMultiNicInSameNetwork, String? allowMultiNicInSameSubnetwork, String? allowMulticast, String? allowNcc, String? allowNetworkMigration, String? allowPacketMirroring, String? allowPrivateGoogleAccess, String? allowPsc, String? allowSameNetworkUnicast, String? allowStaticRoutes, String? allowSubInterfaces, String? allowSubnetworkCreation, String? allowVpcFirewallRules, String? allowVpcPeering, String? allowVpn, List<String>? firewallPolicyTypes, List<String>? interfaceTypes, String? multicast, String? predefinedNetworkInternalIpv6Range, List<NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>? predefinedSubnetworkRanges, List<String>? subnetPurposes, List<String>? subnetStackTypes, List<String>? subnetworkPurposes, List<String>? subnetworkStackTypes, String? unicast})
NetworkProfileNetworkFeatures.fromJson(Map json_)

Properties

addressPurposes ↔ List<String>?
Specifies what address purposes are supported.
getter/setter pair
allowAddressCreation ↔ String?
Specifies whether address creation is allowed. Possible string values are:
getter/setter pair
allowAliasIpRanges ↔ String?
Specifies whether alias IP ranges (and secondary address ranges) are allowed. Possible string values are:
getter/setter pair
allowAutoModeSubnet ↔ String?
Specifies whether auto mode subnet creation is allowed. Possible string values are:
getter/setter pair
allowClassDFirewalls ↔ String?
Specifies whether firewalls for Class D address ranges are supported. Possible string values are:
getter/setter pair
allowCloudNat ↔ String?
Specifies whether cloud NAT creation is allowed. Possible string values are:
getter/setter pair
allowCloudRouter ↔ String?
Specifies whether cloud router creation is allowed. Possible string values are:
getter/setter pair
allowDefaultNicAttachment ↔ String?
Specifies whether default NIC attachment is allowed. Possible string values are:
getter/setter pair
allowExternalIpAccess ↔ String?
Specifies whether VMs are allowed to have external IP access on network interfaces connected to this VPC. Possible string values are:
getter/setter pair
allowFirewallPolicy ↔ String?
Specifies whether firewall policy can be attached to the network. Possible string values are:
getter/setter pair
allowInterconnect ↔ String?
Specifies whether Cloud Interconnect creation is allowed. Possible string values are:
getter/setter pair
allowIpForwarding ↔ String?
Specifies whether IP forwarding is allowed. Possible string values are:
getter/setter pair
allowLoadBalancing ↔ String?
Specifies whether cloud load balancing is allowed. Possible string values are:
getter/setter pair
allowMulticast ↔ String?
Specifies whether multicast is allowed. Possible string values are:
getter/setter pair
allowMultiNicInSameNetwork ↔ String?
Specifies whether multi-nic in the same network is allowed. Possible string values are:
getter/setter pair
allowMultiNicInSameSubnetwork ↔ String?
Specifies whether multi-nic in the same subnetwork is allowed. Possible string values are:
getter/setter pair
allowNcc ↔ String?
Specifies whether NCC is allowed. Possible string values are:
getter/setter pair
allowNetworkMigration ↔ String?
Specifies whether VM network migration is allowed. Possible string values are:
getter/setter pair
allowPacketMirroring ↔ String?
Specifies whether Packet Mirroring 1.0 is supported. Possible string values are:
getter/setter pair
allowPrivateGoogleAccess ↔ String?
Specifies whether private Google access is allowed. Possible string values are:
getter/setter pair
allowPsc ↔ String?
Specifies whether PSC creation is allowed. Possible string values are:
getter/setter pair
allowSameNetworkUnicast ↔ String?
Specifies whether unicast within the same network is allowed. Possible string values are:
getter/setter pair
allowStaticRoutes ↔ String?
Specifies whether static route creation is allowed. Possible string values are:
getter/setter pair
allowSubInterfaces ↔ String?
Specifies whether sub interfaces are allowed. Possible string values are:
getter/setter pair
allowSubnetworkCreation ↔ String?
Specifies whether subnetwork creation is allowed. Possible string values are:
getter/setter pair
allowVpcFirewallRules ↔ String?
Specifies whether VPC firewall rules can be created under the network. Possible string values are:
getter/setter pair
allowVpcPeering ↔ String?
Specifies whether VPC peering is allowed. Possible string values are:
getter/setter pair
allowVpn ↔ String?
Specifies whether VPN creation is allowed. Possible string values are:
getter/setter pair
firewallPolicyTypes ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interfaceTypes ↔ List<String>?
If set, limits the interface types that the network supports.
getter/setter pair
multicast ↔ String?
Specifies which type of multicast is supported. Possible string values are:
getter/setter pair
predefinedNetworkInternalIpv6Range ↔ String?
Specifies a predefined internal IPv6 range for the network.
getter/setter pair
predefinedSubnetworkRanges ↔ List<NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>?
Predefined subnetwork ranges for the network.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetPurposes ↔ List<String>?
Specifies which subnetwork purposes are supported.
getter/setter pair
subnetStackTypes ↔ List<String>?
Specifies which subnetwork stack types are supported.
getter/setter pair
subnetworkPurposes ↔ List<String>?
Specifies which subnetwork purposes are supported.
getter/setter pair
subnetworkStackTypes ↔ List<String>?
Specifies which subnetwork stack types are supported.
getter/setter pair
unicast ↔ String?
Specifies which type of unicast is supported. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited