NetworksAddPeeringRequest class

Constructors

NetworksAddPeeringRequest({bool? autoCreateRoutes, String? name, NetworkPeering? networkPeering, String? peerNetwork})
NetworksAddPeeringRequest.fromJson(Map json_)

Properties

autoCreateRoutes ↔ bool?
This field will be deprecated soon.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the peering, which should conform to RFC1035.
getter/setter pair
networkPeering ↔ NetworkPeering?
Network peering parameters. In order to specify route policies for peering using import and export custom routes, you must specify all peering related parameters (name, peer network,exchange_subnet_routes) in the network_peering field. The corresponding fields in NetworksAddPeeringRequest will be deprecated soon.
getter/setter pair
peerNetwork ↔ String?
URL of the peer network.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited