NodeGroupNode class

Constructors

NodeGroupNode({List<AcceleratorConfig>? accelerators, InstanceConsumptionInfo? consumedResources, String? cpuOvercommitType, List<LocalDisk>? disks, List<InstanceConsumptionData>? instanceConsumptionData, List<String>? instances, String? name, String? nodeType, bool? satisfiesPzs, ServerBinding? serverBinding, String? serverId, String? status, InstanceConsumptionInfo? totalResources, UpcomingMaintenance? upcomingMaintenance})
NodeGroupNode.fromJson(Map json_)

Properties

accelerators ↔ List<AcceleratorConfig>?
Accelerators for this node.
getter/setter pair
consumedResources ↔ InstanceConsumptionInfo?
Node resources that are reserved by all instances.
getter/setter pair
cpuOvercommitType ↔ String?
CPU overcommit. Possible string values are:
getter/setter pair
disks ↔ List<LocalDisk>?
Local disk configurations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceConsumptionData ↔ List<InstanceConsumptionData>?
Instance data that shows consumed resources on the node.
getter/setter pair
instances ↔ List<String>?
Instances scheduled on this node.
getter/setter pair
name ↔ String?
The name of the node.
getter/setter pair
nodeType ↔ String?
The type of this node.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
serverBinding ↔ ServerBinding?
Binding properties for the physical server.
getter/setter pair
serverId ↔ String?
Server ID associated with this node.
getter/setter pair
status ↔ String?
Possible string values are:
getter/setter pair
totalResources ↔ InstanceConsumptionInfo?
Total amount of available resources on the node.
getter/setter pair
upcomingMaintenance ↔ UpcomingMaintenance?
The information about an upcoming maintenance event.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited