NodeGroupsPerformMaintenanceRequest class

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodes ↔ List<String>?
List of nodes affected by the call.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The start time of the schedule.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited