NodeTypeAggregatedList class

Constructors

NodeTypeAggregatedList({String? id, Map<String, NodeTypesScopedList>? items, String? kind, String? nextPageToken, String? selfLink, List<String>? unreachables, NodeTypeAggregatedListWarning? warning})
NodeTypeAggregatedList.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique identifier for the resource; defined by the server.
getter/setter pair
items ↔ Map<String, NodeTypesScopedList>?
A list of NodeTypesScopedList resources.
getter/setter pair
kind ↔ String?
Type of resource.Alwayscompute#nodeTypeAggregatedList for aggregated lists of node types.
getter/setter pair
nextPageToken ↔ String?
This token allows you to get the next page of results for list requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for this resource.
getter/setter pair
unreachables ↔ List<String>?
Unreachable resources.
getter/setter pair
warning ↔ NodeTypeAggregatedListWarning?
Informational warning message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited