NotificationEndpointsScopedList class
Constructors
-
NotificationEndpointsScopedList({List<
NotificationEndpoint> ? resources, NotificationEndpointsScopedListWarning? warning}) - NotificationEndpointsScopedList.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resources
↔ List<
NotificationEndpoint> ? -
A list of NotificationEndpoints contained in this scope.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- warning ↔ NotificationEndpointsScopedListWarning?
-
Informational warning which replaces the list of
notification endpoints when the list is empty.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited