warning property
Informational warning which replaces the list of notification endpoints when the list is empty.
Implementation
NotificationEndpointsScopedListWarning? warning;
Informational warning which replaces the list of notification endpoints when the list is empty.
NotificationEndpointsScopedListWarning? warning;