Operation class

Represents an Operation resource.

Google Compute Engine has three Operation resources:

  • [Global](/compute/docs/reference/rest/v1/globalOperations)
  • [Regional](/compute/docs/reference/rest/v1/regionOperations)
  • [Zonal](/compute/docs/reference/rest/v1/zoneOperations)

You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses.

Operations can be global, regional or zonal.

  • For global operations, use the globalOperations resource.

  • For regional operations, use the regionOperations resource.

  • For zonal operations, use the zoneOperations resource.

For more information, read Global, Regional, and Zonal Resources.

Note that completed Operation resources have a limited retention period.

Constructors

Operation({String? clientOperationId, String? creationTimestamp, String? description, String? endTime, OperationError? error, GetVersionOperationMetadata? getVersionOperationMetadata, String? httpErrorMessage, int? httpErrorStatusCode, String? id, String? insertTime, InstancesBulkInsertOperationMetadata? instancesBulkInsertOperationMetadata, String? kind, String? name, String? operationGroupId, String? operationType, int? progress, String? region, String? selfLink, SetCommonInstanceMetadataOperationMetadata? setCommonInstanceMetadataOperationMetadata, String? startTime, String? status, String? statusMessage, String? targetId, String? targetLink, String? user, List<OperationWarnings>? warnings, String? zone})
Operation.fromJson(Map json_)

Properties

clientOperationId ↔ String?
The value of requestId if you provided it in the request. Not present otherwise.
getter/setter pair
creationTimestamp ↔ String?
This field is deprecated.
getter/setter pair
description ↔ String?
A textual description of the operation, which is set when the operation is created.
getter/setter pair
endTime ↔ String?
The time that this operation was completed.
getter/setter pair
error ↔ OperationError?
If errors are generated during processing of the operation, this field will be populated.
getter/setter pair
getVersionOperationMetadata ↔ GetVersionOperationMetadata?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpErrorMessage ↔ String?
If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND.
getter/setter pair
httpErrorStatusCode ↔ int?
If the operation fails, this field contains the HTTP error status code that was returned.
getter/setter pair
id ↔ String?
The unique identifier for the operation.
getter/setter pair
insertTime ↔ String?
The time that this operation was requested. This value is inRFC3339 text format.
getter/setter pair
instancesBulkInsertOperationMetadata ↔ InstancesBulkInsertOperationMetadata?
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
Name of the operation.
getter/setter pair
operationGroupId ↔ String?
An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request.
getter/setter pair
operationType ↔ String?
The type of operation, such as insert, update, or delete, and so on.
getter/setter pair
progress ↔ int?
An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations.
getter/setter pair
region ↔ String?
The URL of the region where the operation resides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
setCommonInstanceMetadataOperationMetadata ↔ SetCommonInstanceMetadataOperationMetadata?
If the operation is for projects.setCommonInstanceMetadata, this field will contain information on all underlying zonal actions and their state.
getter/setter pair
startTime ↔ String?
The time that this operation was started by the server. This value is inRFC3339 text format.
getter/setter pair
status ↔ String?
The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE.
getter/setter pair
statusMessage ↔ String?
An optional textual description of the current status of the operation.
getter/setter pair
targetId ↔ String?
The unique target ID, which identifies a specific incarnation of the target resource.
getter/setter pair
The URL of the resource that the operation modifies.
getter/setter pair
user ↔ String?
User who requested the operation, for example: user@example.com or alice_smith_identifier (global/workforcePools/example-com-us-employees).
getter/setter pair
warnings ↔ List<OperationWarnings>?
If warning messages are generated during processing of the operation, this field will be populated.
getter/setter pair
zone ↔ String?
The URL of the zone where the operation resides.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited