OutlierDetection class

Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.

Constructors

OutlierDetection({Duration? baseEjectionTime, int? consecutiveErrors, int? consecutiveGatewayFailure, int? enforcingConsecutiveErrors, int? enforcingConsecutiveGatewayFailure, int? enforcingSuccessRate, Duration? interval, int? maxEjectionPercent, int? successRateMinimumHosts, int? successRateRequestVolume, int? successRateStdevFactor})
OutlierDetection.fromJson(Map json_)

Properties

baseEjectionTime ↔ Duration?
The base time that a backend endpoint is ejected for.
getter/setter pair
consecutiveErrors ↔ int?
Number of consecutive errors before a backend endpoint is ejected from the load balancing pool.
getter/setter pair
consecutiveGatewayFailure ↔ int?
The number of consecutive gateway failures (502, 503, 504 status or connection errors that are mapped to one of those status codes) before a consecutive gateway failure ejection occurs.
getter/setter pair
enforcingConsecutiveErrors ↔ int?
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive 5xx.
getter/setter pair
enforcingConsecutiveGatewayFailure ↔ int?
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive gateway failures.
getter/setter pair
enforcingSuccessRate ↔ int?
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through success rate statistics.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interval ↔ Duration?
Time interval between ejection analysis sweeps.
getter/setter pair
maxEjectionPercent ↔ int?
Maximum percentage of backend endpoints in the load balancing pool for the backend service that can be ejected if the ejection conditions are met. Defaults to 50%.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successRateMinimumHosts ↔ int?
The number of backend endpoints in the load balancing pool that must have enough request volume to detect success rate outliers.
getter/setter pair
successRateRequestVolume ↔ int?
The minimum number of total requests that must be collected in one interval (as defined by the interval duration above) to include this backend endpoint in success rate based outlier detection.
getter/setter pair
successRateStdevFactor ↔ int?
This factor is used to determine the ejection threshold for success rate outlier ejection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited