PacketMirroring class

Represents a Packet Mirroring resource.

Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, see Using Packet Mirroring.

Constructors

PacketMirroring({PacketMirroringForwardingRuleInfo? collectorIlb, String? creationTimestamp, String? description, String? enable, PacketMirroringFilter? filter, String? id, String? kind, PacketMirroringMirroredResourceInfo? mirroredResources, String? name, PacketMirroringNetworkInfo? network, int? priority, String? region, String? selfLink})
PacketMirroring.fromJson(Map json_)

Properties

collectorIlb ↔ PacketMirroringForwardingRuleInfo?
The Forwarding Rule resource of type loadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp in RFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
enable ↔ String?
Indicates whether or not this packet mirroring takes effect.
getter/setter pair
filter ↔ PacketMirroringFilter?
Filter for mirrored traffic.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
mirroredResources ↔ PacketMirroringMirroredResourceInfo?
PacketMirroring mirroredResourceInfos.
getter/setter pair
name ↔ String?
Name of the resource; provided by the client when the resource is created.
getter/setter pair
network ↔ PacketMirroringNetworkInfo?
Specifies the mirrored VPC network.
getter/setter pair
priority ↔ int?
The priority of applying this configuration.
getter/setter pair
region ↔ String?
URI of the region where the packetMirroring resides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited