PathMatcher class

A matcher for the path portion of the URL.

The BackendService from the longest-matched rule will serve the URL. If no rule was matched, the default service is used.

Constructors

PathMatcher({CustomErrorResponsePolicy? defaultCustomErrorResponsePolicy, HttpRouteAction? defaultRouteAction, String? defaultService, HttpRedirectAction? defaultUrlRedirect, String? description, HttpHeaderAction? headerAction, String? name, List<PathRule>? pathRules, List<HttpRouteRule>? routeRules})
PathMatcher.fromJson(Map json_)

Properties

defaultCustomErrorResponsePolicy ↔ CustomErrorResponsePolicy?
defaultCustomErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceorBackendBucket responds with an error.
getter/setter pair
defaultRouteAction ↔ HttpRouteAction?
defaultRouteAction takes effect when none of the pathRules or routeRules match.
getter/setter pair
defaultService ↔ String?
The full or partial URL to the BackendService resource.
getter/setter pair
defaultUrlRedirect ↔ HttpRedirectAction?
When none of the specified pathRules orrouteRules match, the request is redirected to a URL specified by defaultUrlRedirect.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headerAction ↔ HttpHeaderAction?
Specifies changes to request and response headers that need to take effect for the selected backend service.
getter/setter pair
name ↔ String?
The name to which this PathMatcher is referred by theHostRule.
getter/setter pair
pathRules ↔ List<PathRule>?
The list of path rules.
getter/setter pair
routeRules ↔ List<HttpRouteRule>?
The list of HTTP route rules.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited