PathRule class

A path-matching rule for a URL.

If matched, will use the specifiedBackendService to handle the traffic arriving at this URL.

Constructors

PathRule({CustomErrorResponsePolicy? customErrorResponsePolicy, List<String>? paths, HttpRouteAction? routeAction, String? service, HttpRedirectAction? urlRedirect})
PathRule.fromJson(Map json_)

Properties

customErrorResponsePolicy ↔ CustomErrorResponsePolicy?
customErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceorBackendBucket responds with an error.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
paths ↔ List<String>?
The list of path patterns to match.
getter/setter pair
routeAction ↔ HttpRouteAction?
In response to a matching path, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
The full or partial URL of the backend service resource to which traffic is directed if this rule is matched.
getter/setter pair
urlRedirect ↔ HttpRedirectAction?
When a path pattern is matched, the request is redirected to a URL specified by urlRedirect.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited