subType property

String? subType
getter/setter pair

The maintenance type in which the zone is during the given window. Possible string values are:

  • "MAINTENANCE_SUBTYPE_UNSPECIFIED" : Default value.
  • "MAINTENANCE_TYPE_CUSTOMER_MAINTENANCE" : A dedicated window for customers to perform their own maintenance. This often runs concurrently with a DISRUPTIVE_UPGRADE.
  • "MAINTENANCE_TYPE_DISRUPTIVE_UPGRADE" : For disruptive updates, including host machine kernel or firmware upgrades.
  • "MAINTENANCE_TYPE_STABLE" : A post-maintenance window for customers to conduct final testing and performance validation before resuming full business operations.
  • "MAINTENANCE_TYPE_TRANSITION" : For preliminary, non-disruptive tasks such as key rotations.

Implementation

core.String? subType;