targetResource property
The target resource that the maintenance window is for. For example, "projects/my-project/zones/us-central1-a".
Implementation
core.String? targetResource;
The target resource that the maintenance window is for. For example, "projects/my-project/zones/us-central1-a".
core.String? targetResource;