PreservedState class

Preserved state for a given instance.

Properties

disks ↔ Map<String, PreservedStatePreservedDisk>?
Preserved disks defined for this instance. This map is keyed with the device names of the disks.
getter/setter pair
externalIPs ↔ Map<String, PreservedStatePreservedNetworkIp>?
Preserved external IPs defined for this instance. This map is keyed with the name of the network interface.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalIPs ↔ Map<String, PreservedStatePreservedNetworkIp>?
Preserved internal IPs defined for this instance. This map is keyed with the name of the network interface.
getter/setter pair
metadata ↔ Map<String, String>?
Preserved metadata defined for this instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited