Region class

Represents a Region resource.

A region is a geographical area where a resource is located.

For more information, readRegions and Zones.

Constructors

Region({String? creationTimestamp, DeprecationStatus? deprecated, String? description, String? id, String? kind, String? name, RegionQuotaStatusWarning? quotaStatusWarning, List<Quota>? quotas, String? selfLink, String? status, bool? supportsPzs, List<String>? zones})
Region.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
deprecated ↔ DeprecationStatus?
The deprecation status associated with this region.
getter/setter pair
description ↔ String?
Textual description of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
quotas ↔ List<Quota>?
Quotas assigned to this region.
getter/setter pair
quotaStatusWarning ↔ RegionQuotaStatusWarning?
Warning of fetching the quotas field for this region.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
status ↔ String?
Status of the region, either UP orDOWN.
getter/setter pair
supportsPzs ↔ bool?
Reserved for future use.
getter/setter pair
zones ↔ List<String>?
A list of zones available in this region, in the form of resource URLs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited