RegionBackendBucketsResource class

Constructors

RegionBackendBucketsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String project, String region, String backendBucket, {String? requestId, String? $fields}) Future<Operation>
Deletes the specified regional BackendBucket resource.
get(String project, String region, String backendBucket, {String? $fields}) Future<BackendBucket>
Returns the specified regional BackendBucket resource.
getIamPolicy(String project, String region, String resource, {int? optionsRequestedPolicyVersion, String? $fields}) Future<Policy>
Gets the access control policy for a resource.
insert(BackendBucket request, String project, String region, {String? requestId, String? $fields}) Future<Operation>
Creates a RegionBackendBucket in the specified project in the given scope using the parameters that are included in the request.
list(String project, String region, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<BackendBucketList>
Retrieves the list of BackendBucket resources available to the specified project in the given region.
listUsable(String project, String region, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<BackendBucketListUsable>
Retrieves a list of all usable backend buckets in the specified project in the given region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(BackendBucket request, String project, String region, String backendBucket, {String? requestId, String? $fields}) Future<Operation>
Updates the specified BackendBucket resource with the data included in the request.
setIamPolicy(RegionSetPolicyRequest request, String project, String region, String resource, {String? $fields}) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestPermissionsRequest request, String project, String region, String resource, {String? $fields}) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited