RegionCompositeHealthChecksResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
aggregatedList(String project, {String? filter, bool? includeAllScopes, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? serviceProjectNumber, String? $fields})
→ Future<CompositeHealthCheckAggregatedList>
-
Retrieves the list of all CompositeHealthCheck resources (all
regional) available to the specified project.
-
delete(String project, String region, String compositeHealthCheck, {String? requestId, String? $fields})
→ Future<Operation>
-
Deletes the specified CompositeHealthCheck in the given region
-
get(String project, String region, String compositeHealthCheck, {String? $fields})
→ Future<CompositeHealthCheck>
-
Returns the specified CompositeHealthCheck resource in the given region.
-
getHealth(String project, String region, String compositeHealthCheck, {String? $fields})
→ Future<CompositeHealthCheckHealth>
-
Gets the most recent health check results for this
regional CompositeHealthCheck.
-
insert(CompositeHealthCheck request, String project, String region, {String? requestId, String? $fields})
→ Future<Operation>
-
Create a CompositeHealthCheck in the specified project in the given region
using the parameters that are included in the request.
-
list(String project, String region, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields})
→ Future<CompositeHealthCheckList>
-
Lists the CompositeHealthChecks for a project in the given region.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(CompositeHealthCheck request, String project, String region, String compositeHealthCheck, {String? requestId, String? $fields})
→ Future<Operation>
-
Updates the specified regional CompositeHealthCheck resource
with the data included in the request.
-
testIamPermissions(TestPermissionsRequest request, String project, String region, String resource, {String? $fields})
→ Future<TestPermissionsResponse>
-
Returns permissions that a caller has on the specified resource.
-
toString()
→ String
-
A string representation of this object.
inherited