RegionInstanceGroupManagerResizeRequestsResource class

Constructors

RegionInstanceGroupManagerResizeRequestsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(String project, String region, String instanceGroupManager, String resizeRequest, {String? requestId, String? $fields}) Future<Operation>
Cancels the specified resize request. Cancelled resize request no longer waits for the resources to be provisioned.
delete(String project, String region, String instanceGroupManager, String resizeRequest, {String? requestId, String? $fields}) Future<Operation>
Deletes the specified, inactive resize request.
get(String project, String region, String instanceGroupManager, String resizeRequest, {String? $fields}) Future<InstanceGroupManagerResizeRequest>
Returns all of the details about the specified resize request.
insert(InstanceGroupManagerResizeRequest request, String project, String region, String instanceGroupManager, {String? requestId, String? $fields}) Future<Operation>
Creates a new Resize Request that starts provisioning VMs immediately or queues VM creation.
list(String project, String region, String instanceGroupManager, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<RegionInstanceGroupManagerResizeRequestsListResponse>
Retrieves a list of Resize Requests that are contained in the managed instance group.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited