RegionInstantSnapshotGroupsResource class

Constructors

RegionInstantSnapshotGroupsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String project, String region, String instantSnapshotGroup, {String? requestId, String? $fields}) Future<Operation>
deletes a Regional InstantSnapshotGroup resource
get(String project, String region, String instantSnapshotGroup, {String? $fields}) Future<InstantSnapshotGroup>
returns the specified InstantSnapshotGroup resource in the specified region.
getIamPolicy(String project, String region, String resource, {int? optionsRequestedPolicyVersion, String? $fields}) Future<Policy>
Gets the access control policy for a resource.
insert(InstantSnapshotGroup request, String project, String region, {String? requestId, String? sourceConsistencyGroup, String? $fields}) Future<Operation>
creates a Regional InstantSnapshotGroup resource
list(String project, String region, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<ListInstantSnapshotGroups>
retrieves the list of InstantSnapshotGroup resources contained within the specified region.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setIamPolicy(RegionSetPolicyRequest request, String project, String region, String resource, {String? $fields}) Future<Policy>
Sets the access control policy on the specified resource. Replaces any existing policy.
testIamPermissions(TestPermissionsRequest request, String project, String region, String resource, {String? $fields}) Future<TestPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited