ReliabilityRisk class

Represents a ReliabilityRisk resource.

Constructors

ReliabilityRisk({String? creationTimestamp, String? description, RiskDetails? details, String? id, String? kind, String? name, RiskRecommendation? recommendation, String? selfLink, String? selfLinkWithId})
ReliabilityRisk.fromJson(Map json_)

Properties

creationTimestamp String?
Creation timestamp in RFC3339 text format.
getter/setter pair
description String?
An optional textual description of the resource; provided when the resource is created.
getter/setter pair
details RiskDetails?
Details of the reliability risk resource
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier for the resource.
getter/setter pair
kind String?
Type of resource.
getter/setter pair
name String?
Name of the resource.
getter/setter pair
recommendation RiskRecommendation?
The recommendation to mitigate the risk.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId String?
Server-defined URL for this resource with the resource id.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited