ReliabilityRisksListResponse class
Response message for the List method of ReliabilityRisksService.
Constructors
-
ReliabilityRisksListResponse({String? etag, String? id, List<
ReliabilityRisk> ? items, String? nextPageToken, String? selfLink, List<String> ? unreachables, ReliabilityRisksListResponseWarning? warning}) - ReliabilityRisksListResponse.fromJson(Map json_)
Properties
- etag ↔ String?
-
An ETag of the resource.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier for the resource; defined by the server.
getter/setter pair
-
items
↔ List<
ReliabilityRisk> ? -
A list of ReliabilityRisk resources.
getter/setter pair
- nextPageToken ↔ String?
-
This token allows you to get the next page of results for
list requests.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink ↔ String?
-
Server-defined URL for this resource.
getter/setter pair
-
unreachables
↔ List<
String> ? -
Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
getter/setter pair
- warning ↔ ReliabilityRisksListResponseWarning?
-
Informational warning message.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited