ReliabilityRisksListResponseWarningData class

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
A key that provides more detail on the warning being returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
A warning data value corresponding to the key.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited