Reservation class

Represents a reservation resource.

A reservation ensures that capacity is held in a specific zone even if the reserved VMs are not running. For more information, read Reserving zonal resources.

Constructors

Reservation({ReservationAdvancedDeploymentControl? advancedDeploymentControl, AllocationAggregateReservation? aggregateReservation, String? commitment, String? creationTimestamp, Duration? deleteAfterDuration, String? deleteAtTime, String? deploymentType, String? description, bool? enableEmergentMaintenance, String? id, String? kind, List<String>? linkedCommitments, String? name, AllocationReservationSharingPolicy? reservationSharingPolicy, Map<String, String>? resourcePolicies, AllocationResourceStatus? resourceStatus, bool? satisfiesPzs, String? schedulingType, String? selfLink, ShareSettings? shareSettings, AllocationSpecificSKUReservation? specificReservation, bool? specificReservationRequired, String? status, String? zone})
Reservation.fromJson(Map json_)

Properties

advancedDeploymentControl ↔ ReservationAdvancedDeploymentControl?
Advanced control for cluster management, applicable only to DENSE deployment type reservations.
getter/setter pair
aggregateReservation ↔ AllocationAggregateReservation?
Reservation for aggregated resources, providing shape flexibility.
getter/setter pair
commitment ↔ String?
Full or partial URL to a parent commitment.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp in RFC3339 text format.
getter/setter pair
deleteAfterDuration ↔ Duration?
Duration time relative to reservation creation when Compute Engine will automatically delete this resource.
getter/setter pair
deleteAtTime ↔ String?
Absolute time in future when the reservation will be auto-deleted by Compute Engine.
getter/setter pair
deploymentType ↔ String?
Specifies the deployment strategy for this reservation. Possible string values are:
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
enableEmergentMaintenance ↔ bool?
Indicates whether Compute Engine allows unplanned maintenance for your VMs; for example, to fix hardware errors.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
linkedCommitments ↔ List<String>?
Full or partial URL to parent commitments.
getter/setter pair
name ↔ String?
The name of the resource, provided by the client when initially creating the resource.
getter/setter pair
reservationSharingPolicy ↔ AllocationReservationSharingPolicy?
Specify the reservation sharing policy.
getter/setter pair
resourcePolicies ↔ Map<String, String>?
Resource policies to be added to this reservation.
getter/setter pair
resourceStatus ↔ AllocationResourceStatus?
Status information for Reservation resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
schedulingType ↔ String?
The type of maintenance for the reservation. Possible string values are:
getter/setter pair
Server-defined fully-qualified URL for this resource.
getter/setter pair
shareSettings ↔ ShareSettings?
Specify share-settings to create a shared reservation.
getter/setter pair
specificReservation ↔ AllocationSpecificSKUReservation?
Reservation for instances with specific machine shapes.
getter/setter pair
specificReservationRequired ↔ bool?
Indicates whether the reservation can be consumed by VMs with affinity for "any" reservation.
getter/setter pair
status ↔ String?
The status of the reservation.
getter/setter pair
zone ↔ String?
Zone in which the reservation resides.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited