earlyAccessMaintenance property

String? earlyAccessMaintenance
getter/setter pair

Indicates the early access maintenance for the reservation. If this field is absent or set to NO_EARLY_ACCESS, the reservation is not enrolled in early access maintenance and the standard notice applies. Possible string values are:

  • "NO_EARLY_ACCESS" : No early access.
  • "WAVE1" : Wave 1: Fastest notification period
  • "WAVE2" : Wave 2: Medium notification period

Implementation

core.String? earlyAccessMaintenance;