params property
Input only.
Additional params passed with the request, but not persisted as part of resource payload.
Implementation
ReservationParams? params;
Input only.
Additional params passed with the request, but not persisted as part of resource payload.
ReservationParams? params;