resourceMetadata property

ResourceMetadata? resourceMetadata
getter/setter pair

Contains standard resource metadata for an Allocation resource.

It is populated for each instance of the Allocation resource, and includes the api_version the instance was retrieved through, and its canonical resource_type name.

Output only.

Implementation

ResourceMetadata? resourceMetadata;