ReservationBlockPhysicalTopology class

Properties

block ↔ String?
The hash of the capacity block within the cluster.
getter/setter pair
cluster ↔ String?
The cluster name of the reservation block.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instances ↔ List<ReservationBlockPhysicalTopologyInstance>?
The detailed instances information for a given Block
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited