ReservationSlot class

Represents a reservation slot resource.

Constructors

ReservationSlot({String? creationTimestamp, String? id, String? kind, String? name, ReservationSlotPhysicalTopology? physicalTopology, String? selfLink, String? selfLinkWithId, ShareSettings? shareSettings, String? state, ReservationSlotStatus? status, String? zone})
ReservationSlot.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
The creation timestamp, formatted asRFC3339 text.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for this resource.
getter/setter pair
kind ↔ String?
The type of resource.
getter/setter pair
name ↔ String?
The name of the reservation slot.
getter/setter pair
physicalTopology ↔ HostPhysicalTopology?
The physical topology of the reservation slot.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
A server-defined fully-qualified URL for this resource.
getter/setter pair
selfLinkWithId ↔ String?
A server-defined URL for this resource with the resource ID.
getter/setter pair
shareSettings ↔ ShareSettings?
Specify share settings to create a shared slot.
getter/setter pair
state ↔ String?
The state of the reservation slot.
getter/setter pair
status ↔ ReservationSlotStatus?
The status of the reservation slot.
getter/setter pair
zone ↔ String?
The zone in which the reservation slot resides.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited