ReservationSubBlocksReportFaultyRequest class

Properties

disruptionSchedule ↔ String?
The disruption schedule for the subBlock. Possible string values are:
getter/setter pair
failureComponent ↔ String?
The component that experienced the fault. Possible string values are:
getter/setter pair
faultReasons ↔ List<ReservationSubBlocksReportFaultyRequestFaultReason>?
The reasons for the fault experienced with the subBlock.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited