ReservationSubBlocksReportFaultyRequestFaultReason class

The reason for the fault experienced with the subBlock.

Properties

behavior ↔ String?
The behavior of the fault experienced with the subBlock. Possible string values are:
getter/setter pair
description ↔ String?
The description of the fault experienced with the subBlock.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited