ResourceMetadata class

Standardized resource metadata common to all compute resources.

Constructors

ResourceMetadata({String? apiVersion, String? resourceType})
ResourceMetadata.fromJson(Map json_)

Properties

apiVersion String?
The version of the API interface that this resource was retrieved through. For example, "2025-01-01" or "2025-01-01-preview".
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
resourceType String?
The canonical resource type name in the format of a resource type as defined by [AIP-123](https://google.aip.dev/123). For example, "compute.googleapis.com/Instance".
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited