resourceType property
The canonical resource type name in the format of a resource type
as defined by [AIP-123](https://google.aip.dev/123).
For example, "compute.googleapis.com/Instance".
Implementation
core.String? resourceType;
The canonical resource type name in the format of a resource type
as defined by [AIP-123](https://google.aip.dev/123).
For example, "compute.googleapis.com/Instance".
core.String? resourceType;