ResourcePolicyInstanceSchedulePolicy class

An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.

Properties

expirationTime ↔ String?
The expiration time of the schedule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The start time of the schedule.
getter/setter pair
timeZone ↔ String?
Specifies the time zone to be used in interpreting Schedule.schedule. The value of this field must be a time zone name from the tz database: https://wikipedia.org/wiki/Tz_database.
getter/setter pair
vmStartSchedule ↔ ResourcePolicyInstanceSchedulePolicySchedule?
Specifies the schedule for starting instances.
getter/setter pair
vmStopSchedule ↔ ResourcePolicyInstanceSchedulePolicySchedule?
Specifies the schedule for stopping instances.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited