ResourcePolicyResourceStatus class

Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification.

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceSchedulePolicy ↔ ResourcePolicyResourceStatusInstanceSchedulePolicyStatus?
Specifies a set of output values reffering to the instance_schedule_policy system status. This field should have the same name as corresponding policy field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited