ResourcePolicyResourceStatusInstanceSchedulePolicyStatus class

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastRunStartTime ↔ String?
The last time the schedule successfully ran. The timestamp is an RFC3339 string.
getter/setter pair
nextRunStartTime ↔ String?
The next time the schedule is planned to run. The actual time might be slightly different. The timestamp is an RFC3339 string.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited