ResourcePolicyWorkloadPolicy class

Represents the workload policy.

Constructors

ResourcePolicyWorkloadPolicy({String? acceleratorTopology, String? acceleratorTopologyMode, String? maxTopologyDistance, String? type})
ResourcePolicyWorkloadPolicy.fromJson(Map json_)

Properties

acceleratorTopology ↔ String?
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
getter/setter pair
acceleratorTopologyMode ↔ String?
Specifies the connection mode for the accelerator topology.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxTopologyDistance ↔ String?
Specifies the maximum distance between instances. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Specifies the intent of the instance placement in the MIG. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited