ResourceStatusEffectiveInstanceMetadata class

Effective values of predefined metadata keys for an instance.

Constructors

ResourceStatusEffectiveInstanceMetadata({bool? blockProjectSshKeysMetadataValue, bool? enableGuestAttributesMetadataValue, bool? enableOsInventoryMetadataValue, bool? enableOsconfigMetadataValue, bool? enableOsloginMetadataValue, bool? gceContainerDeclarationMetadataValue, bool? serialPortEnableMetadataValue, bool? serialPortLoggingEnableMetadataValue, String? vmDnsSettingMetadataValue})
ResourceStatusEffectiveInstanceMetadata.fromJson(Map json_)

Properties

blockProjectSshKeysMetadataValue ↔ bool?
Effective block-project-ssh-keys value at Instance level.
getter/setter pair
enableGuestAttributesMetadataValue ↔ bool?
Effective enable-guest-attributes value at Instance level.
getter/setter pair
enableOsconfigMetadataValue ↔ bool?
Effective enable-osconfig value at Instance level.
getter/setter pair
enableOsInventoryMetadataValue ↔ bool?
Effective enable-os-inventory value at Instance level.
getter/setter pair
enableOsloginMetadataValue ↔ bool?
Effective enable-oslogin value at Instance level.
getter/setter pair
gceContainerDeclarationMetadataValue ↔ bool?
Effective gce-container-declaration value at Instance level.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serialPortEnableMetadataValue ↔ bool?
Effective serial-port-enable value at Instance level.
getter/setter pair
serialPortLoggingEnableMetadataValue ↔ bool?
Effective serial-port-logging-enable value at Instance level.
getter/setter pair
vmDnsSettingMetadataValue ↔ String?
Effective VM DNS setting at Instance level.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited