ResourceStatusPhysicalHostTopology class

Represents the physical host topology of the host on which the VM is running.

Properties

additionalAttributes ↔ ResourceStatusPhysicalHostTopologyAdditionalAttributes?
Additional location information of the running instance.
getter/setter pair
block ↔ String?
The ID of the block in which the running instance is located.
getter/setter pair
cluster ↔ String?
The global name of the Compute Engine cluster where the running instance is located.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subblock ↔ String?
The ID of the sub-block in which the running instance is located.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited