ResourceStatusPhysicalHostTopologyAdditionalAttributes class
Additional location information of the running instance.
Constructors
-
ResourceStatusPhysicalHostTopologyAdditionalAttributes({Map<
String, String> ? acceleratorTopologyIds}) - ResourceStatusPhysicalHostTopologyAdditionalAttributes.fromJson(Map json_)
Properties
-
acceleratorTopologyIds
↔ Map<
String, String> ? -
The IDs of the accelerator topologies the instance belongs to.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited