ResourceStatusReservationConsumptionInfo class
Reservation consumption information that the instance is consuming from.
Constructors
- ResourceStatusReservationConsumptionInfo({String? consumedReservation, String? consumedReservationBlock, String? consumedReservationSubBlock})
- ResourceStatusReservationConsumptionInfo.fromJson(Map json_)
Properties
- consumedReservation ↔ String?
-
The full resource name of the reservation that this
instance is consuming from.
getter/setter pair
- consumedReservationBlock ↔ String?
-
The full resource name of the reservation block that this
instance is consuming from.
getter/setter pair
- consumedReservationSubBlock ↔ String?
-
The full resource name of the reservation sub-block that
this instance is consuming from.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited