consumedReservationBlock property
The full resource name of the reservation block that this instance is consuming from.
Output only.
Implementation
core.String? consumedReservationBlock;
The full resource name of the reservation block that this instance is consuming from.
Output only.
core.String? consumedReservationBlock;