gracefulShutdownTimestamp property
Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.
Output only.
Implementation
core.String? gracefulShutdownTimestamp;
Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.
Output only.
core.String? gracefulShutdownTimestamp;