terminationTimestamp property
Time in future when the instance will be terminated inRFC3339 text format.
Implementation
core.String? terminationTimestamp;
Time in future when the instance will be terminated inRFC3339 text format.
core.String? terminationTimestamp;