ResourceStatusShutdownDetails class

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled.

Constructors

ResourceStatusShutdownDetails({Duration? maxDuration, String? requestTimestamp, String? stopState, String? targetState})
ResourceStatusShutdownDetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxDuration ↔ Duration?
The duration for graceful shutdown.
getter/setter pair
requestTimestamp ↔ String?
Past timestamp indicating the beginning of current stopState in RFC3339 text format.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stopState ↔ String?
Current stopping state of the instance. Possible string values are:
getter/setter pair
targetState ↔ String?
Target instance state. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited