RiskRecommendation class

Recommendation for mitigating a reliability risk, including a reference URL.

Constructors

RiskRecommendation({String? content, String? referenceUrl})
RiskRecommendation.fromJson(Map json_)

Properties

content String?
Mitigation guide for the risk.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
referenceUrl String?
URL referencing a more detailed mitigation guide.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited