Rollout class

Rollout resource.

A Rollout is a specific instance of a RolloutPlan.

It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.

Constructors

Rollout({String? cancellationTime, String? completionTime, String? creationTimestamp, String? currentWaveNumber, String? description, String? etag, String? id, String? kind, String? name, String? pauseTime, String? resumeTime, RolloutRolloutEntity? rolloutEntity, String? rolloutPlan, String? selfLink, String? selfLinkWithId, String? state, List<RolloutWaveDetails>? waveDetails})
Rollout.fromJson(Map json_)

Properties

cancellationTime String?
The timestamp at which the Rollout was cancelled.
getter/setter pair
completionTime String?
The timestamp at which the Rollout was completed.
getter/setter pair
creationTimestamp String?
Creation timestamp inRFC3339 text format.
getter/setter pair
currentWaveNumber String?
The number of the currently running wave. Ex.
getter/setter pair
description String?
An optional description of this resource.
getter/setter pair
etag String?
etag of the Rollout Ex.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier for the resource.
getter/setter pair
kind String?
Type of the resource.
getter/setter pair
name String?
Name of the resource.
getter/setter pair
pauseTime String?
The timestamp at which the Rollout was paused.
getter/setter pair
resumeTime String?
The timestamp at which the Rollout was resumed.
getter/setter pair
rolloutEntity RolloutRolloutEntity?
The resource being rolled out.
getter/setter pair
rolloutPlan String?
Rollout Plan used to model the Rollout. Ex.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Server-defined fully-qualified URL for this resource.
getter/setter pair
selfLinkWithId String?
Server-defined URL for this resource's resource id.
getter/setter pair
state String?
The current state of the Rollout.
getter/setter pair
waveDetails List<RolloutWaveDetails>?
Details about each wave of the rollout.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited