RolloutPlan class

RolloutPlan resource.

A RolloutPlan is the customer-defined strategy to divide a large-scale change into smaller increments, referred to as "waves".

Each wave targets a specific portion of the overall affected area and defines criteria that must be met before progressing to the subsequent wave.

Constructors

RolloutPlan({String? creationTimestamp, String? description, String? id, String? kind, String? locationScope, String? name, String? selfLink, String? selfLinkWithId, List<RolloutPlanWave>? waves})
RolloutPlan.fromJson(Map json_)

Properties

creationTimestamp String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description String?
An optional description of this resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier for the resource.
getter/setter pair
kind String?
Type of the resource.
getter/setter pair
locationScope String?
The location scope of the rollout plan.
getter/setter pair
name String?
Name of the resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
Server-defined fully-qualified URL for this resource.
getter/setter pair
selfLinkWithId String?
Server-defined URL for this resource's resource id.
getter/setter pair
waves List<RolloutPlanWave>?
The waves included in this rollout plan.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited