RolloutPlanWave class

A single wave in a rollout plan.

Constructors

RolloutPlanWave({String? displayName, String? number, RolloutPlanWaveOrchestrationOptions? orchestrationOptions, List<RolloutPlanWaveSelector>? selectors, RolloutPlanWaveValidation? validation})
RolloutPlanWave.fromJson(Map json_)

Properties

displayName String?
The display name of this wave of the rollout plan.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
number String?
The wave number.
getter/setter pair
orchestrationOptions RolloutPlanWaveOrchestrationOptions?
The orchestration options for this wave.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectors List<RolloutPlanWaveSelector>?
The selectors for this wave.
getter/setter pair
validation RolloutPlanWaveValidation?
The validation to be performed at the end of this wave.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited