duration property
The duration of the delay, if any, to be added between batches of projects.
A zero duration corresponds to no delay.
Optional.
Implementation
core.String? duration;
The duration of the delay, if any, to be added between batches of projects.
A zero duration corresponds to no delay.
Optional.
core.String? duration;