type property

String? type
getter/setter pair

Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration.

Must be set to TYPE_UNSPECIFIED if no delay is to be added.

Optional. Possible string values are:

  • "TYPE_MINIMUM" : The total processing time for each batch of projects will be padded if needed to meet the specified delay duration.
  • "TYPE_OFFSET" : The specified delay will directly be added after each batch of projects as specified by the delimiter.
  • "TYPE_UNSPECIFIED" : No delay will be added between batches of projects. Processing will continue with the next batch as soon as the previous batch of LROs is done.

Implementation

core.String? type;