RolloutPlanWaveSelector class
A selector which specifies what resource(s) are included in a given wave.
Constructors
- RolloutPlanWaveSelector({RolloutPlanWaveSelectorLocationSelector? locationSelector, RolloutPlanWaveSelectorResourceHierarchySelector? resourceHierarchySelector})
- RolloutPlanWaveSelector.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- locationSelector ↔ RolloutPlanWaveSelectorLocationSelector?
-
Roll out to resources by Cloud locations.
getter/setter pair
- resourceHierarchySelector ↔ RolloutPlanWaveSelectorResourceHierarchySelector?
-
Roll out to resources by Cloud Resource Manager resource hierarchy.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited