RolloutPlanWaveSelectorResourceHierarchySelector class

Roll out to resources by Cloud Resource Manager resource hierarchy nodes such as projects, folders, orgs.

Constructors

RolloutPlanWaveSelectorResourceHierarchySelector({List<String>? includedFolders, List<String>? includedOrganizations, List<String>? includedProjects})
RolloutPlanWaveSelectorResourceHierarchySelector.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
includedFolders List<String>?
Format: "folders/{folder_id}"
getter/setter pair
includedOrganizations List<String>?
Format: "organizations/{organization_id}"
getter/setter pair
includedProjects List<String>?
Format: "projects/{project_id}"
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited