RolloutPlanWaveValidation class

The validation to be performed before progressing to the next wave.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeBasedValidationMetadata RolloutPlanWaveValidationTimeBasedValidationMetadata?
Metadata required if type = "time".
getter/setter pair
type String?
The type of the validation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited