RolloutPlansResource class

Constructors

RolloutPlansResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String project, String rolloutPlan, {String? requestId, String? $fields}) Future<Operation>
Deletes a RolloutPlan.
get(String project, String rolloutPlan, {String? $fields}) Future<RolloutPlan>
Gets details of a single project-scoped RolloutPlan.
insert(RolloutPlan request, String project, {String? requestId, String? $fields}) Future<Operation>
Creates a new RolloutPlan in a given project and location.
list(String project, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<RolloutPlansListResponse>
Lists RolloutPlans in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited