RolloutRolloutEntity class

Specifications of the resource to roll out.

Properties

hashCode int
The hash code for this object.
no setterinherited
orchestratedEntity RolloutRolloutEntityOrchestratedEntity?
Entity details for products using the Orchestrated Integration model.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited