orchestratedEntity property
Entity details for products using the Orchestrated Integration model.
Optional.
Implementation
RolloutRolloutEntityOrchestratedEntity? orchestratedEntity;
Entity details for products using the Orchestrated Integration model.
Optional.
RolloutRolloutEntityOrchestratedEntity? orchestratedEntity;