orchestrationSource property

String? orchestrationSource
getter/setter pair

Fully qualified resource name of the resource which contains the source of truth of the configuration being rolled out across locations/projects.

For example, in the case of a global Rollout which is applied across regions, this contains the name of the global resource created by the user which contains a payload for a resource that is orchestrated across regions. This follows the following format: //.googleapis.com/projects//locations/global// e.g. //osconfig.googleapis.com/projects/1/locations/global/policyOrchestrators/po1

Required.

Implementation

core.String? orchestrationSource;