RolloutWaveDetails class

Additional metadata about the status of each wave provided by the server.

Constructors

RolloutWaveDetails({RolloutWaveDetailsOrchestratedWaveDetails? orchestratedWaveDetails, String? waveDisplayName, String? waveNumber})
RolloutWaveDetails.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
orchestratedWaveDetails RolloutWaveDetailsOrchestratedWaveDetails?
Additional details of the wave for products using the Orchestrated Integration model.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
waveDisplayName String?
Wave name. Ex.
getter/setter pair
waveNumber String?
System generated number for the wave.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited