RolloutsResource class

Constructors

RolloutsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

advance(String project, String rollout, {String? currentWaveNumber, String? requestId, String? $fields}) Future<Operation>
Advances a Rollout to the next wave, or completes it if no waves remain.
cancel(String project, String rollout, {String? requestId, bool? rollback, String? $fields}) Future<Operation>
Cancels a Rollout.
delete(String project, String rollout, {String? requestId, String? $fields}) Future<Operation>
Deletes a Rollout.
get(String project, String rollout, {String? $fields}) Future<Rollout>
Gets details of a single project-scoped Rollout.
list(String project, {String? filter, int? maxResults, String? orderBy, String? pageToken, bool? returnPartialSuccess, String? $fields}) Future<RolloutsListResponse>
Lists Rollouts in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(String project, String rollout, {String? etag, String? requestId, String? $fields}) Future<Operation>
Pauses a Rollout.
resume(String project, String rollout, {String? etag, String? requestId, String? $fields}) Future<Operation>
Resumes a Rollout.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited