RoutePolicy class

Constructors

RoutePolicy({String? description, String? fingerprint, String? name, List<RoutePolicyPolicyTerm>? terms, String? type})
RoutePolicy.fromJson(Map json_)

Properties

description ↔ String?
An optional description of route policy.
getter/setter pair
fingerprint ↔ String?
A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terms ↔ List<RoutePolicyPolicyTerm>?
List of terms (the order in the list is not important, they are evaluated in order of priority).
getter/setter pair
type ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited