Router class

Represents a Cloud Router resource.

For more information about Cloud Router, read theCloud Router overview.

Constructors

Router({RouterBgp? bgp, List<RouterBgpPeer>? bgpPeers, String? creationTimestamp, String? description, bool? encryptedInterconnectRouter, String? id, List<RouterInterface>? interfaces, String? kind, List<RouterMd5AuthenticationKey>? md5AuthenticationKeys, String? name, List<RouterNat>? nats, String? network, RouterParams? params, String? region, String? selfLink})
Router.fromJson(Map json_)

Properties

bgp ↔ RouterBgp?
BGP information specific to this router.
getter/setter pair
bgpPeers ↔ List<RouterBgpPeer>?
BGP information that must be configured into the routing stack to establish BGP peering.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
encryptedInterconnectRouter ↔ bool?
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
interfaces ↔ List<RouterInterface>?
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
getter/setter pair
kind ↔ String?
Type of resource.
getter/setter pair
md5AuthenticationKeys ↔ List<RouterMd5AuthenticationKey>?
Keys used for MD5 authentication.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
nats ↔ List<RouterNat>?
A list of NAT services created in this router.
getter/setter pair
network ↔ String?
URI of the network to which this router belongs.
getter/setter pair
params ↔ RouterParams?
Input only.
getter/setter pair
region ↔ String?
URI of the region where the router resides. You must specify this field as part of the HTTP request URL.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited