RouterBgp class

Constructors

RouterBgp({String? advertiseMode, List<String>? advertisedGroups, List<RouterAdvertisedIpRange>? advertisedIpRanges, int? asn, String? identifierRange, int? keepaliveInterval})
RouterBgp.fromJson(Map json_)

Properties

advertisedGroups ↔ List<String>?
User-specified list of prefix groups to advertise in custom mode.
getter/setter pair
advertisedIpRanges ↔ List<RouterAdvertisedIpRange>?
User-specified list of individual IP ranges to advertise in custom mode.
getter/setter pair
advertiseMode ↔ String?
User-specified flag to indicate which mode to use for advertisement.
getter/setter pair
asn ↔ int?
Local BGP Autonomous System Number (ASN).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identifierRange ↔ String?
Explicitly specifies a range of valid BGP Identifiers for this Router.
getter/setter pair
keepaliveInterval ↔ int?
The interval in seconds between BGP keepalive messages that are sent to the peer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited