RouterBgpPeer class

Constructors

RouterBgpPeer({String? advertiseMode, List<String>? advertisedGroups, List<RouterAdvertisedIpRange>? advertisedIpRanges, int? advertisedRoutePriority, RouterBgpPeerBfd? bfd, List<RouterBgpPeerCustomLearnedIpRange>? customLearnedIpRanges, int? customLearnedRoutePriority, String? enable, bool? enableIpv4, bool? enableIpv6, List<String>? exportPolicies, List<String>? importPolicies, String? interfaceName, String? ipAddress, String? ipv4NexthopAddress, String? ipv6NexthopAddress, String? managementType, String? md5AuthenticationKeyName, String? name, int? peerAsn, String? peerIpAddress, String? peerIpv4NexthopAddress, String? peerIpv6NexthopAddress, String? routerApplianceInstance})
RouterBgpPeer.fromJson(Map json_)

Properties

advertisedGroups ↔ List<String>?
User-specified list of prefix groups to advertise in custom mode, which currently supports the following option: - ALL_SUBNETS: Advertises all of the router's own VPC subnets.
getter/setter pair
advertisedIpRanges ↔ List<RouterAdvertisedIpRange>?
User-specified list of individual IP ranges to advertise in custom mode.
getter/setter pair
advertisedRoutePriority ↔ int?
The priority of routes advertised to this BGP peer.
getter/setter pair
advertiseMode ↔ String?
User-specified flag to indicate which mode to use for advertisement. Possible string values are:
getter/setter pair
bfd ↔ RouterBgpPeerBfd?
BFD configuration for the BGP peering.
getter/setter pair
customLearnedIpRanges ↔ List<RouterBgpPeerCustomLearnedIpRange>?
A list of user-defined custom learned route IP address ranges for a BGP session.
getter/setter pair
customLearnedRoutePriority ↔ int?
The user-defined custom learned route priority for a BGP session.
getter/setter pair
enable ↔ String?
The status of the BGP peer connection.
getter/setter pair
enableIpv4 ↔ bool?
Enable IPv4 traffic over BGP Peer.
getter/setter pair
enableIpv6 ↔ bool?
Enable IPv6 traffic over BGP Peer.
getter/setter pair
exportPolicies ↔ List<String>?
List of export policies applied to this peer, in the order they must be evaluated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importPolicies ↔ List<String>?
List of import policies applied to this peer, in the order they must be evaluated.
getter/setter pair
interfaceName ↔ String?
Name of the interface the BGP peer is associated with.
getter/setter pair
ipAddress ↔ String?
IP address of the interface inside Google Cloud Platform.
getter/setter pair
ipv4NexthopAddress ↔ String?
IPv4 address of the interface inside Google Cloud Platform.
getter/setter pair
ipv6NexthopAddress ↔ String?
IPv6 address of the interface inside Google Cloud Platform.
getter/setter pair
managementType ↔ String?
The resource that configures and manages this BGP peer.
getter/setter pair
md5AuthenticationKeyName ↔ String?
Present if MD5 authentication is enabled for the peering.
getter/setter pair
name ↔ String?
Name of this BGP peer.
getter/setter pair
peerAsn ↔ int?
Peer BGP Autonomous System Number (ASN).
getter/setter pair
peerIpAddress ↔ String?
IP address of the BGP interface outside Google Cloud Platform.
getter/setter pair
peerIpv4NexthopAddress ↔ String?
IPv4 address of the BGP interface outside Google Cloud Platform.
getter/setter pair
peerIpv6NexthopAddress ↔ String?
IPv6 address of the BGP interface outside Google Cloud Platform.
getter/setter pair
routerApplianceInstance ↔ String?
URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited