RouterInterface class

Constructors

RouterInterface({String? ipRange, String? ipVersion, String? linkedInterconnectAttachment, String? linkedVpnTunnel, String? managementType, String? name, String? privateIpAddress, String? redundantInterface, String? subnetwork})
RouterInterface.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipRange ↔ String?
IP address and range of the interface.
getter/setter pair
ipVersion ↔ String?
IP version of this interface. Possible string values are:
getter/setter pair
linkedInterconnectAttachment ↔ String?
URI of the linked Interconnect attachment.
getter/setter pair
linkedVpnTunnel ↔ String?
URI of the linked VPN tunnel, which must be in the same region as the router.
getter/setter pair
managementType ↔ String?
The resource that configures and manages this interface.
getter/setter pair
name ↔ String?
Name of this interface entry. The name must be 1-63 characters long, and comply withRFC1035.
getter/setter pair
privateIpAddress ↔ String?
The regional private internal IP address that is used to establish BGP sessions to a VM instance acting as a third-party Router Appliance, such as a Next Gen Firewall, a Virtual Router, or an SD-WAN VM.
getter/setter pair
redundantInterface ↔ String?
Name of the interface that will be redundant with the current interface you are creating.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetwork ↔ String?
The URI of the subnetwork resource that this interface belongs to, which must be in the same region as the Cloud Router. When you establish a BGP session to a VM instance using this interface, the VM instance must belong to the same subnetwork as the subnetwork specified here.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited