RouterStatus class

Constructors

RouterStatus({List<Route>? bestRoutes, List<Route>? bestRoutesForRouter, List<RouterStatusBgpPeerStatus>? bgpPeerStatus, List<RouterStatusNatStatus>? natStatus, String? nccGateway, String? network})
RouterStatus.fromJson(Map json_)

Properties

bestRoutes ↔ List<Route>?
A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
getter/setter pair
bestRoutesForRouter ↔ List<Route>?
A list of the best BGP routes learned by this Cloud Router.
getter/setter pair
bgpPeerStatus ↔ List<RouterStatusBgpPeerStatus>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
natStatus ↔ List<RouterStatusNatStatus>?
getter/setter pair
nccGateway ↔ String?
URI of the ncc_gateway to which this router associated.
getter/setter pair
network ↔ String?
URI of the network to which this router belongs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited