RouterStatusBgpPeerStatus class

Constructors

RouterStatusBgpPeerStatus({List<Route>? advertisedRoutes, BfdStatus? bfdStatus, bool? enableIpv4, bool? enableIpv6, String? ipAddress, String? ipv4NexthopAddress, String? ipv6NexthopAddress, String? linkedVpnTunnel, bool? md5AuthEnabled, String? name, int? numLearnedRoutes, String? peerIpAddress, String? peerIpv4NexthopAddress, String? peerIpv6NexthopAddress, String? routerApplianceInstance, String? state, String? status, String? statusReason, String? uptime, String? uptimeSeconds})
RouterStatusBgpPeerStatus.fromJson(Map json_)

Properties

advertisedRoutes ↔ List<Route>?
Routes that were advertised to the remote BGP peer
getter/setter pair
bfdStatus ↔ BfdStatus?
getter/setter pair
enableIpv4 ↔ bool?
Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4.
getter/setter pair
enableIpv6 ↔ bool?
Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String?
IP address of the local BGP interface.
getter/setter pair
ipv4NexthopAddress ↔ String?
IPv4 address of the local BGP interface.
getter/setter pair
ipv6NexthopAddress ↔ String?
IPv6 address of the local BGP interface.
getter/setter pair
linkedVpnTunnel ↔ String?
URL of the VPN tunnel that this BGP peer controls.
getter/setter pair
md5AuthEnabled ↔ bool?
Informs whether MD5 authentication is enabled on this BGP peer.
getter/setter pair
name ↔ String?
Name of this BGP peer.
getter/setter pair
numLearnedRoutes ↔ int?
Number of routes learned from the remote BGP Peer.
getter/setter pair
peerIpAddress ↔ String?
IP address of the remote BGP interface.
getter/setter pair
peerIpv4NexthopAddress ↔ String?
IPv4 address of the remote BGP interface.
getter/setter pair
peerIpv6NexthopAddress ↔ String?
IPv6 address of the remote BGP interface.
getter/setter pair
routerApplianceInstance ↔ String?
URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the BGP session.
getter/setter pair
status ↔ String?
Status of the BGP peer: {UP, DOWN}
getter/setter pair
statusReason ↔ String?
Indicates why particular status was returned. Possible string values are:
getter/setter pair
uptime ↔ String?
Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds
getter/setter pair
uptimeSeconds ↔ String?
Time this session has been up, in seconds. Format: 145
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited