RouterStatusNatStatusNatRuleStatus class

Status of a NAT Rule contained in this NAT.

Constructors

RouterStatusNatStatusNatRuleStatus({List<String>? activeNatIps, List<String>? drainNatIps, int? minExtraIpsNeeded, int? numVmEndpointsWithNatMappings, int? ruleNumber})
RouterStatusNatStatusNatRuleStatus.fromJson(Map json_)

Properties

activeNatIps ↔ List<String>?
A list of active IPs for NAT. Example: ["1.1.1.1", "179.12.26.133"].
getter/setter pair
drainNatIps ↔ List<String>?
A list of IPs for NAT that are in drain mode. Example: ["1.1.1.1", "179.12.26.133"].
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minExtraIpsNeeded ↔ int?
The number of extra IPs to allocate.
getter/setter pair
numVmEndpointsWithNatMappings ↔ int?
Number of VM endpoints (i.e., NICs) that have NAT Mappings from this NAT Rule.
getter/setter pair
ruleNumber ↔ int?
Rule number of the rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited