SSLHealthCheck class

Constructors

SSLHealthCheck({int? port, String? portName, String? portSpecification, String? proxyHeader, String? request, String? response})
SSLHealthCheck.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
port ↔ int?
The TCP port number to which the health check prober sends packets.
getter/setter pair
portName ↔ String?
Not supported.
getter/setter pair
portSpecification ↔ String?
Specifies how a port is selected for health checking.
getter/setter pair
proxyHeader ↔ String?
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
getter/setter pair
request ↔ String?
Instructs the health check prober to send this exact ASCII string, up to 1024 bytes in length, after establishing the TCP connection and SSL handshake.
getter/setter pair
response ↔ String?
Creates a content-based SSL health check.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited