SavedDisk class

An instance-attached disk resource.

Constructors

SavedDisk({String? architecture, String? kind, String? sourceDisk, String? storageBytes, String? storageBytesStatus})
SavedDisk.fromJson(Map json_)

Properties

architecture ↔ String?
The architecture of the attached disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Type of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDisk ↔ String?
Specifies a URL of the disk attached to the source instance.
getter/setter pair
storageBytes ↔ String?
Size of the individual disk snapshot used by this machine image.
getter/setter pair
storageBytesStatus ↔ String?
An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited