ScalingScheduleStatus class

Constructors

ScalingScheduleStatus({String? lastStartTime, String? nextStartTime, String? state})
ScalingScheduleStatus.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastStartTime ↔ String?
The last time the scaling schedule became active. Note: this is a timestamp when a schedule actually became active, not when it was planned to do so. The timestamp is in RFC3339 text format.
getter/setter pair
nextStartTime ↔ String?
The next time the scaling schedule is to become active. Note: this is a timestamp when a schedule is planned to run, but the actual time might be slightly different. The timestamp is in RFC3339 text format.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of a scaling schedule.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited