Scheduling class

Sets the scheduling options for an Instance.

Constructors

Scheduling({bool? automaticRestart, int? availabilityDomain, SchedulingGracefulShutdown? gracefulShutdown, int? hostErrorTimeoutSeconds, String? instanceTerminationAction, Duration? localSsdRecoveryTimeout, String? locationHint, Duration? maxRunDuration, int? minNodeCpus, List<SchedulingNodeAffinity>? nodeAffinities, String? onHostMaintenance, SchedulingOnInstanceStopAction? onInstanceStopAction, bool? preemptible, Duration? preemptionNoticeDuration, String? provisioningModel, bool? skipGuestOsShutdown, String? terminationTime})
Scheduling.fromJson(Map json_)

Properties

automaticRestart ↔ bool?
Specifies whether the instance should be automatically restarted if it is terminated by Compute Engine (not terminated by a user).
getter/setter pair
availabilityDomain ↔ int?
Specifies the availability domain to place the instance in.
getter/setter pair
gracefulShutdown ↔ SchedulingGracefulShutdown?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostErrorTimeoutSeconds ↔ int?
Specify the time in seconds for host error detection, the value must be within the range of [90, 330] with the increment of 30, if unset, the default behavior of host error recovery will be used.
getter/setter pair
instanceTerminationAction ↔ String?
Specifies the termination action for the instance. Possible string values are:
getter/setter pair
localSsdRecoveryTimeout ↔ Duration?
Specifies the maximum amount of time a Local Ssd Vm should wait while recovery of the Local Ssd state is attempted.
getter/setter pair
locationHint ↔ String?
An opaque location hint used to place the instance close to other resources. This field is for use by internal tools that use the public API.
getter/setter pair
maxRunDuration ↔ Duration?
Specifies the max run duration for the given instance.
getter/setter pair
minNodeCpus ↔ int?
The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
getter/setter pair
nodeAffinities ↔ List<SchedulingNodeAffinity>?
A set of node affinity and anti-affinity configurations.
getter/setter pair
onHostMaintenance ↔ String?
Defines the maintenance behavior for this instance.
getter/setter pair
onInstanceStopAction ↔ SchedulingOnInstanceStopAction?
getter/setter pair
preemptible ↔ bool?
Defines whether the instance is preemptible.
getter/setter pair
preemptionNoticeDuration ↔ Duration?
Specifies the Metadata Service preemption notice duration before the GCE ACPI G2 Soft Off signal is triggered for Spot VMs only.
getter/setter pair
provisioningModel ↔ String?
Specifies the provisioning model of the instance. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipGuestOsShutdown ↔ bool?
Default is false and there will be 120 seconds between GCE ACPI G2 Soft Off and ACPI G3 Mechanical Off for Standard VMs and 30 seconds for Spot VMs.
getter/setter pair
terminationTime ↔ String?
Specifies the timestamp, when the instance will be terminated, inRFC3339 text format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited