SchedulingGracefulShutdown class

The configuration for gracefully shutting down the instance.

Constructors

SchedulingGracefulShutdown({bool? enabled, Duration? maxDuration})
SchedulingGracefulShutdown.fromJson(Map json_)

Properties

enabled bool?
Opts-in for graceful shutdown.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxDuration Duration?
The time allotted for the instance to gracefully shut down.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited