maxDuration property
The time allotted for the instance to gracefully shut down.
If the graceful shutdown isn't complete after this time, then the instance transitions to the STOPPING state.
Implementation
Duration? maxDuration;
The time allotted for the instance to gracefully shut down.
If the graceful shutdown isn't complete after this time, then the instance transitions to the STOPPING state.
Duration? maxDuration;