SchedulingNodeAffinity class

Node Affinity: the configuration of desired nodes onto which this Instance could be scheduled.

Constructors

SchedulingNodeAffinity({String? key, String? operator, List<String>? values})
SchedulingNodeAffinity.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
Corresponds to the label key of Node resource.
getter/setter pair
operator ↔ String?
Defines the operation of node selection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<String>?
Corresponds to the label values of Node resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited