SecurityPolicy class

Represents a Google Cloud Armor security policy resource.

Only external backend services that use load balancers can reference a security policy.

For more information, see Google Cloud Armor security policy overview.

Constructors

SecurityPolicy({SecurityPolicyAdaptiveProtectionConfig? adaptiveProtectionConfig, SecurityPolicyAdvancedOptionsConfig? advancedOptionsConfig, List<SecurityPolicyAssociation>? associations, String? creationTimestamp, SecurityPolicyDdosProtectionConfig? ddosProtectionConfig, String? description, String? fingerprint, String? id, String? kind, String? labelFingerprint, Map<String, String>? labels, String? name, String? parent, SecurityPolicyRecaptchaOptionsConfig? recaptchaOptionsConfig, String? region, List<SecurityPolicyRule>? rules, String? selfLink, String? shortName, String? type, List<SecurityPolicyUserDefinedField>? userDefinedFields})
SecurityPolicy.fromJson(Map json_)

Properties

adaptiveProtectionConfig ↔ SecurityPolicyAdaptiveProtectionConfig?
getter/setter pair
advancedOptionsConfig ↔ SecurityPolicyAdvancedOptionsConfig?
getter/setter pair
associations ↔ List<SecurityPolicyAssociation>?
A list of associations that belong to this policy.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
ddosProtectionConfig ↔ SecurityPolicyDdosProtectionConfig?
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
fingerprint ↔ String?
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
labelFingerprint ↔ String?
A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking.
getter/setter pair
labelFingerprintAsBytes ↔ List<int>
getter/setter pair
labels ↔ Map<String, String>?
Labels for this resource.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
parent ↔ String?
The parent of the security policy.
getter/setter pair
recaptchaOptionsConfig ↔ SecurityPolicyRecaptchaOptionsConfig?
getter/setter pair
region ↔ String?
URL of the region where the regional security policy resides.
getter/setter pair
rules ↔ List<SecurityPolicyRule>?
A list of rules that belong to this policy. There must always be a default rule which is a rule with priority 2147483647 and match all condition (for the match condition this means match "" for srcIpRanges and for the networkMatch condition every field must be either match "" or not set).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
shortName ↔ String?
User-provided name of the organization security policy.
getter/setter pair
type ↔ String?
The type indicates the intended use of the security policy.
getter/setter pair
userDefinedFields ↔ List<SecurityPolicyUserDefinedField>?
Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited