SecurityPolicyAssociation class

Constructors

SecurityPolicyAssociation({String? attachmentId, String? displayName, List<String>? excludedFolders, List<String>? excludedProjects, String? name, String? securityPolicyId, String? shortName})
SecurityPolicyAssociation.fromJson(Map json_)

Properties

attachmentId ↔ String?
The resource that the security policy is attached to.
getter/setter pair
displayName ↔ String?
The display name of the security policy of the association.
getter/setter pair
excludedFolders ↔ List<String>?
A list of folders to exclude from the security policy.
getter/setter pair
excludedProjects ↔ List<String>?
A list of projects to exclude from the security policy.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name for an association.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityPolicyId ↔ String?
The security policy ID of the association.
getter/setter pair
shortName ↔ String?
The short name of the security policy of the association.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited