SecurityPolicyDdosProtectionConfig class

Constructors

SecurityPolicyDdosProtectionConfig({String? ddosAdaptiveProtection, double? ddosImpactedBaselineThreshold, String? ddosProtection})
SecurityPolicyDdosProtectionConfig.fromJson(Map json_)

Properties

ddosAdaptiveProtection String?
Possible string values are:
getter/setter pair
ddosImpactedBaselineThreshold double?
DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage.
getter/setter pair
ddosProtection String?
Possible string values are:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited