SecurityPolicyRule class

Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).

Constructors

SecurityPolicyRule({String? action, String? description, SecurityPolicyRuleHttpHeaderAction? headerAction, String? kind, SecurityPolicyRuleMatcher? match, SecurityPolicyRuleNetworkMatcher? networkMatch, SecurityPolicyRulePreconfiguredWafConfig? preconfiguredWafConfig, bool? preview, int? priority, SecurityPolicyRuleRateLimitOptions? rateLimitOptions, SecurityPolicyRuleRedirectOptions? redirectOptions})
SecurityPolicyRule.fromJson(Map json_)

Properties

action ↔ String?
The Action to perform when the rule is matched. The following are the valid actions:
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headerAction ↔ SecurityPolicyRuleHttpHeaderAction?
Optional, additional actions that are performed on headers. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
match ↔ SecurityPolicyRuleMatcher?
A match condition that incoming traffic is evaluated against. If it evaluates to true, the corresponding 'action' is enforced.
getter/setter pair
networkMatch ↔ SecurityPolicyRuleNetworkMatcher?
A match condition that incoming packets are evaluated against for CLOUD_ARMOR_NETWORK security policies.
getter/setter pair
preconfiguredWafConfig ↔ SecurityPolicyRulePreconfiguredWafConfig?
Preconfigured WAF configuration to be applied for the rule.
getter/setter pair
preview ↔ bool?
If set to true, the specified action is not enforced.
getter/setter pair
priority ↔ int?
An integer indicating the priority of a rule in the list.
getter/setter pair
rateLimitOptions ↔ SecurityPolicyRuleRateLimitOptions?
Must be specified if the action is "rate_based_ban" or "throttle" or "fairshare".
getter/setter pair
redirectOptions ↔ SecurityPolicyRuleRedirectOptions?
Parameters defining the redirect action.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited