SecurityPolicyRuleMatcher class

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.

Properties

config ↔ SecurityPolicyRuleMatcherConfig?
The configuration options available when specifying versioned_expr. This field must be specified if versioned_expr is specified and cannot be specified if versioned_expr is not specified.
getter/setter pair
expr ↔ Expr?
User defined CEVAL expression. A CEVAL expression is used to specify match criteria such as origin.ip, source.region_code and contents in the request header. Expressions containing evaluateThreatIntelligence require a Cloud Armor Enterprise subscription and are not supported in Edge Policies nor in Regional Policies.
getter/setter pair
exprOptions ↔ SecurityPolicyRuleMatcherExprOptions?
The configuration options available when specifying a user defined CEVAL expression (i.e., 'expr').
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionedExpr ↔ String?
Preconfigured versioned expression. If this field is specified, config must also be specified. Available preconfigured expressions along with their requirements are: SRC_IPS_V1 - must specify the corresponding src_ip_range field in config. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited