SecurityPolicyRuleNetworkMatcher class

Represents a match condition that incoming network traffic is evaluated against.

Constructors

SecurityPolicyRuleNetworkMatcher({List<String>? destIpRanges, List<String>? destPorts, List<String>? ipProtocols, List<int>? srcAsns, List<String>? srcIpRanges, List<String>? srcPorts, List<String>? srcRegionCodes, List<SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>? userDefinedFields})
SecurityPolicyRuleNetworkMatcher.fromJson(Map json_)

Properties

destIpRanges ↔ List<String>?
Destination IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
getter/setter pair
destPorts ↔ List<String>?
Destination port numbers for TCP/UDP/SCTP.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipProtocols ↔ List<String>?
IPv4 protocol / IPv6 next header (after extension headers).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcAsns ↔ List<int>?
BGP Autonomous System Number associated with the source IP address.
getter/setter pair
srcIpRanges ↔ List<String>?
Source IPv4/IPv6 addresses or CIDR prefixes, in standard text format.
getter/setter pair
srcPorts ↔ List<String>?
Source port numbers for TCP/UDP/SCTP.
getter/setter pair
srcRegionCodes ↔ List<String>?
Two-letter ISO 3166-1 alpha-2 country code associated with the source IP address.
getter/setter pair
userDefinedFields ↔ List<SecurityPolicyRuleNetworkMatcherUserDefinedFieldMatch>?
User-defined fields.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited