SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig class

Properties

enforceOnKeyName ↔ String?
Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value.
getter/setter pair
enforceOnKeyType ↔ String?
Determines the key to enforce the rate_limit_threshold on.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited