SecurityPolicyUserDefinedField class

Constructors

SecurityPolicyUserDefinedField({String? base, String? mask, String? name, int? offset, int? size})
SecurityPolicyUserDefinedField.fromJson(Map json_)

Properties

base ↔ String?
The base relative to which 'offset' is measured.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mask ↔ String?
If specified, apply this mask (bitwise AND) to the field to ignore bits before matching.
getter/setter pair
name ↔ String?
The name of this field.
getter/setter pair
offset ↔ int?
Offset of the first byte of the field (in network byte order) relative to 'base'.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
Size of the field in bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited