ServiceAttachment class

Represents a ServiceAttachment resource.

A service attachment represents a service that a producer has exposed. It encapsulates the load balancer which fronts the service runs and a list of NAT IP ranges that the producers uses to represent the consumers connecting to the service.

Constructors

ServiceAttachment({List<ServiceAttachmentConnectedEndpoint>? connectedEndpoints, String? connectionPreference, List<ServiceAttachmentConsumerProjectLimit>? consumerAcceptLists, List<String>? consumerRejectLists, String? creationTimestamp, String? description, List<String>? domainNames, bool? enableProxyProtocol, String? fingerprint, String? id, String? kind, Map<String, String>? metadata, String? name, List<String>? natSubnets, String? producerForwardingRule, int? propagatedConnectionLimit, Uint128? pscServiceAttachmentId, bool? reconcileConnections, String? region, String? selfLink, String? targetService})
ServiceAttachment.fromJson(Map json_)

Properties

connectedEndpoints ↔ List<ServiceAttachmentConnectedEndpoint>?
An array of connections for all the consumers connected to this service attachment.
getter/setter pair
connectionPreference ↔ String?
The connection preference of service attachment.
getter/setter pair
consumerAcceptLists ↔ List<ServiceAttachmentConsumerProjectLimit>?
Specifies which consumer projects or networks are allowed to connect to the service attachment.
getter/setter pair
consumerRejectLists ↔ List<String>?
Specifies a list of projects or networks that are not allowed to connect to this service attachment.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp in RFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
domainNames ↔ List<String>?
If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS.
getter/setter pair
enableProxyProtocol ↔ bool?
If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
getter/setter pair
fingerprint ↔ String?
Fingerprint of this resource.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource type.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
metadata ↔ Map<String, String>?
Metadata of the service attachment.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
natSubnets ↔ List<String>?
An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment.
getter/setter pair
producerForwardingRule ↔ String?
The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment.
getter/setter pair
propagatedConnectionLimit ↔ int?
The number of consumer spokes that connected Private Service Connect endpoints can be propagated to through Network Connectivity Center.
getter/setter pair
pscServiceAttachmentId ↔ Uint128?
An 128-bit global unique ID of the PSC service attachment.
getter/setter pair
reconcileConnections ↔ bool?
This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints.
getter/setter pair
region ↔ String?
URL of the region where the service attachment resides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
targetService ↔ String?
The URL of a service serving the endpoint identified by this service attachment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited