ServiceAttachmentConnectedEndpoint class

A connection connected to this service attachment.

Output only.

Constructors

ServiceAttachmentConnectedEndpoint({String? consumerNetwork, String? endpoint, String? endpointWithId, List<String>? natIps, int? propagatedConnectionCount, String? pscConnectionId, String? status})
ServiceAttachmentConnectedEndpoint.fromJson(Map json_)

Properties

consumerNetwork ↔ String?
The url of the consumer network.
getter/setter pair
endpoint ↔ String?
The url of a connected endpoint.
getter/setter pair
endpointWithId ↔ String?
The url of a connected endpoint with resource id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
natIps ↔ List<String>?
NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it.
getter/setter pair
propagatedConnectionCount ↔ int?
The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to.
getter/setter pair
pscConnectionId ↔ String?
The PSC connection id of the connected endpoint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status of a connected endpoint to this service attachment. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited