ShareSettings class

The share setting for reservations and sole tenancy node groups.

Constructors

ShareSettings({Map<String, ShareSettingsProjectConfig>? projectMap, String? shareType})
ShareSettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectMap ↔ Map<String, ShareSettingsProjectConfig>?
A map of project id and project config.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareType ↔ String?
Type of sharing for this shared-reservation Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited