ShieldedInstanceIdentity class

A Shielded Instance Identity.

Properties

eccP256EncryptionKey ↔ ShieldedInstanceIdentityEntry?
An Endorsement Key (EK) made by the ECC P256 algorithm issued to the Shielded Instance's vTPM.
getter/setter pair
eccP256SigningKey ↔ ShieldedInstanceIdentityEntry?
An Attestation Key (AK) made by the ECC P256 algorithm issued to the Shielded Instance's vTPM.
getter/setter pair
encryptionKey ↔ ShieldedInstanceIdentityEntry?
An Endorsement Key (EK) made by the RSA 2048 algorithm issued to the Shielded Instance's vTPM.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Type of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signingKey ↔ ShieldedInstanceIdentityEntry?
An Attestation Key (AK) made by the RSA 2048 algorithm issued to the Shielded Instance's vTPM.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited