snapshotGroupId property
The unique ID of the snapshot group that this snapshot belongs to.
The usage of snapshot group feature is restricted.
Output only.
Implementation
core.String? snapshotGroupId;
The unique ID of the snapshot group that this snapshot belongs to.
The usage of snapshot group feature is restricted.
Output only.
core.String? snapshotGroupId;