storageBytesStatus property
Instead, check the storageBytes field.
After snapshot creation, the storageBytesStatus field is alwaysUP_TO_DATE. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be unset, meaning the snapshot is being created, or UP_TO_DATE, meaning the size of the snapshot is up-to-date.
Output only. Deprecated. Possible string values are:
- "UPDATING"
- "UP_TO_DATE"
Implementation
core.String? storageBytesStatus;