SnapshotGroupParameters class

Constructors

SnapshotGroupParameters({List<String>? replicaZones, String? sourceSnapshotGroup, String? type})
SnapshotGroupParameters.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
replicaZones ↔ List<String>?
URLs of the zones where disks should be replicated to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceSnapshotGroup ↔ String?
The source snapshot group used to create disks.
getter/setter pair
type ↔ String?
URL of the disk type resource describing which disk type to use to create disks.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited