SnapshotSettings class

Properties

accessLocation ↔ SnapshotSettingsAccessLocation?
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageLocation ↔ SnapshotSettingsStorageLocationSettings?
Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited