accessLocation property
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
Implementation
SnapshotSettingsAccessLocation? accessLocation;
(Regional snapshots use only)Policy of which location is allowed to access snapshot.
SnapshotSettingsAccessLocation? accessLocation;