SnapshotSettingsAccessLocation class
Constructors
-
SnapshotSettingsAccessLocation({Map<
String, SnapshotSettingsAccessLocationAccessLocationPreference> ? locations, String? policy}) - SnapshotSettingsAccessLocation.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locations
↔ Map<
String, SnapshotSettingsAccessLocationAccessLocationPreference> ? -
List of regions that can restore a regional
snapshot from the current region
getter/setter pair
- policy ↔ String?
-
Policy of which location is allowed to access snapshot.
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited