locations property
List of regions that can restore a regional snapshot from the current region
Implementation
core.Map<core.String, SnapshotSettingsAccessLocationAccessLocationPreference>?
locations;
List of regions that can restore a regional snapshot from the current region
core.Map<core.String, SnapshotSettingsAccessLocationAccessLocationPreference>?
locations;