policy property

String? policy
getter/setter pair

Policy of which location is allowed to access snapshot. Possible string values are:

  • "ALL_REGIONS" : Any regions will be able to access the source location.
  • "POLICY_UNSPECIFIED"
  • "SPECIFIC_REGIONS" : Only allowlisted regions will be able to restore region scoped snapshots

Implementation

core.String? policy;