SslPolicy class

Represents an SSL Policy resource.

Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers.

For more information, read SSL policies overview.

Constructors

SslPolicy({String? creationTimestamp, List<String>? customFeatures, String? description, List<String>? enabledFeatures, String? fingerprint, String? id, String? kind, String? minTlsVersion, String? name, String? postQuantumKeyExchange, String? profile, String? region, String? selfLink, List<SslPolicyWarnings>? warnings})
SslPolicy.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
customFeatures ↔ List<String>?
A list of features enabled when the selected profile is CUSTOM.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
enabledFeatures ↔ List<String>?
The list of features enabled in the SSL policy.
getter/setter pair
fingerprint ↔ String?
Fingerprint of this resource.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
minTlsVersion ↔ String?
The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
postQuantumKeyExchange ↔ String?
One of DEFAULT, ENABLED, orDEFERRED.
getter/setter pair
profile ↔ String?
Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients.
getter/setter pair
region ↔ String?
URL of the region where the regional SSL policy resides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
warnings ↔ List<SslPolicyWarnings>?
If potential misconfigurations are detected for this SSL policy, this field will be populated with warning messages.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited