StatefulPolicyPreservedState class

Configuration of preserved resources.

Properties

disks ↔ Map<String, StatefulPolicyPreservedStateDiskDevice>?
Disks created on the instances that will be preserved on instance delete, update, etc.
getter/setter pair
externalIPs ↔ Map<String, StatefulPolicyPreservedStateNetworkIp>?
External network IPs assigned to the instances that will be preserved on instance delete, update, etc.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalIPs ↔ Map<String, StatefulPolicyPreservedStateNetworkIp>?
Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited