Status class

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.

It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details.

You can find out more about this error model and how to work with it in the API Design Guide.

Constructors

Status({int? code, List<Map<String, Object?>>? details, String? message})
Status.fromJson(Map json_)

Properties

code ↔ int?
The status code, which should be an enum value of google.rpc.Code.
getter/setter pair
details ↔ List<Map<String, Object?>>?
A list of messages that carry the error details.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
A developer-facing error message, which should be in English.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited