StoragePool class

Represents a zonal storage pool resource.

Constructors

StoragePool({String? capacityProvisioningType, String? creationTimestamp, String? description, StoragePoolExapoolProvisionedCapacityGb? exapoolProvisionedCapacityGb, String? id, String? kind, String? labelFingerprint, Map<String, String>? labels, String? name, StoragePoolParams? params, String? performanceProvisioningType, String? poolProvisionedCapacityGb, String? poolProvisionedIops, String? poolProvisionedThroughput, StoragePoolResourceStatus? resourceStatus, String? selfLink, String? selfLinkWithId, StoragePoolShareSettings? shareSettings, String? state, StoragePoolResourceStatus? status, String? storagePoolType, String? zone})
StoragePool.fromJson(Map json_)

Properties

capacityProvisioningType ↔ String?
Provisioning type of the byte capacity of the pool. Possible string values are:
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
exapoolProvisionedCapacityGb ↔ StoragePoolExapoolProvisionedCapacityGb?
Provisioned capacities for each SKU for this Exapool in GiB
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
labelFingerprint ↔ String?
A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking.
getter/setter pair
labelFingerprintAsBytes ↔ List<int>
getter/setter pair
labels ↔ Map<String, String>?
Labels to apply to this storage pool.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
params ↔ StoragePoolParams?
Input only.
getter/setter pair
performanceProvisioningType ↔ String?
Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS. Possible string values are:
getter/setter pair
poolProvisionedCapacityGb ↔ String?
Size of the storage pool in GiB.
getter/setter pair
poolProvisionedIops ↔ String?
Provisioned IOPS of the storage pool.
getter/setter pair
poolProvisionedThroughput ↔ String?
Provisioned throughput of the storage pool in MiB/s.
getter/setter pair
resourceStatus ↔ StoragePoolResourceStatus?
Status information for the storage pool resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined fully-qualified URL for this resource.
getter/setter pair
selfLinkWithId ↔ String?
Server-defined URL for this resource's resource id.
getter/setter pair
shareSettings ↔ StoragePoolShareSettings?
Share settings for the storage pool.
getter/setter pair
state ↔ String?
The status of storage pool creation.
getter/setter pair
status ↔ StoragePoolResourceStatus?
Status information for the storage pool resource.
getter/setter pair
storagePoolType ↔ String?
Type of the storage pool.
getter/setter pair
zone ↔ String?
URL of the zone where the storage pool resides. You must specify this field as part of the HTTP request URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited