StoragePoolDisk class

Constructors

StoragePoolDisk({List<String>? attachedInstances, String? creationTimestamp, String? disk, String? name, String? provisionedIops, String? provisionedThroughput, List<String>? resourcePolicies, String? sizeGb, String? status, String? type, String? usedBytes})
StoragePoolDisk.fromJson(Map json_)

Properties

attachedInstances ↔ List<String>?
Instances this disk is attached to.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
disk ↔ String?
The URL of the disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the disk.
getter/setter pair
provisionedIops ↔ String?
The number of IOPS provisioned for the disk.
getter/setter pair
provisionedThroughput ↔ String?
The throughput provisioned for the disk.
getter/setter pair
resourcePolicies ↔ List<String>?
Resource policies applied to disk for automatic snapshot creations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeGb ↔ String?
The disk size, in GB.
getter/setter pair
status ↔ String?
The disk status.
getter/setter pair
type ↔ String?
The disk type.
getter/setter pair
usedBytes ↔ String?
Amount of disk space used.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited