StoragePoolParams class

Additional storage pool params.

Constructors

StoragePoolParams({Map<String, String>? resourceManagerTags})
StoragePoolParams.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourceManagerTags ↔ Map<String, String>?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited