StoragePoolResourceStatus class

Contains output only fields.

Output only.

Constructors

StoragePoolResourceStatus({String? diskCount, String? exapoolMaxReadIops, String? exapoolMaxReadThroughput, String? exapoolMaxWriteIops, String? exapoolMaxWriteThroughput, String? lastResizeTimestamp, String? maxTotalProvisionedDiskCapacityGb, String? poolUsedCapacityBytes, String? poolUsedIops, String? poolUsedThroughput, String? poolUserWrittenBytes, String? totalProvisionedDiskCapacityGb, String? totalProvisionedDiskIops, String? totalProvisionedDiskThroughput})
StoragePoolResourceStatus.fromJson(Map json_)

Properties

diskCount ↔ String?
Number of disks used.
getter/setter pair
exapoolMaxReadIops ↔ String?
Maximum allowed read IOPS for this Exapool.
getter/setter pair
exapoolMaxReadThroughput ↔ String?
Maximum allowed read throughput in MiB/s for this Exapool.
getter/setter pair
exapoolMaxWriteIops ↔ String?
Maximum allowed write IOPS for this Exapool.
getter/setter pair
exapoolMaxWriteThroughput ↔ String?
Maximum allowed write throughput in MiB/s for this Exapool.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastResizeTimestamp ↔ String?
Timestamp of the last successful resize inRFC3339 text format.
getter/setter pair
maxTotalProvisionedDiskCapacityGb ↔ String?
Maximum allowed aggregate disk size in GiB.
getter/setter pair
poolUsedCapacityBytes ↔ String?
Space used by data stored in disks within the storage pool (in bytes).
getter/setter pair
poolUsedIops ↔ String?
Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity.
getter/setter pair
poolUsedThroughput ↔ String?
Sum of all the disks' provisioned throughput in MiB/s.
getter/setter pair
poolUserWrittenBytes ↔ String?
Amount of data written into the pool, before it is compacted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalProvisionedDiskCapacityGb ↔ String?
Sum of all the disks' provisioned capacity (in GiB) in this storage pool.
getter/setter pair
totalProvisionedDiskIops ↔ String?
Sum of all the disks' provisioned IOPS.
getter/setter pair
totalProvisionedDiskThroughput ↔ String?
Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited