StoragePoolType class

Constructors

StoragePoolType({String? creationTimestamp, DeprecationStatus? deprecated, String? description, String? id, String? kind, String? maxPoolProvisionedCapacityGb, String? maxPoolProvisionedIops, String? maxPoolProvisionedThroughput, String? minPoolProvisionedCapacityGb, String? minPoolProvisionedIops, String? minPoolProvisionedThroughput, String? minSizeGb, String? name, String? selfLink, String? selfLinkWithId, List<String>? supportedDiskTypes, String? zone})
StoragePoolType.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
deprecated ↔ DeprecationStatus?
The deprecation status associated with this storage pool type.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
maxPoolProvisionedCapacityGb ↔ String?
Maximum storage pool size in GB.
getter/setter pair
maxPoolProvisionedIops ↔ String?
Maximum provisioned IOPS.
getter/setter pair
maxPoolProvisionedThroughput ↔ String?
Maximum provisioned throughput.
getter/setter pair
minPoolProvisionedCapacityGb ↔ String?
Minimum storage pool size in GB.
getter/setter pair
minPoolProvisionedIops ↔ String?
Minimum provisioned IOPS.
getter/setter pair
minPoolProvisionedThroughput ↔ String?
Minimum provisioned throughput.
getter/setter pair
minSizeGb ↔ String?
This field is deprecated.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId ↔ String?
Server-defined URL for this resource with the resource id.
getter/setter pair
supportedDiskTypes ↔ List<String>?
The list of disk types supported in this storage pool type.
getter/setter pair
zone ↔ String?
URL of the zone where the storage pool type resides. You must specify this field as part of the HTTP request URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited