SubnetworkUtilizationDetails class

The current IP utilization of all subnetwork ranges.

Contains the total number of allocated and free IPs in each range.

Properties

externalIpv6InstanceUtilization ↔ SubnetworkUtilizationDetailsIPV6Utilization?
Utilizations of external IPV6 IP range.
getter/setter pair
externalIpv6LbUtilization ↔ SubnetworkUtilizationDetailsIPV6Utilization?
Utilizations of external IPV6 IP range for NetLB.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalIpv6Utilization ↔ SubnetworkUtilizationDetailsIPV6Utilization?
Utilizations of internal IPV6 IP range.
getter/setter pair
ipv4Utilizations ↔ List<SubnetworkUtilizationDetailsIPV4Utilization>?
Utilizations of all IPV4 IP ranges.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited