SubnetworkUtilizationDetailsIPV4Utilization class

The IPV4 utilization of a single IP range.

Properties

hashCode → int
The hash code for this object.
no setterinherited
rangeName ↔ String?
Will be set for secondary range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAllocatedIp ↔ String?
getter/setter pair
totalFreeIp ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited