SubnetworkUtilizationDetailsIPV6Utilization class

The IPV6 utilization of a single IP range.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalAllocatedIp ↔ Uint128?
getter/setter pair
totalFreeIp ↔ Uint128?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited