TargetGrpcProxy class

Represents a Target gRPC Proxy resource.

A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic.

Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.

Constructors

TargetGrpcProxy({String? creationTimestamp, String? description, String? fingerprint, String? id, String? kind, String? name, String? selfLink, String? selfLinkWithId, String? urlMap, bool? validateForProxyless})
TargetGrpcProxy.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
Creation timestamp inRFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
fingerprint ↔ String?
Fingerprint of this resource.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource type.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
selfLinkWithId ↔ String?
Server-defined URL with id for the resource.
getter/setter pair
urlMap ↔ String?
URL to the UrlMap resource that defines the mapping from URL to the BackendService.
getter/setter pair
validateForProxyless ↔ bool?
If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited