params property
Input only.
[Input Only] Additional params passed with the request, but not persisted as part of resource payload.
Implementation
TargetVpnGatewayParams? params;
Input only.
[Input Only] Additional params passed with the request, but not persisted as part of resource payload.
TargetVpnGatewayParams? params;