UrlMap class

Represents a URL Map resource.

Compute Engine has two URL Map resources: * [Global](/compute/docs/reference/rest/v1/urlMaps) * [Regional](/compute/docs/reference/rest/v1/regionUrlMaps) A URL map resource is a component of certain types of cloud load balancers and Traffic Director: * urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers. * regionUrlMaps are used by internal Application Load Balancers, regional external Application Load Balancers and regional internal Application Load Balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL, EXTERNAL_MANAGED, or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have a loadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.

Constructors

UrlMap({String? creationTimestamp, CustomErrorResponsePolicy? defaultCustomErrorResponsePolicy, HttpRouteAction? defaultRouteAction, String? defaultService, HttpRedirectAction? defaultUrlRedirect, String? description, String? fingerprint, HttpHeaderAction? headerAction, List<HostRule>? hostRules, String? id, String? kind, String? name, List<PathMatcher>? pathMatchers, String? region, String? selfLink, List<UrlMapTest>? tests})
UrlMap.fromJson(Map json_)

Properties

creationTimestamp ↔ String?
Creation timestamp in RFC3339 text format.
getter/setter pair
defaultCustomErrorResponsePolicy ↔ CustomErrorResponsePolicy?
defaultCustomErrorResponsePolicy specifies how the Load Balancer returns error responses when BackendServiceor BackendBucket responds with an error.
getter/setter pair
defaultRouteAction ↔ HttpRouteAction?
defaultRouteAction takes effect when none of the hostRules match.
getter/setter pair
defaultService ↔ String?
The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match.
getter/setter pair
defaultUrlRedirect ↔ HttpRedirectAction?
When none of the specified hostRules match, the request is redirected to a URL specified by defaultUrlRedirect.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
fingerprint ↔ String?
Fingerprint of this resource.
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headerAction ↔ HttpHeaderAction?
Specifies changes to request and response headers that need to take effect for the selected backendService.
getter/setter pair
hostRules ↔ List<HostRule>?
The list of host rules to use against the URL.
getter/setter pair
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
pathMatchers ↔ List<PathMatcher>?
The list of named PathMatchers to use against the URL.
getter/setter pair
region ↔ String?
URL of the region where the regional URL map resides.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
tests ↔ List<UrlMapTest>?
The list of expected URL mapping tests.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited