UrlMapTest class

Message for the expected URL mappings.

Constructors

UrlMapTest({String? description, String? expectedOutputUrl, int? expectedRedirectResponseCode, List<UrlMapTestHeader>? headers, String? host, String? path, String? service})
UrlMapTest.fromJson(Map json_)

Properties

description ↔ String?
Description of this test case.
getter/setter pair
expectedOutputUrl ↔ String?
The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters.
getter/setter pair
expectedRedirectResponseCode ↔ int?
For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ List<UrlMapTestHeader>?
HTTP headers for this request.
getter/setter pair
host ↔ String?
Host portion of the URL.
getter/setter pair
path ↔ String?
Path portion of the URL.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
Expected BackendService or BackendBucket resource the given URL should be mapped to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited