UrlMapsValidateRequest class

Constructors

UrlMapsValidateRequest({List<String>? loadBalancingSchemes, UrlMap? resource})
UrlMapsValidateRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
loadBalancingSchemes ↔ List<String>?
Specifies the load balancer type(s) this validation request is for.
getter/setter pair
resource ↔ UrlMap?
Content of the UrlMap to be validated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited