UrlRewrite class

The spec for modifying the path before sending the request to the matched backend service.

Constructors

UrlRewrite({String? hostRewrite, String? pathPrefixRewrite, String? pathTemplateRewrite, RegexRewrite? regexRewrite})
UrlRewrite.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostRewrite ↔ String?
Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.
getter/setter pair
pathPrefixRewrite ↔ String?
Before forwarding the request to the selected backend service, the matching portion of the request's path is replaced bypathPrefixRewrite.
getter/setter pair
pathTemplateRewrite ↔ String?
If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax.
getter/setter pair
regexRewrite ↔ RegexRewrite?
The regex rewrite to be applied to the URL.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited