regexRewrite property
The regex rewrite to be applied to the URL.
Only one ofpathPrefixRewrite, pathTemplateRewrite, orregexRewrite may be specified.
Implementation
RegexRewrite? regexRewrite;
The regex rewrite to be applied to the URL.
Only one ofpathPrefixRewrite, pathTemplateRewrite, orregexRewrite may be specified.
RegexRewrite? regexRewrite;