UsableSubnetwork class

Subnetwork which the current user has compute.subnetworks.use permission on.

Constructors

UsableSubnetwork({String? externalIpv6Prefix, String? internalIpv6Prefix, String? ipCidrRange, String? ipv6AccessType, String? network, String? purpose, String? role, List<UsableSubnetworkSecondaryRange>? secondaryIpRanges, String? stackType, String? subnetwork})
UsableSubnetwork.fromJson(Map json_)

Properties

externalIpv6Prefix ↔ String?
The external IPv6 address range that is assigned to this subnetwork.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalIpv6Prefix ↔ String?
The internal IPv6 address range that is assigned to this subnetwork.
getter/setter pair
ipCidrRange ↔ String?
The range of internal addresses that are owned by this subnetwork.
getter/setter pair
ipv6AccessType ↔ String?
The access type of IPv6 address this subnet holds.
getter/setter pair
network ↔ String?
Network URL.
getter/setter pair
purpose ↔ String?
Possible string values are:
getter/setter pair
role ↔ String?
The role of subnetwork.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryIpRanges ↔ List<UsableSubnetworkSecondaryRange>?
Secondary IP ranges.
getter/setter pair
stackType ↔ String?
The stack type for the subnet.
getter/setter pair
subnetwork ↔ String?
Subnetwork URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited