UsableSubnetworkSecondaryRange class

Secondary IP range of a usable subnetwork.

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipCidrRange ↔ String?
The range of IP addresses belonging to this subnetwork secondary range. Can be Ipv4 or Ipv6 range.
getter/setter pair
rangeName ↔ String?
The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance. The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the subnetwork.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited