instanceSelectors property
Selectors to target VMs for this policy.
VMs are selected if they match any of the provided selectors (logical OR). If this list is empty, the policy applies to all VMs.
Optional.
Implementation
core.List<VmExtensionPolicyInstanceSelector>? instanceSelectors;