WafExpressionSet class

Constructors

WafExpressionSet({List<String>? aliases, List<WafExpressionSetExpression>? expressions, String? id})
WafExpressionSet.fromJson(Map json_)

Properties

aliases ↔ List<String>?
A list of alternate IDs.
getter/setter pair
expressions ↔ List<WafExpressionSetExpression>?
List of available expressions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Google specified expression set ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited