WireGroupEndpoint class

A logical endpoint for the wire group.

An endpoint represents a metro that contains redundant Interconnect connections. A wire group is created between two endpoints.

Properties

hashCode → int
The hash code for this object.
no setterinherited
interconnects ↔ Map<String, WireGroupEndpointInterconnect>?
A map that contains the redundant Interconnect connections.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited