WireGroupEndpointInterconnect class

The redundant Interconnect connections for this endpoint.

Constructors

WireGroupEndpointInterconnect({String? interconnect, List<int>? vlanTags})
WireGroupEndpointInterconnect.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
interconnect ↔ String?
An Interconnect connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vlanTags ↔ List<int>?
To configure the wire group for VLAN mode, enter a VLAN tag, which is a number from 2 to 4093.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited