WireProperties class

The properties of a wire.

Constructors

WireProperties({String? bandwidthAllocation, String? bandwidthUnmetered, String? faultResponse})
WireProperties.fromJson(Map json_)

Properties

bandwidthAllocation ↔ String?
The configuration of the bandwidth allocation, one of the following:
getter/setter pair
bandwidthUnmetered ↔ String?
The unmetered bandwidth in Gigabits per second, using decimal units.
getter/setter pair
faultResponse ↔ String?
Response when a fault is detected in a pseudowire:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited