AutoMigrationConfig class

AutoMigrationConfig contains the automigration configuration for a project.

Constructors

AutoMigrationConfig({bool? autoMigrationEnabled, String? name, String? updateTime})
AutoMigrationConfig.fromJson(Map json_)

Properties

autoMigrationEnabled ↔ bool?
Whether the auto migration is enabled for the project.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Time the AutoMigrationConfig was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited