state property
Current state of the deployment group.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : The default value. This value is used if the state is omitted.
- "CREATING" : The deployment group is being created.
- "ACTIVE" : The deployment group is healthy.
- "UPDATING" : The deployment group is being updated.
- "DELETING" : The deployment group is being deleted.
- "FAILED" : The deployment group has encountered an unexpected error.
- "SUSPENDED" : The deployment group is no longer being actively reconciled. This may be the result of recovering the project after deletion.
- "DELETED" : The deployment group has been deleted.
Implementation
core.String? state;