DeploymentSource class

Configuration for a value sourced from a Deployment.

Constructors

DeploymentSource({String? deployment, String? outputName})
DeploymentSource.fromJson(Map json_)

Properties

deployment String?
The resource name of the source Deployment to import the output from.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
outputName String?
The name of the output variable in the source deployment's latest successfully applied revision.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited