outputName property
The name of the output variable in the source deployment's latest successfully applied revision.
Required.
Implementation
core.String? outputName;
The name of the output variable in the source deployment's latest successfully applied revision.
Required.
core.String? outputName;