DeploymentSpec class
Spec for a deployment to be created.
Constructors
- DeploymentSpec({Deployment? deployment, String? deploymentId})
- DeploymentSpec.fromJson(Map json_)
Properties
- deployment ↔ Deployment?
-
The deployment to be created.
getter/setter pair
- deploymentId ↔ String?
-
The id of the deployment to be created which doesn't include the project
id and location.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited