deploymentId property
The id of the deployment to be created which doesn't include the project id and location.
Required.
Implementation
core.String? deploymentId;
The id of the deployment to be created which doesn't include the project id and location.
Required.
core.String? deploymentId;