DeploymentUnit class

A DeploymentUnit is a container for a deployment and its dependencies.

An existing deployment can be provided directly in the unit, or the unit can act as a placeholder to define the DAG, with the deployment specs supplied in a provisionDeploymentRequest.

Constructors

DeploymentUnit({List<String>? dependencies, String? deployment, String? id})
DeploymentUnit.fromJson(Map json_)

Properties

dependencies List<String>?
The IDs of the deployment units within the deployment group that this unit depends on.
getter/setter pair
deployment String?
The name of the deployment to be provisioned.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
The id of the deployment unit.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited