deletePolicy property

String? deletePolicy
getter/setter pair

Policy on how resources within each deployment should be handled during deletion.

This policy is applied globally to the deletion of all deployments in this group. This corresponds to the 'delete_policy' field in DeleteDeploymentRequest.

Optional. Possible string values are:

  • "DELETE_POLICY_UNSPECIFIED" : Unspecified policy, resources will be deleted.
  • "DELETE" : Deletes resources actuated by the deployment.
  • "ABANDON" : Abandons resources and only deletes the deployment and its metadata.

Implementation

core.String? deletePolicy;