ExternalValueSource class

Configuration for a source of an external value.

Constructors

ExternalValueSource({DeploymentSource? deploymentSource})
ExternalValueSource.fromJson(Map json_)

Properties

deploymentSource DeploymentSource?
A source from a Deployment.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited