ListDeploymentGroupRevisionsResponse class
The response message for the ListDeploymentGroupRevisions method.
Constructors
-
ListDeploymentGroupRevisionsResponse({List<
DeploymentGroupRevision> ? deploymentGroupRevisions, String? nextPageToken, List<String> ? unreachable}) - ListDeploymentGroupRevisionsResponse.fromJson(Map json_)
Properties
-
deploymentGroupRevisions
↔ List<
DeploymentGroupRevision> ? -
The deployment group revisions from the specified collection.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
Token to be supplied to the next ListDeploymentGroupRevisions request via
page_tokento obtain the next set of results.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unreachable
↔ List<
String> ? -
Unordered list.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited