ListPreviewsResponse class

A response to a ListPreviews call.

Contains a list of Previews.

Constructors

ListPreviewsResponse({String? nextPageToken, List<Preview>? previews, List<String>? unreachable})
ListPreviewsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to be supplied to the next ListPreviews request via page_token to obtain the next set of results.
getter/setter pair
previews ↔ List<Preview>?
List of Previews.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited