ListResourceChangesResponse class

A response to a 'ListResourceChanges' call.

Contains a list of ResourceChanges.

Constructors

ListResourceChangesResponse({String? nextPageToken, List<ResourceChange>? resourceChanges, List<String>? unreachable})
ListResourceChangesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to request the next page of resources from the 'ListResourceChanges' method.
getter/setter pair
resourceChanges ↔ List<ResourceChange>?
List of ResourceChanges.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unreachable resources, if any.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited