Preview class

A preview represents a set of actions Infra Manager would perform to move the resources towards the desired state as specified in the configuration.

Constructors

Preview({Map<String, String>? annotations, String? artifactsGcsBucket, String? build, String? createTime, String? deployment, String? errorCode, String? errorLogs, Status? errorStatus, Map<String, String>? labels, String? logs, String? name, PreviewArtifacts? previewArtifacts, String? previewMode, ProviderConfig? providerConfig, String? serviceAccount, String? state, TerraformBlueprint? terraformBlueprint, List<TerraformError>? tfErrors, String? tfVersion, String? tfVersionConstraint, String? workerPool})
Preview.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Arbitrary key-value metadata storage e.g. to help client tools identify preview during automation.
getter/setter pair
artifactsGcsBucket ↔ String?
User-defined location of Cloud Build logs, artifacts, and in Google Cloud Storage.
getter/setter pair
build ↔ String?
Cloud Build instance UUID associated with this preview.
getter/setter pair
createTime ↔ String?
Time the preview was created.
getter/setter pair
deployment ↔ String?
Deployment reference.
getter/setter pair
errorCode ↔ String?
Code describing any errors that may have occurred.
getter/setter pair
errorLogs ↔ String?
Link to tf-error.ndjson file, which contains the full list of the errors encountered during a Terraform preview.
getter/setter pair
errorStatus ↔ Status?
Additional information regarding the current state.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
User-defined labels for the preview.
getter/setter pair
logs ↔ String?
Location of preview logs in gs://{bucket}/{object} format.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
previewArtifacts ↔ PreviewArtifacts?
Artifacts from preview.
getter/setter pair
previewMode ↔ String?
Current mode of preview.
getter/setter pair
providerConfig ↔ ProviderConfig?
This field specifies the provider configurations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
User-specified Service Account (SA) credentials to be used when previewing resources.
getter/setter pair
state ↔ String?
Current state of the preview.
getter/setter pair
terraformBlueprint ↔ TerraformBlueprint?
The terraform blueprint to preview.
getter/setter pair
tfErrors ↔ List<TerraformError>?
Summary of errors encountered during Terraform preview.
getter/setter pair
tfVersion ↔ String?
The current Terraform version set on the preview.
getter/setter pair
tfVersionConstraint ↔ String?
The user-specified Terraform version constraint.
getter/setter pair
workerPool ↔ String?
The user-specified Worker Pool resource in which the Cloud Build job will execute.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited