deployment property
Deployment reference.
If specified, the preview will be performed using the provided deployment's current state and use any relevant fields from the deployment unless explicitly specified in the preview create request.
Optional.
Implementation
core.String? deployment;