PreviewResult class

Contains a signed Cloud Storage URLs.

Constructors

PreviewResult({String? binarySignedUri, String? jsonSignedUri})
PreviewResult.fromJson(Map json_)

Properties

binarySignedUri ↔ String?
Plan binary signed URL
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonSignedUri ↔ String?
Plan JSON signed URL
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited