ProjectsLocationsDeploymentGroupsResource class

Constructors

ProjectsLocationsDeploymentGroupsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
revisions ProjectsLocationsDeploymentGroupsRevisionsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(DeploymentGroup request, String parent, {String? deploymentGroupId, String? requestId, String? $fields}) Future<Operation>
Creates a DeploymentGroup The newly created DeploymentGroup will be in the CREATING state and can be retrieved via Get and List calls.
delete(String name, {String? deploymentReferencePolicy, bool? force, String? requestId, String? $fields}) Future<Operation>
Deletes a DeploymentGroup
deprovision(DeprovisionDeploymentGroupRequest request, String name, {String? $fields}) Future<Operation>
Deprovisions a deployment group.
get(String name, {String? $fields}) Future<DeploymentGroup>
Get a DeploymentGroup for a given project and location.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListDeploymentGroupsResponse>
List DeploymentGroups for a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(DeploymentGroup request, String name, {String? requestId, String? updateMask, String? $fields}) Future<Operation>
Updates a DeploymentGroup
provision(ProvisionDeploymentGroupRequest request, String name, {String? $fields}) Future<Operation>
Provisions a deployment group.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited