provision method

Future<Operation> provision(
  1. ProvisionDeploymentGroupRequest request,
  2. String name, {
  3. String? $fields,
})

Provisions a deployment group.

NOTE: As a first step of this operation, Infra Manager will automatically delete any Deployments that were part of the last successful DeploymentGroupRevision but are no longer included in the current DeploymentGroup definition (e.g., following an UpdateDeploymentGroup call), along with their actuated resources.

request - The metadata request object.

Request parameters:

name - Required. The name of the deployment group to provision. Format: 'projects/{project_id}/locations/{location}/deploymentGroups/{deployment_group}'. Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/deploymentGroups/\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Operation.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Operation> provision(
  ProvisionDeploymentGroupRequest request,
  core.String name, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':provision';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}