ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

deploymentGroups ProjectsLocationsDeploymentGroupsResource
no setter
deployments ProjectsLocationsDeploymentsResource
no setter
hashCode int
The hash code for this object.
no setterinherited
operations ProjectsLocationsOperationsResource
no setter
previews ProjectsLocationsPreviewsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformVersions ProjectsLocationsTerraformVersionsResource
no setter

Methods

get(String name, {String? $fields}) Future<Location>
Gets information about a location.
getAutoMigrationConfig(String name, {String? $fields}) Future<AutoMigrationConfig>
Get the AutoMigrationConfig for a given project and location.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) Future<ListLocationsResponse>
Lists information about the supported locations for this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAutoMigrationConfig(AutoMigrationConfig request, String name, {String? updateMask, String? $fields}) Future<Operation>
Updates the AutoMigrationConfig for a given project and location.

Operators

operator ==(Object other) bool
The equality operator.
inherited