PropertyChange class

A property change represents a change to a property in the state file.

Constructors

PropertyChange({Object? after, List<String>? afterSensitivePaths, Object? before, List<String>? beforeSensitivePaths, String? path})
PropertyChange.fromJson(Map json_)

Properties

after ↔ Object?
Representations of the object value after the actions.
getter/setter pair
afterSensitivePaths ↔ List<String>?
The paths of sensitive fields in after.
getter/setter pair
before ↔ Object?
Representations of the object value before the actions.
getter/setter pair
beforeSensitivePaths ↔ List<String>?
The paths of sensitive fields in before.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
path ↔ String?
The path of the property change.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited