ProvisionDeploymentGroupRequest class

The request message for the ProvisionDeploymentGroup method.

Properties

deploymentSpecs Map<String, DeploymentSpec>?
The deployment specs of the deployment units to be created within the same project and location of the deployment group.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited