deploymentSpecs property

Map<String, DeploymentSpec>? deploymentSpecs
getter/setter pair

The deployment specs of the deployment units to be created within the same project and location of the deployment group.

The key is the unit ID, and the value is the DeploymentSpec. Provisioning will fail if a deployment_spec has a deployment_id that matches an existing deployment in the same project and location. If an existing deployment was part of the last successful revision but is no longer in the current DeploymentGroup's deployment_units, it will be recreated if included in deployment_specs.

Optional.

Implementation

core.Map<core.String, DeploymentSpec>? deploymentSpecs;