UnlockDeploymentRequest class

A request to unlock a state file passed to a 'UnlockDeployment' call.

Properties

hashCode → int
The hash code for this object.
no setterinherited
lockId ↔ String?
Lock ID of the lock file to be unlocked.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited