connectors/v1 library

Classes

AdminFilters
  • AdminFilters defines a set of filters that can be applied to a connection.
  • AuditConfig
    Specifies the audit configuration for a service.
    AuthConfig
    AuthConfig defines details of a authentication type.
    AuthConfigTemplate
    AuthConfigTemplate defines required field over an authentication type.
    AuthField
    AuthField defines a field in an authentication type.
    AuthObject
    AuthObject defines a JSON schema of an authentication type.
    This configuration captures the details required to render an authorization link for the OAuth Authorization Code Flow.
    AuthProperty
    AuthProperty defines a property of an authentication type.
    AuthSchema
    AuthSchema defines the schema of an authentication type.
    BillingConfig
    Billing config for the connection.
    Binding
    Associates members, or principals, with a role.
    ConfigVariable
    ConfigVariable represents a configuration variable present in a Connection.
    ConfigVariableTemplate
    ConfigVariableTemplate provides metadata about a ConfigVariable that is used in a Connection.
    Connection
    Connection represents an instance of connector.
    ConnectionSchemaMetadata
    ConnectionSchemaMetadata is the singleton resource of each connection.
    ConnectionStatus
    ConnectionStatus indicates the state of the connection.
    Connector
    Connectors indicates a specific connector type, e.x. Salesforce, SAP etc.
    ConnectorInfraConfig
    This cofiguration provides infra configs like rate limit threshold which need to be configurable for every connector version
    ConnectorsApi
    Enables users to create and manage connections to Google Cloud services and third-party business applications using the Connectors interface.
    ConnectorsLogConfig
    Log configuration for the connection.
    ConnectorVersion
    ConnectorVersion indicates a specific version of a connector.
    ConnectorVersionInfraConfig
    This configuration provides infra configs like rate limit threshold which need to be configurable for every connector version
    CustomConnector
    CustomConnector represents the custom connector defined by the customer as part of byoc.
    CustomConnectorVersion
    CustomConnectorVersion indicates a specific version of a connector.
    DeadLetterConfig
    Dead Letter configuration details provided by the user.
    Destination
    DestinationConfig
    Define the Connectors target endpoint.
    DestinationConfigTemplate
    DestinationConfigTemplate defines required destinations supported by the Connector.
    EgressControlConfig
    Egress control config for connector runtime.
    EncryptionConfig
    Regional encryption config for CMEK details.
    EncryptionKey
    Encryption Key value.
    EndPoint
    Endpoint message includes details of the Destination endpoint.
    EndpointAttachment
    represents the Connector's Endpoint Attachment resource
    EndUserAuthentication
    AuthConfig defines details of a authentication type.
    EndUserAuthenticationConfig
    EndUserAuthenticationConfig defines details of a authentication configuration for EUC
    EndUserAuthenticationConfigOauth2AuthCodeFlow
    Parameters to support Oauth 2.0 Auth Code Grant Authentication.
    EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged
    Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client.
    EndUserAuthenticationConfigOauth2ClientCredentials
    Parameters to support Oauth 2.0 Client Credentials Grant Authentication.
    EndUserAuthenticationConfigOauth2JwtBearer
    Parameters to support JSON Web Token (JWT) Profile for Oauth 2.0 Authorization Grant based authentication.
    EndUserAuthenticationConfigOauth2JwtBearerJwtClaims
    JWT claims used for the jwt-bearer authorization grant.
    EndUserAuthenticationConfigSshPublicKey
    Parameters to support Ssh public key Authentication.
    EndUserAuthenticationConfigUserPassword
    Parameters to support Username and Password Authentication.
    EndUserAuthenticationConfigVariable
    EndUserAuthenticationConfigVariable represents a configuration variable present in a EndUserAuthentication.
    EndUserAuthenticationEndUserAuthenticationStatus
    EndUserAuthentication Status denotes the status of the EndUserAuthentication resource.
    EndUserAuthenticationNotifyEndpointDestination
    Message for NotifyEndpointDestination Destination to hit when the refresh token is expired.
    EndUserAuthenticationNotifyEndpointDestinationEndPoint
    Endpoint message includes details of the Destination endpoint.
    EndUserAuthenticationNotifyEndpointDestinationEndPointHeader
    Header details for a given header to be added to Endpoint.
    EnrichmentConfig
    Data enrichment configuration.
    EnumOption
    EnumOption definition
    EUASecret
    EUASecret provides a reference to entries in Secret Manager.
    EventingConfig
    Eventing Configuration of a connection next: 21
    EventingConfigTemplate
    Eventing Config details of a connector version.
    EventingDetails
    Eventing Details message.
    EventingRuntimeData
    Eventing runtime data has the details related to eventing managed by the system.
    EventingStatus
    EventingStatus indicates the state of eventing.
    EventSubscription
    represents the Connector's EventSubscription resource
    EventSubscriptionDestination
    Message for EventSubscription Destination to act on receiving an event
    EventSubscriptionStatus
    EventSubscription Status denotes the status of the EventSubscription resource.
    EventType
    EventType includes fields.
    ExtractionRule
    Extraction Rule.
    ExtractionRules
    Extraction Rules to identity the backends from customer provided configuration in Connection resource.
    FetchAuthSchemaResponse
    Response message for Connectors.GetAuthSchema.
    FetchConnectionToolspecOverrideRequest
    Request message for FetchConnectionToolspecOverride API.
    FetchConnectionToolspecOverrideResponse
    Response message for FetchConnectionToolspecOverride API.
    Field
    Metadata of an entity field.
    FieldComparison
    Field that needs to be compared.
    GenerateConnectionToolspecOverrideRequest
    Request message for GenerateConnectionToolspecOverride API.
    GenerateConnectionToolspecOverrideResponse
    Response message for GenerateConnectionToolspecOverride API.
    Header details for a given header to be added to Endpoint.
    HPAConfig
    Autoscaling config for connector deployment system metrics.
    InputParameter
    Metadata of an input parameter.
    JMS
    JMS message denotes the source of the event
    JsonAuthSchema
    JsonAuthSchema defines the JSON schema of all authentication types.
    JsonSchema
    JsonSchema representation of schema metadata
    JwtClaims
    JWT claims used for the jwt-bearer authorization grant.
    ListActionsResponse
    Response message for ListActions API
    ListConnectionsResponse
    Response message for ConnectorsService.ListConnections
    ListConnectorsResponse
    Response message for Connectors.ListConnectors.
    ListConnectorVersionsResponse
    Response message for Connectors.ListConnectorVersions.
    ListCustomConnectorsResponse
    Response message for Connectors.ListCustomConnectors.
    ListCustomConnectorVersionsResponse
    Response message for Connectors.ListCustomConnectorVersions.
    ListEndpointAttachmentsResponse
    Response message for ConnectorsService.ListEndpointAttachments
    ListEndUserAuthenticationsResponse
    Response message for ConnectorsService.ListEndUserAuthentications
    ListenEventRequest
    Expected request for ListenEvent API.
    ListEntityTypesResponse
    Response message for ListEntityTypes API
    ListEventSubscriptionsResponse
    Response message for ConnectorsService.ListEventSubscriptions
    ListEventTypesResponse
    Response message for Connectors.ListEventTypes.
    ListLocationsResponse
    The response message for Locations.ListLocations.
    ListManagedZonesResponse
    Response message for ConnectorsService.ListManagedZones
    ListOperationsResponse
    The response message for Operations.ListOperations.
    ListProvidersResponse
    Response message for Connectors.ListProviders.
    ListRuntimeActionSchemasResponse
    Response message for ConnectorsService.ListRuntimeActionSchemas.
    ListRuntimeEntitySchemasResponse
    Response message for ConnectorsService.ListRuntimeEntitySchemas.
    LockConfig
    Determines whether or no a connection is locked.
    LogicalExpression
    Struct for representing boolean expressions.
    ManagedZone
    represents the Connector's Managed Zone resource
    MarketplaceConnectorDetails
    Marketplace connector details.
    ModifyConnectionToolspecOverrideRequest
    Request message for ModifyConnectionToolspecOverride API.
    ModifyConnectionToolspecOverrideResponse
    Response message for ModifyConnectionToolspecOverride API.
    MultipleSelectConfig
    MultipleSelectConfig represents the multiple options for a config variable.
    MultipleSelectOption
    MultiplSelecteOption represents the single option for a config variable.
    NetworkConfig
    Regional Network Config.
    NetworkEgressModeOverride
    NetworkEgressModeOverride provides the network egress mode override for a connector.
    NodeConfig
    Node configuration for the connection.
    Oauth2AuthCodeFlow
    Parameters to support Oauth 2.0 Auth Code Grant Authentication.
    Oauth2AuthCodeFlowGoogleManaged
    Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client.
    Oauth2ClientCredentials
    Parameters to support Oauth 2.0 Client Credentials Grant Authentication.
    Oauth2JwtBearer
    Parameters to support JSON Web Token (JWT) Profile for Oauth 2.0 Authorization Grant based authentication.
    OAuthTokenData
    pass only at create and not update using updateMask Auth Code Data
    Operation
    This resource represents a long-running operation that is the result of a network API call.
    PartnerMetadata
    Partner metadata details.
    Policy
    An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources.
    ProjectsLocationsConnectionsConnectionSchemaMetadataResource
    ProjectsLocationsConnectionsEndUserAuthenticationsResource
    ProjectsLocationsConnectionsEventSubscriptionsResource
    ProjectsLocationsConnectionsResource
    ProjectsLocationsConnectionsRuntimeActionSchemasResource
    ProjectsLocationsConnectionsRuntimeEntitySchemasResource
    ProjectsLocationsCustomConnectorsCustomConnectorVersionsResource
    ProjectsLocationsCustomConnectorsResource
    ProjectsLocationsEndpointAttachmentsResource
    ProjectsLocationsGlobalCustomConnectorsCustomConnectorVersionsResource
    ProjectsLocationsGlobalCustomConnectorsResource
    ProjectsLocationsGlobalManagedZonesResource
    ProjectsLocationsGlobalResource
    ProjectsLocationsOperationsResource
    ProjectsLocationsProvidersConnectorsResource
    ProjectsLocationsProvidersConnectorsVersionsEventtypesResource
    ProjectsLocationsProvidersConnectorsVersionsResource
    ProjectsLocationsProvidersResource
    ProjectsLocationsResource
    ProjectsResource
    Provider
    Provider indicates the owner who provides the connectors.
    PublishCustomConnectorVersionRequest
    Request message for ConnectorsService.PublishCustomConnectorVersion
    PublishStatus
    Publish status of a custom connector.
    PubSub
    Pub/Sub message includes details of the Destination Pub/Sub topic.
    RegionalSettings
    Regional Settings details.
    Resource
    Resource definition
    ResourceLimits
    Resource limits defined for connection pods of a given connector type.
    ResourceRequests
    Resource requests defined for connection pods of a given connector type.
    ResultMetadata
    Metadata of result field.
    RoleGrant
    This configuration defines all the Cloud IAM roles that needs to be granted to a particular Google Cloud resource for the selected principal like service account.
    RuntimeActionSchema
    Schema of a runtime action.
    RuntimeConfig
    RuntimeConfig is the singleton resource of each location.
    RuntimeEntitySchema
    Schema of a runtime entity.
    SchemaRefreshConfig
    Config for connection schema refresh
    SearchConnectionInstance
    SearchConnectionInstance represents an instance of connector with specific fields
    SearchConnectionsResponse
    Response message for Connectors.SearchConnections.
    Secret
    Secret provides a reference to entries in Secret Manager.
    SetIamPolicyRequest
    Request message for SetIamPolicy method.
    Settings
    Global Settings details.
    Source
    Source to extract the backend from.
    SshPublicKey
    Parameters to support Ssh public key Authentication.
    SslConfig
    SSL Configuration of a connection
    SslConfigTemplate
    Ssl config details of a connector version
    StandardAction
    Standard action
    StandardEntity
    Standard entity
    StringListValues
    StringListValues is a message to store a list of string values.
    SupportedRuntimeFeatures
    Supported runtime features of a connector version.
    ToolName
    Tool name for which the tool spec override is to be generated.
    ToolspecOverride
    Toolspec overrides for a connection only holds the information that is to be displayed in the UI for admins.
    TrafficShapingConfig
  • TrafficShapingConfig defines the configuration for shaping API traffic by specifying a quota limit and the duration over which this limit is enforced.
  • UserPassword
    Parameters to support Username and Password Authentication.
    ValidateCustomConnectorSpecRequest
    Request message for ConnectorsService.ValidateCustomConnectorSpec
    ValidateCustomConnectorSpecResponse
    Response message for ConnectorsService.ValidateCustomConnectorSpec
    VpcscConfig
    This configuration provides VPCSC config for a connector.
    WebhookData
    WebhookData has details of webhook configuration.
    WebhookSubscriptions
    WebhookSubscriptions has details of webhook subscriptions.

    Typedefs

    AuditLogConfig = $AuditLogConfig
    Provides the configuration for logging a type of permissions.
    CancelOperationRequest = $Empty
    The request message for Operations.CancelOperation.
    DeprecateCustomConnectorVersionRequest = $Empty
    Request message for ConnectorsService.DeprecateCustomConnectorVersion
    Empty = $Empty
    A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
    Expr = $Expr
    Represents a textual expression in the Common Expression Language (CEL) syntax.
    ListenEventResponse = $Empty
    Expected response for ListenEvent API.
    Location = $Location00
    A resource that represents a Google Cloud location.
    RefreshConnectionSchemaMetadataRequest = $Empty
    Request message for ConnectorsService.RefreshConnectionSchemaMetadata.
    RemoveConnectionToolspecOverrideRequest = $Empty
    Request message for RemoveConnectionToolspecOverride API.
    RepairEventingRequest = $Empty
    Request message for ConnectorsService.RepairEventing
    RetryEventSubscriptionRequest = $Empty
    Request message for ConnectorsService.RefreshEventSubscription
    Status = $Status00
    The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
    TestIamPermissionsRequest = $TestIamPermissionsRequest00
    Request message for TestIamPermissions method.
    TestIamPermissionsResponse = $PermissionsResponse
    Response message for TestIamPermissions method.
    WithdrawCustomConnectorVersionRequest = $Empty
    Request message for ConnectorsService.WithdrawCustomConnectorVersion

    Exceptions / Errors

    ApiRequestError
    Represents a general error reported by the API endpoint.
    DetailedApiRequestError
    Represents a specific error reported by the API endpoint.