AdminFilters class

  • AdminFilters defines a set of filters that can be applied to a connection.

These are currently used by Gemini Enterprise connections.

Constructors

AdminFilters({String? filterKey, String? filterType, String? intValue, StringListValues? stringListValues, String? stringValue})
AdminFilters.fromJson(Map json_)

Properties

filterKey String?
Unique name for the filter, e.g., "SharePointSiteURL", "DocumentType", "ChatSpaceName".
getter/setter pair
filterType String?
Type of the filter.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
intValue String?
A single integer value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringListValues StringListValues?
List of string values.
getter/setter pair
stringValue String?
A single string value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited