AuthConfigTemplate class

AuthConfigTemplate defines required field over an authentication type.

Constructors

AuthConfigTemplate({String? authKey, String? authType, List<ConfigVariableTemplate>? configVariableTemplates, String? description, String? displayName, bool? isDefault})
AuthConfigTemplate.fromJson(Map json_)

Properties

authKey ↔ String?
Identifier key for auth config
getter/setter pair
authType ↔ String?
The type of authentication configured. Possible string values are:
getter/setter pair
configVariableTemplates ↔ List<ConfigVariableTemplate>?
Config variables to describe an AuthConfig for a Connection.
getter/setter pair
description ↔ String?
Connector specific description for an authentication template.
getter/setter pair
displayName ↔ String?
Display name for authentication template.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDefault ↔ bool?
Whether the auth config is the default one.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited