AuthField class

AuthField defines a field in an authentication type.

Constructors

AuthField({String? dataType, String? description, String? key})
AuthField.fromJson(Map json_)

Properties

dataType ↔ String?
Data type of the field.
getter/setter pair
description ↔ String?
Description of the field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
Key of the field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited