AuthObject class

AuthObject defines a JSON schema of an authentication type.

Constructors

AuthObject({bool? additionalProperties, String? authKey, String? authType, String? description, bool? isDefault, Map<String, AuthProperty>? properties, String? type})
AuthObject.fromJson(Map json_)

Properties

additionalProperties ↔ bool?
Whether the object has additional properties.
getter/setter pair
authKey ↔ String?
Auth key of the object.
getter/setter pair
authType ↔ String?
Auth type of the object.
getter/setter pair
description ↔ String?
Description of the object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDefault ↔ bool?
Whether the object is the default one.
getter/setter pair
properties ↔ Map<String, AuthProperty>?
Properties of the object.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of the object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited