ConfigVariable class

ConfigVariable represents a configuration variable present in a Connection.

or AuthConfig.

Constructors

ConfigVariable({bool? boolValue, EncryptionKey? encryptionKeyValue, String? intValue, String? key, Secret? secretValue, String? stringValue})
ConfigVariable.fromJson(Map json_)

Properties

boolValue ↔ bool?
Value is a bool.
getter/setter pair
encryptionKeyValue ↔ EncryptionKey?
Value is a Encryption Key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intValue ↔ String?
Value is an integer
getter/setter pair
key ↔ String?
Key of the config variable.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretValue ↔ Secret?
Value is a secret.
getter/setter pair
stringValue ↔ String?
Value is a string.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited