Connection class

Connection represents an instance of connector.

Constructors

Connection({bool? asyncOperationsEnabled, AuthConfig? authConfig, bool? authOverrideEnabled, BillingConfig? billingConfig, List<ConfigVariable>? configVariables, String? connectionRevision, String? connectorVersion, ConnectorVersionInfraConfig? connectorVersionInfraConfig, String? connectorVersionLaunchStage, String? createTime, String? description, List<DestinationConfig>? destinationConfigs, String? envoyImageLocation, AuthConfig? euaOauthAuthConfig, EventingConfig? eventingConfig, String? eventingEnablementType, EventingRuntimeData? eventingRuntimeData, bool? fallbackOnAdminCredentials, String? host, String? imageLocation, bool? isTrustedTester, Map<String, String>? labels, LockConfig? lockConfig, ConnectorsLogConfig? logConfig, String? name, NodeConfig? nodeConfig, String? serviceAccount, String? serviceDirectory, SslConfig? sslConfig, ConnectionStatus? status, String? subscriptionType, bool? suspended, String? tlsServiceDirectory, List<TrafficShapingConfig>? trafficShapingConfigs, String? updateTime})
Connection.fromJson(Map json_)

Properties

asyncOperationsEnabled ↔ bool?
Async operations enabled for the connection.
getter/setter pair
authConfig ↔ AuthConfig?
Configuration for establishing the connection's authentication with an external system.
getter/setter pair
authOverrideEnabled ↔ bool?
Auth override enabled for the connection.
getter/setter pair
billingConfig ↔ BillingConfig?
Billing config for the connection.
getter/setter pair
configVariables ↔ List<ConfigVariable>?
Configuration for configuring the connection with an external system.
getter/setter pair
connectionRevision ↔ String?
Connection revision.
getter/setter pair
connectorVersion ↔ String?
Connector version on which the connection is created.
getter/setter pair
connectorVersionInfraConfig ↔ ConnectorVersionInfraConfig?
Infra configs supported by Connector Version.
getter/setter pair
connectorVersionLaunchStage ↔ String?
Flag to mark the version indicating the launch stage.
getter/setter pair
createTime ↔ String?
Created time.
getter/setter pair
description ↔ String?
Description of the resource.
getter/setter pair
destinationConfigs ↔ List<DestinationConfig>?
Configuration of the Connector's destination.
getter/setter pair
envoyImageLocation ↔ String?
GCR location where the envoy image is stored.
getter/setter pair
euaOauthAuthConfig ↔ AuthConfig?
Additional Oauth2.0 Auth config for EUA.
getter/setter pair
eventingConfig ↔ EventingConfig?
Eventing config of a connection
getter/setter pair
eventingEnablementType ↔ String?
Eventing enablement type.
getter/setter pair
eventingRuntimeData ↔ EventingRuntimeData?
Eventing Runtime Data.
getter/setter pair
fallbackOnAdminCredentials ↔ bool?
Fallback on admin credentials for the connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
The name of the Hostname of the Service Directory service with TLS.
getter/setter pair
imageLocation ↔ String?
GCR location where the runtime image is stored.
getter/setter pair
isTrustedTester ↔ bool?
Is trusted tester program enabled for the project.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user-provided metadata.
getter/setter pair
lockConfig ↔ LockConfig?
Configuration that indicates whether or not the Connection can be edited.
getter/setter pair
logConfig ↔ ConnectorsLogConfig?
Log configuration for the connection.
getter/setter pair
name ↔ String?
Resource name of the Connection.
getter/setter pair
nodeConfig ↔ NodeConfig?
Node configuration for the connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Service account needed for runtime plane to access Google Cloud resources.
getter/setter pair
serviceDirectory ↔ String?
The name of the Service Directory service name.
getter/setter pair
sslConfig ↔ SslConfig?
Ssl config of a connection
getter/setter pair
status ↔ ConnectionStatus?
Current status of the connection.
getter/setter pair
subscriptionType ↔ String?
This subscription type enum states the subscription type of the project.
getter/setter pair
suspended ↔ bool?
Suspended indicates if a user has suspended a connection or not.
getter/setter pair
tlsServiceDirectory ↔ String?
The name of the Service Directory service with TLS.
getter/setter pair
trafficShapingConfigs ↔ List<TrafficShapingConfig>?
Traffic shaping configuration for the connection.
getter/setter pair
updateTime ↔ String?
Updated time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited