ConnectionSchemaMetadata class

ConnectionSchemaMetadata is the singleton resource of each connection.

It includes the entity and action names of runtime resources exposed by a connection backend.

Constructors

ConnectionSchemaMetadata({List<String>? actions, List<String>? entities, String? errorMessage, String? name, String? refreshTime, String? state, String? updateTime})
ConnectionSchemaMetadata.fromJson(Map json_)

Properties

actions ↔ List<String>?
List of actions.
getter/setter pair
entities ↔ List<String>?
List of entity names.
getter/setter pair
errorMessage ↔ String?
Error message for users.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name.
getter/setter pair
refreshTime ↔ String?
Timestamp when the connection runtime schema refresh was triggered.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of runtime schema.
getter/setter pair
updateTime ↔ String?
Timestamp when the connection runtime schema was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited