ConnectorInfraConfig class

This cofiguration provides infra configs like rate limit threshold which need to be configurable for every connector version

Constructors

ConnectorInfraConfig({bool? alwaysAllocateCpu, String? connectionRatelimitWindowSeconds, bool? connectionServiceAccountEnabled, bool? connectorVersioningEnabled, String? deploymentModel, HPAConfig? hpaConfig, String? internalclientRatelimitThreshold, int? maxInstanceRequestConcurrency, bool? migrateDeploymentModel, bool? migrateTls, NetworkEgressModeOverride? networkEgressModeOverride, bool? provisionCloudSpanner, bool? provisionMemstore, bool? publicNetworkIngressEnabled, String? ratelimitThreshold, ResourceLimits? resourceLimits, ResourceRequests? resourceRequests, String? sharedDeployment})
ConnectorInfraConfig.fromJson(Map json_)

Properties

alwaysAllocateCpu ↔ bool?
Indicates that the Cloud Run CPU should always be allocated.
getter/setter pair
connectionRatelimitWindowSeconds ↔ String?
The window used for ratelimiting runtime requests to connections.
getter/setter pair
connectionServiceAccountEnabled ↔ bool?
Indicate whether connection service account is enabled.
getter/setter pair
connectorVersioningEnabled ↔ bool?
Indicate whether connector versioning is enabled.
getter/setter pair
deploymentModel ↔ String?
Indicate whether connector is deployed on GKE/CloudRun Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hpaConfig ↔ HPAConfig?
HPA autoscaling config.
getter/setter pair
internalclientRatelimitThreshold ↔ String?
Max QPS supported for internal requests originating from Connd.
getter/setter pair
maxInstanceRequestConcurrency ↔ int?
Max Instance Request Conncurrency for Cloud Run service.
getter/setter pair
migrateDeploymentModel ↔ bool?
Indicate whether connector is being migrated to cloud run deployment model.
getter/setter pair
migrateTls ↔ bool?
Indicate whether connector is being migrated to TLS.
getter/setter pair
networkEgressModeOverride ↔ NetworkEgressModeOverride?
Network egress mode override to migrate to direct VPC egress.
getter/setter pair
provisionCloudSpanner ↔ bool?
Indicate whether cloud spanner is required for connector job.
getter/setter pair
provisionMemstore ↔ bool?
Indicate whether memstore is required for connector job.
getter/setter pair
publicNetworkIngressEnabled ↔ bool?
Indicate whether public network ingress should be enabled.
getter/setter pair
ratelimitThreshold ↔ String?
Max QPS supported by the connector version before throttling of requests.
getter/setter pair
resourceLimits ↔ ResourceLimits?
System resource limits.
getter/setter pair
resourceRequests ↔ ResourceRequests?
System resource requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedDeployment ↔ String?
The name of shared connector deployment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited