ConnectorVersion class

ConnectorVersion indicates a specific version of a connector.

Constructors

ConnectorVersion({List<AuthConfigTemplate>? authConfigTemplates, bool? authOverrideEnabled, List<ConfigVariableTemplate>? configVariableTemplates, ConnectorInfraConfig? connectorInfraConfig, String? createTime, List<DestinationConfigTemplate>? destinationConfigTemplates, String? displayName, EgressControlConfig? egressControlConfig, EventingConfigTemplate? eventingConfigTemplate, bool? isCustomActionsSupported, bool? isCustomEntitiesSupported, Map<String, String>? labels, String? launchStage, String? name, String? releaseVersion, RoleGrant? roleGrant, List<RoleGrant>? roleGrants, SchemaRefreshConfig? schemaRefreshConfig, SslConfigTemplate? sslConfigTemplate, SupportedRuntimeFeatures? supportedRuntimeFeatures, List<StandardAction>? supportedStandardActions, List<StandardEntity>? supportedStandardEntities, List<String>? unsupportedConnectionTypes, String? updateTime, VpcscConfig? vpcscConfig})
ConnectorVersion.fromJson(Map json_)

Properties

authConfigTemplates ↔ List<AuthConfigTemplate>?
List of auth configs supported by the Connector Version.
getter/setter pair
authOverrideEnabled ↔ bool?
Flag to mark the dynamic auth override.
getter/setter pair
configVariableTemplates ↔ List<ConfigVariableTemplate>?
List of config variables needed to create a connection.
getter/setter pair
connectorInfraConfig ↔ ConnectorInfraConfig?
Infra configs supported by Connector.
getter/setter pair
createTime ↔ String?
Created time.
getter/setter pair
destinationConfigTemplates ↔ List<DestinationConfigTemplate>?
List of destination configs needed to create a connection.
getter/setter pair
displayName ↔ String?
Display name.
getter/setter pair
egressControlConfig ↔ EgressControlConfig?
Configuration for Egress Control.
getter/setter pair
eventingConfigTemplate ↔ EventingConfigTemplate?
Eventing configuration supported by the Connector.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isCustomActionsSupported ↔ bool?
Is custom actions supported.
getter/setter pair
isCustomEntitiesSupported ↔ bool?
Is custom entities supported.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user-provided metadata.
getter/setter pair
launchStage ↔ String?
Flag to mark the version indicating the launch stage.
getter/setter pair
name ↔ String?
Resource name of the Version.
getter/setter pair
releaseVersion ↔ String?
ReleaseVersion of the connector, for example: "1.0.1-alpha".
getter/setter pair
roleGrant ↔ RoleGrant?
Role grant configuration for this config variable.
getter/setter pair
roleGrants ↔ List<RoleGrant>?
Role grant configurations for this connector version.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaRefreshConfig ↔ SchemaRefreshConfig?
Connection Schema Refresh Config
getter/setter pair
sslConfigTemplate ↔ SslConfigTemplate?
Ssl configuration supported by the Connector.
getter/setter pair
supportedRuntimeFeatures ↔ SupportedRuntimeFeatures?
Information about the runtime features supported by the Connector.
getter/setter pair
supportedStandardActions ↔ List<StandardAction>?
Supported standard actions.
getter/setter pair
supportedStandardEntities ↔ List<StandardEntity>?
Supported standard entities.
getter/setter pair
unsupportedConnectionTypes ↔ List<String>?
Unsupported connection types.
getter/setter pair
updateTime ↔ String?
Updated time.
getter/setter pair
vpcscConfig ↔ VpcscConfig?
VPCSC config for the connector.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited