ConnectorVersionInfraConfig class

This configuration provides infra configs like rate limit threshold which need to be configurable for every connector version

Constructors

ConnectorVersionInfraConfig({String? connectionRatelimitWindowSeconds, String? deploymentModel, String? deploymentModelMigrationState, HPAConfig? hpaConfig, String? internalclientRatelimitThreshold, int? maxInstanceRequestConcurrency, String? ratelimitThreshold, ResourceLimits? resourceLimits, ResourceRequests? resourceRequests, String? sharedDeployment, String? tlsMigrationState})
ConnectorVersionInfraConfig.fromJson(Map json_)

Properties

connectionRatelimitWindowSeconds ↔ String?
The window used for ratelimiting runtime requests to connections.
getter/setter pair
deploymentModel ↔ String?
Indicates whether connector is deployed on GKE/CloudRun
getter/setter pair
deploymentModelMigrationState ↔ String?
Status of the deployment model migration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hpaConfig ↔ HPAConfig?
HPA autoscaling config.
getter/setter pair
internalclientRatelimitThreshold ↔ String?
Max QPS supported for internal requests originating from Connd.
getter/setter pair
maxInstanceRequestConcurrency ↔ int?
Max instance request concurrency.
getter/setter pair
ratelimitThreshold ↔ String?
Max QPS supported by the connector version before throttling of requests.
getter/setter pair
resourceLimits ↔ ResourceLimits?
System resource limits.
getter/setter pair
resourceRequests ↔ ResourceRequests?
System resource requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedDeployment ↔ String?
The name of shared connector deployment.
getter/setter pair
tlsMigrationState ↔ String?
Status of the TLS migration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited