CustomConnector class

CustomConnector represents the custom connector defined by the customer as part of byoc.

Constructors

CustomConnector({List<String>? activeConnectorVersions, List<String>? allConnectorVersions, List<String>? allMarketplaceVersions, String? createTime, String? customConnectorType, String? description, String? displayName, Map<String, String>? labels, String? name, List<String>? publishedMarketplaceVersions, String? updateTime})
CustomConnector.fromJson(Map json_)

Properties

activeConnectorVersions ↔ List<String>?
Active connector versions.
getter/setter pair
allConnectorVersions ↔ List<String>?
All connector versions.
getter/setter pair
allMarketplaceVersions ↔ List<String>?
All marketplace versions.
getter/setter pair
createTime ↔ String?
Created time.
getter/setter pair
customConnectorType ↔ String?
Type of the custom connector.
getter/setter pair
description ↔ String?
Description of the resource.
getter/setter pair
displayName ↔ String?
Display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user-provided metadata.
getter/setter pair
Logo of the resource.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
publishedMarketplaceVersions ↔ List<String>?
Published marketplace versions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Updated time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited