CustomConnectorVersion class

CustomConnectorVersion indicates a specific version of a connector.

Constructors

CustomConnectorVersion({bool? asyncOperationsSupport, AuthConfig? authConfig, List<AuthConfigTemplate>? authConfigTemplates, bool? authOverrideSupport, List<ConfigVariableTemplate>? backendVariableTemplates, String? createTime, List<DestinationConfig>? destinationConfigs, bool? enableBackendDestinationConfig, Map<String, String>? labels, String? name, PartnerMetadata? partnerMetadata, PublishStatus? publishStatus, String? serviceAccount, String? specLocation, List<String>? specServerUrls, String? state, String? updateTime})
CustomConnectorVersion.fromJson(Map json_)

Properties

asyncOperationsSupport ↔ bool?
Indicates if Async Operations/Connector Job is supported.
getter/setter pair
authConfig ↔ AuthConfig?
Authentication config for accessing connector service (facade).
getter/setter pair
authConfigTemplates ↔ List<AuthConfigTemplate>?
Auth Config Templates is only used when connector backend is enabled.
getter/setter pair
authOverrideSupport ↔ bool?
Auth override support.
getter/setter pair
backendVariableTemplates ↔ List<ConfigVariableTemplate>?
Backend variable templates is only used when connector backend is enabled.
getter/setter pair
createTime ↔ String?
Created time.
getter/setter pair
destinationConfigs ↔ List<DestinationConfig>?
Destination config(s) for accessing connector service (facade).
getter/setter pair
enableBackendDestinationConfig ↔ bool?
Indicates if an intermediatory connectorservice is used as backend.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user-provided metadata.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
partnerMetadata ↔ PartnerMetadata?
Partner metadata details.
getter/setter pair
publishStatus ↔ PublishStatus?
Publish status of a custom connector.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Service account used by runtime plane to access auth config secrets.
getter/setter pair
specLocation ↔ String?
Location of the custom connector spec.
getter/setter pair
specServerUrls ↔ List<String>?
Server URLs parsed from the Open API spec.
getter/setter pair
state ↔ String?
State of the custom connector version.
getter/setter pair
updateTime ↔ String?
Updated time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited