DestinationConfig class

Define the Connectors target endpoint.

Constructors

DestinationConfig({List<Destination>? destinations, String? key})
DestinationConfig.fromJson(Map json_)

Properties

destinations ↔ List<Destination>?
The destinations for the key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The key is the destination identifier that is supported by the Connector.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited