DestinationConfigTemplate class

DestinationConfigTemplate defines required destinations supported by the Connector.

Constructors

DestinationConfigTemplate({List<String>? autocompleteSuggestions, int? defaultPort, String? description, String? displayName, bool? isAdvanced, String? key, int? max, int? min, String? portFieldType, String? regexPattern})
DestinationConfigTemplate.fromJson(Map json_)

Properties

autocompleteSuggestions ↔ List<String>?
Autocomplete suggestions for destination URL field.
getter/setter pair
defaultPort ↔ int?
The default port.
getter/setter pair
description ↔ String?
Description.
getter/setter pair
displayName ↔ String?
Display name of the parameter.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAdvanced ↔ bool?
Whether the current destination tempalate is part of Advanced settings
getter/setter pair
key ↔ String?
Key of the destination.
getter/setter pair
max ↔ int?
The maximum number of destinations supported for this key.
getter/setter pair
min ↔ int?
The minimum number of destinations supported for this key.
getter/setter pair
portFieldType ↔ String?
Whether port number should be provided by customers. Possible string values are:
getter/setter pair
regexPattern ↔ String?
Regex pattern for host.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited