EncryptionConfig class

Regional encryption config for CMEK details.

Constructors

EncryptionConfig({String? encryptionType, String? kmsKeyName})
EncryptionConfig.fromJson(Map json_)

Properties

encryptionType ↔ String?
Encryption type for the region.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
KMS crypto key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited