EndUserAuthentication class

AuthConfig defines details of a authentication type.

Constructors

EndUserAuthentication({List<EndUserAuthenticationConfigVariable>? configVariables, String? createTime, List<DestinationConfig>? destinationConfigs, EndUserAuthenticationConfig? endUserAuthenticationConfig, List<String>? labels, String? name, EndUserAuthenticationNotifyEndpointDestination? notifyEndpointDestination, List<String>? roles, EndUserAuthenticationEndUserAuthenticationStatus? status, String? updateTime, String? userId})
EndUserAuthentication.fromJson(Map json_)

Properties

configVariables ↔ List<EndUserAuthenticationConfigVariable>?
Config variables for the EndUserAuthentication.
getter/setter pair
createTime ↔ String?
Created time.
getter/setter pair
destinationConfigs ↔ List<DestinationConfig>?
Destination configs for the EndUserAuthentication.
getter/setter pair
endUserAuthenticationConfig ↔ EndUserAuthenticationConfig?
The EndUserAuthenticationConfig for the EndUserAuthentication.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ List<String>?
Labels for the EndUserAuthentication.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
notifyEndpointDestination ↔ EndUserAuthenticationNotifyEndpointDestination?
The destination to hit when we receive an event
getter/setter pair
roles ↔ List<String>?
Roles for the EndUserAuthentication.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ EndUserAuthenticationEndUserAuthenticationStatus?
Status of the EndUserAuthentication.
getter/setter pair
updateTime ↔ String?
Updated time.
getter/setter pair
userId ↔ String?
The user id of the user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited