EndUserAuthenticationConfig class

EndUserAuthenticationConfig defines details of a authentication configuration for EUC

Properties

additionalVariables ↔ List<EndUserAuthenticationConfigVariable>?
List containing additional auth configs.
getter/setter pair
authKey ↔ String?
Identifier key for auth config
getter/setter pair
authType ↔ String?
The type of authentication configured. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oauth2AuthCodeFlow ↔ EndUserAuthenticationConfigOauth2AuthCodeFlow?
Oauth2AuthCodeFlow.
getter/setter pair
oauth2AuthCodeFlowGoogleManaged ↔ EndUserAuthenticationConfigOauth2AuthCodeFlowGoogleManaged?
Oauth2AuthCodeFlowGoogleManaged.
getter/setter pair
oauth2ClientCredentials ↔ EndUserAuthenticationConfigOauth2ClientCredentials?
Oauth2ClientCredentials.
getter/setter pair
oauth2JwtBearer ↔ EndUserAuthenticationConfigOauth2JwtBearer?
Oauth2JwtBearer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sshPublicKey ↔ EndUserAuthenticationConfigSshPublicKey?
SSH Public Key.
getter/setter pair
userPassword ↔ EndUserAuthenticationConfigUserPassword?
UserPassword.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited