EndUserAuthenticationConfigOauth2ClientCredentials class

Parameters to support Oauth 2.0 Client Credentials Grant Authentication.

See https://tools.ietf.org/html/rfc6749#section-1.3.4 for more details.

Properties

clientId ↔ String?
The client identifier.
getter/setter pair
clientSecret ↔ EUASecret?
string value or secret version containing the client secret.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited