EndUserAuthenticationConfigSshPublicKey class

Parameters to support Ssh public key Authentication.

Constructors

EndUserAuthenticationConfigSshPublicKey({String? certType, EUASecret? sshClientCert, EUASecret? sshClientCertPass, String? username})
EndUserAuthenticationConfigSshPublicKey.fromJson(Map json_)

Properties

certType ↔ String?
Format of SSH Client cert.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sshClientCert ↔ EUASecret?
SSH Client Cert.
getter/setter pair
sshClientCertPass ↔ EUASecret?
Password (passphrase) for ssh client certificate if it has one.
getter/setter pair
username ↔ String?
The user account used to authenticate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited