EndUserAuthenticationNotifyEndpointDestination class

Message for NotifyEndpointDestination Destination to hit when the refresh token is expired.

Properties

endpoint ↔ EndUserAuthenticationNotifyEndpointDestinationEndPoint?
OPTION 1: Hit an endpoint when the refresh token is expired.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Service account needed for runtime plane to notify the backend.
getter/setter pair
type ↔ String?
type of the destination
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited