filter property
Filter for the event subscription.
Incoming events are filtered based on the filter expression.
Optional.
Implementation
core.String? filter;
Filter for the event subscription.
Incoming events are filtered based on the filter expression.
Optional.
core.String? filter;