globalEventFilter property
Filter to be applied on the events to be received by the connection.
Optional.
Implementation
core.String? globalEventFilter;
Filter to be applied on the events to be received by the connection.
Optional.
core.String? globalEventFilter;