EventingConfigTemplate class

Eventing Config details of a connector version.

next: 14

Constructors

EventingConfigTemplate({List<ConfigVariableTemplate>? additionalVariables, List<AuthConfigTemplate>? authConfigTemplates, bool? autoRefresh, bool? autoRegistrationSupported, ConfigVariableTemplate? encryptionKeyTemplate, bool? enrichmentSupported, String? eventListenerType, bool? isEventingSupported, List<AuthConfigTemplate>? listenerAuthConfigTemplates, DestinationConfigTemplate? proxyDestinationConfig, DestinationConfigTemplate? registrationDestinationConfig, SslConfigTemplate? sslConfigTemplate, List<ConfigVariableTemplate>? triggerConfigVariables})
EventingConfigTemplate.fromJson(Map json_)

Properties

additionalVariables ↔ List<ConfigVariableTemplate>?
Additional fields that need to be rendered.
getter/setter pair
authConfigTemplates ↔ List<AuthConfigTemplate>?
AuthConfigTemplates represents the auth values for the webhook adapter.
getter/setter pair
autoRefresh ↔ bool?
Auto refresh to extend webhook life.
getter/setter pair
autoRegistrationSupported ↔ bool?
Auto Registration supported.
getter/setter pair
encryptionKeyTemplate ↔ ConfigVariableTemplate?
Encryption key (can be either Google managed or CMEK).
getter/setter pair
enrichmentSupported ↔ bool?
Enrichment Supported.
getter/setter pair
eventListenerType ↔ String?
The type of the event listener for a specific connector. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isEventingSupported ↔ bool?
Is Eventing Supported.
getter/setter pair
listenerAuthConfigTemplates ↔ List<AuthConfigTemplate>?
ListenerAuthConfigTemplates represents the auth values for the event listener.
getter/setter pair
proxyDestinationConfig ↔ DestinationConfigTemplate?
Proxy destination config template.
getter/setter pair
registrationDestinationConfig ↔ DestinationConfigTemplate?
Registration host destination config template.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sslConfigTemplate ↔ SslConfigTemplate?
SSL Config template for the connector version.
getter/setter pair
triggerConfigVariables ↔ List<ConfigVariableTemplate>?
Trigger Config fields that needs to be rendered
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited