EventingStatus class

EventingStatus indicates the state of eventing.

Constructors

EventingStatus({String? description, String? state})
EventingStatus.fromJson(Map json_)

Properties

description ↔ String?
Description of error if State is set to "ERROR".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited