ExtractionRule class

Extraction Rule.

Constructors

ExtractionRule({String? extractionRegex, String? formatString, Source? source})
ExtractionRule.fromJson(Map json_)

Properties

extractionRegex ↔ String?
Regex used to extract backend details from source.
getter/setter pair
formatString ↔ String?
Format string used to format the extracted backend details.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Source?
Source on which the rule is applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited