FieldComparison class

Field that needs to be compared.

Constructors

FieldComparison({bool? boolValue, String? comparator, String? intValue, String? key, String? stringValue})
FieldComparison.fromJson(Map json_)

Properties

boolValue ↔ bool?
Boolean value
getter/setter pair
comparator ↔ String?
Comparator to use for comparing the field value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intValue ↔ String?
Integer value
getter/setter pair
key ↔ String?
Key of the field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue ↔ String?
String value
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited