GenerateConnectionToolspecOverrideResponse class
Response message for GenerateConnectionToolspecOverride API.
Constructors
- GenerateConnectionToolspecOverrideResponse({ToolspecOverride? toolspecOverride})
- GenerateConnectionToolspecOverrideResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolspecOverride ↔ ToolspecOverride?
-
Toolspec overrides for the connection.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited