InputParameter class

Metadata of an input parameter.

Constructors

InputParameter({String? dataType, Object? defaultValue, String? description, JsonSchema? jsonSchema, bool? nullable, String? parameter})
InputParameter.fromJson(Map json_)

Properties

dataType ↔ String?
The data type of the Parameter. Possible string values are:
getter/setter pair
defaultValue ↔ Object?
The following field specifies the default value of the Parameter provided by the external system if a value is not provided.
getter/setter pair
description ↔ String?
A brief description of the Parameter.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonSchema ↔ JsonSchema?
JsonSchema representation of this action's parameter
getter/setter pair
nullable ↔ bool?
Specifies whether a null value is allowed.
getter/setter pair
parameter ↔ String?
Name of the Parameter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited