LogicalExpression class

Struct for representing boolean expressions.

Constructors

LogicalExpression({List<FieldComparison>? fieldComparisons, List<LogicalExpression>? logicalExpressions, String? logicalOperator})
LogicalExpression.fromJson(Map json_)

Properties

fieldComparisons ↔ List<FieldComparison>?
A list of fields to be compared.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
logicalExpressions ↔ List<LogicalExpression>?
A list of nested conditions to be compared.
getter/setter pair
logicalOperator ↔ String?
The logical operator to use between the fields and conditions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited