MultipleSelectConfig class

MultipleSelectConfig represents the multiple options for a config variable.

Constructors

MultipleSelectConfig({bool? allowCustomValues, List<MultipleSelectOption>? multipleSelectOptions, String? valueSeparator})
MultipleSelectConfig.fromJson(Map json_)

Properties

allowCustomValues ↔ bool?
Allow custom values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
multipleSelectOptions ↔ List<MultipleSelectOption>?
Multiple select options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueSeparator ↔ String?
Value separator.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited