OAuthTokenData class

pass only at create and not update using updateMask Auth Code Data

Constructors

OAuthTokenData({EUASecret? accessToken, String? createTime, String? expiry, EUASecret? refreshToken})
OAuthTokenData.fromJson(Map json_)

Properties

accessToken ↔ EUASecret?
Access token for the connection.
getter/setter pair
createTime ↔ String?
Timestamp when the access token was created.
getter/setter pair
expiry ↔ String?
Time in seconds when the access token expires.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
refreshToken ↔ EUASecret?
Refresh token for the connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited