Oauth2AuthCodeFlowGoogleManaged class

Parameters to support Oauth 2.0 Auth Code Grant Authentication using Google Provided OAuth Client.

See https://tools.ietf.org/html/rfc6749#section-1.3.1 for more details.

Constructors

Oauth2AuthCodeFlowGoogleManaged({String? authCode, String? redirectUri, List<String>? scopes})
Oauth2AuthCodeFlowGoogleManaged.fromJson(Map json_)

Properties

authCode String?
Authorization code to be exchanged for access and refresh tokens.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
redirectUri String?
Redirect URI to be provided during the auth code exchange.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>?
Scopes the connection will request when the user performs the auth code flow.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited