ProjectsLocationsConnectionsConnectionSchemaMetadataResource class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAction(String name, {String? actionId, String? $fields}) → Future<Operation>
Get action.
getEntityType(String name, {String? entityId, String? $fields}) → Future<Operation>
Get entity type.
listActions(String name, {String? filter, int? pageSize, String? pageToken, String? view, String? $fields}) → Future<ListActionsResponse>
List actions.
listEntityTypes(String name, {String? filter, int? pageSize, String? pageToken, String? view, String? $fields}) → Future<ListEntityTypesResponse>
List entity types.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refresh(RefreshConnectionSchemaMetadataRequest request, String name, {String? $fields}) → Future<Operation>
Refresh runtime schema of a connection.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited