ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

connections → ProjectsLocationsConnectionsResource
no setter
customConnectors → ProjectsLocationsCustomConnectorsResource
no setter
endpointAttachments → ProjectsLocationsEndpointAttachmentsResource
no setter
global → ProjectsLocationsGlobalResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
operations → ProjectsLocationsOperationsResource
no setter
providers → ProjectsLocationsProvidersResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) → Future<Location>
Gets information about a location.
getRegionalSettings(String name, {String? $fields}) → Future<RegionalSettings>
GetRegionalSettings gets settings of a region.
getRuntimeConfig(String name, {String? $fields}) → Future<RuntimeConfig>
Gets the runtimeConfig of a location.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateRegionalSettings(RegionalSettings request, String name, {String? updateMask, String? $fields}) → Future<Operation>
Update the settings of a region.

Operators

operator ==(Object other) → bool
The equality operator.
inherited