Provider class

Provider indicates the owner who provides the connectors.

Constructors

Provider({String? createTime, String? description, String? displayName, String? documentationUri, String? externalUri, Map<String, String>? labels, String? launchStage, String? name, String? updateTime, String? webAssetsLocation})
Provider.fromJson(Map json_)

Properties

createTime ↔ String?
Created time.
getter/setter pair
description ↔ String?
Description of the resource.
getter/setter pair
displayName ↔ String?
Display name.
getter/setter pair
documentationUri ↔ String?
Link to documentation page.
getter/setter pair
externalUri ↔ String?
Link to external page.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user-provided metadata.
getter/setter pair
launchStage ↔ String?
Flag to mark the version indicating the launch stage.
getter/setter pair
name ↔ String?
Resource name of the Provider.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Updated time.
getter/setter pair
webAssetsLocation ↔ String?
Cloud storage location of icons etc consumed by UI.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited