RuntimeEntitySchema class

Schema of a runtime entity.

Constructors

RuntimeEntitySchema({String? entity, List<Field>? fields, JsonSchema? jsonSchema, List<String>? operations})
RuntimeEntitySchema.fromJson(Map json_)

Properties

entity ↔ String?
Name of the entity.
getter/setter pair
fields ↔ List<Field>?
List of fields in the entity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonSchema ↔ JsonSchema?
JsonSchema representation of this entity's metadata
getter/setter pair
operations ↔ List<String>?
List of operations supported by this entity
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited