SearchConnectionInstance class

SearchConnectionInstance represents an instance of connector with specific fields

Constructors

SearchConnectionInstance({RuntimeActionSchema? actionSchema, Connection? connection, RuntimeEntitySchema? entitySchema})
SearchConnectionInstance.fromJson(Map json_)

Properties

actionSchema ↔ RuntimeActionSchema?
Schema of a runtime action.
getter/setter pair
connection ↔ Connection?
Connection details
getter/setter pair
entitySchema ↔ RuntimeEntitySchema?
Schema of a runtime entity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited