SslConfig class

SSL Configuration of a connection

Constructors

SslConfig({List<ConfigVariable>? additionalVariables, String? clientCertType, Secret? clientCertificate, Secret? clientPrivateKey, Secret? clientPrivateKeyPass, Secret? privateServerCertificate, String? serverCertType, String? trustModel, String? type, bool? useSsl})
SslConfig.fromJson(Map json_)

Properties

additionalVariables ↔ List<ConfigVariable>?
Additional SSL related field values
getter/setter pair
clientCertificate ↔ Secret?
Client Certificate
getter/setter pair
clientCertType ↔ String?
Type of Client Cert (PEM/JKS/..
getter/setter pair
clientPrivateKey ↔ Secret?
Client Private Key
getter/setter pair
clientPrivateKeyPass ↔ Secret?
Secret containing the passphrase protecting the Client Private Key
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privateServerCertificate ↔ Secret?
Private Server Certificate.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverCertType ↔ String?
Type of Server Cert (PEM/JKS/..
getter/setter pair
trustModel ↔ String?
Trust Model of the SSL connection
getter/setter pair
type ↔ String?
Controls the ssl type for the given connector version.
getter/setter pair
useSsl ↔ bool?
Bool for enabling SSL
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited