baseVersion property
Represents the base version of the toolspec for which admin has added overrides.
Required.
Implementation
core.String? baseVersion;
Represents the base version of the toolspec for which admin has added overrides.
Required.
core.String? baseVersion;