tools property
List of tools defined in the tool spec.
Marking this field as required as this is the only field that is editable by the user in modify API so we should have at least one tool in the list.
Required.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.List<core.Map<core.String, core.Object?>>? tools;