ValidateCustomConnectorSpecRequest class

Request message for ConnectorsService.ValidateCustomConnectorSpec

Constructors

ValidateCustomConnectorSpecRequest({String? serviceAccount, String? specLocation, String? specType})
ValidateCustomConnectorSpecRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Service account to access the spec from Google Cloud Storage.
getter/setter pair
specLocation ↔ String?
Location of the custom connector spec.
getter/setter pair
specType ↔ String?
Spec type of the custom connector spec.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited