AccessCredentials class

AccessCredentials includes the OAuth access token, and the other fields returned along with it.

Constructors

AccessCredentials({String? accessToken, String? expiresIn, String? refreshToken})
AccessCredentials.fromJson(Map json_)

Properties

accessToken ↔ String?
OAuth access token.
getter/setter pair
expiresIn ↔ String?
Duration till the access token expires.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
refreshToken ↔ String?
OAuth refresh token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited