CheckStatusResponse class

The status of the connector.

Constructors

CheckStatusResponse({String? description, Map<String, Map<String, Object?>>? metadata, String? state})
CheckStatusResponse.fromJson(Map json_)

Properties

description ↔ String?
When the connector is not in ACTIVE state, the description must be populated to specify the reason why it's not in ACTIVE state.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, Map<String, Object?>>?
Metadata like service latency, etc.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the connector. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited