EntityType class

EntityType message contains metadata information about a single entity type present in the external system.

Constructors

EntityType({String? defaultSortBy, List<Field>? fields, JsonSchema? jsonSchema, Map<String, Map<String, Object?>>? metadata, String? name, List<String>? operations})
EntityType.fromJson(Map json_)

Properties

defaultSortBy ↔ String?
getter/setter pair
fields ↔ List<Field>?
List containing metadata information about each field of the entity type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonSchema ↔ JsonSchema?
JsonSchema representation of this entity's schema
getter/setter pair
metadata ↔ Map<String, Map<String, Object?>>?
Metadata like service latency, etc.
getter/setter pair
name ↔ String?
The name of the entity type.
getter/setter pair
operations ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited