ExecuteHttpRequestRequest class

Constructors

ExecuteHttpRequestRequest({List<HttpHeader>? headers, String? httpMethod, String? rawBody, String? url})
ExecuteHttpRequestRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers ↔ List<HttpHeader>?
HTTP headers to send with the request (e.g., Content-Type: application/json).
getter/setter pair
httpMethod ↔ String?
The HTTP method to use for the request.
getter/setter pair
rawBody ↔ String?
Raw byte payload.
getter/setter pair
rawBodyAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The fully resolved absolute target URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited