headers property
HTTP headers received in the response.
Order is preserved and duplicate keys are allowed (e.g., multiple Set-Cookie headers).
Implementation
core.List<HttpHeader>? headers;
HTTP headers received in the response.
Order is preserved and duplicate keys are allowed (e.g., multiple Set-Cookie headers).
core.List<HttpHeader>? headers;