ExecuteSqlQueryRequest class

An execute sql query request containing the query and the connection to execute it on.

Properties

hashCode → int
The hash code for this object.
no setterinherited
query ↔ Query?
SQL statement passed by clients like Integration Platform, the query is passed as-is to the driver used for interfacing with external systems.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited