ExecuteSqlQueryResponse class

A response returned by the connection after executing the sql query.

Properties

hashCode → int
The hash code for this object.
no setterinherited
results ↔ List<Map<String, Object?>>?
In the case of successful execution of the query the response contains results returned by the external system.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited