ExecuteToolRequest class

Request message for ConnectorAgentService.ExecuteTool

Constructors

ExecuteToolRequest({ExecutionConfig? executionConfig, Map<String, Object?>? parameters, Map<String, Object?>? toolDefinition})
ExecuteToolRequest.fromJson(Map json_)

Properties

executionConfig ↔ ExecutionConfig?
execution config for the request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parameters ↔ Map<String, Object?>?
Input parameters for the tool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolDefinition ↔ Map<String, Object?>?
Tool definition for the tool to be executed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited