Field class

Message contains EntityType's Field metadata.

Constructors

Field({Map<String, Object?>? additionalDetails, String? dataType, Object? defaultValue, String? description, JsonSchema? jsonSchema, bool? key, String? name, bool? nullable, Reference? reference})
Field.fromJson(Map json_)

Properties

additionalDetails ↔ Map<String, Object?>?
The following map contains fields that are not explicitly mentioned above,this give connectors the flexibility to add new metadata fields.
getter/setter pair
dataType ↔ String?
The data type of the Field. Possible string values are:
getter/setter pair
defaultValue ↔ Object?
The following field specifies the default value of the Field provided by the external system if a value is not provided.
getter/setter pair
description ↔ String?
A brief description of the Field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonSchema ↔ JsonSchema?
JsonSchema of the field, applicable only if field is of type STRUCT
getter/setter pair
key ↔ bool?
The following boolean field specifies if the current Field acts as a primary key or id if the parent is of type entity.
getter/setter pair
name ↔ String?
Name of the Field.
getter/setter pair
nullable ↔ bool?
Specifies whether a null value is allowed.
getter/setter pair
reference ↔ Reference?
Reference captures the association between two different entity types.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited