InputParameter class

Input Parameter message contains metadata about the parameters required for executing an Action.

Constructors

InputParameter({Map<String, Object?>? additionalDetails, String? dataType, Object? defaultValue, String? description, JsonSchema? jsonSchema, String? name, bool? nullable})
InputParameter.fromJson(Map json_)

Properties

additionalDetails ↔ Map<String, Object?>?
The following map contains fields that are not explicitly mentioned above,this give connectors the flexibility to add new metadata fields.
getter/setter pair
dataType ↔ String?
The data type of the Parameter Possible string values are:
getter/setter pair
defaultValue ↔ Object?
The following field specifies the default value of the Parameter provided by the external system if a value is not provided.
getter/setter pair
description ↔ String?
A brief description of the Parameter.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonSchema ↔ JsonSchema?
JsonSchema of the parameter, applicable only if parameter is of type STRUCT
getter/setter pair
name ↔ String?
Name of the Parameter.
getter/setter pair
nullable ↔ bool?
Specifies whether a null value is allowed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited