const_ property
Const value that the data must match.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Object? const_;
Const value that the data must match.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
core.Object? const_;