maximum property
Maximum value of the number field.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Object? maximum;
Maximum value of the number field.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
core.Object? maximum;