minimum property
Minimum value of the number field.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Object? minimum;
Minimum value of the number field.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
core.Object? minimum;