pattern property
Regex pattern of the string field.
This is a string value that describes the regular expression that the string value should match.
Implementation
core.String? pattern;
Regex pattern of the string field.
This is a string value that describes the regular expression that the string value should match.
core.String? pattern;