ListToolsPostRequest class

Request message for ConnectorAgentService.ListToolsPost

Constructors

ListToolsPostRequest({ExecutionConfig? executionConfig, int? pageSize, String? pageToken, List<String>? toolNames, ToolSpec? toolSpec})
ListToolsPostRequest.fromJson(Map json_)

Properties

executionConfig ↔ ExecutionConfig?
execution config for the request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int?
Page size.
getter/setter pair
pageToken ↔ String?
Page token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolNames ↔ List<String>?
List of tool names to for selective tool fetching.
getter/setter pair
toolSpec ↔ ToolSpec?
List of tool specifications.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited