ProjectsLocationsConnectionsEntityTypesResource class

Constructors

ProjectsLocationsConnectionsEntityTypesResource(ApiRequester client)

Properties

entities → ProjectsLocationsConnectionsEntityTypesEntitiesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? contextMetadata, String? executionConfig_headers, String? view, String? $fields}) → Future<EntityType>
Gets metadata of given entity type
list(String parent, {String? executionConfig_headers, int? pageSize, String? pageToken, String? view, String? $fields}) → Future<ListEntityTypesResponse>
Lists metadata related to all entity types present in the external system.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited