Resource class

Constructors

Resource({Map<String, Object?>? P_meta, String? description, String? mimeType, String? name, String? size, String? uri})
Resource.fromJson(Map json_)

Properties

description ↔ String?
A description of what this resource represents.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mimeType ↔ String?
The MIME type of this resource, if known.
getter/setter pair
name ↔ String?
A human-readable name for this resource.
getter/setter pair
P_meta ↔ Map<String, Object?>?
Metadata for the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ String?
The size of the raw resource content, in bytes, if known.
getter/setter pair
uri ↔ String?
The URI of this resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited