ResultMetadata class

Result Metadata message contains metadata about the result returned after executing an Action.

Constructors

ResultMetadata({String? dataType, Object? defaultValue, String? description, JsonSchema? jsonSchema, String? name, bool? nullable})
ResultMetadata.fromJson(Map json_)

Properties

dataType ↔ String?
The data type of the metadata field Possible string values are:
getter/setter pair
defaultValue ↔ Object?
The following field specifies the default value of the Parameter provided by the external system if a value is not provided.
getter/setter pair
description ↔ String?
A brief description of the metadata field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonSchema ↔ JsonSchema?
JsonSchema of the result, applicable only if parameter is of type STRUCT
getter/setter pair
name ↔ String?
Name of the metadata field.
getter/setter pair
nullable ↔ bool?
Specifies whether a null value is allowed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited