ToolName class

Constructors

ToolName({String? entityName, String? name, String? operation})
ToolName.fromJson(Map json_)

Properties

entityName String?
Entity name for which the tool was generated.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Tool name that was generated in the list tools call.
getter/setter pair
operation String?
Operation for which the tool was generated. Possible string values are:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited