ToolSpec class

Constructors

ToolSpec({List<Map<String, Object?>>? toolDefinitions, String? toolSpecVersion})
ToolSpec.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toolDefinitions ↔ List<Map<String, Object?>>?
List of tool definitions.
getter/setter pair
toolSpecVersion ↔ String?
Version of the tool spec.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited