contactcenterinsights/v1 library

Contact Center AI Insights API - v1

For more information, see cloud.google.com/contact-center/insights/docs

Create an instance of ContactcenterinsightsApi to access these resources:

ProjectsLocationsAuthorizedViewSetsAuthorizedViewsConversationsAssessmentsResource

ProjectsLocationsAuthorizedViewSetsAuthorizedViewsConversationsAssessmentsNotesResource

ProjectsLocationsAuthorizedViewSetsAuthorizedViewsConversationsFeedbackLabelsResource

Classes

ContactcenterinsightsApi
GoogleCloudContactcenterinsightsV1Analysis
The analysis resource.
GoogleCloudContactcenterinsightsV1AnalysisResult
The result of an analysis.
GoogleCloudContactcenterinsightsV1AnalysisResultCallAnalysisMetadata
Call-specific metadata created during analysis.
GoogleCloudContactcenterinsightsV1AnalysisRule
The CCAI Insights project wide analysis rule.
GoogleCloudContactcenterinsightsV1AnnotationBoundary
A point in a conversation that marks the start or the end of an annotation.
GoogleCloudContactcenterinsightsV1AnnotatorSelector
Selector of all available annotators and phrase matchers to run.
GoogleCloudContactcenterinsightsV1AnnotatorSelectorQaConfig
Configuration for the QA feature.
GoogleCloudContactcenterinsightsV1AnnotatorSelectorQaConfigScorecardList
Container for a list of scorecards.
GoogleCloudContactcenterinsightsV1AnnotatorSelectorSummarizationConfig
Configuration for summarization.
GoogleCloudContactcenterinsightsV1AnswerFeedback
The feedback that the customer has about a certain answer in the conversation.
GoogleCloudContactcenterinsightsV1ArticleSuggestionData
Agent Assist Article Suggestion data.
GoogleCloudContactcenterinsightsV1Assessment
The assessment resource.
GoogleCloudContactcenterinsightsV1AssessmentRule
The CCAI Insights project wide assessment rule.
GoogleCloudContactcenterinsightsV1AuthorizedView
An AuthorizedView represents a view of accessible Insights resources (for example, Conversation and Scorecard).
GoogleCloudContactcenterinsightsV1AuthorizedViewSet
An AuthorizedViewSet contains a set of AuthorizedView resources.
GoogleCloudContactcenterinsightsV1AutoLabelingRule
Rule for auto-labeling conversations.
GoogleCloudContactcenterinsightsV1AutoLabelingRuleLabelingCondition
Condition for auto-labeling conversations.
GoogleCloudContactcenterinsightsV1BulkAnalyzeConversationsRequest
The request to analyze conversations in bulk.
GoogleCloudContactcenterinsightsV1BulkDeleteConversationsRequest
The request to delete conversations in bulk.
GoogleCloudContactcenterinsightsV1BulkDeleteFeedbackLabelsRequest
Request for the BulkDeleteFeedbackLabels endpoint.
GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequest
Request for the BulkDownloadFeedbackLabel endpoint.
GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestGcsDestination
Google Cloud Storage Object details to write the feedback labels to.
GoogleCloudContactcenterinsightsV1BulkDownloadFeedbackLabelsRequestSheetsDestination
Google Sheets document details to write the feedback labels to.
GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequest
The request for bulk uploading feedback labels.
GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestGcsSource
Google Cloud Storage Object details to get the feedback label file from.
GoogleCloudContactcenterinsightsV1BulkUploadFeedbackLabelsRequestSheetsSource
Google Sheets document details to get the feedback label file from.
GoogleCloudContactcenterinsightsV1CalculateIssueModelStatsResponse
Response of querying an issue model's statistics.
GoogleCloudContactcenterinsightsV1CalculateStatsRequest
The request for calculating conversation statistics.
GoogleCloudContactcenterinsightsV1CalculateStatsResponse
The response for calculating conversation statistics.
GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeries
A time series representing conversations over time.
GoogleCloudContactcenterinsightsV1CalculateStatsResponseTimeSeriesInterval
A single interval in a time series.
GoogleCloudContactcenterinsightsV1CallAnnotation
A piece of metadata that applies to a window of a call.
GoogleCloudContactcenterinsightsV1Chart
Configurable dashboard's widget that displays data as a chart.
GoogleCloudContactcenterinsightsV1ChartDataSource
The request data for visualizing the dataset in the chart.
GoogleCloudContactcenterinsightsV1Container
Configurable dashboard's container.
GoogleCloudContactcenterinsightsV1Conversation
The conversation resource.
GoogleCloudContactcenterinsightsV1ConversationCallMetadata
Call-specific metadata.
GoogleCloudContactcenterinsightsV1ConversationCorrelationInfo
Info for correlating across conversations.
GoogleCloudContactcenterinsightsV1ConversationDataOptions
Options for configuring what metadata is included in the conversation data used in QAI and Discovery Engine.
GoogleCloudContactcenterinsightsV1ConversationDataSource
The conversation source, which is a combination of transcript and audio.
GoogleCloudContactcenterinsightsV1ConversationDataSourceTurnLevelAudio
A wrapper for holding the audio for any given turn.
GoogleCloudContactcenterinsightsV1ConversationLevelSentiment
One channel of conversation-level sentiment data.
GoogleCloudContactcenterinsightsV1ConversationLevelSilence
Conversation-level silence data.
GoogleCloudContactcenterinsightsV1ConversationParticipant
The call participant speaking for a given utterance.
GoogleCloudContactcenterinsightsV1ConversationQualityMetadata
Conversation metadata related to quality management.
GoogleCloudContactcenterinsightsV1ConversationQualityMetadataAgentInfo
Information about an agent involved in the conversation.
GoogleCloudContactcenterinsightsV1ConversationSummarizationSuggestionData
Conversation summarization suggestion data.
GoogleCloudContactcenterinsightsV1ConversationTranscript
A message representing the transcript of a conversation.
GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegment
A segment of a full transcript.
GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentDialogflowSegmentMetadata
Metadata from Dialogflow relating to the current transcript segment.
GoogleCloudContactcenterinsightsV1ConversationTranscriptTranscriptSegmentWordInfo
Word-level info for words in a transcript.
GoogleCloudContactcenterinsightsV1CorrelationConfig
A configuration that defines how to correlate conversations for a given a given project.
GoogleCloudContactcenterinsightsV1CorrelationRule
A correlation rule that defines how to join conversations for a given correlation type.
GoogleCloudContactcenterinsightsV1CorrelationTypeConfig
A list of correlation rules for a given correlation type.
GoogleCloudContactcenterinsightsV1Dashboard
Configurable dashboard
GoogleCloudContactcenterinsightsV1Dataset
Dataset resource represents a collection of conversations that may be bounded (Static Dataset, e.g. golden dataset for training), or unbounded (Dynamic Dataset, e.g. live traffic, or agent training traffic)
GoogleCloudContactcenterinsightsV1DateRangeConfig
Date range configuration for dashboard charts.
GoogleCloudContactcenterinsightsV1DateRangeConfigRelativeDateRange
Relative date range configuration.
GoogleCloudContactcenterinsightsV1DeployIssueModelRequest
The request to deploy an issue model.
GoogleCloudContactcenterinsightsV1DialogflowIntent
The data for a Dialogflow intent.
GoogleCloudContactcenterinsightsV1DialogflowInteractionData
Dialogflow interaction data.
GoogleCloudContactcenterinsightsV1DialogflowSource
A Dialogflow source of conversation data.
GoogleCloudContactcenterinsightsV1Dimension
A dimension determines the grouping key for the query.
GoogleCloudContactcenterinsightsV1DimensionAgentDimensionMetadata
Metadata about the agent dimension.
GoogleCloudContactcenterinsightsV1DimensionClientSentimentCategoryDimensionMetadata
Metadata about the client sentiment category dimension.
GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsPlaybookDimensionMetadata
Metadata about the Conversational Agents playbook dimension.
GoogleCloudContactcenterinsightsV1DimensionConversationalAgentsToolDimensionMetadata
Metadata about the Conversational Agents tool dimension.
GoogleCloudContactcenterinsightsV1DimensionConversationProfileDimensionMetadata
Metadata about the conversation profile dimension.
GoogleCloudContactcenterinsightsV1DimensionIssueDimensionMetadata
Metadata about the issue dimension.
GoogleCloudContactcenterinsightsV1DimensionLabelDimensionMetadata
Metadata about conversation labels.
GoogleCloudContactcenterinsightsV1DimensionMediumDimensionMetadata
Metadata about the conversation medium dimension.
GoogleCloudContactcenterinsightsV1DimensionQaQuestionAnswerDimensionMetadata
Metadata about the QA question-answer dimension.
GoogleCloudContactcenterinsightsV1DimensionQaQuestionDimensionMetadata
Metadata about the QA question dimension.
GoogleCloudContactcenterinsightsV1DimensionQaScorecardDimensionMetadata
Metadata about the QA scorecard dimension.
GoogleCloudContactcenterinsightsV1EncryptionSpec
A customer-managed encryption key specification that can be applied to all created resources (e.g. Conversation).
GoogleCloudContactcenterinsightsV1Entity
The data for an entity annotation.
GoogleCloudContactcenterinsightsV1EntityMentionData
The data for an entity mention annotation.
GoogleCloudContactcenterinsightsV1ExactMatchConfig
Exact match configuration.
GoogleCloudContactcenterinsightsV1ExportInsightsDataRequest
The request to export insights.
GoogleCloudContactcenterinsightsV1ExportInsightsDataRequestBigQueryDestination
A BigQuery Table Reference.
GoogleCloudContactcenterinsightsV1ExportIssueModelRequest
Request to export an issue model.
GoogleCloudContactcenterinsightsV1FaqAnswerData
Agent Assist frequently-asked-question answer data.
GoogleCloudContactcenterinsightsV1FeedbackLabel
Represents a conversation, resource, and label provided by the user.
GoogleCloudContactcenterinsightsV1GcsSource
A Cloud Storage source of conversation data.
GoogleCloudContactcenterinsightsV1GenerateConversationSignedAudioResponse
The response from a GenerateConversationSignedAudio request.
GoogleCloudContactcenterinsightsV1GenerativeInsights
Request that use natural language query to generate the chart.
GoogleCloudContactcenterinsightsV1GenerativeInsightsChartCheckpoint
The current chart checkpoint state.
GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversation
The conversation used to generate the chart.
GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessage
The message in the conversation.
GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessage
A message from the system in response to the user.
GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageSystemMessageTextOutput
A text output message from the system.
GoogleCloudContactcenterinsightsV1GenerativeInsightsChartConversationMessageUserMessage
The user message.
GoogleCloudContactcenterinsightsV1GenerativeInsightsRequest
The request for generative insights.
GoogleCloudContactcenterinsightsV1ImportIssueModelRequest
Request to import an issue model.
GoogleCloudContactcenterinsightsV1IngestConversationsRequest
The request to ingest conversations.
GoogleCloudContactcenterinsightsV1IngestConversationsRequestConversationConfig
Configuration that applies to all conversations.
GoogleCloudContactcenterinsightsV1IngestConversationsRequestGcsSource
Configuration for Cloud Storage bucket sources.
GoogleCloudContactcenterinsightsV1IngestConversationsRequestTranscriptObjectConfig
Configuration for processing transcript objects.
GoogleCloudContactcenterinsightsV1InitializeEncryptionSpecRequest
The request to initialize a location-level encryption specification.
GoogleCloudContactcenterinsightsV1Intent
The data for an intent.
GoogleCloudContactcenterinsightsV1IntentMatchData
The data for an intent match.
GoogleCloudContactcenterinsightsV1Issue
The issue resource.
GoogleCloudContactcenterinsightsV1IssueAssignment
Information about the issue.
GoogleCloudContactcenterinsightsV1IssueMatchData
The data for an issue match annotation.
GoogleCloudContactcenterinsightsV1IssueModel
The issue model resource.
GoogleCloudContactcenterinsightsV1IssueModelInputDataConfig
Configs for the input data used to create the issue model.
GoogleCloudContactcenterinsightsV1IssueModelLabelStats
Aggregated statistics about an issue model.
GoogleCloudContactcenterinsightsV1IssueModelLabelStatsIssueStats
Aggregated statistics about an issue.
GoogleCloudContactcenterinsightsV1IssueModelResult
Issue Modeling result on a conversation.
GoogleCloudContactcenterinsightsV1ListAllFeedbackLabelsResponse
The response for listing all feedback labels.
GoogleCloudContactcenterinsightsV1ListAnalysesResponse
The response to list analyses.
GoogleCloudContactcenterinsightsV1ListAnalysisRulesResponse
The response of listing views.
GoogleCloudContactcenterinsightsV1ListAssessmentRulesResponse
The response of listing assessment rules.
GoogleCloudContactcenterinsightsV1ListAssessmentsResponse
The response of listing assessments.
GoogleCloudContactcenterinsightsV1ListAuthorizedViewSetsResponse
The response from a ListAuthorizedViewSet request.
GoogleCloudContactcenterinsightsV1ListAuthorizedViewsResponse
The response from a ListAuthorizedViews request.
GoogleCloudContactcenterinsightsV1ListAutoLabelingRulesResponse
The response message for listing auto labeling rules.
GoogleCloudContactcenterinsightsV1ListChartsResponse
The response of listing charts.
GoogleCloudContactcenterinsightsV1ListConversationsResponse
The response of listing conversations.
GoogleCloudContactcenterinsightsV1ListDashboardsResponse
The response of listing dashboards.
GoogleCloudContactcenterinsightsV1ListDatasetsResponse
The response to list datasets.
GoogleCloudContactcenterinsightsV1ListFeedbackLabelsResponse
The response for listing feedback labels.
GoogleCloudContactcenterinsightsV1ListIssueModelsResponse
The response of listing issue models.
GoogleCloudContactcenterinsightsV1ListIssuesResponse
The response of listing issues.
GoogleCloudContactcenterinsightsV1ListNotesResponse
The response of listing notes.
GoogleCloudContactcenterinsightsV1ListPhraseMatchersResponse
The response of listing phrase matchers.
GoogleCloudContactcenterinsightsV1ListQaQuestionsResponse
The response from a ListQaQuestions request.
GoogleCloudContactcenterinsightsV1ListQaQuestionTagsResponse
The response from a ListQaQuestionTags request.
GoogleCloudContactcenterinsightsV1ListQaScorecardRevisionsResponse
The response from a ListQaScorecardRevisions request.
GoogleCloudContactcenterinsightsV1ListQaScorecardsResponse
The response from a ListQaScorecards request.
GoogleCloudContactcenterinsightsV1ListViewsResponse
The response of listing views.
GoogleCloudContactcenterinsightsV1Note
The conversation assessment note resource.
GoogleCloudContactcenterinsightsV1NoteConversationTurnNote
A note about a conversation turn.
GoogleCloudContactcenterinsightsV1NoteQaQuestionNote
A note about a QA question.
GoogleCloudContactcenterinsightsV1PhraseMatchData
The data for a matched phrase matcher.
GoogleCloudContactcenterinsightsV1PhraseMatcher
The phrase matcher resource.
GoogleCloudContactcenterinsightsV1PhraseMatchRule
The data for a phrase match rule.
GoogleCloudContactcenterinsightsV1PhraseMatchRuleConfig
Configuration information of a phrase match rule.
GoogleCloudContactcenterinsightsV1PhraseMatchRuleGroup
A message representing a rule in the phrase matcher.
GoogleCloudContactcenterinsightsV1QaAnswer
An answer to a QaQuestion.
GoogleCloudContactcenterinsightsV1QaAnswerAnswerSource
A question may have multiple answers from varying sources, one of which becomes the "main" answer above.
GoogleCloudContactcenterinsightsV1QaAnswerAnswerValue
Message for holding the value of a QaAnswer.
GoogleCloudContactcenterinsightsV1QaQuestion
A single question to be scored by the Insights QA feature.
GoogleCloudContactcenterinsightsV1QaQuestionAnswerChoice
Message representing a possible answer to the question.
GoogleCloudContactcenterinsightsV1QaQuestionMetrics
A wrapper representing metrics calculated against a test-set on a LLM that was fine tuned for this question.
GoogleCloudContactcenterinsightsV1QaQuestionPredefinedQuestionConfig
Configuration for a predefined question.
GoogleCloudContactcenterinsightsV1QaQuestionQaQuestionDataOptions
Options for configuring the data used to generate the QA question.
GoogleCloudContactcenterinsightsV1QaQuestionTag
A tag is a resource which aims to categorize a set of questions across multiple scorecards, e.g., "Customer Satisfaction","Billing", etc.
GoogleCloudContactcenterinsightsV1QaQuestionTuningMetadata
Metadata about the tuning operation for the question.
GoogleCloudContactcenterinsightsV1QaScorecard
A QaScorecard represents a collection of questions to be scored during analysis.
GoogleCloudContactcenterinsightsV1QaScorecardResult
The results of scoring a single conversation against a QaScorecard.
GoogleCloudContactcenterinsightsV1QaScorecardResultQaTagResult
Tags and their corresponding results.
GoogleCloudContactcenterinsightsV1QaScorecardResultScoreSource
A scorecard result may have multiple sets of scores from varying sources, one of which becomes the "main" answer above.
GoogleCloudContactcenterinsightsV1QaScorecardRevision
A revision of a QaScorecard.
GoogleCloudContactcenterinsightsV1QueryInterval
A time window for querying conversations.
GoogleCloudContactcenterinsightsV1QueryMetrics
Request data that use the existing QueryMetrics.
GoogleCloudContactcenterinsightsV1QueryMetricsRequest
The request for querying metrics.
GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequest
The request for summarizing performance according to different metrics for conversations over a specified time window.
GoogleCloudContactcenterinsightsV1QueryPerformanceOverviewRequestAgentSource
The entity whose performance is being queried is a single agent.
GoogleCloudContactcenterinsightsV1RedactionConfig
DLP resources used for redaction while ingesting conversations.
GoogleCloudContactcenterinsightsV1RuntimeAnnotation
An annotation that was generated during the customer and agent interaction.
GoogleCloudContactcenterinsightsV1RuntimeAnnotationUserInput
Explicit input used for generating the answer
GoogleCloudContactcenterinsightsV1SampleConversationsRequest
The request to sample conversations to a dataset.
GoogleCloudContactcenterinsightsV1SampleRule
Message for sampling conversations.
GoogleCloudContactcenterinsightsV1ScheduleInfo
Message for schedule info.
GoogleCloudContactcenterinsightsV1SearchAuthorizedViewsResponse
The response from a ListAuthorizedViews request.
GoogleCloudContactcenterinsightsV1SentimentData
The data for a sentiment annotation.
GoogleCloudContactcenterinsightsV1Settings
The CCAI Insights project wide settings.
GoogleCloudContactcenterinsightsV1SettingsAnalysisConfig
Default configuration when creating Analyses in Insights.
GoogleCloudContactcenterinsightsV1SignedAudioUris
Signed audio URIs for a conversation.
GoogleCloudContactcenterinsightsV1SmartComposeSuggestionData
Agent Assist Smart Compose suggestion data.
GoogleCloudContactcenterinsightsV1SmartReplyData
Agent Assist Smart Reply data.
GoogleCloudContactcenterinsightsV1SpeechConfig
Speech-to-Text configuration.
GoogleCloudContactcenterinsightsV1TestAutoLabelingRuleRequest
The request message for testing auto labeling rules.
GoogleCloudContactcenterinsightsV1TestAutoLabelingRuleResponse
The response message for testing auto labeling rules.
GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequest
The request to test correlation config.
GoogleCloudContactcenterinsightsV1TestCorrelationConfigRequestConversations
Wrapper for a list of conversations.
GoogleCloudContactcenterinsightsV1TuneQaScorecardRevisionRequest
Request for TuneQaScorecardRevision endpoint.
GoogleCloudContactcenterinsightsV1UndeployIssueModelRequest
The request to undeploy an issue model.
GoogleCloudContactcenterinsightsV1UploadConversationRequest
Request to upload a conversation.
GoogleCloudContactcenterinsightsV1UserInfo
Information about a user.
GoogleCloudContactcenterinsightsV1View
The View resource.
GoogleCloudContactcenterinsightsV1Widget
Represents a dashboard element, could be a nested Container or Chart.
GoogleIamV1AuditConfig
Specifies the audit configuration for a service.
GoogleIamV1Binding
Associates members, or principals, with a role.
GoogleIamV1Policy
An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources.
GoogleIamV1SetIamPolicyRequest
Request message for SetIamPolicy method.
GoogleLongrunningListOperationsResponse
The response message for Operations.ListOperations.
GoogleLongrunningOperation
This resource represents a long-running operation that is the result of a network API call.
ProjectsLocationsAnalysisRulesResource
ProjectsLocationsAssessmentRulesResource
ProjectsLocationsAuthorizedViewSetsAuthorizedViewsConversationsAssessmentsNotesResource
ProjectsLocationsAuthorizedViewSetsAuthorizedViewsConversationsAssessmentsResource
ProjectsLocationsAuthorizedViewSetsAuthorizedViewsConversationsFeedbackLabelsResource
ProjectsLocationsAuthorizedViewSetsAuthorizedViewsConversationsResource
ProjectsLocationsAuthorizedViewSetsAuthorizedViewsOperationsResource
ProjectsLocationsAuthorizedViewSetsAuthorizedViewsResource
ProjectsLocationsAuthorizedViewSetsResource
ProjectsLocationsAutoLabelingRulesResource
ProjectsLocationsConversationsAnalysesResource
ProjectsLocationsConversationsAssessmentsNotesResource
ProjectsLocationsConversationsAssessmentsResource
ProjectsLocationsConversationsFeedbackLabelsResource
ProjectsLocationsConversationsResource
ProjectsLocationsConversationsSegmentsResource
ProjectsLocationsDashboardsChartsResource
ProjectsLocationsDashboardsResource
ProjectsLocationsDatasetsConversationsFeedbackLabelsResource
ProjectsLocationsDatasetsConversationsResource
ProjectsLocationsDatasetsInsightsdataResource
ProjectsLocationsDatasetsResource
ProjectsLocationsEncryptionSpecResource
ProjectsLocationsInsightsdataResource
ProjectsLocationsIssueModelsIssuesResource
ProjectsLocationsIssueModelsResource
ProjectsLocationsOperationsResource
ProjectsLocationsPhraseMatchersResource
ProjectsLocationsQaQuestionTagsResource
ProjectsLocationsQaScorecardsResource
ProjectsLocationsQaScorecardsRevisionsQaQuestionsResource
ProjectsLocationsQaScorecardsRevisionsResource
ProjectsLocationsResource
ProjectsLocationsViewsResource
ProjectsResource

Typedefs

GoogleCloudContactcenterinsightsV1AppealAssessmentRequest = $Empty
The message to appeal an assessment.
GoogleCloudContactcenterinsightsV1DeployQaScorecardRevisionRequest = $Empty
The request to deploy a QaScorecardRevision
GoogleCloudContactcenterinsightsV1ExportIssueModelRequestGcsDestination = $Shared14
Google Cloud Storage Object URI to save the issue model to.
GoogleCloudContactcenterinsightsV1FinalizeAssessmentRequest = $Empty
The message to finalize an assessment.
GoogleCloudContactcenterinsightsV1HoldData = $Empty
The data for a hold annotation.
GoogleCloudContactcenterinsightsV1ImportIssueModelRequestGcsSource = $Shared14
Google Cloud Storage Object URI to get the issue model file from.
GoogleCloudContactcenterinsightsV1InterruptionData = $Empty
The data for an interruption annotation.
GoogleCloudContactcenterinsightsV1NoteAssessmentNote = $Empty
A note about the entire parent assessment.
GoogleCloudContactcenterinsightsV1PublishAssessmentRequest = $Empty
The message to publish an assessment.
GoogleCloudContactcenterinsightsV1RegexMatchConfig = $Empty
Regex match configuration.
GoogleCloudContactcenterinsightsV1SilenceData = $Empty
The data for a silence annotation.
GoogleCloudContactcenterinsightsV1UndeployQaScorecardRevisionRequest = $Empty
The request to undeploy a QaScorecardRevision
GoogleIamV1AuditLogConfig = $AuditLogConfig
Provides the configuration for logging a type of permissions.
GoogleIamV1TestIamPermissionsRequest = $TestIamPermissionsRequest00
Request message for TestIamPermissions method.
GoogleIamV1TestIamPermissionsResponse = $PermissionsResponse
Response message for TestIamPermissions method.
GoogleProtobufEmpty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
GoogleRpcStatus = $Status00
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
GoogleTypeExpr = $Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.