AcceleratorConfig class

AcceleratorConfig represents a Hardware Accelerator request.

Constructors

AcceleratorConfig({String? acceleratorCount, String? acceleratorType, GPUDriverInstallationConfig? gpuDriverInstallationConfig, String? gpuPartitionSize, GPUSharingConfig? gpuSharingConfig})
AcceleratorConfig.fromJson(Map json_)

Properties

acceleratorCount ↔ String?
The number of the accelerator cards exposed to an instance.
getter/setter pair
acceleratorType ↔ String?
The accelerator type resource name.
getter/setter pair
gpuDriverInstallationConfig ↔ GPUDriverInstallationConfig?
The configuration for auto installation of GPU driver.
getter/setter pair
gpuPartitionSize ↔ String?
Size of partitions to create on the GPU.
getter/setter pair
gpuSharingConfig ↔ GPUSharingConfig?
The configuration for GPU sharing options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited