AccurateTimeConfig class

AccurateTimeConfig contains configuration for the accurate time synchronization feature.

Constructors

AccurateTimeConfig({bool? enablePtpKvmTimeSync})
AccurateTimeConfig.fromJson(Map json_)

Properties

enablePtpKvmTimeSync bool?
Enables enhanced time synchronization using PTP-KVM.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited