AdditionalNodeNetworkConfig class

AdditionalNodeNetworkConfig is the configuration for additional node networks within the NodeNetworkConfig message

Properties

hashCode → int
The hash code for this object.
no setterinherited
network ↔ String?
Name of the VPC where the additional interface belongs
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetwork ↔ String?
Name of the subnetwork where the additional interface belongs
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited