AdditionalPodRangesConfig class

AdditionalPodRangesConfig is the configuration for additional pod secondary ranges supporting the ClusterUpdate message.

Constructors

AdditionalPodRangesConfig({List<RangeInfo>? podRangeInfo, List<String>? podRangeNames})
AdditionalPodRangesConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
podRangeInfo ↔ List<RangeInfo>?
Information for additional pod range.
getter/setter pair
podRangeNames ↔ List<String>?
Name for pod secondary ipv4 range which has the actual range defined ahead.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited