AddonsConfig class

Configuration for the addons that can be automatically spun up in the cluster, enabling additional functionality.

Constructors

AddonsConfig({AgentSandboxConfig? agentSandboxConfig, CloudRunConfig? cloudRunConfig, ConfigConnectorConfig? configConnectorConfig, DnsCacheConfig? dnsCacheConfig, GcePersistentDiskCsiDriverConfig? gcePersistentDiskCsiDriverConfig, GcpFilestoreCsiDriverConfig? gcpFilestoreCsiDriverConfig, GcsFuseCsiDriverConfig? gcsFuseCsiDriverConfig, GkeBackupAgentConfig? gkeBackupAgentConfig, HighScaleCheckpointingConfig? highScaleCheckpointingConfig, HorizontalPodAutoscaling? horizontalPodAutoscaling, HttpLoadBalancing? httpLoadBalancing, KubernetesDashboard? kubernetesDashboard, LustreCsiDriverConfig? lustreCsiDriverConfig, NetworkPolicyConfig? networkPolicyConfig, NodeReadinessConfig? nodeReadinessConfig, ParallelstoreCsiDriverConfig? parallelstoreCsiDriverConfig, PodSnapshotConfig? podSnapshotConfig, RayOperatorConfig? rayOperatorConfig, SliceControllerConfig? sliceControllerConfig, SlurmOperatorConfig? slurmOperatorConfig, StatefulHAConfig? statefulHaConfig})
AddonsConfig.fromJson(Map json_)

Properties

agentSandboxConfig ↔ AgentSandboxConfig?
Configuration for the AgentSandbox addon.
getter/setter pair
cloudRunConfig ↔ CloudRunConfig?
Configuration for the Cloud Run addon, which allows the user to use a managed Knative service.
getter/setter pair
configConnectorConfig ↔ ConfigConnectorConfig?
Configuration for the ConfigConnector add-on, a Kubernetes extension to manage hosted Google Cloud services through the Kubernetes API.
getter/setter pair
dnsCacheConfig ↔ DnsCacheConfig?
Configuration for NodeLocalDNS, a dns cache running on cluster nodes
getter/setter pair
gcePersistentDiskCsiDriverConfig ↔ GcePersistentDiskCsiDriverConfig?
Configuration for the Compute Engine Persistent Disk CSI driver.
getter/setter pair
gcpFilestoreCsiDriverConfig ↔ GcpFilestoreCsiDriverConfig?
Configuration for the Filestore CSI driver.
getter/setter pair
gcsFuseCsiDriverConfig ↔ GcsFuseCsiDriverConfig?
Configuration for the Cloud Storage Fuse CSI driver.
getter/setter pair
gkeBackupAgentConfig ↔ GkeBackupAgentConfig?
Configuration for the Backup for GKE agent addon.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
highScaleCheckpointingConfig ↔ HighScaleCheckpointingConfig?
Configuration for the High Scale Checkpointing add-on.
getter/setter pair
horizontalPodAutoscaling ↔ HorizontalPodAutoscaling?
Configuration for the horizontal pod autoscaling feature, which increases or decreases the number of replica pods a replication controller has based on the resource usage of the existing pods.
getter/setter pair
httpLoadBalancing ↔ HttpLoadBalancing?
Configuration for the HTTP (L7) load balancing controller addon, which makes it easy to set up HTTP load balancers for services in a cluster.
getter/setter pair
kubernetesDashboard ↔ KubernetesDashboard?
Configuration for the Kubernetes Dashboard.
getter/setter pair
lustreCsiDriverConfig ↔ LustreCsiDriverConfig?
Configuration for the Lustre CSI driver.
getter/setter pair
networkPolicyConfig ↔ NetworkPolicyConfig?
Configuration for NetworkPolicy.
getter/setter pair
nodeReadinessConfig ↔ NodeReadinessConfig?
Configuration for NodeReadinessController add-on.
getter/setter pair
parallelstoreCsiDriverConfig ↔ ParallelstoreCsiDriverConfig?
Configuration for the Cloud Storage Parallelstore CSI driver.
getter/setter pair
podSnapshotConfig ↔ PodSnapshotConfig?
Configuration for the Pod Snapshot feature.
getter/setter pair
rayOperatorConfig ↔ RayOperatorConfig?
Configuration for Ray Operator addon.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliceControllerConfig ↔ SliceControllerConfig?
Configuration for the slice controller add-on.
getter/setter pair
slurmOperatorConfig ↔ SlurmOperatorConfig?
Configuration for the Slurm Operator.
getter/setter pair
statefulHaConfig ↔ StatefulHAConfig?
Configuration for the StatefulHA add-on.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited