AutoUpgradeOptions class

AutoUpgradeOptions defines the set of options for the user to control how the Auto Upgrades will proceed.

Constructors

AutoUpgradeOptions({String? autoUpgradeStartTime, String? description})
AutoUpgradeOptions.fromJson(Map json_)

Properties

autoUpgradeStartTime ↔ String?
This field is set when upgrades are about to commence with the approximate start time for the upgrades, in RFC3339 text format.
getter/setter pair
description ↔ String?
This field is set when upgrades are about to commence with the description of the upgrade.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited