Autopilot class

Autopilot is the configuration for Autopilot settings on the cluster.

Constructors

Autopilot({bool? enabled, PrivilegedAdmissionConfig? privilegedAdmissionConfig, WorkloadPolicyConfig? workloadPolicyConfig})
Autopilot.fromJson(Map json_)

Properties

enabled ↔ bool?
Enable Autopilot
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privilegedAdmissionConfig ↔ PrivilegedAdmissionConfig?
PrivilegedAdmissionConfig is the configuration related to privileged admission control.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workloadPolicyConfig ↔ WorkloadPolicyConfig?
WorkloadPolicyConfig is the configuration related to GCW workload policy
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited