clusterPolicyConfig property
ClusterPolicyConfig denotes cluster level policies that are enforced for the cluster.
Implementation
ClusterPolicyConfig? clusterPolicyConfig;
ClusterPolicyConfig denotes cluster level policies that are enforced for the cluster.
ClusterPolicyConfig? clusterPolicyConfig;