AutopilotCompatibilityIssue class

AutopilotCompatibilityIssue contains information about a specific compatibility issue with Autopilot mode.

Constructors

AutopilotCompatibilityIssue({String? constraintType, String? description, String? documentationUrl, String? incompatibilityType, String? lastObservation, List<String>? subjects})
AutopilotCompatibilityIssue.fromJson(Map json_)

Properties

constraintType ↔ String?
The constraint type of the issue.
getter/setter pair
description ↔ String?
The description of the issue.
getter/setter pair
documentationUrl ↔ String?
A URL to a public documentation, which addresses resolving this issue.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
incompatibilityType ↔ String?
The incompatibility type of this issue. Possible string values are:
getter/setter pair
lastObservation ↔ String?
The last time when this issue was observed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subjects ↔ List<String>?
The name of the resources which are subject to this issue.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited