BigQueryDestination class

Parameters for using BigQuery as the destination of resource usage export.

Constructors

BigQueryDestination({String? datasetId})
BigQueryDestination.fromJson(Map json_)

Properties

datasetId ↔ String?
The ID of a BigQuery Dataset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited