BootDisk class

BootDisk specifies the boot disk configuration for node pools.

Constructors

BootDisk({String? diskType, String? provisionedIops, String? provisionedThroughput, String? sizeGb})
BootDisk.fromJson(Map json_)

Properties

diskType ↔ String?
Disk type of the boot disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
provisionedIops ↔ String?
For Hyperdisk-Balanced only, the provisioned IOPS config value.
getter/setter pair
provisionedThroughput ↔ String?
For Hyperdisk-Balanced only, the provisioned throughput config value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeGb ↔ String?
Disk size in GB.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited