CidrBlock class

CidrBlock contains an optional name and one CIDR block.

Constructors

CidrBlock({String? cidrBlock, String? displayName})
CidrBlock.fromJson(Map json_)

Properties

cidrBlock ↔ String?
cidr_block must be specified in CIDR notation.
getter/setter pair
displayName ↔ String?
display_name is an optional field for users to identify CIDR blocks.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited