Cluster class

A Google Kubernetes Engine cluster.

Constructors

Cluster({AddonsConfig? addonsConfig, List<String>? alphaClusterFeatureGates, AnonymousAuthenticationConfig? anonymousAuthenticationConfig, AuthenticatorGroupsConfig? authenticatorGroupsConfig, Autopilot? autopilot, ClusterAutoscaling? autoscaling, BinaryAuthorization? binaryAuthorization, String? clusterIpv4Cidr, CompliancePostureConfig? compliancePostureConfig, List<StatusCondition>? conditions, ConfidentialNodes? confidentialNodes, ControlPlaneEndpointsConfig? controlPlaneEndpointsConfig, CostManagementConfig? costManagementConfig, String? createTime, String? currentMasterVersion, int? currentNodeCount, String? currentNodeVersion, DatabaseEncryption? databaseEncryption, MaxPodsConstraint? defaultMaxPodsConstraint, String? description, K8sBetaAPIConfig? enableK8sBetaApis, bool? enableKubernetesAlpha, bool? enableTpu, String? endpoint, EnterpriseConfig? enterpriseConfig, String? etag, String? expireTime, Fleet? fleet, GkeAutoUpgradeConfig? gkeAutoUpgradeConfig, String? id, IdentityServiceConfig? identityServiceConfig, String? initialClusterVersion, int? initialNodeCount, List<String>? instanceGroupUrls, IPAllocationPolicy? ipAllocationPolicy, String? labelFingerprint, LegacyAbac? legacyAbac, String? location, List<String>? locations, LoggingConfig? loggingConfig, String? loggingService, MaintenancePolicy? maintenancePolicy, MasterAuth? masterAuth, MasterAuthorizedNetworksConfig? masterAuthorizedNetworksConfig, MeshCertificates? meshCertificates, MonitoringConfig? monitoringConfig, String? monitoringService, String? name, String? network, NetworkConfig? networkConfig, NetworkPolicy? networkPolicy, NodeConfig? nodeConfig, int? nodeIpv4CidrSize, NodePoolAutoConfig? nodePoolAutoConfig, NodePoolDefaults? nodePoolDefaults, List<NodePool>? nodePools, NotificationConfig? notificationConfig, ParentProductConfig? parentProductConfig, PodAutoscaling? podAutoscaling, PrivateClusterConfig? privateClusterConfig, RBACBindingConfig? rbacBindingConfig, ReleaseChannel? releaseChannel, Map<String, String>? resourceLabels, ResourceUsageExportConfig? resourceUsageExportConfig, bool? satisfiesPzi, bool? satisfiesPzs, SecretManagerConfig? secretManagerConfig, SecurityPostureConfig? securityPostureConfig, String? selfLink, String? servicesIpv4Cidr, ShieldedNodes? shieldedNodes, String? status, String? statusMessage, String? subnetwork, String? tpuIpv4CidrBlock, UserManagedKeysConfig? userManagedKeysConfig, VerticalPodAutoscaling? verticalPodAutoscaling, WorkloadIdentityConfig? workloadIdentityConfig, String? zone})
Cluster.fromJson(Map json_)

Properties

addonsConfig ↔ AddonsConfig?
Configurations for the various addons available to run in the cluster.
getter/setter pair
alphaClusterFeatureGates ↔ List<String>?
The list of user specified Kubernetes feature gates.
getter/setter pair
anonymousAuthenticationConfig ↔ AnonymousAuthenticationConfig?
Configuration for limiting anonymous access to all endpoints except the health checks.
getter/setter pair
authenticatorGroupsConfig ↔ AuthenticatorGroupsConfig?
Configuration controlling RBAC group membership information.
getter/setter pair
autopilot ↔ Autopilot?
Autopilot configuration for the cluster.
getter/setter pair
autoscaling ↔ ClusterAutoscaling?
Cluster-level autoscaling configuration.
getter/setter pair
binaryAuthorization ↔ BinaryAuthorization?
Configuration for Binary Authorization.
getter/setter pair
clusterIpv4Cidr ↔ String?
The IP address range of the container pods in this cluster, in CIDR notation (e.g. 10.96.0.0/14).
getter/setter pair
compliancePostureConfig ↔ CompliancePostureConfig?
Enable/Disable Compliance Posture features for the cluster.
getter/setter pair
conditions ↔ List<StatusCondition>?
Which conditions caused the current cluster state.
getter/setter pair
confidentialNodes ↔ ConfidentialNodes?
Configuration of Confidential Nodes.
getter/setter pair
controlPlaneEndpointsConfig ↔ ControlPlaneEndpointsConfig?
Configuration for all cluster's control plane endpoints.
getter/setter pair
costManagementConfig ↔ CostManagementConfig?
Configuration for the fine-grained cost management feature.
getter/setter pair
createTime ↔ String?
The time the cluster was created, in RFC3339 text format.
getter/setter pair
currentMasterVersion ↔ String?
The current software version of the master endpoint.
getter/setter pair
currentNodeCount ↔ int?
The number of nodes currently in the cluster.
getter/setter pair
currentNodeVersion ↔ String?
Deprecated, use NodePools.version instead.
getter/setter pair
databaseEncryption ↔ DatabaseEncryption?
Configuration of etcd encryption.
getter/setter pair
defaultMaxPodsConstraint ↔ MaxPodsConstraint?
The default constraint on the maximum number of pods that can be run simultaneously on a node in the node pool of this cluster.
getter/setter pair
description ↔ String?
An optional description of this cluster.
getter/setter pair
enableK8sBetaApis ↔ K8sBetaAPIConfig?
Beta APIs Config
getter/setter pair
enableKubernetesAlpha ↔ bool?
Kubernetes alpha features are enabled on this cluster.
getter/setter pair
enableTpu ↔ bool?
Enable the ability to use Cloud TPUs in this cluster.
getter/setter pair
endpoint ↔ String?
The IP address of this cluster's master endpoint.
getter/setter pair
enterpriseConfig ↔ EnterpriseConfig?
GKE Enterprise Configuration.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of cluster fields, and may be sent on update requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
expireTime ↔ String?
The time the cluster will be automatically deleted in RFC3339 text format.
getter/setter pair
fleet ↔ Fleet?
Fleet information for the cluster.
getter/setter pair
gkeAutoUpgradeConfig ↔ GkeAutoUpgradeConfig?
Configuration for GKE auto upgrades.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique id for the cluster.
getter/setter pair
identityServiceConfig ↔ IdentityServiceConfig?
Configuration for Identity Service component.
getter/setter pair
initialClusterVersion ↔ String?
The initial Kubernetes version for this cluster.
getter/setter pair
initialNodeCount ↔ int?
The number of nodes to create in this cluster.
getter/setter pair
instanceGroupUrls ↔ List<String>?
Use node_pools.instance_group_urls.
getter/setter pair
ipAllocationPolicy ↔ IPAllocationPolicy?
Configuration for cluster IP allocation.
getter/setter pair
labelFingerprint ↔ String?
The fingerprint of the set of labels for this cluster.
getter/setter pair
legacyAbac ↔ LegacyAbac?
Configuration for the legacy ABAC authorization mode.
getter/setter pair
location ↔ String?
The name of the Google Compute Engine zone or region in which the cluster resides.
getter/setter pair
locations ↔ List<String>?
The list of Google Compute Engine zones in which the cluster's nodes should be located.
getter/setter pair
loggingConfig ↔ LoggingConfig?
Logging configuration for the cluster.
getter/setter pair
loggingService ↔ String?
The logging service the cluster should use to write logs.
getter/setter pair
maintenancePolicy ↔ MaintenancePolicy?
Configure the maintenance policy for this cluster.
getter/setter pair
masterAuth ↔ MasterAuth?
The authentication information for accessing the master endpoint.
getter/setter pair
masterAuthorizedNetworksConfig ↔ MasterAuthorizedNetworksConfig?
The configuration options for master authorized networks feature.
getter/setter pair
meshCertificates ↔ MeshCertificates?
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
getter/setter pair
monitoringConfig ↔ MonitoringConfig?
Monitoring configuration for the cluster.
getter/setter pair
monitoringService ↔ String?
The monitoring service the cluster should use to write metrics.
getter/setter pair
name ↔ String?
The name of this cluster.
getter/setter pair
network ↔ String?
The name of the Google Compute Engine network to which the cluster is connected.
getter/setter pair
networkConfig ↔ NetworkConfig?
Configuration for cluster networking.
getter/setter pair
networkPolicy ↔ NetworkPolicy?
Configuration options for the NetworkPolicy feature.
getter/setter pair
nodeConfig ↔ NodeConfig?
Parameters used in creating the cluster's nodes.
getter/setter pair
nodeIpv4CidrSize ↔ int?
The size of the address space on each node for hosting containers.
getter/setter pair
nodePoolAutoConfig ↔ NodePoolAutoConfig?
Node pool configs that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.
getter/setter pair
nodePoolDefaults ↔ NodePoolDefaults?
Default NodePool settings for the entire cluster.
getter/setter pair
nodePools ↔ List<NodePool>?
The node pools associated with this cluster.
getter/setter pair
notificationConfig ↔ NotificationConfig?
Notification configuration of the cluster.
getter/setter pair
parentProductConfig ↔ ParentProductConfig?
The configuration of the parent product of the cluster.
getter/setter pair
podAutoscaling ↔ PodAutoscaling?
The config for pod autoscaling.
getter/setter pair
privateClusterConfig ↔ PrivateClusterConfig?
Configuration for private cluster.
getter/setter pair
rbacBindingConfig ↔ RBACBindingConfig?
RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings that can be created.
getter/setter pair
releaseChannel ↔ ReleaseChannel?
Release channel configuration.
getter/setter pair
resourceLabels ↔ Map<String, String>?
The resource labels for the cluster to use to annotate any related Google Compute Engine resources.
getter/setter pair
resourceUsageExportConfig ↔ ResourceUsageExportConfig?
Configuration for exporting resource usages.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
secretManagerConfig ↔ SecretManagerConfig?
Secret CSI driver configuration.
getter/setter pair
securityPostureConfig ↔ SecurityPostureConfig?
Enable/Disable Security Posture API features for the cluster.
getter/setter pair
Server-defined URL for the resource.
getter/setter pair
servicesIpv4Cidr ↔ String?
The IP address range of the Kubernetes services in this cluster, in CIDR notation (e.g. 1.2.3.4/29).
getter/setter pair
shieldedNodes ↔ ShieldedNodes?
Shielded Nodes configuration.
getter/setter pair
status ↔ String?
The current status of this cluster.
getter/setter pair
statusMessage ↔ String?
Use conditions instead.
getter/setter pair
subnetwork ↔ String?
The name of the Google Compute Engine subnetwork to which the cluster is connected.
getter/setter pair
tpuIpv4CidrBlock ↔ String?
The IP address range of the Cloud TPUs in this cluster, in CIDR notation (e.g. 1.2.3.4/29).
getter/setter pair
userManagedKeysConfig ↔ UserManagedKeysConfig?
The Custom keys configuration for the cluster.
getter/setter pair
verticalPodAutoscaling ↔ VerticalPodAutoscaling?
Cluster-level Vertical Pod Autoscaling configuration.
getter/setter pair
workloadIdentityConfig ↔ WorkloadIdentityConfig?
Configuration for the use of Kubernetes Service Accounts in GCP IAM policies.
getter/setter pair
zone ↔ String?
The name of the Google Compute Engine zone in which the cluster resides.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited