ClusterPolicyConfig class

ClusterPolicyConfig stores the configuration for cluster wide policies.

Constructors

ClusterPolicyConfig({bool? noStandardNodePools, bool? noSystemImpersonation, bool? noSystemMutation, bool? noUnsafeWebhooks})
ClusterPolicyConfig.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
noStandardNodePools bool?
Denotes preventing standard node pools and requiring only autopilot node pools.
getter/setter pair
noSystemImpersonation bool?
Denotes preventing impersonation and CSRs for GKE System users.
getter/setter pair
noSystemMutation bool?
Denotes that preventing creation and mutation of resources in GKE managed namespaces and cluster-scoped GKE managed resources .
getter/setter pair
noUnsafeWebhooks bool?
Denotes preventing unsafe webhooks.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited