noSystemMutation property
Denotes that preventing creation and mutation of resources in GKE managed namespaces and cluster-scoped GKE managed resources .
Implementation
core.bool? noSystemMutation;
Denotes that preventing creation and mutation of resources in GKE managed namespaces and cluster-scoped GKE managed resources .
core.bool? noSystemMutation;