ClusterUpdate class

ClusterUpdate describes an update to the cluster.

Exactly one update can be applied to a cluster with each request, so at most one field can be provided.

Constructors

ClusterUpdate({AdditionalPodRangesConfig? additionalPodRangesConfig, DesiredAdditionalIPRangesConfig? desiredAdditionalIpRangesConfig, AddonsConfig? desiredAddonsConfig, AnonymousAuthenticationConfig? desiredAnonymousAuthenticationConfig, AuthenticatorGroupsConfig? desiredAuthenticatorGroupsConfig, AutoIpamConfig? desiredAutoIpamConfig, WorkloadPolicyConfig? desiredAutopilotWorkloadPolicyConfig, BinaryAuthorization? desiredBinaryAuthorization, ClusterAutoscaling? desiredClusterAutoscaling, CompliancePostureConfig? desiredCompliancePostureConfig, ContainerdConfig? desiredContainerdConfig, ControlPlaneEndpointsConfig? desiredControlPlaneEndpointsConfig, CostManagementConfig? desiredCostManagementConfig, DatabaseEncryption? desiredDatabaseEncryption, String? desiredDatapathProvider, bool? desiredDefaultEnablePrivateNodes, DefaultSnatStatus? desiredDefaultSnatStatus, bool? desiredDisableL4LbFirewallReconciliation, DNSConfig? desiredDnsConfig, bool? desiredEnableCiliumClusterwideNetworkPolicy, bool? desiredEnableFqdnNetworkPolicy, bool? desiredEnableMultiNetworking, bool? desiredEnablePrivateEndpoint, DesiredEnterpriseConfig? desiredEnterpriseConfig, Fleet? desiredFleet, GatewayAPIConfig? desiredGatewayApiConfig, GcfsConfig? desiredGcfsConfig, IdentityServiceConfig? desiredIdentityServiceConfig, String? desiredImageType, String? desiredInTransitEncryptionConfig, IntraNodeVisibilityConfig? desiredIntraNodeVisibilityConfig, K8sBetaAPIConfig? desiredK8sBetaApis, ILBSubsettingConfig? desiredL4ilbSubsettingConfig, List<String>? desiredLocations, LoggingConfig? desiredLoggingConfig, String? desiredLoggingService, ManagedOpenTelemetryConfig? desiredManagedOpentelemetryConfig, MasterAuthorizedNetworksConfig? desiredMasterAuthorizedNetworksConfig, String? desiredMasterVersion, MeshCertificates? desiredMeshCertificates, MonitoringConfig? desiredMonitoringConfig, String? desiredMonitoringService, ClusterNetworkPerformanceConfig? desiredNetworkPerformanceConfig, NetworkTierConfig? desiredNetworkTierConfig, NodeKubeletConfig? desiredNodeKubeletConfig, NodeKubeletConfig? desiredNodePoolAutoConfigKubeletConfig, LinuxNodeConfig? desiredNodePoolAutoConfigLinuxNodeConfig, NetworkTags? desiredNodePoolAutoConfigNetworkTags, ResourceManagerTags? desiredNodePoolAutoConfigResourceManagerTags, NodePoolAutoscaling? desiredNodePoolAutoscaling, String? desiredNodePoolId, NodePoolLoggingConfig? desiredNodePoolLoggingConfig, String? desiredNodeVersion, NotificationConfig? desiredNotificationConfig, ParentProductConfig? desiredParentProductConfig, PodAutoscaling? desiredPodAutoscaling, PrivateClusterConfig? desiredPrivateClusterConfig, String? desiredPrivateIpv6GoogleAccess, PrivilegedAdmissionConfig? desiredPrivilegedAdmissionConfig, RBACBindingConfig? desiredRbacBindingConfig, ReleaseChannel? desiredReleaseChannel, ResourceUsageExportConfig? desiredResourceUsageExportConfig, SecretManagerConfig? desiredSecretManagerConfig, SecurityPostureConfig? desiredSecurityPostureConfig, ServiceExternalIPsConfig? desiredServiceExternalIpsConfig, ShieldedNodes? desiredShieldedNodes, String? desiredStackType, UserManagedKeysConfig? desiredUserManagedKeysConfig, VerticalPodAutoscaling? desiredVerticalPodAutoscaling, WorkloadIdentityConfig? desiredWorkloadIdentityConfig, K8sBetaAPIConfig? enableK8sBetaApis, String? etag, GkeAutoUpgradeConfig? gkeAutoUpgradeConfig, AdditionalPodRangesConfig? removedAdditionalPodRangesConfig, UserManagedKeysConfig? userManagedKeysConfig})
ClusterUpdate.fromJson(Map json_)

Properties

additionalPodRangesConfig ↔ AdditionalPodRangesConfig?
The additional pod ranges to be added to the cluster.
getter/setter pair
desiredAdditionalIpRangesConfig ↔ DesiredAdditionalIPRangesConfig?
The desired config for additional subnetworks attached to the cluster.
getter/setter pair
desiredAddonsConfig ↔ AddonsConfig?
Configurations for the various addons available to run in the cluster.
getter/setter pair
desiredAnonymousAuthenticationConfig ↔ AnonymousAuthenticationConfig?
Configuration for limiting anonymous access to all endpoints except the health checks.
getter/setter pair
desiredAuthenticatorGroupsConfig ↔ AuthenticatorGroupsConfig?
The desired authenticator groups config for the cluster.
getter/setter pair
desiredAutoIpamConfig ↔ AutoIpamConfig?
AutoIpamConfig contains all information related to Auto IPAM
getter/setter pair
desiredAutopilotWorkloadPolicyConfig ↔ WorkloadPolicyConfig?
WorkloadPolicyConfig is the configuration related to GCW workload policy
getter/setter pair
desiredBinaryAuthorization ↔ BinaryAuthorization?
The desired configuration options for the Binary Authorization feature.
getter/setter pair
desiredClusterAutoscaling ↔ ClusterAutoscaling?
Cluster-level autoscaling configuration.
getter/setter pair
desiredCompliancePostureConfig ↔ CompliancePostureConfig?
Enable/Disable Compliance Posture features for the cluster.
getter/setter pair
desiredContainerdConfig ↔ ContainerdConfig?
The desired containerd config for the cluster.
getter/setter pair
desiredControlPlaneEndpointsConfig ↔ ControlPlaneEndpointsConfig?
Control plane endpoints configuration.
getter/setter pair
desiredCostManagementConfig ↔ CostManagementConfig?
The desired configuration for the fine-grained cost management feature.
getter/setter pair
desiredDatabaseEncryption ↔ DatabaseEncryption?
Configuration of etcd encryption.
getter/setter pair
desiredDatapathProvider ↔ String?
The desired datapath provider for the cluster. Possible string values are:
getter/setter pair
desiredDefaultEnablePrivateNodes ↔ bool?
Override the default setting of whether future created nodes have private IP addresses only, namely NetworkConfig.default_enable_private_nodes
getter/setter pair
desiredDefaultSnatStatus ↔ DefaultSnatStatus?
The desired status of whether to disable default sNAT for this cluster.
getter/setter pair
desiredDisableL4LbFirewallReconciliation ↔ bool?
Enable/Disable L4 LB VPC firewall reconciliation for the cluster.
getter/setter pair
desiredDnsConfig ↔ DNSConfig?
DNSConfig contains clusterDNS config for this cluster.
getter/setter pair
desiredEnableCiliumClusterwideNetworkPolicy ↔ bool?
Enable/Disable Cilium Clusterwide Network Policy for the cluster.
getter/setter pair
desiredEnableFqdnNetworkPolicy ↔ bool?
Enable/Disable FQDN Network Policy for the cluster.
getter/setter pair
desiredEnableMultiNetworking ↔ bool?
Enable/Disable Multi-Networking for the cluster
getter/setter pair
desiredEnablePrivateEndpoint ↔ bool?
Enable/Disable private endpoint for the cluster's master.
getter/setter pair
desiredEnterpriseConfig ↔ DesiredEnterpriseConfig?
The desired enterprise configuration for the cluster.
getter/setter pair
desiredFleet ↔ Fleet?
The desired fleet configuration for the cluster.
getter/setter pair
desiredGatewayApiConfig ↔ GatewayAPIConfig?
The desired config of Gateway API on this cluster.
getter/setter pair
desiredGcfsConfig ↔ GcfsConfig?
The desired GCFS config for the cluster
getter/setter pair
desiredIdentityServiceConfig ↔ IdentityServiceConfig?
The desired Identity Service component configuration.
getter/setter pair
desiredImageType ↔ String?
The desired image type for the node pool.
getter/setter pair
desiredIntraNodeVisibilityConfig ↔ IntraNodeVisibilityConfig?
The desired config of Intra-node visibility.
getter/setter pair
desiredInTransitEncryptionConfig ↔ String?
Specify the details of in-transit encryption. Possible string values are:
getter/setter pair
desiredK8sBetaApis ↔ K8sBetaAPIConfig?
Desired Beta APIs to be enabled for cluster.
getter/setter pair
desiredL4ilbSubsettingConfig ↔ ILBSubsettingConfig?
The desired L4 Internal Load Balancer Subsetting configuration.
getter/setter pair
desiredLocations ↔ List<String>?
The desired list of Google Compute Engine zones in which the cluster's nodes should be located.
getter/setter pair
desiredLoggingConfig ↔ LoggingConfig?
The desired logging configuration.
getter/setter pair
desiredLoggingService ↔ String?
The logging service the cluster should use to write logs.
getter/setter pair
desiredManagedOpentelemetryConfig ↔ ManagedOpenTelemetryConfig?
The desired managed open telemetry configuration.
getter/setter pair
desiredMasterAuthorizedNetworksConfig ↔ MasterAuthorizedNetworksConfig?
The desired configuration options for master authorized networks feature.
getter/setter pair
desiredMasterVersion ↔ String?
The Kubernetes version to change the master to.
getter/setter pair
desiredMeshCertificates ↔ MeshCertificates?
Configuration for issuance of mTLS keys and certificates to Kubernetes pods.
getter/setter pair
desiredMonitoringConfig ↔ MonitoringConfig?
The desired monitoring configuration.
getter/setter pair
desiredMonitoringService ↔ String?
The monitoring service the cluster should use to write metrics.
getter/setter pair
desiredNetworkPerformanceConfig ↔ ClusterNetworkPerformanceConfig?
The desired network performance config.
getter/setter pair
desiredNetworkTierConfig ↔ NetworkTierConfig?
The desired network tier configuration for the cluster.
getter/setter pair
desiredNodeKubeletConfig ↔ NodeKubeletConfig?
The desired node kubelet config for the cluster.
getter/setter pair
desiredNodePoolAutoConfigKubeletConfig ↔ NodeKubeletConfig?
The desired node kubelet config for all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.
getter/setter pair
desiredNodePoolAutoConfigLinuxNodeConfig ↔ LinuxNodeConfig?
The desired Linux node config for all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.
getter/setter pair
desiredNodePoolAutoConfigNetworkTags ↔ NetworkTags?
The desired network tags that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.
getter/setter pair
desiredNodePoolAutoConfigResourceManagerTags ↔ ResourceManagerTags?
The desired resource manager tags that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.
getter/setter pair
desiredNodePoolAutoscaling ↔ NodePoolAutoscaling?
Autoscaler configuration for the node pool specified in desired_node_pool_id.
getter/setter pair
desiredNodePoolId ↔ String?
The node pool to be upgraded.
getter/setter pair
desiredNodePoolLoggingConfig ↔ NodePoolLoggingConfig?
The desired node pool logging configuration defaults for the cluster.
getter/setter pair
desiredNodeVersion ↔ String?
The Kubernetes version to change the nodes to (typically an upgrade).
getter/setter pair
desiredNotificationConfig ↔ NotificationConfig?
The desired notification configuration.
getter/setter pair
desiredParentProductConfig ↔ ParentProductConfig?
The desired parent product config for the cluster.
getter/setter pair
desiredPodAutoscaling ↔ PodAutoscaling?
The desired config for pod autoscaling.
getter/setter pair
desiredPrivateClusterConfig ↔ PrivateClusterConfig?
The desired private cluster configuration.
getter/setter pair
desiredPrivateIpv6GoogleAccess ↔ String?
The desired state of IPv6 connectivity to Google Services. Possible string values are:
getter/setter pair
desiredPrivilegedAdmissionConfig ↔ PrivilegedAdmissionConfig?
The desired privileged admission config for the cluster.
getter/setter pair
desiredRbacBindingConfig ↔ RBACBindingConfig?
RBACBindingConfig allows user to restrict ClusterRoleBindings an RoleBindings that can be created.
getter/setter pair
desiredReleaseChannel ↔ ReleaseChannel?
The desired release channel configuration.
getter/setter pair
desiredResourceUsageExportConfig ↔ ResourceUsageExportConfig?
The desired configuration for exporting resource usage.
getter/setter pair
desiredSecretManagerConfig ↔ SecretManagerConfig?
Enable/Disable Secret Manager Config.
getter/setter pair
desiredSecurityPostureConfig ↔ SecurityPostureConfig?
Enable/Disable Security Posture API features for the cluster.
getter/setter pair
desiredServiceExternalIpsConfig ↔ ServiceExternalIPsConfig?
ServiceExternalIPsConfig specifies the config for the use of Services with ExternalIPs field.
getter/setter pair
desiredShieldedNodes ↔ ShieldedNodes?
Configuration for Shielded Nodes.
getter/setter pair
desiredStackType ↔ String?
The desired stack type of the cluster.
getter/setter pair
desiredUserManagedKeysConfig ↔ UserManagedKeysConfig?
The desired user managed keys config for the cluster.
getter/setter pair
desiredVerticalPodAutoscaling ↔ VerticalPodAutoscaling?
Cluster-level Vertical Pod Autoscaling configuration.
getter/setter pair
desiredWorkloadIdentityConfig ↔ WorkloadIdentityConfig?
Configuration for Workload Identity.
getter/setter pair
enableK8sBetaApis ↔ K8sBetaAPIConfig?
Kubernetes open source beta apis enabled on the cluster.
getter/setter pair
etag ↔ String?
The current etag of the cluster.
getter/setter pair
gkeAutoUpgradeConfig ↔ GkeAutoUpgradeConfig?
Configuration for GKE auto upgrade.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
removedAdditionalPodRangesConfig ↔ AdditionalPodRangesConfig?
The additional pod ranges that are to be removed from the cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userManagedKeysConfig ↔ UserManagedKeysConfig?
The Custom keys configuration for the cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited