desiredControlPlaneEgress property
The desired control plane egress control config for the cluster.
Implementation
ControlPlaneEgress? desiredControlPlaneEgress;
The desired control plane egress control config for the cluster.
ControlPlaneEgress? desiredControlPlaneEgress;