desiredImage property
The desired name of the image to use for this node.
This is used to create clusters using a custom image. NOTE: Set the "desired_node_pool" field as well.
Implementation
core.String? desiredImage;
The desired name of the image to use for this node.
This is used to create clusters using a custom image. NOTE: Set the "desired_node_pool" field as well.
core.String? desiredImage;