desiredImageProject property

String? desiredImageProject
getter/setter pair

The project containing the desired image to use for this node.

This is used to create clusters using a custom image. NOTE: Set the "desired_node_pool" field as well.

Implementation

core.String? desiredImageProject;