containerScope constant

String const containerScope

See, edit, configure, and delete your Google Kubernetes Engine data and see the email address for your Google Account

Implementation

static const containerScope = 'https://www.googleapis.com/auth/container';