ContainerdConfig class

ContainerdConfig contains configuration to customize containerd.

Constructors

ContainerdConfig({PrivateRegistryAccessConfig? privateRegistryAccessConfig, List<RegistryHostConfig>? registryHosts, WritableCgroups? writableCgroups})
ContainerdConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
privateRegistryAccessConfig ↔ PrivateRegistryAccessConfig?
PrivateRegistryAccessConfig is used to configure access configuration for private container registries.
getter/setter pair
registryHosts ↔ List<RegistryHostConfig>?
RegistryHostConfig configures containerd registry host configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writableCgroups ↔ WritableCgroups?
WritableCgroups defines writable cgroups configuration for the node pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited