ControlPlaneEndpointsConfig class

Configuration for all of the cluster's control plane endpoints.

Constructors

ControlPlaneEndpointsConfig({DNSEndpointConfig? dnsEndpointConfig, IPEndpointsConfig? ipEndpointsConfig})
ControlPlaneEndpointsConfig.fromJson(Map json_)

Properties

dnsEndpointConfig ↔ DNSEndpointConfig?
DNS endpoint configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipEndpointsConfig ↔ IPEndpointsConfig?
IP endpoints configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited