CrashLoopBackOffConfig class

Contains config to modify node-level parameters for container restart behavior.

Constructors

CrashLoopBackOffConfig({String? maxContainerRestartPeriod})
CrashLoopBackOffConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxContainerRestartPeriod ↔ String?
The maximum duration the backoff delay can accrue to for container restarts, minimum 1 second, maximum 300 seconds.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited