maxContainerRestartPeriod property

String? maxContainerRestartPeriod
getter/setter pair

The maximum duration the backoff delay can accrue to for container restarts, minimum 1 second, maximum 300 seconds.

If not set, defaults to the internal crashloopbackoff maximum. The string must be a sequence of decimal numbers, each with optional fraction and a unit suffix, such as "300ms". Valid time units are "ns", "us" (or "µs"), "ms", "s", "m", "h". See https://kubernetes.io/docs/concepts/workloads/pods/pod-lifecycle/#configurable-container-restart-delay for more details.

Optional.

Implementation

core.String? maxContainerRestartPeriod;