DNSConfig class

DNSConfig contains the desired set of options for configuring clusterDNS.

Constructors

DNSConfig({String? additiveVpcScopeDnsDomain, String? clusterDns, String? clusterDnsDomain, String? clusterDnsScope})
DNSConfig.fromJson(Map json_)

Properties

additiveVpcScopeDnsDomain ↔ String?
The domain used in Additive VPC scope.
getter/setter pair
clusterDns ↔ String?
cluster_dns indicates which in-cluster DNS provider should be used. Possible string values are:
getter/setter pair
clusterDnsDomain ↔ String?
cluster_dns_domain is the suffix used for all cluster service records.
getter/setter pair
clusterDnsScope ↔ String?
cluster_dns_scope indicates the scope of access to cluster DNS records. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited