DailyMaintenanceWindow class

Time window specified for daily maintenance operations.

Constructors

DailyMaintenanceWindow({String? duration, String? startTime})
DailyMaintenanceWindow.fromJson(Map json_)

Properties

duration ↔ String?
Duration of the time window, automatically chosen to be smallest possible in the given scenario.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Time within the maintenance window to start the maintenance operations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited