DatabaseEncryption class

Configuration of etcd encryption.

Constructors

DatabaseEncryption({String? currentState, List<String>? decryptionKeys, String? keyName, List<OperationError>? lastOperationErrors, String? state})
DatabaseEncryption.fromJson(Map json_)

Properties

currentState ↔ String?
The current state of etcd encryption.
getter/setter pair
decryptionKeys ↔ List<String>?
Keys in use by the cluster for decrypting existing objects, in addition to the key in key_name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyName ↔ String?
Name of CloudKMS key to use for the encryption of secrets in etcd.
getter/setter pair
lastOperationErrors ↔ List<OperationError>?
Records errors seen during DatabaseEncryption update operations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The desired state of etcd encryption. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited