currentState property
The current state of etcd encryption.
Output only. Possible string values are:
- "CURRENT_STATE_UNSPECIFIED" : Should never be set
- "CURRENT_STATE_ENCRYPTED" : Secrets in etcd are encrypted.
- "CURRENT_STATE_DECRYPTED" : Secrets in etcd are stored in plain text (at etcd level) - this is unrelated to Compute Engine level full disk encryption.
- "CURRENT_STATE_ENCRYPTION_PENDING" : Encryption (or re-encryption with a different CloudKMS key) of Secrets is in progress.
- "CURRENT_STATE_ENCRYPTION_ERROR" : Encryption (or re-encryption with a different CloudKMS key) of Secrets in etcd encountered an error.
- "CURRENT_STATE_DECRYPTION_PENDING" : De-crypting Secrets to plain text in etcd is in progress.
- "CURRENT_STATE_DECRYPTION_ERROR" : De-crypting Secrets to plain text in etcd encountered an error.
- "CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ENABLED" : Encryption of all objects in the storage is enabled. It does not guarantee that all objects in the storage are encrypted, but eventually they will be.
- "CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_PENDING" : Enablement of the encryption of all objects in storage is pending.
- "CURRENT_STATE_ALL_OBJECTS_ENCRYPTION_ERROR" : Enabling encryption of all objects in storage encountered an error.
Implementation
core.String? currentState;