DisruptionBudget class

DisruptionBudget defines the upgrade disruption budget for the cluster control plane.

Constructors

DisruptionBudget({String? lastDisruptionTime, String? lastMinorVersionDisruptionTime, String? minorVersionDisruptionInterval, String? patchVersionDisruptionInterval})
DisruptionBudget.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
lastDisruptionTime String?
The last time a disruption was performed on the control plane.
getter/setter pair
lastMinorVersionDisruptionTime String?
The last time a minor version upgrade was performed on the control plane.
getter/setter pair
minorVersionDisruptionInterval String?
The minimum duration between two minor version upgrades of the control plane.
getter/setter pair
patchVersionDisruptionInterval String?
The minimum duration between two patch version upgrades of the control plane.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited