lastDisruptionTime property
The last time a disruption was performed on the control plane.
Output only.
Implementation
core.String? lastDisruptionTime;
The last time a disruption was performed on the control plane.
Output only.
core.String? lastDisruptionTime;