EphemeralLocalSsdProfile class

Swap on the local SSD shared with pod ephemeral storage.

Constructors

EphemeralLocalSsdProfile({String? swapSizeGib, int? swapSizePercent})
EphemeralLocalSsdProfile.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swapSizeGib ↔ String?
Specifies the size of the swap space in gibibytes (GiB).
getter/setter pair
swapSizePercent ↔ int?
Specifies the size of the swap space as a percentage of the ephemeral local SSD capacity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited