EphemeralStorageLocalSsdConfig class

EphemeralStorageLocalSsdConfig contains configuration for the node ephemeral storage using Local SSDs.

Constructors

EphemeralStorageLocalSsdConfig({int? dataCacheCount, int? localSsdCount})
EphemeralStorageLocalSsdConfig.fromJson(Map json_)

Properties

dataCacheCount ↔ int?
Number of local SSDs to use for GKE Data Cache.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localSsdCount ↔ int?
Number of local SSDs to use to back ephemeral storage.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited