endTime property

String? endTime
getter/setter pair

The end time of the maintenance exclusion.

It is output only. It is the cluster control plane version's end of support time, or end of extended support time when the cluster is on extended support channel.

Output only.

Implementation

core.String? endTime;