GPUDirectConfig class

GPUDirectConfig specifies the GPU direct strategy on the node pool.

Constructors

GPUDirectConfig({String? gpuDirectStrategy})
GPUDirectConfig.fromJson(Map json_)

Properties

gpuDirectStrategy ↔ String?
The type of GPU direct strategy to enable on the node pool. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited