GetJSONWebKeysResponse class

GetJSONWebKeysResponse is a valid JSON Web Key Set as specified in rfc 7517

Properties

cacheHeader ↔ HttpCacheControlResponseHeader?
For HTTP requests, this field is automatically extracted into the Cache-Control HTTP header.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ List<Jwk>?
The public component of the keys used by the cluster to sign token requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited