HttpCacheControlResponseHeader class

RFC-2616: cache control support

Properties

age ↔ String?
14.6 response cache age, in seconds since the response is generated
getter/setter pair
directive ↔ String?
14.9 request and response directives
getter/setter pair
expires ↔ String?
14.21 response cache expires, in RFC 1123 date format
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited