IPAllocationPolicy class

Configuration for controlling how IPs are allocated in the cluster.

Constructors

IPAllocationPolicy({List<AdditionalIPRangesConfig>? additionalIpRangesConfigs, AdditionalPodRangesConfig? additionalPodRangesConfig, AutoIpamConfig? autoIpamConfig, String? clusterIpv4Cidr, String? clusterIpv4CidrBlock, String? clusterSecondaryRangeName, bool? createSubnetwork, double? defaultPodIpv4RangeUtilization, String? ipv6AccessType, NetworkTierConfig? networkTierConfig, String? nodeIpv4Cidr, String? nodeIpv4CidrBlock, PodCIDROverprovisionConfig? podCidrOverprovisionConfig, String? servicesIpv4Cidr, String? servicesIpv4CidrBlock, String? servicesIpv6CidrBlock, String? servicesSecondaryRangeName, String? stackType, String? subnetIpv6CidrBlock, String? subnetworkName, String? tpuIpv4CidrBlock, bool? useIpAliases, bool? useRoutes})
IPAllocationPolicy.fromJson(Map json_)

Properties

additionalIpRangesConfigs ↔ List<AdditionalIPRangesConfig>?
The additional IP ranges that are added to the cluster.
getter/setter pair
additionalPodRangesConfig ↔ AdditionalPodRangesConfig?
The additional pod ranges that are added to the cluster.
getter/setter pair
autoIpamConfig ↔ AutoIpamConfig?
AutoIpamConfig contains all information related to Auto IPAM
getter/setter pair
clusterIpv4Cidr ↔ String?
This field is deprecated, use cluster_ipv4_cidr_block.
getter/setter pair
clusterIpv4CidrBlock ↔ String?
The IP address range for the cluster pod IPs.
getter/setter pair
clusterSecondaryRangeName ↔ String?
The name of the secondary range to be used for the cluster CIDR block.
getter/setter pair
createSubnetwork ↔ bool?
Whether a new subnetwork will be created automatically for the cluster.
getter/setter pair
defaultPodIpv4RangeUtilization ↔ double?
The utilization of the cluster default IPv4 range for the pod.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipv6AccessType ↔ String?
The ipv6 access type (internal or external) when create_subnetwork is true Possible string values are:
getter/setter pair
networkTierConfig ↔ NetworkTierConfig?
Cluster-level network tier configuration is used to determine the default network tier for external IP addresses on cluster resources, such as node pools and load balancers.
getter/setter pair
nodeIpv4Cidr ↔ String?
This field is deprecated, use node_ipv4_cidr_block.
getter/setter pair
nodeIpv4CidrBlock ↔ String?
The IP address range of the instance IPs in this cluster.
getter/setter pair
podCidrOverprovisionConfig ↔ PodCIDROverprovisionConfig?
[PRIVATE FIELD] Pod CIDR size overprovisioning config for the cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servicesIpv4Cidr ↔ String?
This field is deprecated, use services_ipv4_cidr_block.
getter/setter pair
servicesIpv4CidrBlock ↔ String?
The IP address range of the services IPs in this cluster.
getter/setter pair
servicesIpv6CidrBlock ↔ String?
The services IPv6 CIDR block for the cluster.
getter/setter pair
servicesSecondaryRangeName ↔ String?
The name of the secondary range to be used as for the services CIDR block.
getter/setter pair
stackType ↔ String?
The IP stack type of the cluster Possible string values are:
getter/setter pair
subnetIpv6CidrBlock ↔ String?
The subnet's IPv6 CIDR block used by nodes and pods.
getter/setter pair
subnetworkName ↔ String?
A custom subnetwork name to be used if create_subnetwork is true.
getter/setter pair
tpuIpv4CidrBlock ↔ String?
The IP address range of the Cloud TPUs in this cluster.
getter/setter pair
useIpAliases ↔ bool?
Whether alias IPs will be used for pod IPs in the cluster.
getter/setter pair
useRoutes ↔ bool?
Whether routes will be used for pod IPs in the cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited