IPEndpointsConfig class

IP endpoints configuration.

Constructors

IPEndpointsConfig({MasterAuthorizedNetworksConfig? authorizedNetworksConfig, bool? enablePublicEndpoint, bool? enabled, bool? globalAccess, String? privateEndpoint, String? privateEndpointSubnetwork, String? publicEndpoint})
IPEndpointsConfig.fromJson(Map json_)

Properties

authorizedNetworksConfig ↔ MasterAuthorizedNetworksConfig?
Configuration of authorized networks.
getter/setter pair
enabled ↔ bool?
Controls whether to allow direct IP access.
getter/setter pair
enablePublicEndpoint ↔ bool?
Controls whether the control plane allows access through a public IP.
getter/setter pair
globalAccess ↔ bool?
Controls whether the control plane's private endpoint is accessible from sources in other regions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privateEndpoint ↔ String?
The internal IP address of this cluster's control plane.
getter/setter pair
privateEndpointSubnetwork ↔ String?
Subnet to provision the master's private endpoint during cluster creation.
getter/setter pair
publicEndpoint ↔ String?
The external IP address of this cluster's control plane.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited