InitScript class

InitScript provide a simply bash script to be executed on the node.

Constructors

InitScript({List<String>? args, String? gcpSecretManagerSecretUri, String? gcsGeneration, String? gcsUri})
InitScript.fromJson(Map json_)

Properties

args ↔ List<String>?
The optional arguments line to be passed to the init script.
getter/setter pair
gcpSecretManagerSecretUri ↔ String?
The resource name of the secret manager secret hosting the init script.
getter/setter pair
gcsGeneration ↔ String?
The generation of the init script stored in Gloud Storage.
getter/setter pair
gcsUri ↔ String?
The Cloud Storage URI for storing the init script.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited