gcsGeneration property

String? gcsGeneration
getter/setter pair

The generation of the init script stored in Gloud Storage.

This is the required field to identify the version of the init script. User can get the genetaion from gcloud storage objects describe gs://BUCKET_NAME/OBJECT_NAME --format="value(generation)" or from the "Version history" tab of the object in the Cloud Console UI.

Implementation

core.String? gcsGeneration;