KubeletCertInfo class

Contains expiry information about the kubelet certificate.

Constructors

KubeletCertInfo({String? nonTpmBootstrapCertExpireTime, String? tpmBootstrapCertExpireTime})
KubeletCertInfo.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
nonTpmBootstrapCertExpireTime String?
Output only.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tpmBootstrapCertExpireTime String?
Output only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited