customNodeInit property
Allow users to run arbitrary bash script or container on the node.
Optional.
Implementation
CustomNodeInit? customNodeInit;
Allow users to run arbitrary bash script or container on the node.
Optional.
CustomNodeInit? customNodeInit;