disableMultiNic property

bool? disableMultiNic
getter/setter pair

When set to true, this disables multi-NIC support for the Lustre CSI driver.

By default, GKE enables multi-NIC support, which allows the Lustre CSI driver to automatically detect and configure all suitable network interfaces on a node to maximize I/O performance for demanding workloads.

Implementation

core.bool? disableMultiNic;