MaintenanceExclusionOptions class

Represents the Maintenance exclusion option.

Constructors

MaintenanceExclusionOptions({String? endTimeBehavior, String? scope})
MaintenanceExclusionOptions.fromJson(Map json_)

Properties

endTimeBehavior ↔ String?
EndTimeBehavior specifies the behavior of the exclusion end time. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
Scope specifies the upgrade scope which upgrades are blocked by the exclusion. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited