MasterAuthorizedNetworksConfig class

Configuration options for the master authorized networks feature.

Enabled master authorized networks will disallow all external traffic to access Kubernetes master through HTTPS except traffic from the given CIDR blocks, Google Compute Engine Public IPs and Google Prod IPs.

Constructors

MasterAuthorizedNetworksConfig({List<CidrBlock>? cidrBlocks, bool? enabled, bool? gcpPublicCidrsAccessEnabled, bool? privateEndpointEnforcementEnabled})
MasterAuthorizedNetworksConfig.fromJson(Map json_)

Properties

cidrBlocks ↔ List<CidrBlock>?
cidr_blocks define up to 50 external networks that could access Kubernetes master through HTTPS.
getter/setter pair
enabled ↔ bool?
Whether or not master authorized networks is enabled.
getter/setter pair
gcpPublicCidrsAccessEnabled ↔ bool?
Whether master is accessible via Google Compute Engine Public IP addresses.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privateEndpointEnforcementEnabled ↔ bool?
Whether master authorized networks is enforced on private endpoint or not.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited