MemoryManager class

The option enables the Kubernetes NUMA-aware Memory Manager feature.

Detailed description about the feature can be found here.

Constructors

MemoryManager({String? policy})
MemoryManager.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
policy ↔ String?
Controls the memory management policy on the Node.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited