MonitoringConfig class

MonitoringConfig is cluster monitoring configuration.

Constructors

MonitoringConfig({AdvancedDatapathObservabilityConfig? advancedDatapathObservabilityConfig, MonitoringComponentConfig? componentConfig, ManagedPrometheusConfig? managedPrometheusConfig})
MonitoringConfig.fromJson(Map json_)

Properties

advancedDatapathObservabilityConfig ↔ AdvancedDatapathObservabilityConfig?
Configuration of Advanced Datapath Observability features.
getter/setter pair
componentConfig ↔ MonitoringComponentConfig?
Monitoring components configuration
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
managedPrometheusConfig ↔ ManagedPrometheusConfig?
Enable Google Cloud Managed Service for Prometheus in the cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited