NodeAffinity class

Specifies the NodeAffinity key, values, and affinity operator according to shared sole tenant node group affinities.

Constructors

NodeAffinity({String? key, String? operator, List<String>? values})
NodeAffinity.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
Key for NodeAffinity.
getter/setter pair
operator ↔ String?
Operator for NodeAffinity. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<String>?
Values for NodeAffinity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited