NodeConfigDefaults class

Subset of NodeConfig message that has defaults.

Constructors

NodeConfigDefaults({ContainerdConfig? containerdConfig, GcfsConfig? gcfsConfig, NodePoolLoggingConfig? loggingConfig, NodeKubeletConfig? nodeKubeletConfig})
NodeConfigDefaults.fromJson(Map json_)

Properties

containerdConfig ↔ ContainerdConfig?
Parameters for containerd customization.
getter/setter pair
gcfsConfig ↔ GcfsConfig?
GCFS (Google Container File System, also known as Riptide) options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loggingConfig ↔ NodePoolLoggingConfig?
Logging configuration for node pools.
getter/setter pair
nodeKubeletConfig ↔ NodeKubeletConfig?
NodeKubeletConfig controls the defaults for new node-pools.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited