NodeNetworkConfig class

Parameters for node pool-level network config.

Constructors

NodeNetworkConfig({String? acceleratorNetworkProfile, List<AdditionalNodeNetworkConfig>? additionalNodeNetworkConfigs, List<AdditionalPodNetworkConfig>? additionalPodNetworkConfigs, bool? createPodRange, bool? enablePrivateNodes, String? network, NetworkPerformanceConfig? networkPerformanceConfig, NetworkTierConfig? networkTierConfig, PodCIDROverprovisionConfig? podCidrOverprovisionConfig, String? podIpv4CidrBlock, double? podIpv4RangeUtilization, String? podRange, String? subnetwork})
NodeNetworkConfig.fromJson(Map json_)

Properties

acceleratorNetworkProfile ↔ String?
The accelerator network profile for the node pool.
getter/setter pair
additionalNodeNetworkConfigs ↔ List<AdditionalNodeNetworkConfig>?
We specify the additional node networks for this node pool using this list.
getter/setter pair
additionalPodNetworkConfigs ↔ List<AdditionalPodNetworkConfig>?
We specify the additional pod networks for this node pool using this list.
getter/setter pair
createPodRange ↔ bool?
Input only.
getter/setter pair
enablePrivateNodes ↔ bool?
Whether nodes have internal IP addresses only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
network ↔ String?
The VPC network for the node pool.
getter/setter pair
networkPerformanceConfig ↔ NetworkPerformanceConfig?
Network bandwidth tier configuration.
getter/setter pair
networkTierConfig ↔ NetworkTierConfig?
The network tier configuration for the node pool inherits from the cluster-level configuration and remains immutable throughout the node pool's lifecycle, including during upgrades.
getter/setter pair
podCidrOverprovisionConfig ↔ PodCIDROverprovisionConfig?
[PRIVATE FIELD] Pod CIDR size overprovisioning config for the node pool.
getter/setter pair
podIpv4CidrBlock ↔ String?
The IP address range for pod IPs in this node pool.
getter/setter pair
podIpv4RangeUtilization ↔ double?
The utilization of the IPv4 range for the pod.
getter/setter pair
podRange ↔ String?
The ID of the secondary range for pod IPs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetwork ↔ String?
The subnetwork name/path for the node pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited