NodePool class

NodePool contains the name and configuration for a cluster's node pool.

Node pools are a set of nodes (i.e. VM's), with a common configuration and specification, under the control of the cluster master. They may have a set of Kubernetes labels applied to them, which may be used to reference them during pod scheduling. They may also be resized up or down, to accommodate the workload.

Constructors

NodePool({AutopilotConfig? autopilotConfig, NodePoolAutoscaling? autoscaling, BestEffortProvisioning? bestEffortProvisioning, List<StatusCondition>? conditions, NodeConfig? config, String? etag, int? initialNodeCount, List<String>? instanceGroupUrls, KubeletCertInfo? kubeletCertInfo, List<String>? locations, NodePoolMaintenancePolicy? maintenancePolicy, NodeManagement? management, MaxPodsConstraint? maxPodsConstraint, String? name, NodeNetworkConfig? networkConfig, NodeDrainConfig? nodeDrainConfig, PlacementPolicy? placementPolicy, int? podIpv4CidrSize, QueuedProvisioning? queuedProvisioning, String? selfLink, String? status, String? statusMessage, UpdateInfo? updateInfo, UpgradeSettings? upgradeSettings, String? version})
NodePool.fromJson(Map json_)

Properties

autopilotConfig ↔ AutopilotConfig?
Specifies the autopilot configuration for this node pool.
getter/setter pair
autoscaling ↔ NodePoolAutoscaling?
Autoscaler configuration for this NodePool.
getter/setter pair
bestEffortProvisioning ↔ BestEffortProvisioning?
Enable best effort provisioning for nodes
getter/setter pair
conditions ↔ List<StatusCondition>?
Which conditions caused the current node pool state.
getter/setter pair
config ↔ NodeConfig?
The node configuration of the pool.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of node pool fields, and may be sent on update requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialNodeCount ↔ int?
The initial node count for the pool.
getter/setter pair
instanceGroupUrls ↔ List<String>?
The resource URLs of the managed instance groups associated with this node pool.
getter/setter pair
kubeletCertInfo ↔ KubeletCertInfo?
Contains expiry information about the kubelet certificate.
getter/setter pair
locations ↔ List<String>?
The list of Google Compute Engine zones in which the NodePool's nodes should be located.
getter/setter pair
maintenancePolicy ↔ NodePoolMaintenancePolicy?
Specifies the maintenance policy for the node pool.
getter/setter pair
management ↔ NodeManagement?
NodeManagement configuration for this NodePool.
getter/setter pair
maxPodsConstraint ↔ MaxPodsConstraint?
The constraint on the maximum number of pods that can be run simultaneously on a node in the node pool.
getter/setter pair
name ↔ String?
The name of the node pool.
getter/setter pair
networkConfig ↔ NodeNetworkConfig?
Networking configuration for this NodePool.
getter/setter pair
nodeDrainConfig ↔ NodeDrainConfig?
Specifies the node drain configuration for this node pool.
getter/setter pair
placementPolicy ↔ PlacementPolicy?
Specifies the node placement policy.
getter/setter pair
podIpv4CidrSize ↔ int?
The pod CIDR block size per node in this node pool.
getter/setter pair
queuedProvisioning ↔ QueuedProvisioning?
Specifies the configuration of queued provisioning.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
status ↔ String?
The status of the nodes in this pool instance.
getter/setter pair
statusMessage ↔ String?
Use conditions instead.
getter/setter pair
updateInfo ↔ UpdateInfo?
Update info contains relevant information during a node pool update.
getter/setter pair
upgradeSettings ↔ UpgradeSettings?
Upgrade settings control disruption and speed of the upgrade.
getter/setter pair
version ↔ String?
The version of Kubernetes running on this NodePool's nodes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited