NodePoolAutoConfig class

Node pool configs that apply to all auto-provisioned node pools in autopilot clusters and node auto-provisioning enabled clusters.

Constructors

NodePoolAutoConfig({LinuxNodeConfig? linuxNodeConfig, NetworkTags? networkTags, NodeKubeletConfig? nodeKubeletConfig, ResourceManagerTags? resourceManagerTags})
NodePoolAutoConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
linuxNodeConfig ↔ LinuxNodeConfig?
Configuration options for Linux nodes.
getter/setter pair
networkTags ↔ NetworkTags?
The list of instance tags applied to all nodes.
getter/setter pair
nodeKubeletConfig ↔ NodeKubeletConfig?
NodeKubeletConfig controls the defaults for autoprovisioned node-pools.
getter/setter pair
resourceManagerTags ↔ ResourceManagerTags?
Resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited