NodePoolAutoscaling class

NodePoolAutoscaling contains information required by cluster autoscaler to adjust the size of the node pool to the current cluster usage.

Constructors

NodePoolAutoscaling({bool? autoprovisioned, bool? enabled, String? locationPolicy, int? maxNodeCount, int? minNodeCount, int? totalMaxNodeCount, int? totalMinNodeCount})
NodePoolAutoscaling.fromJson(Map json_)

Properties

autoprovisioned ↔ bool?
Can this node pool be deleted automatically.
getter/setter pair
enabled ↔ bool?
Is autoscaling enabled for this node pool.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locationPolicy ↔ String?
Location policy used when scaling up a node pool. Possible string values are:
getter/setter pair
maxNodeCount ↔ int?
Maximum number of nodes for one location in the node pool.
getter/setter pair
minNodeCount ↔ int?
Minimum number of nodes for one location in the node pool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalMaxNodeCount ↔ int?
Maximum number of nodes in the node pool.
getter/setter pair
totalMinNodeCount ↔ int?
Minimum number of nodes in the node pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited