customImageInfo property
Upgrade info for the node pool specific to the usage of custom images.
Output only.
Implementation
CustomImageInfo? customImageInfo;
Upgrade info for the node pool specific to the usage of custom images.
Output only.
CustomImageInfo? customImageInfo;