NodeReadinessConfig class

Configuration for the GKE Node Readiness Controller.

Constructors

NodeReadinessConfig({bool? enabled})
NodeReadinessConfig.fromJson(Map json_)

Properties

enabled bool?
Whether the GKE Node Readiness Controller is enabled for this cluster.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited