OperationError class

OperationError records errors seen from CloudKMS keys encountered during updates to DatabaseEncryption configuration.

Constructors

OperationError({String? errorMessage, String? keyName, String? timestamp})
OperationError.fromJson(Map json_)

Properties

errorMessage ↔ String?
Description of the error seen during the operation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyName ↔ String?
CloudKMS key resource that had the error.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ String?
Time when the CloudKMS error was seen.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited