ParentProductConfig class

ParentProductConfig is the configuration of the parent product of the cluster.

This field is used by Google internal products that are built on top of a GKE cluster and take the ownership of the cluster.

Constructors

ParentProductConfig({Map<String, String>? labels, String? productName})
ParentProductConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels contain the configuration of the parent product.
getter/setter pair
productName ↔ String?
Name of the parent product associated with the cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited