PlacementPolicy class

PlacementPolicy defines the placement policy used by the node pool.

Constructors

PlacementPolicy({String? policyName, String? tpuTopology, String? type})
PlacementPolicy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
policyName ↔ String?
If set, refers to the name of a custom resource policy supplied by the user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tpuTopology ↔ String?
TPU placement topology for pod slice node pool.
getter/setter pair
type ↔ String?
The type of placement. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited