PodSnapshotConfig class

PodSnapshotConfig is the configuration for GKE Pod Snapshots feature.

Constructors

PodSnapshotConfig({bool? enabled})
PodSnapshotConfig.fromJson(Map json_)

Properties

enabled ↔ bool?
Whether or not the Pod Snapshots feature is enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited