PrivateClusterConfig class

Configuration options for private clusters.

Constructors

PrivateClusterConfig({bool? enablePrivateEndpoint, bool? enablePrivateNodes, PrivateClusterMasterGlobalAccessConfig? masterGlobalAccessConfig, String? masterIpv4CidrBlock, String? peeringName, String? privateEndpoint, String? privateEndpointSubnetwork, String? publicEndpoint})
PrivateClusterConfig.fromJson(Map json_)

Properties

enablePrivateEndpoint ↔ bool?
Whether the master's internal IP address is used as the cluster endpoint.
getter/setter pair
enablePrivateNodes ↔ bool?
Whether nodes have internal IP addresses only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
masterGlobalAccessConfig ↔ PrivateClusterMasterGlobalAccessConfig?
Controls master global access settings.
getter/setter pair
masterIpv4CidrBlock ↔ String?
The IP range in CIDR notation to use for the hosted master network.
getter/setter pair
peeringName ↔ String?
The peering name in the customer VPC used by this cluster.
getter/setter pair
privateEndpoint ↔ String?
The internal IP address of this cluster's master endpoint.
getter/setter pair
privateEndpointSubnetwork ↔ String?
Subnet to provision the master's private endpoint during cluster creation.
getter/setter pair
publicEndpoint ↔ String?
The external IP address of this cluster's master endpoint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited