PubSub class

Pub/Sub specific notification config.

Constructors

PubSub({bool? enabled, Filter? filter, String? topic})
PubSub.fromJson(Map json_)

Properties

enabled ↔ bool?
Enable notifications for Pub/Sub.
getter/setter pair
filter ↔ Filter?
Allows filtering to one or more specific event types.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic ↔ String?
The desired Pub/Sub topic to which notifications will be sent by GKE.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited