windowStartTime property
Start time of the window on days that it is scheduled, assuming UTC timezone.
Required.
Implementation
TimeOfDay? windowStartTime;
Start time of the window on days that it is scheduled, assuming UTC timezone.
Required.
TimeOfDay? windowStartTime;