server property
Defines the host name of the registry server, which will be used to create configuration file as /etc/containerd/hosts.d//hosts.toml.
It supports fully qualified domain names (FQDN) and IP addresses:
Specifying port is supported, while scheme and path are NOT supported.
Wildcards are NOT supported. Examples: - my.customdomain.com -
10.0.1.2:5000
Implementation
core.String? server;