ReleaseChannelConfig class

ReleaseChannelConfig exposes configuration for a release channel.

Constructors

ReleaseChannelConfig({String? channel, List<String>? customVersions, String? defaultVersion, String? upgradeTargetVersion, List<String>? validVersions})
ReleaseChannelConfig.fromJson(Map json_)

Properties

channel ↔ String?
The release channel this configuration applies to. Possible string values are:
getter/setter pair
customVersions ↔ List<String>?
List of custom versions for the channel.
getter/setter pair
defaultVersion ↔ String?
The default version for newly created clusters on the channel.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upgradeTargetVersion ↔ String?
The auto upgrade target version for clusters on the channel.
getter/setter pair
validVersions ↔ List<String>?
List of valid versions for the channel.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited