ResourceUsageExportConfig class

Configuration for exporting cluster resource usages.

Constructors

ResourceUsageExportConfig({BigQueryDestination? bigqueryDestination, ConsumptionMeteringConfig? consumptionMeteringConfig, bool? enableNetworkEgressMetering})
ResourceUsageExportConfig.fromJson(Map json_)

Properties

bigqueryDestination ↔ BigQueryDestination?
Configuration to use BigQuery as usage export destination.
getter/setter pair
consumptionMeteringConfig ↔ ConsumptionMeteringConfig?
Configuration to enable resource consumption metering.
getter/setter pair
enableNetworkEgressMetering ↔ bool?
Whether to enable network egress metering for this cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited