RollbackSafeUpgrade class

RollbackSafeUpgrade is the configuration for the rollback safe upgrade.

Constructors

RollbackSafeUpgrade({String? controlPlaneSoakDuration})
RollbackSafeUpgrade.fromJson(Map json_)

Properties

controlPlaneSoakDuration String?
A user-defined period for the cluster remains in the rollbackable state.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited