controlPlaneSoakDuration property
A user-defined period for the cluster remains in the rollbackable state.
ex: {seconds: 21600}.
Optional.
Implementation
core.String? controlPlaneSoakDuration;
A user-defined period for the cluster remains in the rollbackable state.
ex: {seconds: 21600}.
Optional.
core.String? controlPlaneSoakDuration;