RollbackSafeUpgradeStatus class

RollbackSafeUpgradeStatus contains the rollback-safe upgrade status of a cluster.

Constructors

RollbackSafeUpgradeStatus({String? controlPlaneUpgradeRollbackEndTime, String? mode, String? previousVersion})
RollbackSafeUpgradeStatus.fromJson(Map json_)

Properties

controlPlaneUpgradeRollbackEndTime String?
The rollback-safe mode expiration time.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mode String?
The mode of the rollback-safe upgrade.
getter/setter pair
previousVersion String?
The GKE version that the cluster previously used before step-one upgrade.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited