SecretSyncConfig class

Configuration for sync Secret Manager secrets as k8s secrets.

Constructors

SecretSyncConfig({bool? enabled, SyncRotationConfig? rotationConfig})
SecretSyncConfig.fromJson(Map json_)

Properties

enabled bool?
Enable/Disable Secret Sync Config.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rotationConfig RotationConfig?
Rotation config for secret manager.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited