ShieldedInstanceConfig class

A set of Shielded Instance options.

Constructors

ShieldedInstanceConfig({bool? enableIntegrityMonitoring, bool? enableSecureBoot})
ShieldedInstanceConfig.fromJson(Map json_)

Properties

enableIntegrityMonitoring ↔ bool?
Defines whether the instance has integrity monitoring enabled.
getter/setter pair
enableSecureBoot ↔ bool?
Defines whether the instance has Secure Boot enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited