SlurmOperatorConfig class

Configuration for the Slurm Operator.

Constructors

SlurmOperatorConfig({bool? enabled})
SlurmOperatorConfig.fromJson(Map json_)

Properties

enabled bool?
When enabled, it runs a Slurm Operator that manages the set of compute pods for Slurm Cluster.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited