enabled property
When enabled, it runs a Slurm Operator that manages the set of compute pods for Slurm Cluster.
Implementation
core.bool? enabled;
When enabled, it runs a Slurm Operator that manages the set of compute pods for Slurm Cluster.
core.bool? enabled;