SoleTenantConfig class

SoleTenantConfig contains the NodeAffinities to specify what shared sole tenant node groups should back the node pool.

Constructors

SoleTenantConfig({int? minNodeCpus, List<NodeAffinity>? nodeAffinities})
SoleTenantConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
minNodeCpus ↔ int?
The minimum number of virtual CPUs this instance will consume when running on a sole-tenant node.
getter/setter pair
nodeAffinities ↔ List<NodeAffinity>?
NodeAffinities used to match to a shared sole tenant node group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited