SwapConfig class

Configuration for swap memory on a node pool.

Constructors

SwapConfig({BootDiskProfile? bootDiskProfile, DedicatedLocalSsdProfile? dedicatedLocalSsdProfile, bool? enabled, EncryptionConfig? encryptionConfig, EphemeralLocalSsdProfile? ephemeralLocalSsdProfile})
SwapConfig.fromJson(Map json_)

Properties

bootDiskProfile ↔ BootDiskProfile?
Swap on the node's boot disk.
getter/setter pair
dedicatedLocalSsdProfile ↔ DedicatedLocalSsdProfile?
Provisions a new, separate local NVMe SSD exclusively for swap.
getter/setter pair
enabled ↔ bool?
Enables or disables swap for the node pool.
getter/setter pair
encryptionConfig ↔ EncryptionConfig?
If omitted, swap space is encrypted by default.
getter/setter pair
ephemeralLocalSsdProfile ↔ EphemeralLocalSsdProfile?
Swap on the local SSD shared with pod ephemeral storage.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited