architectureTaintBehavior property

String? architectureTaintBehavior
getter/setter pair

Controls architecture tainting behavior.

Optional. Possible string values are:

  • "ARCHITECTURE_TAINT_BEHAVIOR_UNSPECIFIED" : Specifies that the behavior is unspecified, defaults to ARM.
  • "NONE" : Disables default architecture taints on the node pool.
  • "ARM" : Taints all the nodes in the node pool with the default ARM taint.

Implementation

core.String? architectureTaintBehavior;