TopologyManager class
TopologyManager defines the configuration options for the [kubelet
Topology Manager
component](https://kubernetes.io/docs/tasks/administer-cluster/topology-manager/).
For more information about the supported machine types and versions for the Topology Manager in GKE, see Customizing node system configuration.
Constructors
- TopologyManager({String? policy, String? scope})
- TopologyManager.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- policy ↔ String?
-
Configures the strategy for resource alignment.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope ↔ String?
-
The Topology Manager aligns resources in following scopes: * container *
pod The default scope is 'container' if unspecified.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited