UpdateNodePoolRequest class

UpdateNodePoolRequests update a node pool's image and/or version.

Constructors

UpdateNodePoolRequest({List<AcceleratorConfig>? accelerators, BootDisk? bootDisk, String? clusterId, ConfidentialNodes? confidentialNodes, String? consolidationDelay, ContainerdConfig? containerdConfig, String? diskSizeGb, String? diskType, String? etag, FastSocket? fastSocket, bool? flexStart, GcfsConfig? gcfsConfig, VirtualNIC? gvnic, String? image, String? imageProject, String? imageType, NodeKubeletConfig? kubeletConfig, NodeLabels? labels, LinuxNodeConfig? linuxNodeConfig, List<String>? locations, NodePoolLoggingConfig? loggingConfig, String? machineType, NodePoolMaintenancePolicy? maintenancePolicy, String? maxRunDuration, String? name, NodeDrainConfig? nodeDrainConfig, NodeNetworkConfig? nodeNetworkConfig, String? nodePoolId, String? nodeVersion, String? projectId, QueuedProvisioning? queuedProvisioning, ResourceLabels? resourceLabels, ResourceManagerTags? resourceManagerTags, List<String>? storagePools, NetworkTags? tags, TaintConfig? taintConfig, NodeTaints? taints, UpgradeSettings? upgradeSettings, WindowsNodeConfig? windowsNodeConfig, WorkloadMetadataConfig? workloadMetadataConfig, String? zone})
UpdateNodePoolRequest.fromJson(Map json_)

Properties

accelerators ↔ List<AcceleratorConfig>?
A list of hardware accelerators to be attached to each node.
getter/setter pair
bootDisk ↔ BootDisk?
The desired boot disk config for nodes in the node pool.
getter/setter pair
clusterId ↔ String?
The name of the cluster to upgrade.
getter/setter pair
confidentialNodes ↔ ConfidentialNodes?
Confidential nodes config.
getter/setter pair
consolidationDelay ↔ String?
Consolidation delay defines duration after which the Cluster Autoscaler can scale down underutilized nodes.
getter/setter pair
containerdConfig ↔ ContainerdConfig?
The desired containerd config for nodes in the node pool.
getter/setter pair
diskSizeGb ↔ String?
The desired disk size for nodes in the node pool specified in GB.
getter/setter pair
diskType ↔ String?
The desired disk type (e.g. 'pd-standard', 'pd-ssd' or 'pd-balanced') for nodes in the node pool.
getter/setter pair
etag ↔ String?
The current etag of the node pool.
getter/setter pair
fastSocket ↔ FastSocket?
Enable or disable NCCL fast socket for the node pool.
getter/setter pair
flexStart ↔ bool?
Flex Start flag for enabling Flex Start VM.
getter/setter pair
gcfsConfig ↔ GcfsConfig?
GCFS config.
getter/setter pair
gvnic ↔ VirtualNIC?
Enable or disable gvnic on the node pool.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
The desired name of the image name to use for this node.
getter/setter pair
imageProject ↔ String?
The project containing the desired image to use for this node pool.
getter/setter pair
imageType ↔ String?
The desired image type for the node pool.
getter/setter pair
kubeletConfig ↔ NodeKubeletConfig?
Node kubelet configs.
getter/setter pair
labels ↔ NodeLabels?
The desired node labels to be applied to all nodes in the node pool.
getter/setter pair
linuxNodeConfig ↔ LinuxNodeConfig?
Parameters that can be configured on Linux nodes.
getter/setter pair
locations ↔ List<String>?
The desired list of Google Compute Engine zones in which the node pool's nodes should be located.
getter/setter pair
loggingConfig ↔ NodePoolLoggingConfig?
Logging configuration.
getter/setter pair
machineType ↔ String?
The desired Google Compute Engine machine type for nodes in the node pool.
getter/setter pair
maintenancePolicy ↔ NodePoolMaintenancePolicy?
Specifies the maintenance policy for the node pool, including maintenance exclusion options.
getter/setter pair
maxRunDuration ↔ String?
The maximum duration for the nodes to exist.
getter/setter pair
name ↔ String?
The name (project, location, cluster, node pool) of the node pool to update.
getter/setter pair
nodeDrainConfig ↔ NodeDrainConfig?
The desired node drain configuration for nodes in the node pool.
getter/setter pair
nodeNetworkConfig ↔ NodeNetworkConfig?
Node network config.
getter/setter pair
nodePoolId ↔ String?
The name of the node pool to upgrade.
getter/setter pair
nodeVersion ↔ String?
The Kubernetes version to change the nodes to (typically an upgrade).
getter/setter pair
projectId ↔ String?
The Google Developers Console project ID or project number.
getter/setter pair
queuedProvisioning ↔ QueuedProvisioning?
Specifies the configuration of queued provisioning.
getter/setter pair
resourceLabels ↔ NodeLabels?
The resource labels for the node pool to use to annotate any related Google Compute Engine resources.
getter/setter pair
resourceManagerTags ↔ ResourceManagerTags?
Desired resource manager tag keys and values to be attached to the nodes for managing Compute Engine firewalls using Network Firewall Policies.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storagePools ↔ List<String>?
List of Storage Pools where boot disks are provisioned.
getter/setter pair
tags ↔ NetworkTags?
The desired network tags to be applied to all nodes in the node pool.
getter/setter pair
taintConfig ↔ TaintConfig?
The taint configuration for the node pool.
getter/setter pair
taints ↔ NodeTaints?
The desired node taints to be applied to all nodes in the node pool.
getter/setter pair
upgradeSettings ↔ UpgradeSettings?
Upgrade settings control disruption and speed of the upgrade.
getter/setter pair
windowsNodeConfig ↔ WindowsNodeConfig?
Parameters that can be configured on Windows nodes.
getter/setter pair
workloadMetadataConfig ↔ WorkloadMetadataConfig?
The desired workload metadata config for the node pool.
getter/setter pair
zone ↔ String?
The name of the Google Compute Engine zone in which the cluster resides.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited