image property
The desired name of the image name to use for this node.
This is used to create clusters using a custom image.
Implementation
core.String? image;
The desired name of the image name to use for this node.
This is used to create clusters using a custom image.
core.String? image;