imageProject property

String? imageProject
getter/setter pair

The project containing the desired image to use for this node pool.

This is used to create clusters using a custom image.

Implementation

core.String? imageProject;