maintenancePolicy property
Specifies the maintenance policy for the node pool, including maintenance exclusion options.
Optional.
Implementation
NodePoolMaintenancePolicy? maintenancePolicy;
Specifies the maintenance policy for the node pool, including maintenance exclusion options.
Optional.
NodePoolMaintenancePolicy? maintenancePolicy;