UsableSubnetwork class

UsableSubnetwork resource returns the subnetwork name, its associated network and the primary CIDR range.

Constructors

UsableSubnetwork({String? ipCidrRange, String? network, List<UsableSubnetworkSecondaryRange>? secondaryIpRanges, String? statusMessage, String? subnetwork})
UsableSubnetwork.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipCidrRange ↔ String?
The range of internal addresses that are owned by this subnetwork.
getter/setter pair
network ↔ String?
Network Name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryIpRanges ↔ List<UsableSubnetworkSecondaryRange>?
Secondary IP ranges.
getter/setter pair
statusMessage ↔ String?
A human readable status message representing the reasons for cases where the caller cannot use the secondary ranges under the subnet.
getter/setter pair
subnetwork ↔ String?
Subnetwork Name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited