UserManagedKeysConfig class

UserManagedKeysConfig holds the resource address to Keys which are used for signing certs and token that are used for communication within cluster.

Constructors

UserManagedKeysConfig({String? aggregationCa, String? clusterCa, String? controlPlaneDiskEncryptionKey, String? etcdApiCa, String? etcdPeerCa, String? gkeopsEtcdBackupEncryptionKey, List<String>? serviceAccountSigningKeys, List<String>? serviceAccountVerificationKeys})
UserManagedKeysConfig.fromJson(Map json_)

Properties

aggregationCa ↔ String?
The Certificate Authority Service caPool to use for the aggregation CA in this cluster.
getter/setter pair
clusterCa ↔ String?
The Certificate Authority Service caPool to use for the cluster CA in this cluster.
getter/setter pair
controlPlaneDiskEncryptionKey ↔ String?
The Cloud KMS cryptoKey to use for Confidential Hyperdisk on the control plane nodes.
getter/setter pair
etcdApiCa ↔ String?
Resource path of the Certificate Authority Service caPool to use for the etcd API CA in this cluster.
getter/setter pair
etcdPeerCa ↔ String?
Resource path of the Certificate Authority Service caPool to use for the etcd peer CA in this cluster.
getter/setter pair
gkeopsEtcdBackupEncryptionKey ↔ String?
Resource path of the Cloud KMS cryptoKey to use for encryption of internal etcd backups.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountSigningKeys ↔ List<String>?
The Cloud KMS cryptoKeyVersions to use for signing service account JWTs issued by this cluster.
getter/setter pair
serviceAccountVerificationKeys ↔ List<String>?
The Cloud KMS cryptoKeyVersions to use for verifying service account JWTs issued by this cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited