WindowsNodeConfig class

Parameters that can be configured on Windows nodes.

Windows Node Config that define the parameters that will be used to configure the Windows node pool settings.

Constructors

WindowsNodeConfig({String? osVersion})
WindowsNodeConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
osVersion ↔ String?
OSVersion specifies the Windows node config to be used on the node. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited