WorkloadPolicyConfig class

WorkloadPolicyConfig is the configuration related to GCW workload policy

Constructors

WorkloadPolicyConfig({bool? allowNetAdmin, bool? autopilotCompatibilityAuditingEnabled})
WorkloadPolicyConfig.fromJson(Map json_)

Properties

allowNetAdmin ↔ bool?
If true, workloads can use NET_ADMIN capability.
getter/setter pair
autopilotCompatibilityAuditingEnabled ↔ bool?
If true, enables the GCW Auditor that audits workloads on standard clusters.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited