AISkillAnalysisOccurrence class

AISkillAnalysisOccurrence provides the results of an AI-based skill analysis.

Constructors

AISkillAnalysisOccurrence({List<Finding>? findings, String? maxSeverity, PerScannerVerdict? perScannerVerdict, String? skillName})
AISkillAnalysisOccurrence.fromJson(Map json_)

Properties

findings List<Finding>?
Findings produced by the analysis.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxSeverity String?
Maximum severity found among findings.
getter/setter pair
perScannerVerdict PerScannerVerdict?
Per scanner verdict.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skillName String?
Name of the skill that produced this analysis.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited