ComplianceOccurrence class

An indication that the compliance checks in the associated ComplianceNote were not satisfied for particular resources or a specified reason.

Constructors

ComplianceOccurrence({String? nonComplianceReason, List<NonCompliantFile>? nonCompliantFiles, ComplianceVersion? version})
ComplianceOccurrence.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nonComplianceReason ↔ String?
getter/setter pair
nonCompliantFiles ↔ List<NonCompliantFile>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ ComplianceVersion?
The OS and config version the benchmark was run on.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited