Finding class
Finding provides details for a single finding within an AISkillAnalysisOccurrence.
Constructors
- Finding({String? category, String? details, FindingLocation? location, String? scanner, String? severity})
- Finding.fromJson(Map json_)
Properties
- category ↔ String?
-
Category of the finding.
getter/setter pair
- details ↔ String?
-
Description of the finding category.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- location ↔ FindingLocation?
-
Location (path and line) where the finding was detected.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanner ↔ String?
-
Scanner determines which engine (e.g. static, llm) emitted the finding.
Possible string values are:
getter/setter pair
- severity ↔ String?
-
Severity of the finding.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited