ListOccurrencesResponse class

Response for listing occurrences.

Constructors

ListOccurrencesResponse({String? nextPageToken, List<Occurrence>? occurrences, List<String>? unreachable})
ListOccurrencesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The next pagination token in the list response.
getter/setter pair
occurrences ↔ List<Occurrence>?
The occurrences requested.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unordered list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited