PerScannerVerdict class

Constructors

PerScannerVerdict({MaliciousContentLLMResult? maliciousContentLlmResult, MaliciousContentStaticResult? maliciousContentStaticResult, MalwareScanResult? malwareScan, WorkspacePolicyResult? workspacePolicy})
PerScannerVerdict.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
maliciousContentLlmResult MaliciousContentLLMResult?
Malicious Content LLM scan result.
getter/setter pair
maliciousContentStaticResult MaliciousContentLLMResult?
Malicious Content Static scan result.
getter/setter pair
malwareScan MalwareScanResult?
Malware scan result.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workspacePolicy MalwareScanResult?
Workspace Policy scan result.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited