Product class

Product contains information about a product and how to uniquely identify it.

Constructors

Product({String? genericUri, String? id, String? name})
Product.fromJson(Map json_)

Properties

genericUri ↔ String?
Contains a URI which is vendor-specific.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Token that identifies a product so that it can be referred to from other parts in the document.
getter/setter pair
name ↔ String?
Name of the product.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited