SlsaProvenance class

Constructors

SlsaProvenance({SlsaBuilder? builder, List<Material>? materials, SlsaMetadata? metadata, SlsaRecipe? recipe})
SlsaProvenance.fromJson(Map json_)

Properties

builder ↔ BuilderConfig?
required
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
materials ↔ List<Material>?
The collection of artifacts that influenced the build including sources, dependencies, build tools, base images, and so on.
getter/setter pair
metadata ↔ SlsaMetadata?
getter/setter pair
recipe ↔ SlsaRecipe?
Identifies the configuration used for the build.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited