SlsaProvenanceV1 class

Keep in sync with schema at https://github.com/slsa-framework/slsa/blob/main/docs/provenance/schema/v1/provenance.proto Builder renamed to ProvenanceBuilder because of Java conflicts.

Constructors

SlsaProvenanceV1({BuildDefinition? buildDefinition, RunDetails? runDetails})
SlsaProvenanceV1.fromJson(Map json_)

Properties

buildDefinition ↔ BuildDefinition?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runDetails ↔ RunDetails?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited