AccountAddress class

Constructors

AccountAddress({String? country, String? locality, String? postalCode, String? region, String? streetAddress})
AccountAddress.fromJson(Map json_)

Properties

country ↔ String?
CLDR country code (for example, "US").
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locality ↔ String?
City, town or commune.
getter/setter pair
postalCode ↔ String?
Postal code or ZIP (for example, "94043").
getter/setter pair
region ↔ String?
Top-level administrative subdivision of the country.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streetAddress ↔ String?
Street-level part of the address.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited