AccountBusinessIdentity class

The business identity attributes can be used to self-declare attributes that let customers know more about your business.

Constructors

AccountBusinessIdentity({AccountIdentityType? blackOwned, bool? includeForPromotions, AccountIdentityType? latinoOwned, AccountIdentityType? smallBusiness, AccountIdentityType? veteranOwned, AccountIdentityType? womenOwned})
AccountBusinessIdentity.fromJson(Map json_)

Properties

blackOwned ↔ AccountIdentityType?
Specifies whether the business identifies itself as being black-owned.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeForPromotions ↔ bool?
By setting this field, your business may be included in promotions for all the selected attributes.
getter/setter pair
latinoOwned ↔ AccountIdentityType?
Specifies whether the business identifies itself as being latino-owned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallBusiness ↔ AccountIdentityType?
Specifies whether the business identifies itself as a small business.
getter/setter pair
veteranOwned ↔ AccountIdentityType?
Specifies whether the business identifies itself as being veteran-owned.
getter/setter pair
womenOwned ↔ AccountIdentityType?
Specifies whether the business identifies itself as being women-owned.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited