AccountCredentials class

Credentials allowing Google to call a partner's API on behalf of a merchant.

Constructors

AccountCredentials({String? accessToken, String? expiresIn, String? purpose})
AccountCredentials.fromJson(Map json_)

Properties

accessToken ↔ String?
An OAuth access token.
getter/setter pair
expiresIn ↔ String?
The amount of time, in seconds, after which the access token is no longer valid.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
purpose ↔ String?
Indicates to Google how Google should use these OAuth tokens. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited