AccountCustomerService class

Constructors

AccountCustomerService({String? email, String? phoneNumber, String? url})
AccountCustomerService.fromJson(Map json_)

Properties

email ↔ String?
Customer service email.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber ↔ String?
Customer service phone number.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
Customer service URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited