AccountIdentifier class

Constructors

AccountIdentifier({String? aggregatorId, String? merchantId})
AccountIdentifier.fromJson(Map json_)

Properties

aggregatorId ↔ String?
The aggregator ID, set for aggregators and subaccounts (in that case, it represents the aggregator of the subaccount).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantId ↔ String?
The merchant account ID, set for individual accounts and subaccounts.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited