AccountIssue class

An issue affecting specific merchant.

Constructors

AccountIssue({List<Action>? actions, AccountIssueImpact? impact, String? prerenderedContent, String? prerenderedOutOfCourtDisputeSettlement, String? title})
AccountIssue.fromJson(Map json_)

Properties

actions ↔ List<Action>?
A list of actionable steps that can be executed to solve the issue.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
impact ↔ AccountIssueImpact?
Clarifies the severity of the issue.
getter/setter pair
prerenderedContent ↔ String?
Details of the issue as a pre-rendered HTML.
getter/setter pair
prerenderedOutOfCourtDisputeSettlement ↔ String?
Pre-rendered HTML that contains a link to the external location where the ODS can be requested and instructions for how to request it.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title of the issue.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited