AccountIssueImpact class

Overall impact of the issue.

Constructors

AccountIssueImpact({List<Breakdown>? breakdowns, String? message, String? severity})
AccountIssueImpact.fromJson(Map json_)

Properties

breakdowns ↔ List<Breakdown>?
Detailed impact breakdown.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
Message summarizing the overall impact of the issue.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of the issue. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited