AccountItemUpdates class

Turning on item updates allows Google to automatically update items for you.

When item updates are on, Google uses the structured data markup on the website and advanced data extractors to update the price and availability of the items. When the item updates are off, items with mismatched data aren't shown.

Constructors

AccountItemUpdates({AccountItemUpdatesSettings? accountItemUpdatesSettings, bool? effectiveAllowAvailabilityUpdates, bool? effectiveAllowConditionUpdates, bool? effectiveAllowPriceUpdates, bool? effectiveAllowStrictAvailabilityUpdates})
AccountItemUpdates.fromJson(Map json_)

Properties

accountItemUpdatesSettings ↔ AccountItemUpdatesSettings?
Determines which attributes of the items should be automatically updated.
getter/setter pair
effectiveAllowAvailabilityUpdates ↔ bool?
The effective value of allow_availability_updates.
getter/setter pair
effectiveAllowConditionUpdates ↔ bool?
The effective value of allow_condition_updates.
getter/setter pair
effectiveAllowPriceUpdates ↔ bool?
The effective value of allow_price_updates.
getter/setter pair
effectiveAllowStrictAvailabilityUpdates ↔ bool?
The effective value of allow_strict_availability_updates.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited