AccountStatusAccountLevelIssue class

Constructors

AccountStatusAccountLevelIssue({String? country, String? destination, String? detail, String? documentation, String? id, String? severity, String? title})
AccountStatusAccountLevelIssue.fromJson(Map json_)

Properties

country ↔ String?
Country for which this issue is reported.
getter/setter pair
destination ↔ String?
The destination the issue applies to.
getter/setter pair
detail ↔ String?
Additional details about the issue.
getter/setter pair
documentation ↔ String?
The URL of a web page to help resolving this issue.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Issue identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Severity of the issue.
getter/setter pair
title ↔ String?
Short description of the issue.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited