AccountStatusItemLevelIssue class

Constructors

AccountStatusItemLevelIssue({String? attributeName, String? code, String? description, String? detail, String? documentation, String? numItems, String? resolution, String? servability})
AccountStatusItemLevelIssue.fromJson(Map json_)

Properties

attributeName ↔ String?
The attribute's name, if the issue is caused by a single attribute.
getter/setter pair
code ↔ String?
The error code of the issue.
getter/setter pair
description ↔ String?
A short issue description in English.
getter/setter pair
detail ↔ String?
A detailed issue description in English.
getter/setter pair
documentation ↔ String?
The URL of a web page to help with resolving this issue.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numItems ↔ String?
Number of items with this issue.
getter/setter pair
resolution ↔ String?
Whether the issue can be resolved by the merchant.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servability ↔ String?
How this issue affects serving of the offer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited