AccountUser class

Constructors

AccountUser({bool? admin, String? emailAddress, bool? orderManager, bool? paymentsAnalyst, bool? paymentsManager, bool? readOnly, bool? reportingManager})
AccountUser.fromJson(Map json_)

Properties

admin ↔ bool?
Whether user is an admin.
getter/setter pair
emailAddress ↔ String?
User's email address.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
orderManager ↔ bool?
This role is deprecated and can no longer be assigned.
getter/setter pair
paymentsAnalyst ↔ bool?
This role is deprecated and can no longer be assigned.
getter/setter pair
paymentsManager ↔ bool?
This role is deprecated and can no longer be assigned.
getter/setter pair
readOnly ↔ bool?
Whether user has standard read-only access.
getter/setter pair
reportingManager ↔ bool?
Whether user is a reporting manager.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited