AccountsCustomBatchRequestEntry class

A batch entry encoding a single non-batch accounts request.

Constructors

AccountsCustomBatchRequestEntry({Account? account, String? accountId, int? batchId, bool? force, List<String>? labelIds, AccountsCustomBatchRequestEntryLinkRequest? linkRequest, String? merchantId, String? method, bool? overwrite, String? view})
AccountsCustomBatchRequestEntry.fromJson(Map json_)

Properties

account ↔ Account?
The account to create or update.
getter/setter pair
accountId ↔ String?
The ID of the targeted account.
getter/setter pair
batchId ↔ int?
An entry ID, unique within the batch request.
getter/setter pair
force ↔ bool?
Whether the account should be deleted if the account has offers.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labelIds ↔ List<String>?
Label IDs for the 'updatelabels' request.
getter/setter pair
linkRequest ↔ AccountsCustomBatchRequestEntryLinkRequest?
Details about the link request.
getter/setter pair
merchantId ↔ String?
The ID of the managing account.
getter/setter pair
method ↔ String?
The method of the batch entry.
getter/setter pair
overwrite ↔ bool?
Only applicable if the method is claimwebsite.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view ↔ String?
Controls which fields are visible.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited