AccountstatusesCustomBatchRequestEntry class

A batch entry encoding a single non-batch accountstatuses request.

Constructors

AccountstatusesCustomBatchRequestEntry({String? accountId, int? batchId, List<String>? destinations, String? merchantId, String? method})
AccountstatusesCustomBatchRequestEntry.fromJson(Map json_)

Properties

accountId ↔ String?
The ID of the (sub-)account whose status to get.
getter/setter pair
batchId ↔ int?
An entry ID, unique within the batch request.
getter/setter pair
destinations ↔ List<String>?
If set, only issues for the specified destinations are returned, otherwise only issues for the Shopping destination.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantId ↔ String?
The ID of the managing account.
getter/setter pair
method ↔ String?
The method of the batch entry.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited