ActionFlow class

Flow that can be selected for an action.

When merchant selects a flow, application should open a dialog with more information and input form.

Constructors

ActionFlow({String? dialogButtonLabel, Callout? dialogCallout, TextWithTooltip? dialogMessage, String? dialogTitle, String? id, List<InputField>? inputs, String? label})
ActionFlow.fromJson(Map json_)

Properties

dialogButtonLabel ↔ String?
Label for the button to trigger the action from the action dialog.
getter/setter pair
dialogCallout ↔ Callout?
Important message to be highlighted in the request dialog.
getter/setter pair
dialogMessage ↔ TextWithTooltip?
Message displayed in the request dialog.
getter/setter pair
dialogTitle ↔ String?
Title of the request dialog.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Not for display but need to be sent back for the selected action flow.
getter/setter pair
inputs ↔ List<InputField>?
A list of input fields.
getter/setter pair
label ↔ String?
Text value describing the intent for the action flow.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited