ActionInput class

Input provided by the merchant.

Constructors

ActionInput({String? actionFlowId, List<InputValue>? inputValues})
ActionInput.fromJson(Map json_)

Properties

actionFlowId ↔ String?
Id of the selected action flow.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputValues ↔ List<InputValue>?
Values for input fields.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited