Callout class

An important message that should be highlighted.

Usually displayed as a banner.

Constructors

Callout({TextWithTooltip? fullMessage, String? styleHint})
Callout.fromJson(Map json_)

Properties

fullMessage ↔ TextWithTooltip?
A full message that needs to be shown to the merchant.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
styleHint ↔ String?
Can be used to render messages with different severity in different styles.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited