CollectionFeaturedProduct class

The message for FeaturedProduct.

FeaturedProduct

Properties

hashCode → int
The hash code for this object.
no setterinherited
offerId ↔ String?
The unique identifier for the product item.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double?
X-coordinate of the product callout on the Shoppable Image.
getter/setter pair
y ↔ double?
Y-coordinate of the product callout on the Shoppable Image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited