CollectionStatus class

The collectionstatus message.

Constructors

CollectionStatus({List<CollectionStatusItemLevelIssue>? collectionLevelIssuses, String? creationDate, List<CollectionStatusDestinationStatus>? destinationStatuses, String? id, String? lastUpdateDate})
CollectionStatus.fromJson(Map json_)

Properties

collectionLevelIssuses ↔ List<CollectionStatusItemLevelIssue>?
A list of all issues associated with the collection.
getter/setter pair
creationDate ↔ String?
Date on which the collection has been created in ISO 8601 format: Date, time, and offset, for example "2020-01-02T09:00:00+01:00" or "2020-01-02T09:00:00Z"
getter/setter pair
destinationStatuses ↔ List<CollectionStatusDestinationStatus>?
The intended destinations for the collection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the collection for which status is reported.
getter/setter pair
lastUpdateDate ↔ String?
Date on which the collection has been last updated in ISO 8601 format: Date, time, and offset, for example "2020-01-02T09:00:00+01:00" or "2020-01-02T09:00:00Z"
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited