ConversionSource class

Represents a conversion source owned by a Merchant account.

A merchant account can have up to 200 conversion sources.

Constructors

ConversionSource({String? conversionSourceId, String? expireTime, GoogleAnalyticsLink? googleAnalyticsLink, MerchantCenterDestination? merchantCenterDestination, String? state})
ConversionSource.fromJson(Map json_)

Properties

conversionSourceId ↔ String?
Generated by the Content API upon creation of a new ConversionSource.
getter/setter pair
expireTime ↔ String?
The time when an archived conversion source becomes permanently deleted and is no longer available to undelete.
getter/setter pair
Conversion Source of type "Link to Google Analytics Property".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantCenterDestination ↔ MerchantCenterDestination?
Conversion Source of type "Merchant Center Tag Destination".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Current state of this conversion source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited