CutoffTime class

Constructors

CutoffTime({int? hour, int? minute, String? timezone})
CutoffTime.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hour ↔ int?
Hour of the cutoff time until which an order has to be placed to be processed in the same day.
getter/setter pair
minute ↔ int?
Minute of the cutoff time until which an order has to be placed to be processed in the same day.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timezone ↔ String?
Timezone identifier for the cutoff time (for example, "Europe/Zurich").
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited