DatafeedFetchSchedule class

The required fields vary based on the frequency of fetching.

For a monthly fetch schedule, day_of_month and hour are required. For a weekly fetch schedule, weekday and hour are required. For a daily fetch schedule, only hour is required.

Constructors

DatafeedFetchSchedule({int? dayOfMonth, String? fetchUrl, int? hour, int? minuteOfHour, String? password, bool? paused, String? timeZone, String? username, String? weekday})
DatafeedFetchSchedule.fromJson(Map json_)

Properties

dayOfMonth ↔ int?
The day of the month the feed file should be fetched (1-31).
getter/setter pair
fetchUrl ↔ String?
The URL where the feed file can be fetched.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hour ↔ int?
The hour of the day the feed file should be fetched (0-23).
getter/setter pair
minuteOfHour ↔ int?
The minute of the hour the feed file should be fetched (0-59).
getter/setter pair
password ↔ String?
An optional password for fetch_url.
getter/setter pair
paused ↔ bool?
Whether the scheduled fetch is paused or not.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone ↔ String?
Time zone used for schedule.
getter/setter pair
username ↔ String?
An optional user name for fetch_url.
getter/setter pair
weekday ↔ String?
The day of the week the feed file should be fetched.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited