DatafeedFormat class

Constructors

DatafeedFormat({String? columnDelimiter, String? fileEncoding, String? quotingMode})
DatafeedFormat.fromJson(Map json_)

Properties

columnDelimiter ↔ String?
Delimiter for the separation of values in a delimiter-separated values feed.
getter/setter pair
fileEncoding ↔ String?
Character encoding scheme of the data feed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
quotingMode ↔ String?
Specifies how double quotes are interpreted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited