DatafeedStatus class

The status of a datafeed, that is, the result of the last retrieval of the datafeed computed asynchronously when the feed processing is finished.

Constructors

DatafeedStatus({String? country, String? datafeedId, List<DatafeedStatusError>? errors, String? feedLabel, String? itemsTotal, String? itemsValid, String? kind, String? language, String? lastUploadDate, String? processingStatus, List<DatafeedStatusError>? warnings})
DatafeedStatus.fromJson(Map json_)

Properties

country ↔ String?
The country for which the status is reported, represented as a CLDR territory code.
getter/setter pair
datafeedId ↔ String?
The ID of the feed for which the status is reported.
getter/setter pair
errors ↔ List<DatafeedStatusError>?
The list of errors occurring in the feed.
getter/setter pair
feedLabel ↔ String?
The feed label status is reported for.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemsTotal ↔ String?
The number of items in the feed that were processed.
getter/setter pair
itemsValid ↔ String?
The number of items in the feed that were valid.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
language ↔ String?
The two-letter ISO 639-1 language for which the status is reported.
getter/setter pair
lastUploadDate ↔ String?
The last date at which the feed was uploaded.
getter/setter pair
processingStatus ↔ String?
The processing status of the feed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warnings ↔ List<DatafeedStatusError>?
The list of errors occurring in the feed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited