DatafeedStatusExample class

An example occurrence for a particular error.

Constructors

DatafeedStatusExample({String? itemId, String? lineNumber, String? value})
DatafeedStatusExample.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
itemId ↔ String?
The ID of the example item.
getter/setter pair
lineNumber ↔ String?
Line number in the data feed where the example is found.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The problematic value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited