DatafeedTarget class

Constructors

DatafeedTarget({String? country, List<String>? excludedDestinations, String? feedLabel, List<String>? includedDestinations, String? language, List<String>? targetCountries})
DatafeedTarget.fromJson(Map json_)

Properties

country ↔ String?
Use feedLabel instead.
getter/setter pair
excludedDestinations ↔ List<String>?
The list of [destinations to exclude](//support.google.com/merchants/answer/6324486) for this target (corresponds to cleared check boxes in Merchant Center).
getter/setter pair
feedLabel ↔ String?
Feed label for the DatafeedTarget.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includedDestinations ↔ List<String>?
The list of [destinations to include](//support.google.com/merchants/answer/7501026) for this target (corresponds to checked check boxes in Merchant Center).
getter/setter pair
language ↔ String?
The two-letter ISO 639-1 language of the items in the feed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetCountries ↔ List<String>?
The countries where the items may be displayed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited