DatafeedstatusesListResponse class

Constructors

DatafeedstatusesListResponse({String? kind, String? nextPageToken, List<DatafeedStatus>? resources})
DatafeedstatusesListResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
nextPageToken ↔ String?
The token for the retrieval of the next page of datafeed statuses.
getter/setter pair
resources ↔ List<DatafeedStatus>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited