DeliveryTime class

Constructors

DeliveryTime({CutoffTime? cutoffTime, BusinessDayConfig? handlingBusinessDayConfig, List<HolidayCutoff>? holidayCutoffs, int? maxHandlingTimeInDays, int? maxTransitTimeInDays, int? minHandlingTimeInDays, int? minTransitTimeInDays, BusinessDayConfig? transitBusinessDayConfig, TransitTable? transitTimeTable, List<WarehouseBasedDeliveryTime>? warehouseBasedDeliveryTimes})
DeliveryTime.fromJson(Map json_)

Properties

cutoffTime ↔ CutoffTime?
Business days cutoff time definition.
getter/setter pair
handlingBusinessDayConfig ↔ BusinessDayConfig?
The business days during which orders can be handled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
holidayCutoffs ↔ List<HolidayCutoff>?
Holiday cutoff definitions.
getter/setter pair
maxHandlingTimeInDays ↔ int?
Maximum number of business days spent before an order is shipped.
getter/setter pair
maxTransitTimeInDays ↔ int?
Maximum number of business days that are spent in transit.
getter/setter pair
minHandlingTimeInDays ↔ int?
Minimum number of business days spent before an order is shipped.
getter/setter pair
minTransitTimeInDays ↔ int?
Minimum number of business days that are spent in transit.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transitBusinessDayConfig ↔ BusinessDayConfig?
The business days during which orders can be in-transit.
getter/setter pair
transitTimeTable ↔ TransitTable?
Transit time table, number of business days spent in transit based on row and column dimensions.
getter/setter pair
warehouseBasedDeliveryTimes ↔ List<WarehouseBasedDeliveryTime>?
Indicates that the delivery time should be calculated per warehouse (shipping origin location) based on the settings of the selected carrier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited