Errors class

A list of errors returned by a failed batch entry.

Constructors

Errors({int? code, List<Error>? errors, String? message})
Errors.fromJson(Map json_)

Properties

code ↔ int?
The HTTP status of the first error in errors.
getter/setter pair
errors ↔ List<Error>?
A list of errors.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
The message of the first error in errors.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited