InputField class

Input field that needs to be available to the merchant.

If the field is marked as required, then a value needs to be provided for a successful processing of the request.

Constructors

InputField({InputFieldCheckboxInput? checkboxInput, InputFieldChoiceInput? choiceInput, String? id, TextWithTooltip? label, bool? required, InputFieldTextInput? textInput})
InputField.fromJson(Map json_)

Properties

checkboxInput ↔ InputFieldCheckboxInput?
Input field to provide a boolean value.
getter/setter pair
choiceInput ↔ InputFieldChoiceInput?
Input field to select one of the offered choices.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Not for display but need to be sent back for the given input field.
getter/setter pair
label ↔ TextWithTooltip?
Input field label.
getter/setter pair
required ↔ bool?
Whether the field is required.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textInput ↔ InputFieldTextInput?
Input field to provide text information.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited