InputValue class

Input provided by the merchant for input field.

Constructors

InputValue({InputValueCheckboxInputValue? checkboxInputValue, InputValueChoiceInputValue? choiceInputValue, String? inputFieldId, InputValueTextInputValue? textInputValue})
InputValue.fromJson(Map json_)

Properties

checkboxInputValue ↔ InputValueCheckboxInputValue?
Value for checkbox input field.
getter/setter pair
choiceInputValue ↔ InputValueChoiceInputValue?
Value for choice input field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputFieldId ↔ String?
Id of the corresponding input field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textInputValue ↔ InputValueTextInputValue?
Value for text input field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited