LiasettingsCustomBatchResponseEntry class

Constructors

LiasettingsCustomBatchResponseEntry({int? batchId, Errors? errors, GmbAccounts? gmbAccounts, String? kind, LiaSettings? liaSettings, LiaOmnichannelExperience? omnichannelExperience, List<PosDataProviders>? posDataProviders})
LiasettingsCustomBatchResponseEntry.fromJson(Map json_)

Properties

batchId ↔ int?
The ID of the request entry to which this entry responds.
getter/setter pair
errors ↔ Errors?
A list of errors defined if, and only if, the request failed.
getter/setter pair
gmbAccounts ↔ GmbAccounts?
The list of accessible Business Profiles.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
liaSettings ↔ LiaSettings?
The retrieved or updated Lia settings.
getter/setter pair
omnichannelExperience ↔ LiaOmnichannelExperience?
The updated omnichannel experience for a country.
getter/setter pair
posDataProviders ↔ List<PosDataProviders>?
The list of POS data providers.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited