LinkService class

Constructors

LinkService({String? service, String? status})
LinkService.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
Service provided to or by the linked account.
getter/setter pair
status ↔ String?
Status of the link Acceptable values are: - "active" - "inactive" - "pending"
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited