LinkedAccount class

Constructors

LinkedAccount({String? linkedAccountId, List<LinkService>? services})
LinkedAccount.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
linkedAccountId ↔ String?
The ID of the linked account.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services ↔ List<LinkService>?
List of provided services.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited