LocalinventoryCustomBatchRequestEntry class

Batch entry encoding a single local inventory update request.

Constructors

LocalinventoryCustomBatchRequestEntry({int? batchId, LocalInventory? localInventory, String? merchantId, String? method, String? productId})
LocalinventoryCustomBatchRequestEntry.fromJson(Map json_)

Properties

batchId ↔ int?
An entry ID, unique within the batch request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localInventory ↔ LocalInventory?
Local inventory of the product.
getter/setter pair
merchantId ↔ String?
The ID of the managing account.
getter/setter pair
method ↔ String?
Method of the batch request entry.
getter/setter pair
productId ↔ String?
The ID of the product for which to update local inventory.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited