LoyaltyProgram class

Allows the setting up of loyalty program benefits (for example price or points).

https://support.google.com/merchants/answer/12922446

Constructors

LoyaltyProgram({Price? cashbackForFutureUse, String? loyaltyPoints, String? memberPriceEffectiveDate, Price? price, String? programLabel, String? shippingLabel, String? tierLabel})
LoyaltyProgram.fromJson(Map json_)

Properties

cashbackForFutureUse ↔ Price?
The cashback that can be used for future purchases.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loyaltyPoints ↔ String?
The amount of loyalty points earned on a purchase.
getter/setter pair
memberPriceEffectiveDate ↔ String?
A date range during which the item is eligible for member price.
getter/setter pair
price ↔ Price?
The price for members of the given tier (instant discount price).
getter/setter pair
programLabel ↔ String?
The label of the loyalty program.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingLabel ↔ String?
The shipping label for the loyalty program.
getter/setter pair
tierLabel ↔ String?
The label of the tier within the loyalty program.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited