MethodQuota class

The quota information per method in the Content API.

Constructors

MethodQuota({String? method, String? quotaLimit, String? quotaMinuteLimit, String? quotaUsage})
MethodQuota.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
method ↔ String?
The method name, for example products.list.
getter/setter pair
quotaLimit ↔ String?
The maximum number of calls allowed per day for the method.
getter/setter pair
quotaMinuteLimit ↔ String?
The maximum number of calls allowed per minute for the method.
getter/setter pair
quotaUsage ↔ String?
The current quota usage, meaning the number of calls already made to the method per day.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited