Metrics class

Performance metrics.

Values are only set for metrics requested explicitly in the request's search query.

Constructors

Metrics({double? aos, double? aovMicros, String? clicks, double? conversionRate, String? conversionValueMicros, double? conversions, double? ctr, double? daysToShip, String? impressions, double? itemDaysToShip, double? itemFillRate, String? orderedItemSalesMicros, String? orderedItems, String? orders, String? rejectedItems, double? returnRate, String? returnedItems, String? returnsMicros, String? shippedItemSalesMicros, String? shippedItems, String? shippedOrders, double? unshippedItems, double? unshippedOrders})
Metrics.fromJson(Map json_)

Properties

aos ↔ double?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
aovMicros ↔ double?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
clicks ↔ String?
Number of clicks.
getter/setter pair
conversionRate ↔ double?
Number of conversions divided by the number of clicks, reported on the impression date.
getter/setter pair
conversions ↔ double?
Number of conversions attributed to the product, reported on the conversion date.
getter/setter pair
conversionValueMicros ↔ String?
Value of conversions in micros (1 millionth of a standard unit, 1 USD = 1000000 micros) attributed to the product, reported on the conversion date.
getter/setter pair
ctr ↔ double?
Click-through rate - the number of clicks merchant's products receive (clicks) divided by the number of times the products are shown (impressions).
getter/setter pair
daysToShip ↔ double?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
impressions ↔ String?
Number of times merchant's products are shown.
getter/setter pair
itemDaysToShip ↔ double?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
itemFillRate ↔ double?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
orderedItems ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
orderedItemSalesMicros ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
orders ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
rejectedItems ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
returnedItems ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
returnRate ↔ double?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
returnsMicros ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippedItems ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
shippedItemSalesMicros ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
shippedOrders ↔ String?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
unshippedItems ↔ double?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair
unshippedOrders ↔ double?
Deprecated: This field is no longer supported and retrieving it returns 0 starting from May 2024.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited