OrderTrackingSignal class

Represents a merchant trade from which signals are extracted, e.g. shipping.

Constructors

OrderTrackingSignal({PriceAmount? customerShippingFee, String? deliveryPostalCode, String? deliveryRegionCode, List<OrderTrackingSignalLineItemDetails>? lineItems, String? merchantId, DateTime? orderCreatedTime, String? orderId, String? orderTrackingSignalId, List<OrderTrackingSignalShipmentLineItemMapping>? shipmentLineItemMapping, List<OrderTrackingSignalShippingInfo>? shippingInfo})
OrderTrackingSignal.fromJson(Map json_)

Properties

customerShippingFee ↔ Price?
The shipping fee of the order; this value should be set to zero in the case of free shipping.
getter/setter pair
deliveryPostalCode ↔ String?
The delivery postal code, as a continuous string without spaces or dashes, e.g. "95016".
getter/setter pair
deliveryRegionCode ↔ String?
The CLDR territory code for the shipping destination.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineItems ↔ List<OrderTrackingSignalLineItemDetails>?
Information about line items in the order.
getter/setter pair
merchantId ↔ String?
The Google merchant ID of this order tracking signal.
getter/setter pair
orderCreatedTime ↔ DateTime?
The time when the order was created on the merchant side.
getter/setter pair
orderId ↔ String?
The ID of the order on the merchant side.
getter/setter pair
orderTrackingSignalId ↔ String?
The ID that uniquely identifies this order tracking signal.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipmentLineItemMapping ↔ List<OrderTrackingSignalShipmentLineItemMapping>?
The mapping of the line items to the shipment information.
getter/setter pair
shippingInfo ↔ List<OrderTrackingSignalShippingInfo>?
The shipping information for the order.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited