OrderTrackingSignalLineItemDetails class

The line items of the order.

Constructors

OrderTrackingSignalLineItemDetails({String? brand, String? gtin, String? lineItemId, String? mpn, String? productDescription, String? productId, String? productTitle, String? quantity, String? sku, String? upc})
OrderTrackingSignalLineItemDetails.fromJson(Map json_)

Properties

brand ↔ String?
Brand of the product.
getter/setter pair
gtin ↔ String?
The Global Trade Item Number.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineItemId ↔ String?
The ID for this line item.
getter/setter pair
mpn ↔ String?
The manufacturer part number.
getter/setter pair
productDescription ↔ String?
Plain text description of this product (deprecated: Please use product_title instead).
getter/setter pair
productId ↔ String?
The Content API REST ID of the product, in the form channel:contentLanguage:targetCountry:offerId.
getter/setter pair
productTitle ↔ String?
Plain text title of this product.
getter/setter pair
quantity ↔ String?
The quantity of the line item in the order.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sku ↔ String?
Merchant SKU for this item (deprecated).
getter/setter pair
upc ↔ String?
Universal product code for this item (deprecated: Please use GTIN instead).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited