OrderTrackingSignalShippingInfo class

The shipping information for the order.

Constructors

OrderTrackingSignalShippingInfo({DateTime? actualDeliveryTime, String? carrierName, String? carrierServiceName, DateTime? earliestDeliveryPromiseTime, DateTime? latestDeliveryPromiseTime, String? originPostalCode, String? originRegionCode, String? shipmentId, DateTime? shippedTime, String? shippingStatus, String? trackingId})
OrderTrackingSignalShippingInfo.fromJson(Map json_)

Properties

actualDeliveryTime ↔ DateTime?
The time when the shipment was actually delivered.
getter/setter pair
carrierName ↔ String?
The name of the shipping carrier for the delivery.
getter/setter pair
carrierServiceName ↔ String?
The service type for fulfillment, e.g., GROUND, FIRST_CLASS, etc.
getter/setter pair
earliestDeliveryPromiseTime ↔ DateTime?
The earliest delivery promised time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latestDeliveryPromiseTime ↔ DateTime?
The latest delivery promised time.
getter/setter pair
originPostalCode ↔ String?
The origin postal code, as a continuous string without spaces or dashes, e.g. "95016".
getter/setter pair
originRegionCode ↔ String?
The CLDR territory code for the shipping origin.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipmentId ↔ String?
The shipment ID.
getter/setter pair
shippedTime ↔ DateTime?
The time when the shipment was shipped.
getter/setter pair
shippingStatus ↔ String?
The status of the shipment. Possible string values are:
getter/setter pair
trackingId ↔ String?
The tracking ID of the shipment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited