PosDataProvidersPosDataProvider class

Constructors

PosDataProvidersPosDataProvider({String? displayName, String? fullName, String? providerId})
PosDataProvidersPosDataProvider.fromJson(Map json_)

Properties

displayName ↔ String?
The display name of Pos data Provider.
getter/setter pair
fullName ↔ String?
The full name of this POS data Provider.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
providerId ↔ String?
The ID of the account.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited