PosInventoryResponse class

Constructors

PosInventoryResponse({String? contentLanguage, String? gtin, String? itemId, String? kind, String? pickupMethod, String? pickupSla, Price? price, String? quantity, String? storeCode, String? targetCountry, String? timestamp})
PosInventoryResponse.fromJson(Map json_)

Properties

contentLanguage ↔ String?
The two-letter ISO 639-1 language code for the item.
getter/setter pair
gtin ↔ String?
Global Trade Item Number.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemId ↔ String?
A unique identifier for the item.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
pickupMethod ↔ String?
Supported pickup method for this offer.
getter/setter pair
pickupSla ↔ String?
Expected date that an order will be ready for pickup relative to the order date.
getter/setter pair
price ↔ Price?
The current price of the item.
getter/setter pair
quantity ↔ String?
The available quantity of the item.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeCode ↔ String?
The identifier of the merchant's store.
getter/setter pair
targetCountry ↔ String?
The CLDR territory code for the item.
getter/setter pair
timestamp ↔ String?
The inventory timestamp, in ISO 8601 format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited