PosSaleRequest class

Constructors

PosSaleRequest({String? contentLanguage, String? gtin, String? itemId, Price? price, String? quantity, String? saleId, String? storeCode, String? targetCountry, String? timestamp})
PosSaleRequest.fromJson(Map json_)

Properties

contentLanguage ↔ String?
The two-letter ISO 639-1 language code for the item.
getter/setter pair
gtin ↔ String?
Global Trade Item Number.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemId ↔ String?
A unique identifier for the item.
getter/setter pair
price ↔ Price?
The price of the item.
getter/setter pair
quantity ↔ String?
The relative change of the available quantity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saleId ↔ String?
A unique ID to group items from the same sale event.
getter/setter pair
storeCode ↔ String?
The identifier of the merchant's store.
getter/setter pair
targetCountry ↔ String?
The CLDR territory code for the item.
getter/setter pair
timestamp ↔ String?
The inventory timestamp, in ISO 8601 format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited