ProductStatus class

The status of a product, that is, information about a product computed asynchronously.

Constructors

ProductStatus({String? creationDate, List<ProductStatusDestinationStatus>? destinationStatuses, String? googleExpirationDate, List<ProductStatusItemLevelIssue>? itemLevelIssues, String? kind, String? lastUpdateDate, String? link, String? productId, String? title})
ProductStatus.fromJson(Map json_)

Properties

creationDate ↔ String?
Date on which the item has been created, in ISO 8601 format.
getter/setter pair
destinationStatuses ↔ List<ProductStatusDestinationStatus>?
The intended destinations for the product.
getter/setter pair
googleExpirationDate ↔ String?
Date on which the item expires in Google Shopping, in ISO 8601 format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemLevelIssues ↔ List<ProductStatusItemLevelIssue>?
A list of all issues associated with the product.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lastUpdateDate ↔ String?
Date on which the item has been last updated, in ISO 8601 format.
getter/setter pair
The link to the product.
getter/setter pair
productId ↔ String?
The ID of the product for which status is reported.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The title of the product.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited