ProductView class

Product fields.

Values are only set for fields requested explicitly in the request's search query.

Constructors

ProductView({String? aggregatedDestinationStatus, String? availability, String? brand, String? categoryL1, String? categoryL2, String? categoryL3, String? categoryL4, String? categoryL5, String? channel, String? clickPotential, String? clickPotentialRank, String? condition, String? creationTime, String? currencyCode, Date? expirationDate, List<String>? gtin, String? id, String? itemGroupId, List<ProductViewItemIssue>? itemIssues, String? languageCode, String? offerId, String? priceMicros, String? productTypeL1, String? productTypeL2, String? productTypeL3, String? productTypeL4, String? productTypeL5, String? shippingLabel, String? title})
ProductView.fromJson(Map json_)

Properties

aggregatedDestinationStatus ↔ String?
Aggregated destination status. Possible string values are:
getter/setter pair
availability ↔ String?
Availability of the product.
getter/setter pair
brand ↔ String?
Brand of the product.
getter/setter pair
categoryL1 ↔ String?
First level of the product category in Google's product taxonomy.
getter/setter pair
categoryL2 ↔ String?
Second level of the product category in Google's product taxonomy.
getter/setter pair
categoryL3 ↔ String?
Third level of the product category in Google's product taxonomy.
getter/setter pair
categoryL4 ↔ String?
Fourth level of the product category in Google's product taxonomy.
getter/setter pair
categoryL5 ↔ String?
Fifth level of the product category in Google's product taxonomy.
getter/setter pair
channel ↔ String?
Channel of the product (online versus local). Possible string values are:
getter/setter pair
clickPotential ↔ String?
Estimated performance potential compared to highest performing products of the merchant. Possible string values are:
getter/setter pair
clickPotentialRank ↔ String?
Normalized click potential of the product.
getter/setter pair
condition ↔ String?
Condition of the product.
getter/setter pair
creationTime ↔ String?
The time the merchant created the product in timestamp seconds.
getter/setter pair
currencyCode ↔ String?
Product price currency code (for example, ISO 4217).
getter/setter pair
expirationDate ↔ Date?
Expiration date for the product.
getter/setter pair
gtin ↔ List<String>?
GTIN of the product.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The REST ID of the product, in the form of channel:contentLanguage:targetCountry:offerId.
getter/setter pair
itemGroupId ↔ String?
Item group ID provided by the merchant for grouping variants together.
getter/setter pair
itemIssues ↔ List<ProductViewItemIssue>?
List of item issues for the product.
getter/setter pair
languageCode ↔ String?
Language code of the product in BCP 47 format.
getter/setter pair
offerId ↔ String?
Merchant-provided id of the product.
getter/setter pair
priceMicros ↔ String?
Product price specified as micros (1 millionth of a standard unit, 1 USD = 1000000 micros) in the product currency.
getter/setter pair
productTypeL1 ↔ String?
First level of the product type in merchant's own product taxonomy.
getter/setter pair
productTypeL2 ↔ String?
Second level of the product type in merchant's own product taxonomy.
getter/setter pair
productTypeL3 ↔ String?
Third level of the product type in merchant's own product taxonomy.
getter/setter pair
productTypeL4 ↔ String?
Fourth level of the product type in merchant's own product taxonomy.
getter/setter pair
productTypeL5 ↔ String?
Fifth level of the product type in merchant's own product taxonomy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingLabel ↔ String?
The normalized shipping label specified in the feed
getter/setter pair
title ↔ String?
Title of the product.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited