ProductViewItemIssue class

Item issue associated with the product.

Properties

hashCode → int
The hash code for this object.
no setterinherited
issueType ↔ ProductViewItemIssueItemIssueType?
Item issue type.
getter/setter pair
resolution ↔ String?
Item issue resolution. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ ProductViewItemIssueItemIssueSeverity?
Item issue severity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited