PromotionPromotionStatus class

The status of the promotion.

Properties

creationDate ↔ String?
Date on which the promotion has been created in ISO 8601 format: Date, time, and offset, for example "2020-01-02T09:00:00+01:00" or "2020-01-02T09:00:00Z"
getter/setter pair
destinationStatuses ↔ List<PromotionPromotionStatusDestinationStatus>?
The intended destinations for the promotion.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateDate ↔ String?
Date on which the promotion status has been last updated in ISO 8601 format: Date, time, and offset, for example "2020-01-02T09:00:00+01:00" or "2020-01-02T09:00:00Z"
getter/setter pair
promotionIssue ↔ List<PromotionPromotionStatusPromotionIssue>?
A list of issues associated with the promotion.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited