Recommendation class

Recommendations are suggested ways to improve your merchant account's performance.

For example, to engage with a feature, or start using a new Google product.

Constructors

Recommendation({List<RecommendationCallToAction>? additionalCallToAction, List<RecommendationDescription>? additionalDescriptions, List<RecommendationCreative>? creative, RecommendationCallToAction? defaultCallToAction, String? defaultDescription, int? numericalImpact, bool? paid, String? recommendationName, String? subType, String? title, String? type})
Recommendation.fromJson(Map json_)

Properties

additionalCallToAction ↔ List<RecommendationCallToAction>?
CTAs of this recommendation.
getter/setter pair
additionalDescriptions ↔ List<RecommendationDescription>?
List of additional localized descriptions for a recommendation.
getter/setter pair
creative ↔ List<RecommendationCreative>?
Any creatives attached to the recommendation.
getter/setter pair
defaultCallToAction ↔ RecommendationCallToAction?
Default CTA of the recommendation.
getter/setter pair
defaultDescription ↔ String?
Localized recommendation description.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numericalImpact ↔ int?
A numerical score of the impact from the recommendation's description.
getter/setter pair
Indicates whether a user needs to pay when they complete the user journey suggested by the recommendation.
getter/setter pair
recommendationName ↔ String?
Localized recommendation name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subType ↔ String?
Subtype of the recommendations.
getter/setter pair
title ↔ String?
Localized Recommendation Title.
getter/setter pair
type ↔ String?
Type of the recommendation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited