Region class

Represents a geographic region that you can use as a target with both the RegionalInventory and ShippingSettings services.

You can define regions as collections of either postal codes or, in some countries, using predefined geotargets.

Constructors

Region({String? displayName, RegionGeoTargetArea? geotargetArea, String? merchantId, RegionPostalCodeArea? postalCodeArea, String? regionId, bool? regionalInventoryEligible, bool? shippingEligible})
Region.fromJson(Map json_)

Properties

displayName ↔ String?
The display name of the region.
getter/setter pair
geotargetArea ↔ RegionGeoTargetArea?
A list of geotargets that defines the region area.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantId ↔ String?
Merchant that owns the region.
getter/setter pair
postalCodeArea ↔ RegionPostalCodeArea?
A list of postal codes that defines the region area.
getter/setter pair
regionalInventoryEligible ↔ bool?
Indicates if the region is eligible to use in the Regional Inventory configuration.
getter/setter pair
regionId ↔ String?
The ID uniquely identifying each region.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingEligible ↔ bool?
Indicates if the region is eligible to use in the Shipping Services configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited