RegionPostalCodeArea class

A list of postal codes that defines the region area.

Note: All regions defined using postal codes are accessible via the account's ShippingSettings.postalCodeGroups resource.

Properties

hashCode → int
The hash code for this object.
no setterinherited
postalCodes ↔ List<RegionPostalCodeAreaPostalCodeRange>?
A range of postal codes.
getter/setter pair
regionCode ↔ String?
CLDR territory code or the country the postal code group applies to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited