ReportInteractionRequest class

Request to report interactions on a recommendation.

Constructors

ReportInteractionRequest({String? interactionType, String? responseToken, String? subtype, String? type})
ReportInteractionRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
interactionType ↔ String?
Type of the interaction that is reported, for example INTERACTION_CLICK.
getter/setter pair
responseToken ↔ String?
Token of the response when recommendation was returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtype ↔ String?
Subtype of the recommendations this interaction happened on.
getter/setter pair
type ↔ String?
Type of the recommendations on which this interaction happened.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited