ReportRow class

Result row returned from the search query.

Constructors

ReportRow({BestSellers? bestSellers, Brand? brand, CompetitiveVisibility? competitiveVisibility, Metrics? metrics, PriceCompetitiveness? priceCompetitiveness, PriceInsights? priceInsights, ProductCluster? productCluster, ProductView? productView, Segments? segments, TopicTrends? topicTrends})
ReportRow.fromJson(Map json_)

Properties

bestSellers ↔ BestSellers?
Best sellers fields requested by the merchant in the query.
getter/setter pair
brand ↔ Brand?
Brand fields requested by the merchant in the query.
getter/setter pair
competitiveVisibility ↔ CompetitiveVisibility?
Competitive visibility fields requested by the merchant in the query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ Metrics?
Metrics requested by the merchant in the query.
getter/setter pair
priceCompetitiveness ↔ PriceCompetitiveness?
Price competitiveness fields requested by the merchant in the query.
getter/setter pair
priceInsights ↔ PriceInsights?
Price insights fields requested by the merchant in the query.
getter/setter pair
productCluster ↔ ProductCluster?
Product cluster fields requested by the merchant in the query.
getter/setter pair
productView ↔ ProductView?
Product fields requested by the merchant in the query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segments ↔ Segments?
Segmentation dimensions requested by the merchant in the query.
getter/setter pair
topicTrends ↔ TopicTrends?
Topic trends fields requested by the merchant in the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited