ReturnAddress class

Return address resource.

Constructors

ReturnAddress({ReturnAddressAddress? address, String? country, String? kind, String? label, String? phoneNumber, String? returnAddressId})
ReturnAddress.fromJson(Map json_)

Properties

address ↔ ReturnAddressAddress?
The address.
getter/setter pair
country ↔ String?
The country of sale where the return address is applicable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
label ↔ String?
The user-defined label of the return address.
getter/setter pair
phoneNumber ↔ String?
The merchant's contact phone number regarding the return.
getter/setter pair
returnAddressId ↔ String?
Return address ID generated by Google.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited