ReturnPolicy class

Return policy resource.

Constructors

ReturnPolicy({String? country, String? kind, String? label, String? name, List<String>? nonFreeReturnReasons, ReturnPolicyPolicy? policy, String? returnPolicyId, Price? returnShippingFee, List<ReturnPolicySeasonalOverride>? seasonalOverrides})
ReturnPolicy.fromJson(Map json_)

Properties

country ↔ String?
The country of sale where the return policy is applicable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
label ↔ String?
The user-defined label of the return policy.
getter/setter pair
name ↔ String?
The name of the policy as shown in Merchant Center.
getter/setter pair
nonFreeReturnReasons ↔ List<String>?
Return reasons that will incur return fees.
getter/setter pair
policy ↔ ReturnPolicyPolicy?
The policy.
getter/setter pair
returnPolicyId ↔ String?
Return policy ID generated by Google.
getter/setter pair
returnShippingFee ↔ Price?
The return shipping fee that will apply to non free return reasons.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seasonalOverrides ↔ List<ReturnPolicySeasonalOverride>?
An optional list of seasonal overrides.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited