ReturnpolicyCustomBatchRequestEntry class

Constructors

ReturnpolicyCustomBatchRequestEntry({int? batchId, String? merchantId, String? method, ReturnPolicy? returnPolicy, String? returnPolicyId})
ReturnpolicyCustomBatchRequestEntry.fromJson(Map json_)

Properties

batchId ↔ int?
An entry ID, unique within the batch request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merchantId ↔ String?
The Merchant Center account ID.
getter/setter pair
method ↔ String?
Method of the batch request entry.
getter/setter pair
returnPolicy ↔ ReturnPolicy?
The return policy to submit.
getter/setter pair
returnPolicyId ↔ String?
The return policy ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited