SearchRequest class

Request message for the ReportService.Search method.

Constructors

SearchRequest({int? pageSize, String? pageToken, String? query})
SearchRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int?
Number of ReportRows to retrieve in a single page.
getter/setter pair
pageToken ↔ String?
Token of the page to retrieve.
getter/setter pair
query ↔ String?
Query that defines performance metrics to retrieve and dimensions according to which the metrics are to be segmented.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited