SearchResponse class

Response message for the ReportService.Search method.

Constructors

SearchResponse({String? nextPageToken, List<ReportRow>? results})
SearchResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token which can be sent as page_token to retrieve the next page.
getter/setter pair
results ↔ List<ReportRow>?
Rows that matched the search query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited