Segments class

Dimensions according to which metrics are segmented in the response.

Values of product dimensions, such as offer_id, reflect the state of a product at the time of the corresponding event, for example, impression or order. Segment fields cannot be selected in queries without also selecting at least one metric field. Values are only set for dimensions requested explicitly in the request's search query.

Constructors

Segments({String? brand, String? categoryL1, String? categoryL2, String? categoryL3, String? categoryL4, String? categoryL5, String? currencyCode, String? customLabel0, String? customLabel1, String? customLabel2, String? customLabel3, String? customLabel4, String? customerCountryCode, Date? date, String? offerId, String? productTypeL1, String? productTypeL2, String? productTypeL3, String? productTypeL4, String? productTypeL5, String? program, String? title, Date? week})
Segments.fromJson(Map json_)

Properties

brand ↔ String?
Brand of the product.
getter/setter pair
categoryL1 ↔ String?
[Product category (1st level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
categoryL2 ↔ String?
[Product category (2nd level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
categoryL3 ↔ String?
[Product category (3rd level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
categoryL4 ↔ String?
[Product category (4th level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
categoryL5 ↔ String?
[Product category (5th level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
currencyCode ↔ String?
Currency in which price metrics are represented, for example, if you select ordered_item_sales_micros, the returned value will be represented by this currency.
getter/setter pair
customerCountryCode ↔ String?
Code of the country where the customer is located at the time of the event.
getter/setter pair
customLabel0 ↔ String?
Custom label 0 for custom grouping of products.
getter/setter pair
customLabel1 ↔ String?
Custom label 1 for custom grouping of products.
getter/setter pair
customLabel2 ↔ String?
Custom label 2 for custom grouping of products.
getter/setter pair
customLabel3 ↔ String?
Custom label 3 for custom grouping of products.
getter/setter pair
customLabel4 ↔ String?
Custom label 4 for custom grouping of products.
getter/setter pair
date ↔ Date?
Date in the merchant timezone to which metrics apply.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offerId ↔ String?
Merchant-provided id of the product.
getter/setter pair
productTypeL1 ↔ String?
[Product type (1st level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
productTypeL2 ↔ String?
[Product type (2nd level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
productTypeL3 ↔ String?
[Product type (3rd level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
productTypeL4 ↔ String?
[Product type (4th level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
productTypeL5 ↔ String?
[Product type (5th level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
program ↔ String?
Program to which metrics apply, for example, Free Product Listing. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title of the product.
getter/setter pair
week ↔ Date?
First day of the week (Monday) of the metrics date in the merchant timezone.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited