Service class

Constructors

Service({bool? active, String? currency, String? deliveryCountry, DeliveryTime? deliveryTime, String? eligibility, Price? minimumOrderValue, MinimumOrderValueTable? minimumOrderValueTable, String? name, PickupCarrierService? pickupService, List<RateGroup>? rateGroups, String? shipmentType, ServiceStoreConfig? storeConfig})
Service.fromJson(Map json_)

Properties

active ↔ bool?
A boolean exposing the active status of the shipping service.
getter/setter pair
currency ↔ String?
The CLDR code of the currency to which this service applies.
getter/setter pair
deliveryCountry ↔ String?
The CLDR territory code of the country to which the service applies.
getter/setter pair
deliveryTime ↔ DeliveryTime?
Time spent in various aspects from order to the delivery of the product.
getter/setter pair
eligibility ↔ String?
Eligibility for this service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minimumOrderValue ↔ Price?
Minimum order value for this service.
getter/setter pair
minimumOrderValueTable ↔ MinimumOrderValueTable?
Table of per store minimum order values for the pickup fulfillment type.
getter/setter pair
name ↔ String?
Free-form name of the service.
getter/setter pair
pickupService ↔ PickupCarrierService?
The carrier-service pair delivering items to collection points.
getter/setter pair
rateGroups ↔ List<RateGroup>?
Shipping rate group definitions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipmentType ↔ String?
Type of locations this service ships orders to.
getter/setter pair
storeConfig ↔ ServiceStoreConfig?
A list of stores your products are delivered from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited