ServiceStoreConfig class

Stores that provide local delivery.

Only valid with local delivery fulfillment.

Constructors

ServiceStoreConfig({ServiceStoreConfigCutoffConfig? cutoffConfig, Distance? serviceRadius, List<String>? storeCodes, String? storeServiceType})
ServiceStoreConfig.fromJson(Map json_)

Properties

cutoffConfig ↔ ServiceStoreConfigCutoffConfig?
Time local delivery ends for the day.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceRadius ↔ Distance?
Maximum delivery radius.
getter/setter pair
storeCodes ↔ List<String>?
A list of store codes that provide local delivery.
getter/setter pair
storeServiceType ↔ String?
Indicates whether all stores listed by this merchant provide local delivery or not.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited