ShippingSettings class

The merchant account's shipping settings.

All methods except getsupportedcarriers and getsupportedholidays require the admin role.

Constructors

ShippingSettings({String? accountId, List<PostalCodeGroup>? postalCodeGroups, List<Service>? services, List<Warehouse>? warehouses})
ShippingSettings.fromJson(Map json_)

Properties

accountId ↔ String?
The ID of the account to which these account shipping settings belong.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postalCodeGroups ↔ List<PostalCodeGroup>?
A list of postal code groups that can be referred to in services.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services ↔ List<Service>?
The target account's list of services.
getter/setter pair
warehouses ↔ List<Warehouse>?
A list of warehouses which can be referred to in services.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited