ShoppingadsprogramResource class

Constructors

ShoppingadsprogramResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String merchantId, {String? $fields}) → Future<ShoppingAdsProgramStatus>
Retrieves the status and review eligibility for the Shopping Ads program.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestreview(RequestReviewShoppingAdsRequest request, String merchantId, {String? $fields}) → Future<void>
Requests a review of Shopping ads in a specific region.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited