TransitTableTransitTimeRowTransitTimeValue class

Constructors

TransitTableTransitTimeRowTransitTimeValue({int? maxTransitTimeInDays, int? minTransitTimeInDays})
TransitTableTransitTimeRowTransitTimeValue.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxTransitTimeInDays ↔ int?
Must be greater than or equal to minTransitTimeInDays.
getter/setter pair
minTransitTimeInDays ↔ int?
Transit time range (min-max) in business days.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited