VerifyPhoneNumberRequest class

Request message for the VerifyPhoneNumber method.

Constructors

VerifyPhoneNumberRequest({String? phoneVerificationMethod, String? verificationCode, String? verificationId})
VerifyPhoneNumberRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
phoneVerificationMethod ↔ String?
Verification method used to receive verification code. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verificationCode ↔ String?
The verification code that was sent to the phone number for validation.
getter/setter pair
verificationId ↔ String?
The verification ID returned by requestphoneverification.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited