VerifyPhoneNumberResponse class

Response message for the VerifyPhoneNumber method.

Constructors

VerifyPhoneNumberResponse({String? verifiedPhoneNumber})
VerifyPhoneNumberResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verifiedPhoneNumber ↔ String?
Verified phone number if verification is successful.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited