GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock class

Represents a block.

A block could be one of the various types (text, table, list) supported.

Properties

blockId ↔ String?
ID of the block.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listBlock ↔ GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutListBlock?
Block consisting of list content/structure.
getter/setter pair
pageSpan ↔ GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutPageSpan?
Page span of the block.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableBlock ↔ GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableBlock?
Block consisting of table content/structure.
getter/setter pair
textBlock ↔ GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock?
Block consisting of text content.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited