GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTableCell class

Represents a cell in a table row.

Properties

blocks ↔ List<GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock>?
A table cell is a list of blocks.
getter/setter pair
colSpan ↔ int?
How many columns this cell spans.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rowSpan ↔ int?
How many rows this cell spans.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited