GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutTextBlock class

Represents a text type block.

Properties

blocks ↔ List<GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlock>?
A text block could further have child blocks.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
Text content stored in the block.
getter/setter pair
type ↔ String?
Type of the text in the block.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited