ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

documents → ProjectsLocationsDocumentsResource
no setter
documentSchemas → ProjectsLocationsDocumentSchemasResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
operations → ProjectsLocationsOperationsResource
no setter
ruleSets → ProjectsLocationsRuleSetsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
synonymSets → ProjectsLocationsSynonymSetsResource
no setter

Methods

getStatus(String location, {String? $fields}) → Future<GoogleCloudContentwarehouseV1ProjectStatus>
Get the project status.
initialize(GoogleCloudContentwarehouseV1InitializeProjectRequest request, String location, {String? $fields}) → Future<GoogleLongrunningOperation>
Provisions resources for given tenant project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
runPipeline(GoogleCloudContentwarehouseV1RunPipelineRequest request, String name, {String? $fields}) → Future<GoogleLongrunningOperation>
Run a predefined pipeline.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited