Account class

Information about CSS/MC account.

Constructors

Account({String? accountType, List<String>? automaticLabelIds, String? displayName, String? fullName, String? homepageUri, List<String>? labelIds, String? name, String? parent})
Account.fromJson(Map json_)

Properties

accountType ↔ String?
The type of this account.
getter/setter pair
automaticLabelIds ↔ List<String>?
Automatically created label IDs assigned to the MC account by CSS Center.
getter/setter pair
displayName ↔ String?
The CSS/MC account's short display name.
getter/setter pair
fullName ↔ String?
The CSS/MC account's full name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
homepageUri ↔ String?
The CSS/MC account's homepage.
getter/setter pair
labelIds ↔ List<String>?
Manually created label IDs assigned to the CSS/MC account by a CSS parent account.
getter/setter pair
name ↔ String?
The label resource name.
getter/setter pair
parent ↔ String?
The CSS/MC account's parent resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited