AccountsResource class

Constructors

AccountsResource(ApiRequester client)

Properties

cssProductInputs → AccountsCssProductInputsResource
no setter
cssProducts → AccountsCssProductsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
labels → AccountsLabelsResource
no setter
quotas → AccountsQuotasResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? parent, String? $fields}) → Future<Account>
Retrieves a single CSS/MC account by ID.
listChildAccounts(String parent, {String? fullName, String? labelId, int? pageSize, String? pageToken, String? $fields}) → Future<ListChildAccountsResponse>
Lists all the accounts under the specified CSS account ID, and optionally filters by label ID and account name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateLabels(UpdateAccountLabelsRequest request, String name, {String? $fields}) → Future<Account>
Updates labels assigned to CSS/MC accounts by a CSS domain.

Operators

operator ==(Object other) → bool
The equality operator.
inherited