CssProductInput class

This resource represents input data you submit for a CSS Product, not the processed CSS Product that you see in CSS Center, in Shopping Ads, or across Google surfaces.

Constructors

CssProductInput({Attributes? attributes, String? contentLanguage, List<CustomAttribute>? customAttributes, String? feedLabel, String? finalName, String? freshnessTime, String? name, String? rawProvidedId})
CssProductInput.fromJson(Map json_)

Properties

attributes ↔ Attributes?
A list of CSS Product attributes.
getter/setter pair
contentLanguage ↔ String?
The two-letter [ISO 639-1](http://en.wikipedia.org/wiki/ISO_639-1) language code for the CSS Product.
getter/setter pair
customAttributes ↔ List<CustomAttribute>?
A list of custom (CSS-provided) attributes.
getter/setter pair
feedLabel ↔ String?
The feed label for the CSS Product.
getter/setter pair
finalName ↔ String?
The name of the processed CSS Product.
getter/setter pair
freshnessTime ↔ String?
Use expiration_date instead.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
rawProvidedId ↔ String?
Your unique identifier for the CSS Product.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited