CssProductStatus class

The status of the Css Product, data validation issues, that is, information about the Css Product computed asynchronously.

Constructors

CssProductStatus({String? creationDate, List<DestinationStatus>? destinationStatuses, String? googleExpirationDate, List<ItemLevelIssue>? itemLevelIssues, String? lastUpdateDate})
CssProductStatus.fromJson(Map json_)

Properties

creationDate ↔ String?
Date on which the item has been created, in ISO 8601 format.
getter/setter pair
destinationStatuses ↔ List<DestinationStatus>?
The intended destinations for the product.
getter/setter pair
googleExpirationDate ↔ String?
Date on which the item expires, in ISO 8601 format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemLevelIssues ↔ List<ItemLevelIssue>?
A list of all issues associated with the product.
getter/setter pair
lastUpdateDate ↔ String?
Date on which the item has been last updated, in ISO 8601 format.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited