HeadlineOfferInstallment class

A message that represents installment.

Constructors

HeadlineOfferInstallment({Price? amount, Price? downpayment, String? months})
HeadlineOfferInstallment.fromJson(Map json_)

Properties

amount ↔ Price?
The amount the buyer has to pay per month.
getter/setter pair
downpayment ↔ Price?
The up-front down payment amount the buyer has to pay.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
months ↔ String?
The number of installments the buyer has to pay.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited