HeadlineOfferSubscriptionCost class

The SubscriptionCost of the product.

Constructors

HeadlineOfferSubscriptionCost({Price? amount, String? period, String? periodLength})
HeadlineOfferSubscriptionCost.fromJson(Map json_)

Properties

amount ↔ Price?
The amount the buyer has to pay per subscription period.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
period ↔ String?
The type of subscription period.
getter/setter pair
periodLength ↔ String?
The number of subscription periods the buyer has to pay.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited