ListChildAccountsResponse class

Response message for the ListChildAccounts method.

Constructors

ListChildAccountsResponse({List<Account>? accounts, String? nextPageToken})
ListChildAccountsResponse.fromJson(Map json_)

Properties

accounts ↔ List<Account>?
The CSS/MC accounts returned for the specified CSS parent account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited