ResultImage class

Image belonging to a custom search result.

Constructors

ResultImage({int? byteSize, String? contextLink, int? height, int? thumbnailHeight, String? thumbnailLink, int? thumbnailWidth, int? width})
ResultImage.fromJson(Map json_)

Properties

byteSize ↔ int?
The size of the image, in bytes.
getter/setter pair
A URL pointing to the webpage hosting the image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
The height of the image, in pixels.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnailHeight ↔ int?
The height of the thumbnail image, in pixels.
getter/setter pair
A URL to the thumbnail image.
getter/setter pair
thumbnailWidth ↔ int?
The width of the thumbnail image, in pixels.
getter/setter pair
width ↔ int?
The width of the image, in pixels.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited