ResultLabels class

Refinement label associated with a custom search result.

Constructors

ResultLabels({String? displayName, String? labelWithOp, String? name})
ResultLabels.fromJson(Map json_)

Properties

displayName ↔ String?
The display name of a refinement label.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labelWithOp ↔ String?
Refinement label and the associated refinement operation.
getter/setter pair
name ↔ String?
The name of a refinement label, which you can use to refine searches.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited