Search class

Response to a custom search request.

Constructors

Search({Map<String, Object?>? context, List<Result>? items, String? kind, List<Promotion>? promotions, SearchQueries? queries, SearchSearchInformation? searchInformation, SearchSpelling? spelling, SearchUrl? url})
Search.fromJson(Map json_)

Properties

context ↔ Map<String, Object?>?
Metadata and refinements associated with the given search engine, including: * The name of the search engine that was used for the query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Result>?
The current set of custom search results.
getter/setter pair
kind ↔ String?
Unique identifier for the type of current object.
getter/setter pair
promotions ↔ List<Promotion>?
The set of promotions.
getter/setter pair
queries ↔ SearchQueries?
Query metadata for the previous, current, and next pages of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchInformation ↔ SearchSearchInformation?
Metadata about a search operation.
getter/setter pair
spelling ↔ SearchSpelling?
Spell correction information for a query.
getter/setter pair
url ↔ SearchUrl?
OpenSearch template and URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited