SearchQueries class

Query metadata for the previous, current, and next pages of results.

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPage ↔ List<SearchQueriesNextPage>?
Metadata representing the next page of results, if applicable.
getter/setter pair
previousPage ↔ List<SearchQueriesPreviousPage>?
Metadata representing the previous page of results, if applicable.
getter/setter pair
request ↔ List<SearchQueriesRequest>?
Metadata representing the current request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited