GoogleCloudDatacatalogV1DatabaseTableSpecDatabaseViewSpec class

Specification that applies to database view.

Properties

baseTable ↔ String?
Name of a singular table this view reflects one to one.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlQuery ↔ String?
SQL query used to generate this view.
getter/setter pair
viewType ↔ String?
Type of this view. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited