GoogleCloudDatacatalogV1GraphSpecGraphElementTable class

Element table definition.

Properties

alias ↔ String?
The alias name of the graph element.
getter/setter pair
dataSource ↔ String?
The name of the data source.
getter/setter pair
destinationNodeReference ↔ GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference?
The destination node reference of the edge.
getter/setter pair
dynamicLabelColumn ↔ String?
If set, this is the input column for dynamic label in schemaless data model.
getter/setter pair
dynamicPropertiesColumn ↔ String?
If set, this is the input column for dynamic properties in schemaless data model.
getter/setter pair
elementKeys ↔ List<String>?
The name of the keys of the elements in the table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputSource ↔ String?
The input source of the graph element.
getter/setter pair
kind ↔ String?
The kind of the graph element.
getter/setter pair
labelAndProperties ↔ List<GoogleCloudDatacatalogV1GraphSpecGraphElementTableLabelAndProperties>?
The labels and their properties for the graph element.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNodeReference ↔ GoogleCloudDatacatalogV1GraphSpecGraphElementTableGraphNodeReference?
The source node reference of the edge.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited