ActionLoadConfig class

Simplified load configuration for actions

Properties

append ↔ ActionSimpleLoadMode?
Append into destination table
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maximum ↔ ActionIncrementalLoadMode?
Insert records where the value exceeds the previous maximum value for a column in the destination table
getter/setter pair
replace ↔ ActionSimpleLoadMode?
Replace destination table
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unique ↔ ActionIncrementalLoadMode?
Insert records where the value of a column is not already present in the destination table
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited