ActionSqlDefinition class

Definition of a SQL Data Preparation

Constructors

ActionSqlDefinition({ActionErrorTable? errorTable, ActionLoadConfig? loadConfig, String? query})
ActionSqlDefinition.fromJson(Map json_)

Properties

errorTable ↔ ActionErrorTable?
Error table configuration,
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loadConfig ↔ ActionLoadConfig?
Load configuration.
getter/setter pair
query ↔ String?
The SQL query representing the data preparation steps.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited