ColumnDescriptor class

Describes a column.

Constructors

ColumnDescriptor({List<String>? bigqueryPolicyTags, String? description, List<String>? path})
ColumnDescriptor.fromJson(Map json_)

Properties

bigqueryPolicyTags ↔ List<String>?
A list of BigQuery policy tags that will be applied to the column.
getter/setter pair
description ↔ String?
A textual description of the column.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
path ↔ List<String>?
The identifier for the column.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited