CommitAuthor class

Represents the author of a Git commit.

Constructors

CommitAuthor({String? emailAddress, String? name})
CommitAuthor.fromJson(Map json_)

Properties

emailAddress ↔ String?
The commit author's email address.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The commit author's name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited