CommitLogEntry class

Represents a single commit log.

Constructors

CommitLogEntry({CommitAuthor? author, String? commitMessage, String? commitSha, String? commitTime})
CommitLogEntry.fromJson(Map json_)

Properties

author ↔ CommitAuthor?
The commit author for this commit log entry.
getter/setter pair
commitMessage ↔ String?
The commit message for this commit log entry.
getter/setter pair
commitSha ↔ String?
The commit SHA for this commit log entry.
getter/setter pair
commitTime ↔ String?
Commit timestamp.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited