gcsRepositorySnapshotMetadata property
Metadata about the repository snapshot used by scheduled notebooks.
Output only.
Implementation
GcsRepositorySnapshotMetadata? gcsRepositorySnapshotMetadata;
Metadata about the repository snapshot used by scheduled notebooks.
Output only.
GcsRepositorySnapshotMetadata? gcsRepositorySnapshotMetadata;