CompilationResultAction class

Represents a single Dataform action in a compilation result.

Constructors

CompilationResultAction({Assertion? assertion, Target? canonicalTarget, DataPreparation? dataPreparation, Declaration? declaration, String? filePath, String? internalMetadata, Notebook? notebook, Operations? operations, Relation? relation, Target? target})
CompilationResultAction.fromJson(Map json_)

Properties

assertion ↔ Assertion?
The assertion executed by this action.
getter/setter pair
canonicalTarget ↔ Target?
The action's identifier if the project had been compiled without any overrides configured.
getter/setter pair
dataPreparation ↔ DataPreparation?
The data preparation executed by this action.
getter/setter pair
declaration ↔ Declaration?
The declaration declared by this action.
getter/setter pair
filePath ↔ String?
The full path including filename in which this action is located, relative to the workspace root.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalMetadata ↔ String?
All the metadata information that is used internally to serve the resource.
getter/setter pair
notebook ↔ Notebook?
The notebook executed by this action.
getter/setter pair
operations ↔ Operations?
The database operations executed by this action.
getter/setter pair
relation ↔ Relation?
The database relation created/updated by this action.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ Target?
This action's identifier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited