Config class

Config for all repositories in a given project and location.

Constructors

Config({String? defaultKmsKeyName, String? internalMetadata, String? name})
Config.fromJson(Map json_)

Properties

defaultKmsKeyName ↔ String?
The default KMS key that is used if no encryption key is provided when a repository is created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalMetadata ↔ String?
All the metadata information that is used internally to serve the resource.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited