DirectoryEntry class

Represents a single entry in a directory.

Constructors

DirectoryEntry({String? directory, String? file, FilesystemEntryMetadata? metadata})
DirectoryEntry.fromJson(Map json_)

Properties

directory ↔ String?
A child directory in the directory.
getter/setter pair
file ↔ String?
A file in the directory.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FilesystemEntryMetadata?
Entry with metadata.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited