directory property
A child directory in the directory.
The path is returned including the full folder structure from the root.
Implementation
core.String? directory;
A child directory in the directory.
The path is returned including the full folder structure from the root.
core.String? directory;