file property
A file in the directory.
The path is returned including the full folder structure from the root.
Implementation
core.String? file;
A file in the directory.
The path is returned including the full folder structure from the root.
core.String? file;