Folder class

Represents a Dataform Folder.

This is a resource that is used to organize Files and other Folders and provide hierarchical access controls.

Constructors

Folder({String? containingFolder, String? createTime, String? creatorIamPrincipal, String? displayName, String? internalMetadata, String? name, String? teamFolderName, String? updateTime})
Folder.fromJson(Map json_)

Properties

containingFolder String?
The containing Folder resource name.
getter/setter pair
createTime String?
The timestamp of when the Folder was created.
getter/setter pair
creatorIamPrincipal String?
The IAM principal identifier of the creator of the Folder.
getter/setter pair
displayName String?
The Folder's user-friendly name.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internalMetadata String?
All the metadata information that is used internally to serve the resource.
getter/setter pair
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
teamFolderName String?
The resource name of the TeamFolder that this Folder is associated with.
getter/setter pair
updateTime String?
The timestamp of when the Folder was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited