creatorIamPrincipal property
The IAM principal identifier of the creator of the Folder.
Output only.
Implementation
core.String? creatorIamPrincipal;
The IAM principal identifier of the creator of the Folder.
Output only.
core.String? creatorIamPrincipal;