repositorySnapshotUri property
The Google Cloud Storage destination to upload the repository snapshot to.
Format: gs://bucket-name/path/.
Optional.
Implementation
core.String? repositorySnapshotUri;
The Google Cloud Storage destination to upload the repository snapshot to.
Format: gs://bucket-name/path/.
Optional.
core.String? repositorySnapshotUri;