IncrementalTableConfig class

Contains settings for relations of type INCREMENTAL_TABLE.

Constructors

IncrementalTableConfig({List<String>? incrementalPostOperations, List<String>? incrementalPreOperations, String? incrementalSelectQuery, bool? refreshDisabled, List<String>? uniqueKeyParts, String? updatePartitionFilter})
IncrementalTableConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
incrementalPostOperations ↔ List<String>?
SQL statements to be executed after inserting new rows into the relation.
getter/setter pair
incrementalPreOperations ↔ List<String>?
SQL statements to be executed before inserting new rows into the relation.
getter/setter pair
incrementalSelectQuery ↔ String?
The SELECT query which returns rows which should be inserted into the relation if it already exists and is not being refreshed.
getter/setter pair
refreshDisabled ↔ bool?
Whether this table should be protected from being refreshed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uniqueKeyParts ↔ List<String>?
A set of columns or SQL expressions used to define row uniqueness.
getter/setter pair
updatePartitionFilter ↔ String?
A SQL expression conditional used to limit the set of existing rows considered for a merge operation (see unique_key_parts for more information).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited