InstallNpmPackagesRequest class
InstallNpmPackages request message.
Constructors
- InstallNpmPackagesRequest({PipelineConfig? pipelineConfig})
- InstallNpmPackagesRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pipelineConfig ↔ PipelineConfig?
-
The pipeline options which defines the pipeline type and path within the
Git repository.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited