pipelineConfig property
The pipeline options which defines the pipeline type and path within the Git repository.
Optional.
Implementation
PipelineConfig? pipelineConfig;
The pipeline options which defines the pipeline type and path within the Git repository.
Optional.
PipelineConfig? pipelineConfig;