InvocationConfig class

Includes various configuration options for a workflow invocation.

If both included_targets and included_tags are unset, all actions will be included.

Constructors

InvocationConfig({bool? fullyRefreshIncrementalTablesEnabled, List<String>? includedTags, List<Target>? includedTargets, String? queryPriority, String? serviceAccount, bool? transitiveDependenciesIncluded, bool? transitiveDependentsIncluded})
InvocationConfig.fromJson(Map json_)

Properties

fullyRefreshIncrementalTablesEnabled ↔ bool?
When set to true, any incremental tables will be fully refreshed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includedTags ↔ List<String>?
The set of tags to include.
getter/setter pair
includedTargets ↔ List<Target>?
The set of action identifiers to include.
getter/setter pair
queryPriority ↔ String?
Specifies the priority for query execution in BigQuery.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
The service account to run workflow invocations under.
getter/setter pair
transitiveDependenciesIncluded ↔ bool?
When set to true, transitive dependencies of included actions will be executed.
getter/setter pair
transitiveDependentsIncluded ↔ bool?
When set to true, transitive dependents of included actions will be executed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited