MoveRepositoryRequest class

MoveRepository request message.

Constructors

MoveRepositoryRequest({String? destinationContainingFolder})
MoveRepositoryRequest.fromJson(Map json_)

Properties

destinationContainingFolder ↔ String?
The name of the Folder, TeamFolder, or root location to move the repository to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited