NotebookAction class

Represents a workflow action that will run against a Notebook runtime.

Constructors

NotebookAction({String? contents, String? filePath, String? jobId})
NotebookAction.fromJson(Map json_)

Properties

contents ↔ String?
The code contents of a Notebook to be run.
getter/setter pair
filePath ↔ String?
The path to the notebook file in the repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobId ↔ String?
The ID of the Gemini Enterprise Agent Platform job that executed the notebook in contents and also the ID used for the outputs created in Google Cloud Storage buckets.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited