NotebookRuntimeOptions class

Configures various aspects of Dataform notebook runtime.

Constructors

NotebookRuntimeOptions({String? aiPlatformNotebookRuntimeTemplate, String? gcsOutputBucket, GcsRepositorySnapshotDestination? gcsRepositorySnapshotDestination})
NotebookRuntimeOptions.fromJson(Map json_)

Properties

aiPlatformNotebookRuntimeTemplate ↔ String?
The resource name of the Colab runtime template, from which a runtime is created for notebook executions.
getter/setter pair
gcsOutputBucket ↔ String?
The Google Cloud Storage location to upload the result to.
getter/setter pair
gcsRepositorySnapshotDestination ↔ GcsRepositorySnapshotDestination?
The Google Cloud Storage destination to upload the snapshot to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited