PipelineConfig class

Defines the pipeline type and path within the Git repository.

Constructors

PipelineConfig({String? path, String? pipelineType})
PipelineConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
path ↔ String?
The relative path within the Git repository where the pipeline is defined.
getter/setter pair
pipelineType ↔ String?
The type of the pipeline.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited