ProjectsLocationsFoldersResource class

Constructors

ProjectsLocationsFoldersResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Folder request, String parent, {String? $fields}) Future<Folder>
Creates a new Folder in a given project and location.
delete(String name, {String? $fields}) Future<Empty>
Deletes a single Folder.
deleteTree(DeleteFolderTreeRequest request, String name, {String? $fields}) Future<Operation>
Deletes a Folder with its contents (Folders, Repositories, Workspaces, ReleaseConfigs, and WorkflowConfigs).
get(String name, {String? $fields}) Future<Folder>
Fetches a single Folder.
getIamPolicy(String resource, {int? options_requestedPolicyVersion, String? $fields}) Future<Policy>
Gets the access control policy for a resource.
move(MoveFolderRequest request, String name, {String? $fields}) Future<Operation>
Moves a Folder to a new Folder, TeamFolder, or the root location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Folder request, String name, {String? updateMask, String? $fields}) Future<Folder>
Updates a single Folder.
queryFolderContents(String folder, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<QueryFolderContentsResponse>
Returns the contents of a given Folder.
setIamPolicy(SetIamPolicyRequest request, String resource, {String? $fields}) Future<Policy>
Sets the access control policy on the specified resource.
testIamPermissions(TestIamPermissionsRequest request, String resource, {String? $fields}) Future<TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited