patch method

Future<Folder> patch(
  1. Folder request,
  2. String name, {
  3. String? updateMask,
  4. String? $fields,
})

Updates a single Folder.

request - The metadata request object.

Request parameters:

name - Identifier. The Folder's name. Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/folders/\[^/\]+$.

updateMask - Optional. Specifies the fields to be updated in the Folder. If left unset, all fields that can be updated, will be updated. A few fields cannot be updated and will be ignored if specified in the update_mask (e.g. parent_name, team_folder_name).

$fields - Selector specifying which fields to include in a partial response.

Completes with a Folder.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Folder> patch(
  Folder request,
  core.String name, {
  core.String? updateMask,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'updateMask': ?updateMask == null ? null : [updateMask],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'PATCH',
    body: body_,
    queryParams: queryParams_,
  );
  return Folder.fromJson(response_ as core.Map<core.String, core.dynamic>);
}