ProjectsLocationsResource class
Methods
-
get(String name, {String? $fields})
→ Future<Location>
-
Gets information about a location.
-
getConfig(String name, {String? $fields})
→ Future<Config>
-
Get default config for a given project and location.
-
list(String name, {String? filter, int? pageSize, String? pageToken, String? $fields})
→ Future<ListLocationsResponse>
-
Lists information about the supported locations for this service.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
queryUserRootContents(String location, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields})
→ Future<QueryUserRootContentsResponse>
-
Returns the contents of a caller's root folder in a given location.
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateConfig(Config request, String name, {String? updateMask, String? $fields})
→ Future<Config>
-
Update default config for a given project and location.