connection property

String? connection
getter/setter pair

The connection specifying the credentials to be used to read and write to external storage, such as Cloud Storage.

The connection can have the form {project}.{location}.{connection_id} or projects/{project}/locations/{location}/connections/{connection_id}, or be set to DEFAULT.

Optional.

Implementation

core.String? connection;