timeZone property
Specifies the time zone to be used when interpreting cron_schedule.
Must be a time zone name from the
time zone database.
If left unspecified, the default is UTC.
Optional.
Implementation
core.String? timeZone;
Specifies the time zone to be used when interpreting cron_schedule.
Must be a time zone name from the
time zone database.
If left unspecified, the default is UTC.
Optional.
core.String? timeZone;