Repository class

Represents a Dataform Git repository.

Constructors

Repository({String? containingFolder, String? createTime, DataEncryptionState? dataEncryptionState, String? displayName, GitRemoteSettings? gitRemoteSettings, String? internalMetadata, String? kmsKeyName, Map<String, String>? labels, String? name, String? npmrcEnvironmentVariablesSecretVersion, String? serviceAccount, bool? setAuthenticatedUserAdmin, String? teamFolderName, WorkspaceCompilationOverrides? workspaceCompilationOverrides})
Repository.fromJson(Map json_)

Properties

containingFolder ↔ String?
The name of the containing folder of the repository.
getter/setter pair
createTime ↔ String?
The timestamp of when the repository was created.
getter/setter pair
dataEncryptionState ↔ DataEncryptionState?
A data encryption state of a Git repository if this Repository is protected by a KMS key.
getter/setter pair
displayName ↔ String?
The repository's user-friendly name.
getter/setter pair
gitRemoteSettings ↔ GitRemoteSettings?
If set, configures this repository to be linked to a Git remote.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalMetadata ↔ String?
All the metadata information that is used internally to serve the resource.
getter/setter pair
kmsKeyName ↔ String?
The reference to a KMS encryption key.
getter/setter pair
labels ↔ Map<String, String>?
Repository user labels.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
npmrcEnvironmentVariablesSecretVersion ↔ String?
The name of the Secret Manager secret version to be used to interpolate variables into the .npmrc file for package installation operations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
The service account to run workflow invocations under.
getter/setter pair
setAuthenticatedUserAdmin ↔ bool?
Input only.
getter/setter pair
teamFolderName ↔ String?
The resource name of the TeamFolder that this Repository is associated with.
getter/setter pair
workspaceCompilationOverrides ↔ WorkspaceCompilationOverrides?
If set, fields of workspace_compilation_overrides override the default compilation settings that are specified in dataform.json when creating workspace-scoped compilation results.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited