ResetWorkspaceChangesRequest class

ResetWorkspaceChanges request message.

Properties

clean ↔ bool?
If set to true, untracked files will be deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
paths ↔ List<String>?
Full file paths to reset back to their committed state including filename, rooted at workspace root.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited