ScheduledExecutionRecord class

A record of an attempt to create a workflow invocation for this workflow config.

Constructors

ScheduledExecutionRecord({Status? errorStatus, String? executionTime, String? workflowInvocation})
ScheduledExecutionRecord.fromJson(Map json_)

Properties

errorStatus ↔ Status?
The error status encountered upon this attempt to create the workflow invocation, if the attempt was unsuccessful.
getter/setter pair
executionTime ↔ String?
The timestamp of this execution attempt.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workflowInvocation ↔ String?
The name of the created workflow invocation, if one was successfully created.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited