SqlDefinition class

Definition of a SQL Data Preparation

Constructors

SqlDefinition({ErrorTable? errorTable, LoadConfig? load, String? query})
SqlDefinition.fromJson(Map json_)

Properties

errorTable ↔ ErrorTable?
Error table configuration,
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
load ↔ LoadConfig?
Load configuration.
getter/setter pair
query ↔ String?
The SQL query representing the data preparation steps.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited