SshAuthenticationConfig class

Configures fields for performing SSH authentication.

Constructors

SshAuthenticationConfig({String? hostPublicKey, String? userPrivateKeySecretVersion})
SshAuthenticationConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostPublicKey ↔ String?
Content of a public SSH key to verify an identity of a remote Git host.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userPrivateKeySecretVersion ↔ String?
The name of the Secret Manager secret version to use as a ssh private key for Git operations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited