TeamFolder class
Represents a Dataform TeamFolder.
This is a resource that sits at the project level and is used to organize Repositories and Folders with hierarchical access controls. They provide a team context and stricter access controls.
Constructors
- TeamFolder({String? createTime, String? creatorIamPrincipal, String? displayName, String? internalMetadata, String? name, String? updateTime})
- TeamFolder.fromJson(Map json_)
Properties
- createTime ↔ String?
-
The timestamp of when the TeamFolder was created.
getter/setter pair
- creatorIamPrincipal ↔ String?
-
The IAM principal identifier of the creator of the TeamFolder.
getter/setter pair
- displayName ↔ String?
-
The TeamFolder's user-friendly name.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- internalMetadata ↔ String?
-
All the metadata information that is used internally to serve the
resource.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateTime ↔ String?
-
The timestamp of when the TeamFolder was last updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited