TeamFolderSearchResult class
Represents a single content entry.
Constructors
- TeamFolderSearchResult({TeamFolder? teamFolder})
- TeamFolderSearchResult.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- teamFolder ↔ TeamFolder?
-
A TeamFolder resource that is in the project / location.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited