WorkflowConfig class

Represents a Dataform workflow configuration.

Constructors

WorkflowConfig({String? createTime, String? cronSchedule, bool? disabled, String? internalMetadata, InvocationConfig? invocationConfig, String? name, List<ScheduledExecutionRecord>? recentScheduledExecutionRecords, String? releaseConfig, String? timeZone, String? updateTime})
WorkflowConfig.fromJson(Map json_)

Properties

createTime ↔ String?
The timestamp of when the WorkflowConfig was created.
getter/setter pair
cronSchedule ↔ String?
Optional schedule (in cron format) for automatic execution of this workflow config.
getter/setter pair
disabled ↔ bool?
Disables automatic creation of workflow invocations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalMetadata ↔ String?
All the metadata information that is used internally to serve the resource.
getter/setter pair
invocationConfig ↔ InvocationConfig?
If left unset, a default InvocationConfig will be used.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
recentScheduledExecutionRecords ↔ List<ScheduledExecutionRecord>?
Records of the 10 most recent scheduled execution attempts, ordered in descending order of execution_time.
getter/setter pair
releaseConfig ↔ String?
The name of the release config whose release_compilation_result should be executed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZone ↔ String?
Specifies the time zone to be used when interpreting cron_schedule.
getter/setter pair
updateTime ↔ String?
The timestamp of when the WorkflowConfig was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited