WorkflowInvocation class

Represents a single invocation of a compilation result.

Constructors

WorkflowInvocation({String? compilationResult, DataEncryptionState? dataEncryptionState, String? internalMetadata, InvocationConfig? invocationConfig, Interval? invocationTiming, String? name, PipelineConfig? pipelineConfig, PrivateResourceMetadata? privateResourceMetadata, String? resolvedCompilationResult, String? state, String? workflowConfig})
WorkflowInvocation.fromJson(Map json_)

Properties

compilationResult ↔ String?
The name of the compilation result to use for this invocation.
getter/setter pair
dataEncryptionState ↔ DataEncryptionState?
Only set if the repository has a KMS Key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalMetadata ↔ String?
All the metadata information that is used internally to serve the resource.
getter/setter pair
invocationConfig ↔ InvocationConfig?
If left unset, a default InvocationConfig will be used.
getter/setter pair
invocationTiming ↔ Interval?
This workflow invocation's timing details.
getter/setter pair
name ↔ String?
The workflow invocation's name.
getter/setter pair
pipelineConfig ↔ PipelineConfig?
The pipeline options which defines the pipeline type and path within the Git repository.
getter/setter pair
privateResourceMetadata ↔ PrivateResourceMetadata?
Metadata indicating whether this resource is user-scoped.
getter/setter pair
resolvedCompilationResult ↔ String?
The resolved compilation result that was used to create this invocation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
This workflow invocation's current state.
getter/setter pair
workflowConfig ↔ String?
The name of the workflow config to invoke.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited