pipelineConfig property
The pipeline options which defines the pipeline type and path within the Git repository.
Output only.
Implementation
PipelineConfig? pipelineConfig;
The pipeline options which defines the pipeline type and path within the Git repository.
Output only.
PipelineConfig? pipelineConfig;