Workspace class

Represents a Dataform Git workspace.

Constructors

Workspace({String? createTime, DataEncryptionState? dataEncryptionState, bool? disableMoves, String? internalMetadata, String? name, PrivateResourceMetadata? privateResourceMetadata})
Workspace.fromJson(Map json_)

Properties

createTime ↔ String?
The timestamp of when the workspace was created.
getter/setter pair
dataEncryptionState ↔ DataEncryptionState?
A data encryption state of a Git repository if this Workspace is protected by a KMS key.
getter/setter pair
disableMoves ↔ bool?
If set to true, workspaces will not be moved if its linked Repository is moved.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalMetadata ↔ String?
All the metadata information that is used internally to serve the resource.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
privateResourceMetadata ↔ PrivateResourceMetadata?
Metadata indicating whether this resource is user-scoped.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited