disableMoves property
If set to true, workspaces will not be moved if its linked Repository is moved.
Instead, it will be deleted.
Optional.
Implementation
core.bool? disableMoves;
If set to true, workspaces will not be moved if its linked Repository is moved.
Instead, it will be deleted.
Optional.
core.bool? disableMoves;