WorkspaceCompilationOverrides class

Configures workspace compilation overrides for a repository.

Constructors

WorkspaceCompilationOverrides({String? defaultDatabase, String? schemaSuffix, String? tablePrefix})
WorkspaceCompilationOverrides.fromJson(Map json_)

Properties

defaultDatabase ↔ String?
The default database (Google Cloud project ID).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaSuffix ↔ String?
The suffix that should be appended to all schema (BigQuery dataset ID) names.
getter/setter pair
tablePrefix ↔ String?
The prefix that should be prepended to all table names.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited