WriteFileRequest class

WriteFile request message.

Constructors

WriteFileRequest({String? contents, String? path})
WriteFileRequest.fromJson(Map json_)

Properties

contents ↔ String?
The file's contents.
getter/setter pair
contentsAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
path ↔ String?
The file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited