Instance class

Represents a Data Fusion instance.

Constructors

Instance({List<Accelerator>? accelerators, String? apiEndpoint, List<Version>? availableVersion, String? createTime, CryptoKeyConfig? cryptoKeyConfig, bool? dataplexDataLineageIntegrationEnabled, String? dataprocServiceAccount, String? description, List<String>? disabledReason, String? displayName, bool? enableRbac, bool? enableStackdriverLogging, bool? enableStackdriverMonitoring, bool? enableZoneSeparation, EventPublishConfig? eventPublishConfig, String? gcsBucket, Map<String, String>? labels, LoggingConfig? loggingConfig, List<MaintenanceEvent>? maintenanceEvents, MaintenancePolicy? maintenancePolicy, MonitoringConfig? monitoringConfig, String? name, NetworkConfig? networkConfig, Map<String, String>? options, String? p4ServiceAccount, String? patchRevision, bool? privateInstance, bool? satisfiesPzi, bool? satisfiesPzs, String? serviceAccount, String? serviceEndpoint, String? state, String? stateMessage, Map<String, String>? tags, String? tenantProjectId, String? type, String? updateTime, String? version, String? workforceIdentityServiceEndpoint, String? zone})
Instance.fromJson(Map json_)

Properties

accelerators ↔ List<Accelerator>?
List of accelerators enabled for this CDF instance.
getter/setter pair
apiEndpoint ↔ String?
Endpoint on which the REST APIs is accessible.
getter/setter pair
availableVersion ↔ List<Version>?
Available versions that the instance can be upgraded to using UpdateInstanceRequest.
getter/setter pair
createTime ↔ String?
The time the instance was created.
getter/setter pair
cryptoKeyConfig ↔ CryptoKeyConfig?
The crypto key configuration.
getter/setter pair
dataplexDataLineageIntegrationEnabled ↔ bool?
Option to enable the Dataplex Lineage Integration feature.
getter/setter pair
dataprocServiceAccount ↔ String?
User-managed service account to set on Dataproc when Cloud Data Fusion creates Dataproc to run data processing pipelines.
getter/setter pair
description ↔ String?
A description of this instance.
getter/setter pair
disabledReason ↔ List<String>?
If the instance state is DISABLED, the reason for disabling the instance.
getter/setter pair
displayName ↔ String?
Display name for an instance.
getter/setter pair
enableRbac ↔ bool?
Option to enable granular role-based access control.
getter/setter pair
enableStackdriverLogging ↔ bool?
Option to enable Dataproc Stackdriver Logging.
getter/setter pair
enableStackdriverMonitoring ↔ bool?
Option to enable Stackdriver Monitoring.
getter/setter pair
enableZoneSeparation ↔ bool?
Option to enable granular zone separation.
getter/setter pair
eventPublishConfig ↔ EventPublishConfig?
Option to enable and pass metadata for event publishing.
getter/setter pair
gcsBucket ↔ String?
Cloud Storage bucket generated by Data Fusion in the customer project.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The resource labels for instance to use to annotate any related underlying resources such as Compute Engine VMs.
getter/setter pair
loggingConfig ↔ LoggingConfig?
The logging configuration for this instance.
getter/setter pair
maintenanceEvents ↔ List<MaintenanceEvent>?
The maintenance events for this instance.
getter/setter pair
maintenancePolicy ↔ MaintenancePolicy?
Configure the maintenance policy for this instance.
getter/setter pair
monitoringConfig ↔ MonitoringConfig?
The monitoring configuration for this instance.
getter/setter pair
name ↔ String?
The name of this instance is in the form of projects/{project}/locations/{location}/instances/{instance}.
getter/setter pair
networkConfig ↔ NetworkConfig?
Network configuration options.
getter/setter pair
options ↔ Map<String, String>?
Map of additional options used to configure the behavior of Data Fusion instance.
getter/setter pair
p4ServiceAccount ↔ String?
Service agent for the customer project.
getter/setter pair
patchRevision ↔ String?
Current patch revision of the Data Fusion.
getter/setter pair
privateInstance ↔ bool?
Specifies whether the Data Fusion instance should be private.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
serviceAccount ↔ String?
Use tenant_project_id instead to extract the tenant project ID.
getter/setter pair
serviceEndpoint ↔ String?
Endpoint on which the Data Fusion UI is accessible.
getter/setter pair
state ↔ String?
The current state of this Data Fusion instance.
getter/setter pair
stateMessage ↔ String?
Additional information about the current state of this Data Fusion instance if available.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
tenantProjectId ↔ String?
The name of the tenant project.
getter/setter pair
type ↔ String?
Instance type.
getter/setter pair
updateTime ↔ String?
The time the instance was last updated.
getter/setter pair
version ↔ String?
Current version of the Data Fusion.
getter/setter pair
workforceIdentityServiceEndpoint ↔ String?
Endpoint on which the Data Fusion UI is accessible to third-party users
getter/setter pair
zone ↔ String?
Name of the zone in which the Data Fusion instance will be created.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited