MonitoringConfig class

Monitoring configuration for a Data Fusion instance.

Constructors

MonitoringConfig({bool? enableInstanceV2Metrics})
MonitoringConfig.fromJson(Map json_)

Properties

enableInstanceV2Metrics ↔ bool?
Option to enable the instance v2 metrics for this instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited