PrivateServiceConnectConfig class

Configuration for using Private Service Connect to establish connectivity between the Data Fusion consumer project and the corresponding tenant project.

Constructors

PrivateServiceConnectConfig({String? effectiveUnreachableCidrBlock, String? networkAttachment, String? unreachableCidrBlock})
PrivateServiceConnectConfig.fromJson(Map json_)

Properties

effectiveUnreachableCidrBlock ↔ String?
The CIDR block to which the CDF instance can't route traffic to in the consumer project VPC.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
networkAttachment ↔ String?
The reference to the network attachment used to establish private connectivity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachableCidrBlock ↔ String?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited