list method
Lists lineage events in the given project and location.
The list order is not defined.
Request parameters:
parent - Required. The name of the run that owns the collection of
lineage events to get.
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/processes/\[^/\]+/runs/\[^/\]+$.
pageSize - Optional. The maximum number of lineage events to return. The
service may return fewer events than this value. If unspecified, at most
50 events are returned. The maximum value is 100; values greater than 100
are cut to 100.
pageToken - Optional. The page token received from a previous
ListLineageEvents call. Specify it to get the next page. When
paginating, all other parameters specified in this call must match the
parameters of the call that provided the page token.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudDatacatalogLineageV1ListLineageEventsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleCloudDatacatalogLineageV1ListLineageEventsResponse> list(
core.String parent, {
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/lineageEvents';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleCloudDatacatalogLineageV1ListLineageEventsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}