datamanager/v1 library

Classes

AccountTypesAccountsInsightsResource
AccountTypesAccountsPartnerLinksResource
AccountTypesAccountsResource
AccountTypesAccountsUserListDirectLicensesResource
AccountTypesAccountsUserListGlobalLicensesResource
AccountTypesAccountsUserListGlobalLicensesUserListGlobalLicenseCustomerInfosResource
AccountTypesAccountsUserListsResource
AccountTypesResource
AddressInfo
Address information for the user.
AdEvent
An ad event.
AdEventsResource
AdIdentifiers
Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).
AudienceMember
The audience member to be operated on.
AudienceMembersResource
AwsWrappedKeyInfo
A data encryption key wrapped by an AWS KMS key.
Baseline
Baseline criteria against which insights are compared.
CartData
The cart data associated with the event.
CompositeData
Composite data holding identifiers and associated data for a user.
[Digital Markets Act (DMA)](//digital-markets-act.ec.europa.eu/index_en) consent settings for the user.
ContactIdInfo
Additional information when CONTACT_ID is one of the upload_key_types.
CoordinatorKeyInfo
Information about the coordinator key.
DataManagerApi
A unified ingestion API for data partners, agencies and advertisers to connect first-party data across Google advertising products.
DataTypeCount
The count for a specific data type.
Destination
The Google product you're sending data to.
DeviceInfo
Information about the device being used (if any) when the event happened.
EncryptedUserId
A user identifier issued to be used for attribution.
EncryptionInfo
Encryption information for the data being ingested.
ErrorCount
The error count for a given error reason.
ErrorInfo
Error counts for each type of error.
Event
An event representing a user interaction with an advertiser's website or app.
EventLocation
The location where the event occurred.
EventsResource
ExperimentalField
Experimental field representing unofficial fields.
FieldWarning
Detailed row-level warning with field paths.
GcpWrappedKeyInfo
Information about the Google Cloud Platform wrapped key.
GoogleUserIdData
Google user id data holding encrypted google user IDs.
IngestAdEventsRequest
Request to upload ad events.
IngestAudienceMembersRequest
Request to upload audience members to the provided destinations.
IngestAudienceMembersResponse
Response from the IngestAudienceMembersRequest.
IngestAudienceMembersStatus
The status of the ingest audience members request.
IngestCompositeDataStatus
The status of the composite data ingestion to the destination containing stats related to the ingestion.
IngestedUserListInfo
Represents a user list that is populated by user provided data.
IngestEventsRequest
Request to upload audience members to the provided destinations.
IngestEventsResponse
Response from the IngestEventsRequest.
IngestEventsStatus
The status of the events ingestion to the destination.
IngestGoogleUserIdDataStatus
The status of the google user id data ingestion to the destination containing stats related to the ingestion.
IngestMobileDataStatus
The status of the mobile data ingestion to the destination containing stats related to the ingestion.
IngestPairDataStatus
The status of the pair data ingestion to the destination containing stats related to the ingestion.
IngestPartnerProvidedIdDataStatus
The status of the partner provided id data ingestion to the destination containing stats related to the ingestion.
IngestPpidDataStatus
The status of the ppid data ingestion to the destination containing stats related to the ingestion.
IngestUserDataStatus
The status of the user data ingestion to the destination containing stats related to the ingestion.
IngestUserIdDataStatus
The status of the user id data ingestion to the destination containing stats related to the ingestion.
IpData
IP address information for a user.
Item
Represents an item in the cart associated with the event.
ListUserListDirectLicensesResponse
Response from the ListUserListDirectLicensesRequest.
ListUserListGlobalLicenseCustomerInfosResponse
Response from the ListUserListGlobalLicensesCustomerInfoRequest.
ListUserListGlobalLicensesResponse
Response from the ListUserListGlobalLicensesRequest.
ListUserListsResponse
Response message for ListUserLists.
Location
The baseline location of the request.
MarketingDataInsight
Insights for marketing data.
MarketingDataInsightsAttribute
Insights for a collection of related attributes of the same dimension.
MobileData
Mobile IDs for the audience.
MobileIdInfo
Additional information when MOBILE_ID is one of the upload_key_types.
PairData
[PAIR](//support.google.com/admanager/answer/15067908) IDs for the audience.
PairIdInfo
Additional information when PAIR_ID is one of the upload_key_types.
PartnerAudienceInfo
Additional information for partner audiences.
PartnerCustomerAccount
Represents a customer account in the partner's system.
A partner link between an owning account and a partner account.
PartnerLinkMetadata
Represents metadata associated with a partner link.
PartnerProvidedIdData
Partner-provided data holding the partner-provided identifiers.
PpidData
Publisher provided identifiers data holding the ppids.
ProductAccount
Represents a specific account.
PseudonymousIdInfo
Additional information when PSEUDONYMOUS_ID is one of the upload_key_types.
RemoveAllAudienceMembersRequest
Request to remove all users from an audience in the provided destinations.
RemoveAudienceMembersRequest
Request to remove users from an audience in the provided destinations.
RemoveAudienceMembersStatus
The status of the remove audience members request.
RemoveCompositeDataStatus
The status of the composite data removal from the destination.
RemoveGoogleUserIdDataStatus
The status of the google user id data removal from the destination.
RemoveMobileDataStatus
The status of the mobile data removal from the destination.
RemovePairDataStatus
The status of the pair data removal from the destination.
RemovePartnerProvidedIdDataStatus
The status of the partner provided id data removal from the destination.
RemovePpidDataStatus
The status of the ppid data removal from the destination.
RemoveUserDataStatus
The status of the user data removal from the destination.
RemoveUserIdDataStatus
The status of the user id data removal from the destination.
RequestStatusPerDestination
A request status per destination.
RequestStatusResource
RetrieveInsightsRequest
Request message for DM API MarketingDataInsightsService.RetrieveInsights
RetrieveInsightsResponse
Response message for DM API MarketingDataInsightsService.RetrieveInsights
RetrieveRequestStatusResponse
Response from the RetrieveRequestStatusRequest.
SearchPartnerLinksResponse
Response from the SearchPartnerLinksRequest.
SizeInfo
Estimated number of members in this user list in different target networks.
TargetNetworkInfo
Eligibility information for different target networks.
TermsOfService
The terms of service that the user has accepted/rejected.
UserData
Data that identifies the user.
UserIdData
User id data holding the user id.
UserIdentifier
A single identifier for the user.
UserIdInfo
Additional information when USER_ID is one of the upload_key_types.
UserList
A user list resource.
UserListDirectLicense
A user list direct license.
UserListGlobalLicense
A user list global license.
UserListGlobalLicenseCustomerInfo
Information about a customer of a user list global license.
UserListLicenseMetrics
Metrics related to a user list license.
UserListLicensePricing
A user list license pricing.
UserProperties
Advertiser-assessed information about the user at the time that the event happened.
UserProperty
A bucket of any additional user properties for the user associated with this event.
ViewabilityInfo
Details of the viewability of the ad served.
WarningCount
The warning count for a given warning reason.
WarningInfo
Warning counts for each type of warning.

Typedefs

CustomVariable = $CustomVariable
Custom variable for ads conversions.
Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
EventParameter = $Parameter
Event parameter for GA4 events.
IngestAdEventsResponse = $Empty
Response from an ad event ingestion operation.
ItemCustomVariable = $CustomVariable
Item-level custom variable for ads conversions.
ItemParameter = $Parameter
A bucket of any event parameters related to an item to be included within the event that were not already specified using other structured fields.
RemoveAllAudienceMembersResponse = $AudienceMembersResponse
Response from the RemoveAllAudienceMembersRequest.
RemoveAllAudienceMembersStatus = $Empty
The status of the remove all audience members request.
RemoveAudienceMembersResponse = $AudienceMembersResponse
Response from the RemoveAudienceMembersRequest.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.