AccountTypesAccountsResource class

Constructors

AccountTypesAccountsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
insights → AccountTypesAccountsInsightsResource
no setter
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userListDirectLicenses → AccountTypesAccountsUserListDirectLicensesResource
no setter
userListGlobalLicenses → AccountTypesAccountsUserListGlobalLicensesResource
no setter
userLists → AccountTypesAccountsUserListsResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited