AccountTypesAccountsUserListGlobalLicensesResource class

Constructors

AccountTypesAccountsUserListGlobalLicensesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userListGlobalLicenseCustomerInfos AccountTypesAccountsUserListGlobalLicensesUserListGlobalLicenseCustomerInfosResource
no setter

Methods

create(UserListGlobalLicense request, String parent, {String? $fields}) Future<UserListGlobalLicense>
Creates a user list global license.
get(String name, {String? $fields}) Future<UserListGlobalLicense>
Retrieves a user list global license.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) Future<ListUserListGlobalLicensesResponse>
Lists all user list global licenses owned by the parent account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(UserListGlobalLicense request, String name, {String? updateMask, String? $fields}) Future<UserListGlobalLicense>
Updates a user list global license.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited