AccountTypesAccountsUserListsResource class

Constructors

AccountTypesAccountsUserListsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(UserList request, String parent, {bool? validateOnly, String? $fields}) → Future<UserList>
Creates a UserList.
delete(String name, {bool? validateOnly, String? $fields}) → Future<Empty>
Deletes a UserList.
get(String name, {String? $fields}) → Future<UserList>
Gets a UserList.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListUserListsResponse>
Lists UserLists.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(UserList request, String name, {String? updateMask, bool? validateOnly, String? $fields}) → Future<UserList>
Updates a UserList.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited