deviceInfo property
Information gathered about the device being used when the ad event happened.
Required.
Implementation
DeviceInfo? deviceInfo;
Information gathered about the device being used when the ad event happened.
Required.
DeviceInfo? deviceInfo;