eventId property

String? eventId
getter/setter pair

An ID created and managed by the caller that uniquely identifies this event.

Required if you want to deduplicate ad events that are included in multiple requests. Otherwise, this field is optional.

Optional.

Implementation

core.String? eventId;