userData property
Multiple pieces of user-provided data, representing the user the event is associated with.
It is possible to provide multiple instances of the same type of data (e.g. email address). The more data provided, the more likely a match will be found.
Optional.
Implementation
UserData? userData;