AdEventsResource class
Constructors
- AdEventsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
ingest(
IngestAdEventsRequest request, {String? $fields}) → Future< Empty> - Uploads a list of AdEvent resources to Google Analytics.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited