AddressInfo class

Address information for the user.

Constructors

AddressInfo({String? addressLine, String? administrativeArea, String? city, String? familyName, String? givenName, String? postalCode, String? regionCode})
AddressInfo.fromJson(Map json_)

Properties

addressLine ↔ String?
The street and number of the user's address.
getter/setter pair
administrativeArea ↔ String?
The administrative area (state/province) of the user's address.
getter/setter pair
city ↔ String?
The city of the user's address.
getter/setter pair
familyName ↔ String?
Family (last) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256.
getter/setter pair
givenName ↔ String?
Given (first) name of the user, all lowercase, with no punctuation, no leading or trailing whitespace, and hashed as SHA-256.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postalCode ↔ String?
The postal code of the user's address.
getter/setter pair
regionCode ↔ String?
The 2-letter region code in ISO-3166-1 alpha-2 of the user's address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited