AwsWrappedKeyInfo class

A data encryption key wrapped by an AWS KMS key.

Constructors

AwsWrappedKeyInfo({String? encryptedDek, String? kekUri, String? keyType, String? roleArn})
AwsWrappedKeyInfo.fromJson(Map json_)

Properties

encryptedDek ↔ String?
The base64 encoded encrypted data encryption key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kekUri ↔ String?
The URI of the AWS KMS key used to decrypt the DEK.
getter/setter pair
keyType ↔ String?
The type of algorithm used to encrypt the data.
getter/setter pair
roleArn ↔ String?
The Amazon Resource Name of the IAM Role to assume for KMS decryption access.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited