Baseline class

Baseline criteria against which insights are compared.

Constructors

Baseline({Location? baselineLocation, bool? locationAutoDetectionEnabled})
Baseline.fromJson(Map json_)

Properties

baselineLocation ↔ Location?
The baseline location of the request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locationAutoDetectionEnabled ↔ bool?
If set to true, the service will try to automatically detect the baseline location for insights.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited