locationAutoDetectionEnabled property
If set to true, the service will try to automatically detect the baseline location for insights.
Implementation
core.bool? locationAutoDetectionEnabled;
If set to true, the service will try to automatically detect the baseline location for insights.
core.bool? locationAutoDetectionEnabled;