CartData class

The cart data associated with the event.

Constructors

CartData({List<Item>? items, String? merchantFeedLabel, String? merchantFeedLanguageCode, String? merchantId, double? transactionDiscount})
CartData.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Item>?
The list of items associated with the event.
getter/setter pair
merchantFeedLabel ↔ String?
The Merchant Center feed label associated with the feed of the items.
getter/setter pair
merchantFeedLanguageCode ↔ String?
The language code in ISO 639-1 associated with the Merchant Center feed of the items.where your items are uploaded.
getter/setter pair
merchantId ↔ String?
The Merchant Center ID associated with the items.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionDiscount ↔ double?
The sum of all discounts associated with the transaction.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited