couponCodes property

List<String>? couponCodes
getter/setter pair

The list of coupon codes that were applied to the cart.

Cart-level and item-level coupon codes are independent. If the event is for a Google Analytics destination, only provide a single coupon code. Google Analytics ignores additional coupon codes.

Optional.

Implementation

core.List<core.String>? couponCodes;