CompositeData class

Composite data holding identifiers and associated data for a user.

At least one of user_data or ip_data is required.

Constructors

CompositeData({List<IpData>? ipData, UserData? userData})
CompositeData.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipData ↔ List<IpData>?
IP address data representing customer interaction used to build the audience.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userData ↔ UserData?
User-provided data that identifies the user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited