DataManagerApi class

A unified ingestion API for data partners, agencies and advertisers to connect first-party data across Google advertising products.

Constructors

DataManagerApi(Client client, {String rootUrl = 'https://datamanager.googleapis.com/', String servicePath = ''})

Properties

accountTypes AccountTypesResource
no setter
adEvents AdEventsResource
no setter
audienceMembers AudienceMembersResource
no setter
events EventsResource
no setter
hashCode int
The hash code for this object.
no setterinherited
requestStatus RequestStatusResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

datamanagerPartnerlinkScope → const String
View, create, or delete your partner links in Google Ads, Marketing Platform (Campaign Manager 360, Search Ads 360, Display & Video 360), and Analytics
datamanagerScope → const String
See, edit, create, import, or delete your customer data in Google Ads, Google Marketing Platform (Campaign Manager 360, Search Ads 360, Display & Video 360), and Google Analytics