Destination class

The Google product you're sending data to.

For example, a Google Ads account.

Constructors

Destination({ProductAccount? linkedAccount, ProductAccount? loginAccount, ProductAccount? operatingAccount, String? productDestinationId, String? reference})
Destination.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
linkedAccount ↔ ProductAccount?
An account that the calling user's login_account has access to, through an established account link.
getter/setter pair
loginAccount ↔ ProductAccount?
The account used to make this API call.
getter/setter pair
operatingAccount ↔ ProductAccount?
The account to send the data to or remove the data from.
getter/setter pair
productDestinationId ↔ String?
The object within the product account to ingest into.
getter/setter pair
reference ↔ String?
ID for this Destination resource, unique within the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited