DeviceInfo class

Information about the device being used (if any) when the event happened.

Constructors

DeviceInfo({String? brand, String? browser, String? browserVersion, String? category, String? ipAddress, String? languageCode, String? model, String? operatingSystem, String? operatingSystemVersion, int? screenHeight, int? screenWidth, String? userAgent})
DeviceInfo.fromJson(Map json_)

Properties

brand ↔ String?
The brand of the device.
getter/setter pair
browser ↔ String?
The brand or type of the browser.
getter/setter pair
browserVersion ↔ String?
The version of the browser.
getter/setter pair
category ↔ String?
The category of device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String?
The IP address of the device for the given context.
getter/setter pair
languageCode ↔ String?
The language the device uses in ISO 639-1 format.
getter/setter pair
model ↔ String?
The model of the device.
getter/setter pair
operatingSystem ↔ String?
The operating system or platform of the device.
getter/setter pair
operatingSystemVersion ↔ String?
The version of the operating system or platform.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenHeight ↔ int?
The height of the screen in pixels.
getter/setter pair
screenWidth ↔ int?
The width of the screen in pixels.
getter/setter pair
userAgent ↔ String?
The user-agent string of the device for the given context.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited