ipAddress property
The IP address of the device for the given context.
Required when used in an AdEvent.
Optional.
Implementation
core.String? ipAddress;
The IP address of the device for the given context.
Required when used in an AdEvent.
Optional.
core.String? ipAddress;