EncryptedUserId class

A user identifier issued to be used for attribution.

All fields are required if this is used.

Constructors

EncryptedUserId({String? encryptedId, String? entityId, String? entityType, String? source})
EncryptedUserId.fromJson(Map json_)

Properties

encryptedId ↔ String?
The alphanumeric encrypted id.
getter/setter pair
entityId ↔ String?
The encryption entity ID.
getter/setter pair
entityType ↔ String?
The encryption entity type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
Describes whether the encrypted cookie was received from ad serving (the %m macro) or from Data Transfer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited