entityId property
The encryption entity ID.
This should match the encryption configuration for ad serving or Data Transfer.
Required.
Implementation
core.String? entityId;
The encryption entity ID.
This should match the encryption configuration for ad serving or Data Transfer.
Required.
core.String? entityId;