EncryptionInfo class

Encryption information for the data being ingested.

Constructors

EncryptionInfo({AwsWrappedKeyInfo? awsWrappedKeyInfo, GcpWrappedKeyInfo? gcpWrappedKeyInfo})
EncryptionInfo.fromJson(Map json_)

Properties

awsWrappedKeyInfo ↔ AwsWrappedKeyInfo?
Amazon Web Services wrapped key information.
getter/setter pair
gcpWrappedKeyInfo ↔ GcpWrappedKeyInfo?
Google Cloud Platform wrapped key information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited