reason property

String? reason
getter/setter pair

The error reason of the failed records. Possible string values are:

  • "PROCESSING_ERROR_REASON_UNSPECIFIED" : The processing error reason is unknown.
  • "PROCESSING_ERROR_REASON_INVALID_CUSTOM_VARIABLE" : The custom variable is invalid.
  • "PROCESSING_ERROR_REASON_CUSTOM_VARIABLE_NOT_ENABLED" : The status of the custom variable is not enabled.
  • "PROCESSING_ERROR_REASON_EVENT_TOO_OLD" : The conversion is older than max supported age.
  • "PROCESSING_ERROR_REASON_DENIED_CONSENT" : The ad user data is denied, either by the user or in the advertiser default settings.
  • "PROCESSING_ERROR_REASON_NO_CONSENT" : Advertiser did not give 3P consent for the Ads core platform services.
  • "PROCESSING_ERROR_REASON_UNKNOWN_CONSENT" : The overall consent (determined from row level consent, request level consent, and account settings) could not be determined for this user
  • "PROCESSING_ERROR_REASON_DUPLICATE_GCLID" : A conversion with the same GCLID and conversion time already exists in the system.
  • "PROCESSING_ERROR_REASON_DUPLICATE_TRANSACTION_ID" : A conversion with the same order id and conversion action combination was already uploaded.
  • "PROCESSING_ERROR_REASON_INVALID_GBRAID" : The gbraid could not be decoded.
  • "PROCESSING_ERROR_REASON_INVALID_GCLID" : The google click ID could not be decoded.
  • "PROCESSING_ERROR_REASON_INVALID_MERCHANT_ID" : Merchant id contains non-digit characters.
  • "PROCESSING_ERROR_REASON_INVALID_WBRAID" : The wbraid could not be decoded.
  • "PROCESSING_ERROR_REASON_INTERNAL_ERROR" : Internal error.

"PROCESSING_ERROR_REASON_DESTINATION_ACCOUNT_ENHANCED_CONVERSIONS_TERMS_NOT_SIGNED" : Enhanced conversions terms are not signed in the destination account.

  • "PROCESSING_ERROR_REASON_INVALID_EVENT" : The event is invalid.
  • "PROCESSING_ERROR_REASON_INSUFFICIENT_MATCHED_TRANSACTIONS" : The matched transactions are less than the minimum threshold.
  • "PROCESSING_ERROR_REASON_INSUFFICIENT_TRANSACTIONS" : The transactions are less than the minimum threshold.
  • "PROCESSING_ERROR_REASON_INVALID_FORMAT" : The event has format error.
  • "PROCESSING_ERROR_REASON_DECRYPTION_ERROR" : The event has a decryption error.
  • "PROCESSING_ERROR_REASON_DEK_DECRYPTION_ERROR" : The DEK failed to be decrypted.
  • "PROCESSING_ERROR_REASON_INVALID_WIP" : The WIP is formatted incorrectly or the WIP does not exist.
  • "PROCESSING_ERROR_REASON_INVALID_KEK" : The KEK cannot decrypt data because it is the wrong KEK, or it does not exist.
  • "PROCESSING_ERROR_REASON_WIP_AUTH_FAILED" : The WIP could not be used because it was rejected by its attestation condition.
  • "PROCESSING_ERROR_REASON_KEK_PERMISSION_DENIED" : The system did not have the permissions needed to access the KEK.
  • "PROCESSING_ERROR_REASON_AWS_AUTH_FAILED" : The system failed to authenticate with AWS.
  • "PROCESSING_ERROR_REASON_USER_IDENTIFIER_DECRYPTION_ERROR" : Failed to decrypt the UserIdentifier data using the DEK.
  • "PROCESSING_ERROR_OPERATING_ACCOUNT_MISMATCH_FOR_AD_IDENTIFIER" : The user attempted to ingest events with an ad identifier that isn't from the operating account's ads.

"PROCESSING_ERROR_REASON_ONE_PER_CLICK_CONVERSION_ACTION_NOT_PERMITTED_WITH_BRAID" : One-per-click conversion actions cannot be used with BRAIDs.

  • "PROCESSING_ERROR_REASON_MATCH_ID_NOT_FOUND" : The match ID can not be found.
  • "PROCESSING_ERROR_REASON_USER_ID_NOT_FOUND_FOR_MATCH_ID" : The user ID can not be found for the match ID.
  • "PROCESSING_ERROR_REASON_USER_ID_NOT_FOUND_FOR_GCLID" : The user ID can not be found for the GCLID.
  • "PROCESSING_ERROR_REASON_USER_ID_NOT_FOUND_FOR_DCLID" : The user ID can not be found for the DCLID.
  • "PROCESSING_ERROR_REASON_INVALID_AD_IDENTIFIERS" : There are ad identifiers that are invalid.
  • "PROCESSING_ERROR_REASON_INVALID_MOBILE_ID_FORMAT" : The mobile ID format is invalid.
  • "PROCESSING_ERROR_REASON_ORIGINAL_CONVERSIONS_NOT_FOUND" : The original conversions can't be found.
  • "PROCESSING_ERROR_REASON_EVENT_ID_DECODE_ERROR" : The event ID (dclid or impression ID) cannot be decoded.
  • "PROCESSING_ERROR_REASON_USER_ID_NOT_FOUND_FOR_IMPRESSION_ID" : The user ID cannot be found for the given impression ID.
  • "PROCESSING_ERROR_REASON_USER_ID_NOT_FOUND" : The user ID cannot be found.
  • "PROCESSING_ERROR_REASON_CONVERSION_PRECEDES_CLICK" : The event timestamp on the event was earlier than the associated click.
  • "PROCESSING_ERROR_REASON_TOO_RECENT_CLICK" : The click occurred too recently.
  • "PROCESSING_ERROR_REASON_INVALID_CLICK" : The event can't be attributed to a click (GCLID). This may be because the click did not come from a Google Ads campaign, for example.
  • "PROCESSING_ERROR_REASON_INVALID_OPERATING_ACCOUNT_FOR_CLICK" : The click from the event isn't associated with the operating_account of the destination.
  • "PROCESSING_ERROR_REASON_CLICK_NOT_FOUND" : A corresponding click can't be found that matches the provided attributes.
  • "PROCESSING_ERROR_REASON_EXTERNAL_ATTRIBUTION_DATA_MISSING" : External attribution data is missing. Sending events to a destination for an external attribution conversion action isn't supported.

Implementation

core.String? reason;