Event class

An event representing a user interaction with an advertiser's website or app.

Constructors

Event({AdIdentifiers? adIdentifiers, List<EventParameter>? additionalEventParameters, String? appInstanceId, CartData? cartData, String? clientId, Consent? consent, double? conversionCount, double? conversionValue, String? currency, List<CustomVariable>? customVariables, List<String>? destinationReferences, DeviceInfo? eventDeviceInfo, EventLocation? eventLocation, String? eventName, String? eventSource, String? eventTimestamp, List<ExperimentalField>? experimentalFields, String? lastUpdatedTimestamp, UserData? thirdPartyUserData, String? transactionId, UserData? userData, String? userId, UserProperties? userProperties})
Event.fromJson(Map json_)

Properties

additionalEventParameters ↔ List<EventParameter>?
A bucket of any event parameters to be included within the event that were not already specified using other structured fields.
getter/setter pair
adIdentifiers ↔ AdIdentifiers?
Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).
getter/setter pair
appInstanceId ↔ String?
A unique identifier for the user instance of an app client for this GA4 app stream.
getter/setter pair
cartData ↔ CartData?
Information about the transaction and items associated with the event.
getter/setter pair
clientId ↔ String?
A unique identifier for the user instance of a web client for this GA4 web stream.
getter/setter pair
Information about whether the associated user has provided different types of consent.
getter/setter pair
conversionCount ↔ double?
The conversion quantity associated with the event, for counting-based conversions.
getter/setter pair
conversionValue ↔ double?
The conversion value associated with the event, for value-based conversions.
getter/setter pair
currency ↔ String?
The currency code associated with all monetary values within this event.
getter/setter pair
customVariables ↔ List<CustomVariable>?
Additional key/value pair information to send to the conversion containers (conversion action or FL activity).
getter/setter pair
destinationReferences ↔ List<String>?
Reference string used to determine the destination.
getter/setter pair
eventDeviceInfo ↔ DeviceInfo?
Information gathered about the device being used (if any) when the event happened.
getter/setter pair
eventLocation ↔ EventLocation?
Information gathered about the location of the user when this event occurred.
getter/setter pair
eventName ↔ String?
The name of the event.
getter/setter pair
eventSource ↔ String?
Signal for where the event happened (web, app, in-store, etc.).
getter/setter pair
eventTimestamp ↔ String?
The time the event occurred.
getter/setter pair
experimentalFields ↔ List<ExperimentalField>?
A list of key/value pairs for experimental fields that may eventually be promoted to be part of the API.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdatedTimestamp ↔ String?
The last time the event was updated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thirdPartyUserData ↔ UserData?
The same type of data provided in user_data, but explicitly flagged as being provided as owned by a third-party and not first-party advertiser data.
getter/setter pair
transactionId ↔ String?
The unique identifier for this event.
getter/setter pair
userData ↔ UserData?
Pieces of user provided data, representing the user the event is associated with.
getter/setter pair
userId ↔ String?
A unique identifier for a user, as defined by the advertiser.
getter/setter pair
userProperties ↔ UserProperties?
Advertiser-assessed information about the user at the time that the event happened.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited