appInstanceId property
A unique identifier for the user instance of an app client for this GA4 app stream.
Optional.
Implementation
core.String? appInstanceId;
A unique identifier for the user instance of an app client for this GA4 app stream.
Optional.
core.String? appInstanceId;