conversionCount property
The conversion quantity associated with the event, for counting-based conversions.
Optional.
Implementation
core.double? conversionCount;
The conversion quantity associated with the event, for counting-based conversions.
Optional.
core.double? conversionCount;