eventLocation property
Information gathered about the location of the user when this event occurred.
Optional.
Implementation
EventLocation? eventLocation;
Information gathered about the location of the user when this event occurred.
Optional.
EventLocation? eventLocation;