EventLocation class

The location where the event occurred.

Constructors

EventLocation({String? city, String? continentCode, String? regionCode, String? storeId, String? subcontinentCode, String? subdivisionCode})
EventLocation.fromJson(Map json_)

Properties

city ↔ String?
The name of the city where the event occurred.
getter/setter pair
continentCode ↔ String?
The continent code in UN M49 format where the event occurred.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
regionCode ↔ String?
The 2-letter CLDR region code of the user's address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeId ↔ String?
Required for Store Sales.
getter/setter pair
subcontinentCode ↔ String?
The subcontinent code in UN M49 format where the event occurred.
getter/setter pair
subdivisionCode ↔ String?
The ISO 3166-2 subdivision code where the event occurred.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited