storeId property
Required for Store Sales.
The identifier to represent a physical store where the event happened.
Optional.
Implementation
core.String? storeId;
Required for Store Sales.
The identifier to represent a physical store where the event happened.
Optional.
core.String? storeId;