FieldWarning class

Detailed row-level warning with field paths.

Constructors

FieldWarning({String? description, String? field, String? reason})
FieldWarning.fromJson(Map json_)

Properties

description String?
The detailed warning message describing the issue.
getter/setter pair
field String?
The field path that triggered the warning.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
reason String?
The warning reason. Possible string values are:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited