reason property

String? reason
getter/setter pair

The warning reason. Possible string values are:

  • "WARNING_REASON_UNSPECIFIED" : Unspecified warning reason.
  • "WARNING_REASON_CUSTOM_VARIABLE_NOT_ENABLED" : A custom variable in custom_variables is not enabled in the account.
  • "WARNING_REASON_CUSTOM_VARIABLE_NOT_PREDEFINED" : A custom variable value in custom_variables is not among the predefined allowed values configured for the custom variable on the destination account.
  • "WARNING_REASON_CART_DATA_NOT_SUPPORTED_WITH_GBRAID_OR_WBRAID" : The cart_data is not supported with gbraid or wbraid.
  • "WARNING_REASON_CART_DATA_ITEM_MERCHANT_PRODUCT_ID_MISSING" : The merchant_product_id is missing in the cart item.
  • "WARNING_REASON_CART_DATA_ITEM_UNIT_PRICE_MISSING" : The unit_price is missing in the cart item.
  • "WARNING_REASON_GENERIC" : Generic warning reason for issues that do not fit into other specific categories.
  • "WARNING_REASON_INVALID_CLIENT_ID" : The client_id is invalid.
  • "WARNING_REASON_INVALID_SUBDIVISION_CODE" : The subdivision_code is invalid.
  • "WARNING_REASON_INVALID_REGION_CODE" : The region_code is invalid.
  • "WARNING_REASON_INVALID_SUBCONTINENT_CODE" : The subcontinent_code is invalid.
  • "WARNING_REASON_INVALID_CONTINENT_CODE" : The continent_code is invalid.
  • "WARNING_REASON_INVALID_DEVICE_CATEGORY" : The device category is invalid.
  • "WARNING_REASON_INVALID_DEVICE_SCREEN_RESOLUTION" : The device screen_height or screen_width is invalid.
  • "WARNING_REASON_INVALID_MERCHANT_ID" : The merchant_id is invalid.

Implementation

core.String? reason;