IngestAdEventsRequest class

Request to upload ad events.

Constructors

IngestAdEventsRequest({List<AdEvent>? adEvents, EncryptionInfo? encryptionInfo, bool? validateOnly})
IngestAdEventsRequest.fromJson(Map json_)

Properties

adEvents List<AdEvent>?
Required (at least 1).
getter/setter pair
encryptionInfo EncryptionInfo?
Information about encryption keys which are used to encrypt the data.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validateOnly bool?
If true, the request is validated, but not executed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited