encryptionInfo property
Information about encryption keys which are used to encrypt the data.
Required.
Implementation
EncryptionInfo? encryptionInfo;
Information about encryption keys which are used to encrypt the data.
Required.
EncryptionInfo? encryptionInfo;