googleUserIdDataIngestionStatus property
The status of the google user id data ingestion to the destination.
Implementation
IngestGoogleUserIdDataStatus? googleUserIdDataIngestionStatus;
The status of the google user id data ingestion to the destination.
IngestGoogleUserIdDataStatus? googleUserIdDataIngestionStatus;