IngestCompositeDataStatus class
The status of the composite data ingestion to the destination containing stats related to the ingestion.
Constructors
-
IngestCompositeDataStatus({List<
DataTypeCount> ? dataTypeCounts, String? recordCount, String? uploadMatchRateRange}) - IngestCompositeDataStatus.fromJson(Map json_)
Properties
-
dataTypeCounts
↔ List<
DataTypeCount> ? -
The total count of data types sent in the upload request for the
destination, broken down by data type.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- recordCount ↔ String?
-
The total count of audience members sent in the upload request for the
destination.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uploadMatchRateRange ↔ String?
-
The match rate range of the upload.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited