dataTypeCounts property

List<DataTypeCount>? dataTypeCounts
getter/setter pair

The total count of data types sent in the upload request for the destination, broken down by data type.

Includes all data types in the request, regardless of whether they were successfully ingested or not.

Implementation

core.List<DataTypeCount>? dataTypeCounts;