IngestEventsRequest class

Request to upload audience members to the provided destinations.

Returns an IngestEventsResponse.

Constructors

IngestEventsRequest({Consent? consent, List<Destination>? destinations, String? encoding, EncryptionInfo? encryptionInfo, List<Event>? events, bool? validateOnly})
IngestEventsRequest.fromJson(Map json_)

Properties

Request-level consent to apply to all users in the request.
getter/setter pair
destinations ↔ List<Destination>?
The list of destinations to send the events to.
getter/setter pair
encoding ↔ String?
Required for UserData uploads.
getter/setter pair
encryptionInfo ↔ EncryptionInfo?
Encryption information for UserData uploads.
getter/setter pair
events ↔ List<Event>?
The list of events to send to the specified destinations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
For testing purposes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited