googleUserIdCount property

String? googleUserIdCount
getter/setter pair

The total count of google user ids sent in the upload request for the destination.

Includes all google user ids in the request, regardless of whether they were successfully ingested or not.

Implementation

core.String? googleUserIdCount;