IngestPartnerProvidedIdDataStatus class
The status of the partner provided id data ingestion to the destination containing stats related to the ingestion.
Constructors
- IngestPartnerProvidedIdDataStatus({String? partnerProvidedIdCount, String? recordCount})
- IngestPartnerProvidedIdDataStatus.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- partnerProvidedIdCount ↔ String?
-
The total count of partner provided ids sent in the upload request for the
destination.
getter/setter pair
- recordCount ↔ String?
-
The total count of audience members sent in the upload request for the
destination.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited