IngestedUserListInfo class

Represents a user list that is populated by user provided data.

Constructors

IngestedUserListInfo({ContactIdInfo? contactIdInfo, MobileIdInfo? mobileIdInfo, PairIdInfo? pairIdInfo, PartnerAudienceInfo? partnerAudienceInfo, PseudonymousIdInfo? pseudonymousIdInfo, List<String>? uploadKeyTypes, UserIdInfo? userIdInfo})
IngestedUserListInfo.fromJson(Map json_)

Properties

contactIdInfo ContactIdInfo?
Additional information when CONTACT_ID is one of the upload_key_types.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mobileIdInfo MobileIdInfo?
Additional information when MOBILE_ID is one of the upload_key_types.
getter/setter pair
pairIdInfo PairIdInfo?
Additional information when PAIR_ID is one of the upload_key_types.
getter/setter pair
partnerAudienceInfo PartnerAudienceInfo?
Additional information for partner audiences.
getter/setter pair
pseudonymousIdInfo PseudonymousIdInfo?
Additional information for PSEUDONYMOUS_ID is one of the upload_key_types.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uploadKeyTypes List<String>?
Upload key types of this user list.
getter/setter pair
userIdInfo UserIdInfo?
Additional information when USER_ID is one of the upload_key_types.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited