IpData class

IP address information for a user.

We recommend including observe_start_time and observe_end_time to help improve Customer Match match rates.

Constructors

IpData({String? ipAddress, String? observeEndTime, String? observeStartTime})
IpData.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
ipAddress String?
IP address captured at the time of customer interaction.
getter/setter pair
observeEndTime String?
Last recorded interaction time from this IP address in a session.
getter/setter pair
observeStartTime String?
First recorded interaction time from this IP address in a session.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited