ipAddress property
IP address captured at the time of customer interaction.
Accepts standard string formats for both IPv4 and IPv6.
Required.
Implementation
core.String? ipAddress;
IP address captured at the time of customer interaction.
Accepts standard string formats for both IPv4 and IPv6.
Required.
core.String? ipAddress;