Item class

Represents an item in the cart associated with the event.

Constructors

Item({List<EventParameter>? additionalItemParameters, double? conversionValue, List<CustomVariable>? customVariables, String? itemId, String? merchantFeedLabel, String? merchantFeedLanguageCode, String? merchantId, String? merchantProductId, String? quantity, double? unitPrice})
Item.fromJson(Map json_)

Properties

additionalItemParameters ↔ List<EventParameter>?
A bucket of any event parameters related to an item to be included within the event that were not already specified using other structured fields.
getter/setter pair
conversionValue ↔ double?
The conversion value associated with this item within the event, for cases where the conversion value is different for each item.
getter/setter pair
customVariables ↔ List<CustomVariable>?
Additional key/value pair information to send to the conversion containers (conversion action or Floodlight activity), when tracking per-item conversions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemId ↔ String?
A unique identifier to reference the item.
getter/setter pair
merchantFeedLabel ↔ String?
The feed label of the Merchant Center feed.
getter/setter pair
merchantFeedLanguageCode ↔ String?
The language code in ISO 639-1 associated with the Merchant Center feed where your items are uploaded.
getter/setter pair
merchantId ↔ String?
The Merchant Center ID associated with the item.
getter/setter pair
merchantProductId ↔ String?
The product ID within the Merchant Center account.
getter/setter pair
quantity ↔ String?
The number of this item associated with the event.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unitPrice ↔ double?
The unit price excluding tax, shipping, and any transaction level discounts.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited