ListUserListGlobalLicensesResponse class
Response from the ListUserListGlobalLicensesRequest.
Constructors
-
ListUserListGlobalLicensesResponse({String? nextPageToken, List<
UserListGlobalLicense> ? userListGlobalLicenses}) - ListUserListGlobalLicensesResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
A token, which can be sent as
page_tokento retrieve the next page.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userListGlobalLicenses
↔ List<
UserListGlobalLicense> ? -
The licenses for the given user list in the request.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited