Location class

The baseline location of the request.

Baseline location is on OR-list of ISO 3166-1 alpha-2 region codes of the requested regions.

Constructors

Location({List<String>? regionCodes})
Location.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
regionCodes List<String>?
List of ISO 3166-1 alpha-2 region codes.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited