MarketingDataInsight class

Insights for marketing data.

This feature is only available to data partners.

Properties

attributes List<MarketingDataInsightsAttribute>?
Insights for values of a given dimension.
getter/setter pair
dimension String?
The dimension to which the insight belongs. Possible string values are:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited