appId property
A string that uniquely identifies a mobile application from which the data was collected.
Required. Immutable.
Implementation
core.String? appId;
A string that uniquely identifies a mobile application from which the data was collected.
Required. Immutable.
core.String? appId;