PartnerAudienceInfo class
Additional information for partner audiences.
This feature is only available to data partners.
Constructors
- PartnerAudienceInfo({String? commercePartner, String? partnerAudienceSource})
- PartnerAudienceInfo.fromJson(Map json_)
Properties
- commercePartner ↔ String?
-
The commerce partner name.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- partnerAudienceSource ↔ String?
-
The source of the partner audience.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited