accountType property
The type of the account.
Can be used to distinguish between advertiser accounts and business level accounts, for example.
Optional.
Implementation
core.String? accountType;
The type of the account.
Can be used to distinguish between advertiser accounts and business level accounts, for example.
Optional.
core.String? accountType;