PartnerLink class

A partner link between an owning account and a partner account.

Constructors

PartnerLink({String? featureSet, String? name, ProductAccount? owningAccount, ProductAccount? partnerAccount, PartnerCustomerAccount? partnerCustomerAccount, String? partnerLinkId, PartnerLinkMetadata? partnerLinkMetadata})
PartnerLink.fromJson(Map json_)

Properties

featureSet String?
The set of features supported for the partner link.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
owningAccount ProductAccount?
The owning account granting access to the partner account.
getter/setter pair
partnerAccount ProductAccount?
The partner account granted access by the owning account.
getter/setter pair
partnerCustomerAccount PartnerCustomerAccount?
The customer account in the partner system.
getter/setter pair
partnerLinkId String?
The partner link ID.
getter/setter pair
partnerLinkMetadata PartnerLinkMetadata?
Metadata associated with the partner link.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited