partnerCustomerAccount property
The customer account in the partner system.
This is required for partner links with the FEATURE_SET_AD_EVENT_MANAGEMENT feature set.
Optional.
Implementation
PartnerCustomerAccount? partnerCustomerAccount;
The customer account in the partner system.
This is required for partner links with the FEATURE_SET_AD_EVENT_MANAGEMENT feature set.
Optional.
PartnerCustomerAccount? partnerCustomerAccount;