partnerLinkMetadata property
Metadata associated with the partner link.
This is optional and only accepted for partner links with the FEATURE_SET_AD_EVENT_MANAGEMENT.
Optional.
Implementation
PartnerLinkMetadata? partnerLinkMetadata;
Metadata associated with the partner link.
This is optional and only accepted for partner links with the FEATURE_SET_AD_EVENT_MANAGEMENT.
Optional.
PartnerLinkMetadata? partnerLinkMetadata;