PseudonymousIdInfo class

Additional information when PSEUDONYMOUS_ID is one of the upload_key_types.

Constructors

PseudonymousIdInfo({String? billableRecordCount, String? syncStatus})
PseudonymousIdInfo.fromJson(Map json_)

Properties

billableRecordCount String?
The number of billable records (e.g. uploaded or matched).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
syncStatus String?
Sync status of the user list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited