RemoveAudienceMembersRequest class

Request to remove users from an audience in the provided destinations.

Returns a RemoveAudienceMembersResponse.

Constructors

RemoveAudienceMembersRequest({List<AudienceMember>? audienceMembers, List<Destination>? destinations, String? encoding, EncryptionInfo? encryptionInfo, bool? validateOnly})
RemoveAudienceMembersRequest.fromJson(Map json_)

Properties

audienceMembers ↔ List<AudienceMember>?
The list of users to remove.
getter/setter pair
destinations ↔ List<Destination>?
The list of destinations to remove the users from.
getter/setter pair
encoding ↔ String?
Required for UserData uploads.
getter/setter pair
encryptionInfo ↔ EncryptionInfo?
Encryption information for UserData uploads.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
For testing purposes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited