RemoveAudienceMembersStatus class

The status of the remove audience members request.

Constructors

RemoveAudienceMembersStatus({RemoveCompositeDataStatus? compositeDataRemovalStatus, RemoveGoogleUserIdDataStatus? googleUserIdDataRemovalStatus, RemoveMobileDataStatus? mobileDataRemovalStatus, RemovePairDataStatus? pairDataRemovalStatus, RemovePartnerProvidedIdDataStatus? partnerProvidedIdDataRemovalStatus, RemovePpidDataStatus? ppidDataRemovalStatus, RemoveUserDataStatus? userDataRemovalStatus, RemoveUserIdDataStatus? userIdDataRemovalStatus})
RemoveAudienceMembersStatus.fromJson(Map json_)

Properties

compositeDataRemovalStatus ↔ RemoveCompositeDataStatus?
The status of the composite data removal from the destination.
getter/setter pair
googleUserIdDataRemovalStatus ↔ RemoveGoogleUserIdDataStatus?
The status of the google user id data removal from the destination.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mobileDataRemovalStatus ↔ RemoveMobileDataStatus?
The status of the mobile data removal from the destination.
getter/setter pair
pairDataRemovalStatus ↔ RemovePairDataStatus?
The status of the pair data removal from the destination.
getter/setter pair
partnerProvidedIdDataRemovalStatus ↔ RemovePartnerProvidedIdDataStatus?
The status of the partner provided id data removal from the destination.
getter/setter pair
ppidDataRemovalStatus ↔ RemovePpidDataStatus?
The status of the ppid data removal from the destination.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userDataRemovalStatus ↔ RemoveUserDataStatus?
The status of the user data removal from the destination.
getter/setter pair
userIdDataRemovalStatus ↔ RemoveUserIdDataStatus?
The status of the user id data removal from the destination.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited