compositeDataRemovalStatus property
The status of the composite data removal from the destination.
Implementation
RemoveCompositeDataStatus? compositeDataRemovalStatus;
The status of the composite data removal from the destination.
RemoveCompositeDataStatus? compositeDataRemovalStatus;