googleUserIdDataRemovalStatus property
The status of the google user id data removal from the destination.
Implementation
RemoveGoogleUserIdDataStatus? googleUserIdDataRemovalStatus;
The status of the google user id data removal from the destination.
RemoveGoogleUserIdDataStatus? googleUserIdDataRemovalStatus;