partnerProvidedIdDataRemovalStatus property
The status of the partner provided id data removal from the destination.
Implementation
RemovePartnerProvidedIdDataStatus? partnerProvidedIdDataRemovalStatus;
The status of the partner provided id data removal from the destination.
RemovePartnerProvidedIdDataStatus? partnerProvidedIdDataRemovalStatus;