ppidDataRemovalStatus property
The status of the ppid data removal from the destination.
Implementation
RemovePpidDataStatus? ppidDataRemovalStatus;
The status of the ppid data removal from the destination.
RemovePpidDataStatus? ppidDataRemovalStatus;