userIdDataRemovalStatus property
The status of the user id data removal from the destination.
Implementation
RemoveUserIdDataStatus? userIdDataRemovalStatus;
The status of the user id data removal from the destination.
RemoveUserIdDataStatus? userIdDataRemovalStatus;