RemoveCompositeDataStatus class

The status of the composite data removal from the destination.

Constructors

RemoveCompositeDataStatus({List<DataTypeCount>? dataTypeCounts, String? recordCount})
RemoveCompositeDataStatus.fromJson(Map json_)

Properties

dataTypeCounts List<DataTypeCount>?
The total count of data types sent in the removal request, broken down by data type.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
recordCount String?
The total count of audience members sent in the removal request.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited