dataTypeCounts property

List<DataTypeCount>? dataTypeCounts
getter/setter pair

The total count of data types sent in the removal request, broken down by data type.

Includes all data types in the request, regardless of whether they were successfully removed or not.

Implementation

core.List<DataTypeCount>? dataTypeCounts;