googleUserIdCount property

String? googleUserIdCount
getter/setter pair

The total count of google user ids sent in the removal request.

Includes all google user ids in the request, regardless of whether they were successfully removed or not.

Implementation

core.String? googleUserIdCount;