RemovePartnerProvidedIdDataStatus class

The status of the partner provided id data removal from the destination.

Constructors

RemovePartnerProvidedIdDataStatus({String? partnerProvidedIdCount, String? recordCount})
RemovePartnerProvidedIdDataStatus.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
partnerProvidedIdCount ↔ String?
The total count of partner provided ids sent in the removal request.
getter/setter pair
recordCount ↔ String?
The total count of audience members sent in the removal request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited