RequestStatusPerDestination class

A request status per destination.

Constructors

RequestStatusPerDestination({IngestAudienceMembersStatus? audienceMembersIngestionStatus, RemoveAudienceMembersStatus? audienceMembersRemovalStatus, Destination? destination, ErrorInfo? errorInfo, IngestEventsStatus? eventsIngestionStatus, String? requestStatus, WarningInfo? warningInfo})
RequestStatusPerDestination.fromJson(Map json_)

Properties

audienceMembersIngestionStatus ↔ IngestAudienceMembersStatus?
The status of the ingest audience members request.
getter/setter pair
audienceMembersRemovalStatus ↔ RemoveAudienceMembersStatus?
The status of the remove audience members request.
getter/setter pair
destination ↔ Destination?
A destination within a DM API request.
getter/setter pair
errorInfo ↔ ErrorInfo?
An error info error containing the error reason and error counts related to the upload.
getter/setter pair
eventsIngestionStatus ↔ IngestEventsStatus?
The status of the ingest events request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestStatus ↔ String?
The request status of the destination. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
warningInfo ↔ WarningInfo?
A warning info containing the warning reason and warning counts related to the upload.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited