requestStatus property

String? requestStatus
getter/setter pair

The request status of the destination. Possible string values are:

  • "REQUEST_STATUS_UNKNOWN" : The request status is unknown.
  • "SUCCESS" : Processing succeeded for all records without any errors. However, there may be warnings in the warning_info field.
  • "PROCESSING" : The request is processing.
  • "FAILED" : Processing failed for all records. Check the error_info field for error details, and check the warning_info field for warning details.
  • "PARTIAL_SUCCESS" : Processing completed successfully without errors for some records, but failed with errors for other records. Check the error_info field for error details, and check the warning_info field for warning details.

Implementation

core.String? requestStatus;