warningInfo property
A warning info containing the warning reason and warning counts related to the upload.
This field isn't populated while the request has request_status of
PROCESSING.
Implementation
WarningInfo? warningInfo;
A warning info containing the warning reason and warning counts related to the upload.
This field isn't populated while the request has request_status of
PROCESSING.
WarningInfo? warningInfo;