RetrieveInsightsRequest class
Request message for DM API MarketingDataInsightsService.RetrieveInsights
Constructors
- RetrieveInsightsRequest({Baseline? baseline, String? userListId})
- RetrieveInsightsRequest.fromJson(Map json_)
Properties
- baseline ↔ Baseline?
-
Baseline for the insights requested.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userListId ↔ String?
-
The user list ID for which insights are requested.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited