SizeInfo class

Estimated number of members in this user list in different target networks.

Constructors

SizeInfo({String? displayNetworkMembersCount, String? gmailMembersCount, String? searchNetworkMembersCount, String? youtubeMembersCount})
SizeInfo.fromJson(Map json_)

Properties

displayNetworkMembersCount ↔ String?
Estimated number of members in this user list, on the Google Display Network.
getter/setter pair
gmailMembersCount ↔ String?
Estimated number of members in this user list on Gmail.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchNetworkMembersCount ↔ String?
Estimated number of members in this user list in the google.com domain.
getter/setter pair
youtubeMembersCount ↔ String?
Estimated number of members in this user list on YouTube.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited