eligibleForSearch property
Indicates if this user list is eligible for Google Search Network.
Optional.
Implementation
core.bool? eligibleForSearch;
Indicates if this user list is eligible for Google Search Network.
Optional.
core.bool? eligibleForSearch;