UserIdInfo class

Additional information when USER_ID is one of the upload_key_types.

Constructors

UserIdInfo({String? dataSourceType})
UserIdInfo.fromJson(Map json_)

Properties

dataSourceType ↔ String?
Source of the upload data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited