UserIdentifier class

A single identifier for the user.

Constructors

UserIdentifier({AddressInfo? address, String? emailAddress, String? phoneNumber})
UserIdentifier.fromJson(Map json_)

Properties

address ↔ AddressInfo?
The known components of a user's address.
getter/setter pair
emailAddress ↔ String?
Hashed email address using SHA-256 hash function after normalization.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber ↔ String?
Hashed phone number using SHA-256 hash function after normalization (E164 standard).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited