UserList class

A user list resource.

Constructors

UserList({String? accessReason, String? accountAccessStatus, String? closingReason, String? description, String? displayName, String? id, IngestedUserListInfo? ingestedUserListInfo, String? integrationCode, String? membershipDuration, String? membershipStatus, String? name, bool? readOnly, SizeInfo? sizeInfo, TargetNetworkInfo? targetNetworkInfo})
UserList.fromJson(Map json_)

Properties

accessReason ↔ String?
The reason this account has been granted access to the list.
getter/setter pair
accountAccessStatus ↔ String?
Indicates if this share is still enabled.
getter/setter pair
closingReason ↔ String?
The reason why this user list membership status is closed.
getter/setter pair
description ↔ String?
A description of the user list.
getter/setter pair
displayName ↔ String?
The display name of the user list.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique ID of the user list.
getter/setter pair
ingestedUserListInfo ↔ IngestedUserListInfo?
Represents a user list that is populated by user ingested data.
getter/setter pair
integrationCode ↔ String?
An ID from external system.
getter/setter pair
membershipDuration ↔ String?
The duration a user remains in the user list.
getter/setter pair
membershipStatus ↔ String?
Membership status of this user list.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
readOnly ↔ bool?
An option that indicates if a user may edit a list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeInfo ↔ SizeInfo?
Estimated number of members in this user list in different target networks.
getter/setter pair
targetNetworkInfo ↔ TargetNetworkInfo?
Eligibility information for different target networks.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited