closingReason property
The reason why this user list membership status is closed.
Output only. Possible string values are:
- "CLOSING_REASON_UNSPECIFIED" : Not specified.
- "UNUSED" : The user list was closed because it has not been used in targeting recently. See https://support.google.com/google-ads/answer/2472738 for details.
Implementation
core.String? closingReason;