integrationCode property
An ID from external system.
It is used by user list sellers to correlate IDs on their systems.
Optional.
Implementation
core.String? integrationCode;
An ID from external system.
It is used by user list sellers to correlate IDs on their systems.
Optional.
core.String? integrationCode;