sizeInfo property
Estimated number of members in this user list in different target networks.
Output only.
Implementation
SizeInfo? sizeInfo;
Estimated number of members in this user list in different target networks.
Output only.
SizeInfo? sizeInfo;