clientAccountId property
ID of client customer which the user list is being licensed to.
Immutable.
Implementation
core.String? clientAccountId;
ID of client customer which the user list is being licensed to.
Immutable.
core.String? clientAccountId;