metrics property

UserListLicenseMetrics? metrics
getter/setter pair

Metrics related to this license This field is read-only and only populated if the start and end dates are set in the ListUserListDirectLicenses call

Output only.

Implementation

UserListLicenseMetrics? metrics;