clientAccountDisplayName property
Name of client customer which the user list is being licensed to.
Output only.
Implementation
core.String? clientAccountDisplayName;
Name of client customer which the user list is being licensed to.
Output only.
core.String? clientAccountDisplayName;