clientAccountId property
ID of client customer which the user list is being licensed to.
Output only.
Implementation
core.String? clientAccountId;
ID of client customer which the user list is being licensed to.
Output only.
core.String? clientAccountId;