costMicros property
The cost associated with the model, in micro units (10^-6), in the currency specified by the currency_code field.
For example, 2000000 means $2 if currency_code is USD.
Optional.
Implementation
core.String? costMicros;
The cost associated with the model, in micro units (10^-6), in the currency specified by the currency_code field.
For example, 2000000 means $2 if currency_code is USD.
Optional.
core.String? costMicros;