UserProperties class

Advertiser-assessed information about the user at the time that the event happened.

See https://support.google.com/google-ads/answer/14007601 for more details.

Constructors

UserProperties({List<UserProperty>? additionalUserProperties, String? customerType, String? customerValueBucket})
UserProperties.fromJson(Map json_)

Properties

additionalUserProperties ↔ List<UserProperty>?
A bucket of any additional user properties for the user associated with this event.
getter/setter pair
customerType ↔ String?
Type of the customer associated with the event.
getter/setter pair
customerValueBucket ↔ String?
The advertiser-assessed value of the customer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited