ViewabilityInfo class

Details of the viewability of the ad served.

Constructors

ViewabilityInfo({String? mediaDuration, String? mediaQuartile, bool? mediaSkippable, int? mediaVolumePercent, String? playbackDuration, String? viewType, String? viewableDuration, int? viewablePercent})
ViewabilityInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mediaDuration ↔ String?
The duration of the ad media.
getter/setter pair
mediaQuartile ↔ String?
The amount of the media that was played as discrete quartiles.
getter/setter pair
mediaSkippable ↔ bool?
Whether the ad media was skippable or not.
getter/setter pair
mediaVolumePercent ↔ int?
The numerical percent (0-100) of the volume of the media playback.
getter/setter pair
playbackDuration ↔ String?
The duration of playback of the ad media, regardless of whether it was viewable or not.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewableDuration ↔ String?
The amount of time the ad was viewable for.
getter/setter pair
viewablePercent ↔ int?
The numerical percent (0-100) of the pixels that were viewable.
getter/setter pair
viewType ↔ String?
The type of the event.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited