ApplyConversionWorkspaceRequest class

Request message for 'ApplyConversionWorkspace' request.

Constructors

ApplyConversionWorkspaceRequest({bool? autoCommit, String? connectionProfile, bool? dryRun, String? filter})
ApplyConversionWorkspaceRequest.fromJson(Map json_)

Properties

autoCommit ↔ bool?
Specifies whether the conversion workspace is to be committed automatically after the apply.
getter/setter pair
connectionProfile ↔ String?
Fully qualified (Uri) name of the destination connection profile.
getter/setter pair
dryRun ↔ bool?
Only validates the apply process, but doesn't change the destination database.
getter/setter pair
filter ↔ String?
Filter which entities to apply.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited