ApplyJobDetails class

Details regarding an Apply background job.

Constructors

ApplyJobDetails({String? connectionProfile, String? filter})
ApplyJobDetails.fromJson(Map json_)

Properties

connectionProfile ↔ String?
The connection profile which was used for the apply job.
getter/setter pair
filter ↔ String?
AIP-160 based filter used to specify the entities to apply
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited