CloudSqlConnectionProfile class

Specifies required connection parameters, and, optionally, the parameters required to create a Cloud SQL destination database instance.

Constructors

CloudSqlConnectionProfile({String? additionalPublicIp, String? cloudSqlId, String? privateIp, String? publicIp, CloudSqlSettings? settings})
CloudSqlConnectionProfile.fromJson(Map json_)

Properties

additionalPublicIp ↔ String?
The Cloud SQL database instance's additional (outgoing) public IP.
getter/setter pair
cloudSqlId ↔ String?
The Cloud SQL instance ID that this connection profile is associated with.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privateIp ↔ String?
The Cloud SQL database instance's private IP.
getter/setter pair
publicIp ↔ String?
The Cloud SQL database instance's public IP.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ CloudSqlSettings?
Metadata used to create the destination Cloud SQL database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited