ColumnEntity class

Column is not used as an independent entity, it is retrieved as part of a Table entity.

Constructors

ColumnEntity({bool? array, int? arrayLength, bool? autoGenerated, String? charset, String? collation, String? comment, bool? computed, Map<String, Object?>? customFeatures, String? dataType, String? defaultValue, int? fractionalSecondsPrecision, String? length, String? name, bool? nullable, int? ordinalPosition, int? precision, int? scale, List<String>? setValues, bool? udt})
ColumnEntity.fromJson(Map json_)

Properties

array ↔ bool?
Is the column of array type.
getter/setter pair
arrayLength ↔ int?
If the column is array, of which length.
getter/setter pair
autoGenerated ↔ bool?
Is the column auto-generated/identity.
getter/setter pair
charset ↔ String?
Charset override - instead of table level charset.
getter/setter pair
collation ↔ String?
Collation override - instead of table level collation.
getter/setter pair
comment ↔ String?
Comment associated with the column.
getter/setter pair
computed ↔ bool?
Is the column a computed column.
getter/setter pair
customFeatures ↔ Map<String, Object?>?
Custom engine specific features.
getter/setter pair
dataType ↔ String?
Column data type.
getter/setter pair
defaultValue ↔ String?
Default value of the column.
getter/setter pair
fractionalSecondsPrecision ↔ int?
Column fractional second precision - used for timestamp based datatypes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
length ↔ String?
Column length - e.g. varchar (50).
getter/setter pair
name ↔ String?
Column name.
getter/setter pair
nullable ↔ bool?
Is the column nullable.
getter/setter pair
ordinalPosition ↔ int?
Column order in the table.
getter/setter pair
precision ↔ int?
Column precision - when relevant.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ int?
Column scale - when relevant.
getter/setter pair
setValues ↔ List<String>?
Specifies the list of values allowed in the column.
getter/setter pair
udt ↔ bool?
Is the column a UDT.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited