ConditionalColumnSetValue class

Options to configure rule type ConditionalColumnSetValue.

The rule is used to transform the data which is being replicated/migrated. The rule filter field can refer to one or more entities. The rule scope can be one of: Column.

Constructors

ConditionalColumnSetValue({Map<String, Object?>? customFeatures, SourceNumericFilter? sourceNumericFilter, SourceTextFilter? sourceTextFilter, ValueTransformation? valueTransformation})
ConditionalColumnSetValue.fromJson(Map json_)

Properties

customFeatures ↔ Map<String, Object?>?
Custom engine specific features.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceNumericFilter ↔ SourceNumericFilter?
Optional filter on source column precision and scale.
getter/setter pair
sourceTextFilter ↔ SourceTextFilter?
Optional filter on source column length.
getter/setter pair
valueTransformation ↔ ValueTransformation?
Description of data transformation during migration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited