ConnectionProfile class

A connection profile definition.

Constructors

ConnectionProfile({AlloyDbConnectionProfile? alloydb, CloudSqlConnectionProfile? cloudsql, String? createTime, String? displayName, Status? error, Map<String, String>? labels, MySqlConnectionProfile? mysql, String? name, OracleConnectionProfile? oracle, PostgreSqlConnectionProfile? postgresql, String? provider, String? role, bool? satisfiesPzi, bool? satisfiesPzs, SqlServerConnectionProfile? sqlserver, String? state, String? updateTime})
ConnectionProfile.fromJson(Map json_)

Properties

alloydb ↔ AlloyDbConnectionProfile?
An AlloyDB cluster connection profile.
getter/setter pair
cloudsql ↔ CloudSqlConnectionProfile?
A CloudSQL database connection profile.
getter/setter pair
createTime ↔ String?
The timestamp when the resource was created.
getter/setter pair
displayName ↔ String?
The connection profile display name.
getter/setter pair
error ↔ Status?
The error details in case of state FAILED.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The resource labels for connection profile to use to annotate any related underlying resources such as Compute Engine VMs.
getter/setter pair
mysql ↔ MySqlConnectionProfile?
A MySQL database connection profile.
getter/setter pair
name ↔ String?
The name of this connection profile resource in the form of projects/{project}/locations/{location}/connectionProfiles/{connectionProfile}.
getter/setter pair
oracle ↔ OracleConnectionProfile?
An Oracle database connection profile.
getter/setter pair
postgresql ↔ PostgreSqlConnectionProfile?
A PostgreSQL database connection profile.
getter/setter pair
provider ↔ String?
The database provider. Possible string values are:
getter/setter pair
role ↔ String?
The connection profile role.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
sqlserver ↔ SqlServerConnectionProfile?
Connection profile for a SQL Server data source.
getter/setter pair
state ↔ String?
The current connection profile state (e.g. DRAFT, READY, or FAILED). Possible string values are:
getter/setter pair
updateTime ↔ String?
The timestamp when the resource was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited