EntityDdl class

A single DDL statement for a specific entity

Constructors

EntityDdl({String? ddl, String? ddlKind, String? ddlType, String? editedDdlKind, String? entity, String? entityType, List<String>? issueId})
EntityDdl.fromJson(Map json_)

Properties

ddl ↔ String?
The actual ddl code.
getter/setter pair
ddlKind ↔ String?
The DDL Kind selected for apply, or UNSPECIFIED if the entity wasn't converted yet. Possible string values are:
getter/setter pair
ddlType ↔ String?
Type of DDL (Create, Alter).
getter/setter pair
editedDdlKind ↔ String?
If ddl_kind is USER_EDIT, this holds the DDL kind of the original content
getter/setter pair
entity ↔ String?
The name of the database entity the ddl refers to.
getter/setter pair
entityType ↔ String?
The entity type (if the DDL is for a sub entity). Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issueId ↔ List<String>?
EntityIssues found for this ddl.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited