GenerateTcpProxyScriptRequest class

Request message for 'GenerateTcpProxyScript' request.

Constructors

GenerateTcpProxyScriptRequest({String? vmMachineType, String? vmName, String? vmSubnet, String? vmZone})
GenerateTcpProxyScriptRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vmMachineType ↔ String?
The type of the Compute instance that will host the proxy.
getter/setter pair
vmName ↔ String?
The name of the Compute instance that will host the proxy.
getter/setter pair
vmSubnet ↔ String?
The name of the subnet the Compute instance will use for private connectivity.
getter/setter pair
vmZone ↔ String?
The Google Cloud Platform zone to create the VM in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited