IndexEntity class

Index is not used as an independent entity, it is retrieved as part of a Table entity.

Constructors

IndexEntity({Map<String, Object?>? customFeatures, String? name, List<String>? tableColumns, List<bool>? tableColumnsDescending, String? type, bool? unique})
IndexEntity.fromJson(Map json_)

Properties

customFeatures ↔ Map<String, Object?>?
Custom engine specific features.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the index.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableColumns ↔ List<String>?
Table columns used as part of the Index, for example B-TREE index should list the columns which constitutes the index.
getter/setter pair
tableColumnsDescending ↔ List<bool>?
For each table_column, mark whether it's sorting order is ascending (false) or descending (true).
getter/setter pair
type ↔ String?
Type of index, for example B-TREE.
getter/setter pair
unique ↔ bool?
Boolean value indicating whether the index is unique.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited