InstanceNetworkConfig class

Metadata related to instance level network configuration.

Constructors

InstanceNetworkConfig({List<AuthorizedNetwork>? authorizedExternalNetworks, bool? enableOutboundPublicIp, bool? enablePublicIp})
InstanceNetworkConfig.fromJson(Map json_)

Properties

authorizedExternalNetworks ↔ List<AuthorizedNetwork>?
A list of external network authorized to access this instance.
getter/setter pair
enableOutboundPublicIp ↔ bool?
Enabling an outbound public IP address to support a database server sending requests out into the internet.
getter/setter pair
enablePublicIp ↔ bool?
Enabling public ip for the instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited