IntComparisonFilter class

Filter based on relation between source value and compare value of type integer in ConditionalColumnSetValue

Constructors

IntComparisonFilter({String? value, String? valueComparison})
IntComparisonFilter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
Integer compare value to be used
getter/setter pair
valueComparison ↔ String?
Relation between source value and compare value
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited