MappingRule class

Definition of a transformation that is to be applied to a group of entities in the source schema.

Several such transformations can be applied to an entity sequentially to define the corresponding entity in the target schema.

Constructors

MappingRule({ConditionalColumnSetValue? conditionalColumnSetValue, ConvertRowIdToColumn? convertRowidColumn, String? displayName, EntityMove? entityMove, MappingRuleFilter? filter, FilterTableColumns? filterTableColumns, MultiColumnDatatypeChange? multiColumnDataTypeChange, MultiEntityRename? multiEntityRename, String? name, String? revisionCreateTime, String? revisionId, String? ruleOrder, String? ruleScope, SetTablePrimaryKey? setTablePrimaryKey, SingleColumnChange? singleColumnChange, SingleEntityRename? singleEntityRename, SinglePackageChange? singlePackageChange, SourceSqlChange? sourceSqlChange, String? state})
MappingRule.fromJson(Map json_)

Properties

conditionalColumnSetValue ↔ ConditionalColumnSetValue?
Rule to specify how the data contained in a column should be transformed (such as trimmed, rounded, etc) provided that the data meets certain criteria.
getter/setter pair
convertRowidColumn ↔ ConvertRowIdToColumn?
Rule to specify how multiple tables should be converted with an additional rowid column.
getter/setter pair
displayName ↔ String?
A human readable name
getter/setter pair
entityMove ↔ EntityMove?
Rule to specify how multiple entities should be relocated into a different schema.
getter/setter pair
filter ↔ MappingRuleFilter?
The rule filter
getter/setter pair
filterTableColumns ↔ FilterTableColumns?
Rule to specify the list of columns to include or exclude from a table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
multiColumnDataTypeChange ↔ MultiColumnDatatypeChange?
Rule to specify how multiple columns should be converted to a different data type.
getter/setter pair
multiEntityRename ↔ MultiEntityRename?
Rule to specify how multiple entities should be renamed.
getter/setter pair
name ↔ String?
Full name of the mapping rule resource, in the form of: projects/{project}/locations/{location}/conversionWorkspaces/{set}/mappingRule/{rule}.
getter/setter pair
revisionCreateTime ↔ String?
The timestamp that the revision was created.
getter/setter pair
revisionId ↔ String?
The revision ID of the mapping rule.
getter/setter pair
ruleOrder ↔ String?
The order in which the rule is applied.
getter/setter pair
ruleScope ↔ String?
The rule scope
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setTablePrimaryKey ↔ SetTablePrimaryKey?
Deprecated: This rule is no longer supported.
getter/setter pair
singleColumnChange ↔ SingleColumnChange?
Rule to specify how a single column is converted.
getter/setter pair
singleEntityRename ↔ SingleEntityRename?
Rule to specify how a single entity should be renamed.
getter/setter pair
singlePackageChange ↔ SinglePackageChange?
Rule to specify how a single package is converted.
getter/setter pair
sourceSqlChange ↔ SourceSqlChange?
Rule to change the sql code for an entity, for example, function, procedure.
getter/setter pair
state ↔ String?
The mapping rule state
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited