isPrimaryDestination property
Whether the destination for the migration job is a primary instance.
Optional.
Implementation
core.bool? isPrimaryDestination;
Whether the destination for the migration job is a primary instance.
Optional.
core.bool? isPrimaryDestination;