OracleAsmConfig class

Configuration for Oracle Automatic Storage Management (ASM) connection.

Constructors

OracleAsmConfig({String? asmService, String? hostname, String? password, bool? passwordSet, int? port, SslConfig? ssl, String? username})
OracleAsmConfig.fromJson(Map json_)

Properties

asmService ↔ String?
ASM service name for the Oracle ASM connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
Hostname for the Oracle ASM connection.
getter/setter pair
password ↔ String?
Input only.
getter/setter pair
passwordSet ↔ bool?
Indicates whether a new password is included in the request.
getter/setter pair
port ↔ int?
Port for the Oracle ASM connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssl ↔ SslConfig?
SSL configuration for the Oracle connection.
getter/setter pair
username ↔ String?
Username for the Oracle ASM connection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited