OracleSourceConfig class

Configuration for Oracle as a source in a migration.

Constructors

OracleSourceConfig({BinaryLogParser? binaryLogParser, String? cdcStartPosition, LogMiner? logMiner, int? maxConcurrentCdcConnections, int? maxConcurrentFullDumpConnections, bool? skipFullDump})
OracleSourceConfig.fromJson(Map json_)

Properties

binaryLogParser ↔ BinaryLogParser?
Use Binary Log Parser.
getter/setter pair
cdcStartPosition ↔ String?
The schema change number (SCN) to start CDC data migration from.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
logMiner ↔ Empty?
Use LogMiner.
getter/setter pair
maxConcurrentCdcConnections ↔ int?
Maximum number of connections Database Migration Service will open to the source for CDC phase.
getter/setter pair
maxConcurrentFullDumpConnections ↔ int?
Maximum number of connections Database Migration Service will open to the source for full dump phase.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipFullDump ↔ bool?
Whether to skip full dump or not.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited