PostgresHomogeneousConfig class

Configuration for PostgreSQL to PostgreSQL migrations.

Constructors

PostgresHomogeneousConfig({bool? isNativeLogical, int? maxAdditionalSubscriptions})
PostgresHomogeneousConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isNativeLogical ↔ bool?
Whether the migration is native logical.
getter/setter pair
maxAdditionalSubscriptions ↔ int?
Maximum number of additional subscriptions to use for the migration job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited