PscInterfaceConfig class

The PSC Interface configuration is used to create PSC Interface between DMS's internal VPC and the consumer's PSC.

Constructors

PscInterfaceConfig({String? networkAttachment})
PscInterfaceConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkAttachment ↔ String?
Fully qualified name of the Network Attachment that DMS will connect to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited