RoundToScale class

This allows the data to change scale, for example if the source is 2 digits after the decimal point, specify round to scale value = 2.

If for example the value needs to be converted to an integer, use round to scale value = 0.

Constructors

RoundToScale({int? scale})
RoundToScale.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ int?
Scale value to be used
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited