SequenceEntity class

Sequence's parent is a schema.

Constructors

SequenceEntity({String? cache, Map<String, Object?>? customFeatures, bool? cycle, String? increment, String? maxValue, String? minValue, String? startValue})
SequenceEntity.fromJson(Map json_)

Properties

cache ↔ String?
Indicates number of entries to cache / precreate.
getter/setter pair
customFeatures ↔ Map<String, Object?>?
Custom engine specific features.
getter/setter pair
cycle ↔ bool?
Indicates whether the sequence value should cycle through.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
increment ↔ String?
Increment value for the sequence.
getter/setter pair
maxValue ↔ String?
Maximum number for the sequence represented as bytes to accommodate large.
getter/setter pair
maxValueAsBytes ↔ List<int>
getter/setter pair
minValue ↔ String?
Minimum number for the sequence represented as bytes to accommodate large.
getter/setter pair
minValueAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startValue ↔ String?
Start number for the sequence represented as bytes to accommodate large.
getter/setter pair
startValueAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited