SinglePackageChange class

Options to configure rule type SinglePackageChange.

The rule is used to alter the sql code for a package entities. The rule filter field can refer to one entity. The rule scope can be: Package

Constructors

SinglePackageChange({String? packageBody, String? packageDescription})
SinglePackageChange.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
packageBody ↔ String?
Sql code for package body
getter/setter pair
packageDescription ↔ String?
Sql code for package description
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited