SourceObjectIdentifier class

An identifier for the Migration Job Object.

Constructors

SourceObjectIdentifier({String? database, String? schema, String? table, String? type})
SourceObjectIdentifier.fromJson(Map json_)

Properties

database ↔ String?
The database name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ String?
The schema name.
getter/setter pair
table ↔ String?
The table name.
getter/setter pair
type ↔ String?
The type of the migration job object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited