SourceTextFilter class

Filter for text-based data types like varchar.

Constructors

SourceTextFilter({String? sourceMaxLengthFilter, String? sourceMinLengthFilter})
SourceTextFilter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceMaxLengthFilter ↔ String?
The filter will match columns with length smaller than or equal to this number.
getter/setter pair
sourceMinLengthFilter ↔ String?
The filter will match columns with length greater than or equal to this number.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited