SqlAclEntry class

An entry for an Access Control list.

Constructors

SqlAclEntry({String? expireTime, String? label, String? ttl, String? value})
SqlAclEntry.fromJson(Map json_)

Properties

expireTime ↔ String?
The time when this access control entry expires in RFC 3339 format, for example: 2012-11-15T16:19:00.094Z.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
A label to identify this entry.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl ↔ String?
Input only.
getter/setter pair
value ↔ String?
The allowlisted value for the access control list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited