SqlIpConfig class

IP Management configuration.

Constructors

SqlIpConfig({String? allocatedIpRange, List<SqlAclEntry>? authorizedNetworks, bool? enableIpv4, String? privateNetwork, bool? requireSsl})
SqlIpConfig.fromJson(Map json_)

Properties

allocatedIpRange ↔ String?
The name of the allocated IP address range for the private IP Cloud SQL instance.
getter/setter pair
authorizedNetworks ↔ List<SqlAclEntry>?
The list of external networks that are allowed to connect to the instance using the IP.
getter/setter pair
enableIpv4 ↔ bool?
Whether the instance should be assigned an IPv4 address or not.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
privateNetwork ↔ String?
The resource link for the VPC network from which the Cloud SQL instance is accessible for private IP.
getter/setter pair
requireSsl ↔ bool?
Whether SSL connections over IP should be enforced or not.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited