SqlServerBackups class

Specifies the backup details in Cloud Storage for homogeneous migration to Cloud SQL for SQL Server.

Constructors

SqlServerBackups({String? gcsBucket, String? gcsPrefix})
SqlServerBackups.fromJson(Map json_)

Properties

gcsBucket ↔ String?
The Cloud Storage bucket that stores backups for all replicated databases.
getter/setter pair
gcsPrefix ↔ String?
Cloud Storage path inside the bucket that stores backups.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited