SqlServerConnectionProfile class

Specifies connection parameters required specifically for SQL Server databases.

Constructors

SqlServerConnectionProfile({SqlServerBackups? backups, String? cloudSqlId, String? cloudSqlProjectId, String? database, int? dbmPort, ForwardSshTunnelConnectivity? forwardSshConnectivity, String? host, String? password, bool? passwordSet, int? port, PrivateConnectivity? privateConnectivity, PrivateServiceConnectConnectivity? privateServiceConnectConnectivity, SslConfig? ssl, StaticIpConnectivity? staticIpConnectivity, String? username})
SqlServerConnectionProfile.fromJson(Map json_)

Properties

backups ↔ SqlServerBackups?
The backup details in Cloud Storage for homogeneous migration to Cloud SQL for SQL Server.
getter/setter pair
cloudSqlId ↔ String?
If the source is a Cloud SQL database, use this field to provide the Cloud SQL instance ID of the source.
getter/setter pair
cloudSqlProjectId ↔ String?
The project id of the Cloud SQL instance.
getter/setter pair
database ↔ String?
The name of the specific database within the host.
getter/setter pair
dbmPort ↔ int?
The Database Mirroring (DBM) port of the source SQL Server instance.
getter/setter pair
forwardSshConnectivity ↔ ForwardSshTunnelConnectivity?
Forward SSH tunnel connectivity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
The IP or hostname of the source SQL Server database.
getter/setter pair
password ↔ String?
Input only.
getter/setter pair
passwordSet ↔ bool?
Indicates whether a new password is included in the request.
getter/setter pair
port ↔ int?
The network port of the source SQL Server database.
getter/setter pair
privateConnectivity ↔ PrivateConnectivity?
Private connectivity.
getter/setter pair
privateServiceConnectConnectivity ↔ PrivateServiceConnectConnectivity?
Private Service Connect connectivity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssl ↔ SslConfig?
SSL configuration for the destination to connect to the source database.
getter/setter pair
staticIpConnectivity ↔ Empty?
Static IP connectivity data (default, no additional details needed).
getter/setter pair
username ↔ String?
The username that Database Migration Service will use to connect to the database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited