TableEntity class

Table's parent is a schema.

Constructors

TableEntity({List<ColumnEntity>? columns, String? comment, List<ConstraintEntity>? constraints, Map<String, Object?>? customFeatures, List<IndexEntity>? indices, List<TriggerEntity>? triggers})
TableEntity.fromJson(Map json_)

Properties

columns ↔ List<ColumnEntity>?
Table columns.
getter/setter pair
comment ↔ String?
Comment associated with the table.
getter/setter pair
constraints ↔ List<ConstraintEntity>?
Table constraints.
getter/setter pair
customFeatures ↔ Map<String, Object?>?
Custom engine specific features.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indices ↔ List<IndexEntity>?
Table indices.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggers ↔ List<TriggerEntity>?
Table triggers.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited