ValueListFilter class

A list of values to filter by in ConditionalColumnSetValue

Constructors

ValueListFilter({bool? ignoreCase, String? valuePresentList, List<String>? values})
ValueListFilter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreCase ↔ bool?
Whether to ignore case when filtering by values.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valuePresentList ↔ String?
Indicates whether the filter matches rows with values that are present in the list or those with values not present in it.
getter/setter pair
values ↔ List<String>?
The list to be used to filter by
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited