ValueTransformation class

Description of data transformation during migration as part of the ConditionalColumnSetValue.

Constructors

ValueTransformation({ApplyHash? applyHash, Empty? assignMaxValue, Empty? assignMinValue, Empty? assignNull, AssignSpecificValue? assignSpecificValue, DoubleComparisonFilter? doubleComparison, IntComparisonFilter? intComparison, Empty? isNull, RoundToScale? roundScale, ValueListFilter? valueList})
ValueTransformation.fromJson(Map json_)

Properties

applyHash ↔ ApplyHash?
Applies a hash function on the data
getter/setter pair
assignMaxValue ↔ Empty?
Set to max_value - if integer or numeric, will use int.maxvalue, etc
getter/setter pair
assignMinValue ↔ Empty?
Set to min_value - if integer or numeric, will use int.minvalue, etc
getter/setter pair
assignNull ↔ Empty?
Set to null
getter/setter pair
assignSpecificValue ↔ AssignSpecificValue?
Set to a specific value (value is converted to fit the target data type)
getter/setter pair
doubleComparison ↔ DoubleComparisonFilter?
Filter on relation between source value and compare value of type double.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intComparison ↔ IntComparisonFilter?
Filter on relation between source value and compare value of type integer.
getter/setter pair
isNull ↔ Empty?
Value is null
getter/setter pair
roundScale ↔ RoundToScale?
Allows the data to change scale
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueList ↔ ValueListFilter?
Value is found in the specified list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited