VmCreationConfig class

VM creation configuration message

Constructors

VmCreationConfig({String? subnet, String? vmMachineType, String? vmZone})
VmCreationConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnet ↔ String?
The subnet name the vm needs to be created in.
getter/setter pair
vmMachineType ↔ String?
VM instance machine type to create.
getter/setter pair
vmZone ↔ String?
The Google Cloud Platform zone to create the VM in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited