dataplexReadWriteScope constant

String const dataplexReadWriteScope

See, edit, configure, and delete your Google Cloud Dataplex data and see the email address for your Google Account

Implementation

static const dataplexReadWriteScope =
    'https://www.googleapis.com/auth/dataplex.read-write';