GoogleCloudDataplexV1CreateEntryLinkRequest class
Request message for CreateEntryLink.
Constructors
- GoogleCloudDataplexV1CreateEntryLinkRequest({GoogleCloudDataplexV1EntryLink? entryLink, String? entryLinkId, String? parent})
- GoogleCloudDataplexV1CreateEntryLinkRequest.fromJson(Map json_)
Properties
- entryLink ↔ GoogleCloudDataplexV1EntryLink?
-
Entry Link resource.
getter/setter pair
- entryLinkId ↔ String?
-
Entry Link identifier * Must contain only lowercase letters, numbers and
hyphens.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- parent ↔ String?
-
The resource name of the parent Entry Group:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited