GoogleCloudDataplexV1DataAttributeBindingPath class

Represents a subresource of the given resource, and associated bindings with it.

Currently supported subresources are column and partition schema fields within a table.

Properties

attributes ↔ List<String>?
List of attributes to be associated with the path of the resource, provided in the form: projects/{project}/locations/{location}/dataTaxonomies/{dataTaxonomy}/attributes/{data_attribute_id}
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name identifier of the path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited