GoogleCloudDataplexV1DataDiscoverySpecStorageConfig class

Configurations related to Cloud Storage as the data source.

Properties

csvOptions ↔ GoogleCloudDataplexV1DataDiscoverySpecStorageConfigCsvOptions?
Configuration for CSV data.
getter/setter pair
excludePatterns ↔ List<String>?
Defines the data to exclude during discovery.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includePatterns ↔ List<String>?
Defines the data to include during discovery when only a subset of the data should be considered.
getter/setter pair
jsonOptions ↔ GoogleCloudDataplexV1DataDiscoverySpecStorageConfigJsonOptions?
Configuration for JSON data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited