GoogleCloudDataplexV1DataDocumentationSpec class

DataDocumentation scan related spec.

Constructors

GoogleCloudDataplexV1DataDocumentationSpec({bool? catalogPublishingEnabled, List<String>? generationScopes})
GoogleCloudDataplexV1DataDocumentationSpec.fromJson(Map json_)

Properties

catalogPublishingEnabled ↔ bool?
Whether to publish result to Dataplex Catalog.
getter/setter pair
generationScopes ↔ List<String>?
Specifies which components of the data documentation to generate.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited