accessGroupDisplayName property

String? accessGroupDisplayName
getter/setter pair

The display name of the access group defined in the Data Product for which access is being requested.

Output only.

Implementation

core.String? accessGroupDisplayName;