attributes property
Map of attribute name and value linked to the rule.
The rules to evaluate can be filtered based on attributes provided here and a filter expression provided in the DataQualitySpec.filter field.
Optional.
Implementation
core.Map<core.String, core.String>? attributes;