debugQueries property
Specifies the debug queries for this rule.
Currently, only one query is supported, but this may be expanded in the future.
Optional.
Implementation
core.List<GoogleCloudDataplexV1DataQualityRuleDebugQuery>? debugQueries;
Specifies the debug queries for this rule.
Currently, only one query is supported, but this may be expanded in the future.
Optional.
core.List<GoogleCloudDataplexV1DataQualityRuleDebugQuery>? debugQueries;