ruleSource property
Contains information about the source of the rule and its relationship with the BigQuery table, where applicable.
Output only.
Implementation
GoogleCloudDataplexV1DataQualityRuleRuleSource? ruleSource;
Contains information about the source of the rule and its relationship with the BigQuery table, where applicable.
Output only.
GoogleCloudDataplexV1DataQualityRuleRuleSource? ruleSource;