debugQueriesResultSets property

List<GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResultSet>? debugQueriesResultSets
getter/setter pair

Contains the results of all debug queries for this rule.

The number of result sets will correspond to the number of debug_queries.

Output only.

Implementation

core.List<GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResultSet>?
debugQueriesResultSets;