name property
Specifies the name of the result.
Available if provided with an explicit alias using [AS] alias.
Implementation
core.String? name;
Specifies the name of the result.
Available if provided with an explicit alias using [AS] alias.
core.String? name;