GoogleCloudDataplexV1DataQualityRuleRuleSource class

Represents the rule source information from Catalog.

Properties

hashCode int
The hash code for this object.
no setterinherited
rulePathElements List<GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement>?
Rule path elements represent information about the individual items in the relationship path between the scan resource and rule origin in that order.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited