rulePathElements property

Rule path elements represent information about the individual items in the relationship path between the scan resource and rule origin in that order.

Output only.

Implementation

core.List<GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement>?
rulePathElements;