GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElement class

Path Element represents the direct relationship between the rule origin (aspects) to the BigQuery Entry.

Ordering of the rule relationship will be maintained such that the first entry in the list is the closest ancestor (BigQuery table itself). A blank source denotes that the rule is derived directly from the DataScan itself.

Properties

entryLinkSource GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntryLinkSource?
Entry link source represents information about the entry link.
getter/setter pair
entrySource GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource?
Entry source represents information about the related source entry.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited