dimension property
The dimension a rule template belongs to.
Rule level results are also aggregated at the dimension level.
Output only.
Implementation
core.String? dimension;
The dimension a rule template belongs to.
Rule level results are also aggregated at the dimension level.
Output only.
core.String? dimension;