GoogleCloudDataplexV1DataQualityRuleTemplateReference class

A rule that constructs a SQL statement to evaluate using a rule template and parameter values.

If the constructed statement returns any rows, this rule fails

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The template entry name.
getter/setter pair
resolvedSql String?
The resolved SQL statement generated from the template with parameters substituted.
getter/setter pair
ruleTemplate GoogleCloudDataplexV1DataQualityRuleTemplate?
The rule template used to resolve the rule.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, GoogleCloudDataplexV1DataQualityRuleTemplateReferenceParameterValue>?
Provides the map of parameter name and value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited