GoogleCloudDataplexV1DataQualitySpec class

DataQualityScan related setting.

Constructors

GoogleCloudDataplexV1DataQualitySpec({bool? catalogPublishingEnabled, bool? enableCatalogBasedRules, String? filter, GoogleCloudDataplexV1DataQualitySpecPostScanActions? postScanActions, String? rowFilter, List<GoogleCloudDataplexV1DataQualityRule>? rules, double? samplingPercent})
GoogleCloudDataplexV1DataQualitySpec.fromJson(Map json_)

Properties

catalogPublishingEnabled bool?
If set, the latest DataScan job result will be published as Dataplex Universal Catalog metadata.
getter/setter pair
enableCatalogBasedRules bool?
If enabled, the data scan will retrieve rules defined in the dataplex-types.global.data-rules aspect on all paths of the catalog entry corresponding to the BigQuery table resource and all attached glossary terms.
getter/setter pair
filter String?
Filter for selectively running a subset of rules.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
postScanActions GoogleCloudDataplexV1DataQualitySpecPostScanActions?
Actions to take upon job completion.
getter/setter pair
rowFilter String?
A filter applied to all rows in a single DataScan job.
getter/setter pair
rules List<GoogleCloudDataplexV1DataQualityRule>?
The list of rules to evaluate against a data source.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplingPercent double?
The percentage of the records to be selected from the dataset for DataScan.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited