GoogleCloudDataplexV1DataScan class

Represents a user-visible job which provides the insights for the related data source.For example: Data quality: generates queries based on the rules and runs against the data to get data quality check results.

For more information, see Auto data quality overview (https://cloud.google.com/dataplex/docs/auto-data-quality-overview). Data profile: analyzes the data in tables and generates insights about the structure, content and relationships (such as null percent, cardinality, min/max/mean, etc). For more information, see About data profiling (https://cloud.google.com/dataplex/docs/data-profiling-overview). Data discovery: scans data in Cloud Storage buckets to extract and then catalog metadata. For more information, see Discover and catalog Cloud Storage data (https://cloud.google.com/bigquery/docs/automatic-discovery). Data documentation: analyzes the table or dataset metadata and generates insights. For tables, insights include descriptions and sample SQL queries. For datasets, insights include descriptions, schema relationships and sample SQL queries. For more information, see Generate data insights in BigQuery (https://cloud.google.com/bigquery/docs/data-insights).

Properties

createTime ↔ String?
The time when the scan was created.
getter/setter pair
data ↔ GoogleCloudDataplexV1DataSource?
The data source for DataScan.
getter/setter pair
dataDiscoveryResult ↔ GoogleCloudDataplexV1DataDiscoveryResult?
The result of a data discovery scan.
getter/setter pair
dataDiscoverySpec ↔ GoogleCloudDataplexV1DataDiscoverySpec?
Settings for a data discovery scan.
getter/setter pair
dataDocumentationResult ↔ GoogleCloudDataplexV1DataDocumentationResult?
The result of a data documentation scan.
getter/setter pair
dataDocumentationSpec ↔ GoogleCloudDataplexV1DataDocumentationSpec?
Settings for a data documentation scan.
getter/setter pair
dataProfileResult ↔ GoogleCloudDataplexV1DataProfileResult?
The result of a data profile scan.
getter/setter pair
dataProfileSpec ↔ GoogleCloudDataplexV1DataProfileSpec?
Settings for a data profile scan.
getter/setter pair
dataQualityResult ↔ GoogleCloudDataplexV1DataQualityResult?
The result of a data quality scan.
getter/setter pair
dataQualitySpec ↔ GoogleCloudDataplexV1DataQualitySpec?
Settings for a data quality scan.
getter/setter pair
description ↔ String?
Description of the scan.
getter/setter pair
displayName ↔ String?
User friendly display name.
getter/setter pair
executionIdentity ↔ GoogleCloudDataplexV1ExecutionIdentity?
The identity to run the datascan.
getter/setter pair
executionSpec ↔ GoogleCloudDataplexV1DataScanExecutionSpec?
DataScan execution settings.If not specified, the fields in it will use their default values.
getter/setter pair
executionStatus ↔ GoogleCloudDataplexV1DataScanExecutionStatus?
Status of the data scan execution.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
User-defined labels for the scan.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Current state of the DataScan.
getter/setter pair
type ↔ String?
The type of DataScan.
getter/setter pair
uid ↔ String?
System generated globally unique ID for the scan.
getter/setter pair
unstructuredDataProfileResult ↔ GoogleCloudDataplexV1UnstructuredDataProfileResult?
The result of an unstructured data profile scan.
getter/setter pair
unstructuredDataProfileSpec ↔ GoogleCloudDataplexV1UnstructuredDataProfileSpec?
Settings for an unstructured data profile scan.
getter/setter pair
updateTime ↔ String?
The time when the scan was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited