executionIdentity property
The identity to run the datascan.
If not specified, defaults to the Dataplex Service Agent.
Optional. Immutable.
Implementation
GoogleCloudDataplexV1ExecutionIdentity? executionIdentity;
The identity to run the datascan.
If not specified, defaults to the Dataplex Service Agent.
Optional. Immutable.
GoogleCloudDataplexV1ExecutionIdentity? executionIdentity;