GoogleCloudDataplexV1DataScanJob class

A DataScanJob represents an instance of DataScan execution.

Constructors

GoogleCloudDataplexV1DataScanJob({String? createTime, GoogleCloudDataplexV1DataDiscoveryResult? dataDiscoveryResult, GoogleCloudDataplexV1DataDiscoverySpec? dataDiscoverySpec, GoogleCloudDataplexV1DataDocumentationResult? dataDocumentationResult, GoogleCloudDataplexV1DataDocumentationSpec? dataDocumentationSpec, GoogleCloudDataplexV1DataProfileResult? dataProfileResult, GoogleCloudDataplexV1DataProfileSpec? dataProfileSpec, GoogleCloudDataplexV1DataQualityResult? dataQualityResult, GoogleCloudDataplexV1DataQualitySpec? dataQualitySpec, String? endTime, String? message, String? name, String? partialFailureMessage, String? startTime, String? state, String? type, String? uid, GoogleCloudDataplexV1UnstructuredDataProfileResult? unstructuredDataProfileResult, GoogleCloudDataplexV1UnstructuredDataProfileSpec? unstructuredDataProfileSpec})
GoogleCloudDataplexV1DataScanJob.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the DataScanJob was created.
getter/setter pair
dataDiscoveryResult ↔ GoogleCloudDataplexV1DataDiscoveryResult?
The result of a data discovery scan.
getter/setter pair
dataDiscoverySpec ↔ GoogleCloudDataplexV1DataDiscoverySpec?
Settings for a data discovery scan.
getter/setter pair
dataDocumentationResult ↔ GoogleCloudDataplexV1DataDocumentationResult?
The result of a data documentation scan.
getter/setter pair
dataDocumentationSpec ↔ GoogleCloudDataplexV1DataDocumentationSpec?
Settings for a data documentation scan.
getter/setter pair
dataProfileResult ↔ GoogleCloudDataplexV1DataProfileResult?
The result of a data profile scan.
getter/setter pair
dataProfileSpec ↔ GoogleCloudDataplexV1DataProfileSpec?
Settings for a data profile scan.
getter/setter pair
dataQualityResult ↔ GoogleCloudDataplexV1DataQualityResult?
The result of a data quality scan.
getter/setter pair
dataQualitySpec ↔ GoogleCloudDataplexV1DataQualitySpec?
Settings for a data quality scan.
getter/setter pair
endTime ↔ String?
The time when the DataScanJob ended.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
Additional information about the current state.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
partialFailureMessage ↔ String?
A message indicating partial failure details.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time when the DataScanJob was started.
getter/setter pair
state ↔ String?
Execution state for the DataScanJob.
getter/setter pair
type ↔ String?
The type of the parent DataScan.
getter/setter pair
uid ↔ String?
System generated globally unique ID for the DataScanJob.
getter/setter pair
unstructuredDataProfileResult ↔ GoogleCloudDataplexV1UnstructuredDataProfileResult?
The result of an unstructured data profile scan.
getter/setter pair
unstructuredDataProfileSpec ↔ GoogleCloudDataplexV1UnstructuredDataProfileSpec?
Settings for an unstructured data profile scan.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited