GoogleCloudDataplexV1EncryptionConfigFailureDetails class

Details of the failure if anything related to Cmek db fails.

Properties

errorCode ↔ String?
The error code for the failure.
getter/setter pair
errorMessage ↔ String?
The error message will be shown to the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited