GoogleCloudDataplexV1EntryGroup class

An Entry Group represents a logical grouping of one or more Entries.

Constructors

GoogleCloudDataplexV1EntryGroup({String? createTime, String? description, String? displayName, String? etag, Map<String, String>? labels, String? name, String? transferStatus, String? uid, String? updateTime})
GoogleCloudDataplexV1EntryGroup.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the EntryGroup was created.
getter/setter pair
description ↔ String?
Description of the EntryGroup.
getter/setter pair
displayName ↔ String?
User friendly display name.
getter/setter pair
etag ↔ String?
This checksum is computed by the service, and might be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
User-defined labels for the EntryGroup.
getter/setter pair
name ↔ String?
The relative resource name of the EntryGroup, in the format projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferStatus ↔ String?
Denotes the transfer status of the Entry Group.
getter/setter pair
uid ↔ String?
System generated globally unique ID for the EntryGroup.
getter/setter pair
updateTime ↔ String?
The time when the EntryGroup was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited