GoogleCloudDataplexV1EntryLinkEntryReference class

Reference to the Entry that is linked through the Entry Link.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The relative resource name of the referenced Entry, of the form: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}
getter/setter pair
path ↔ String?
The path in the Entry that is referenced in the Entry Link.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The reference type of the Entry.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited