GoogleCloudDataplexV1EntrySource class

Information related to the source system of the data resource that is represented by the entry.

Constructors

GoogleCloudDataplexV1EntrySource({List<GoogleCloudDataplexV1EntrySourceAncestor>? ancestors, String? createTime, String? description, String? displayName, Map<String, String>? labels, String? location, String? platform, String? resource, String? system, String? updateTime})
GoogleCloudDataplexV1EntrySource.fromJson(Map json_)

Properties

ancestors ↔ List<GoogleCloudDataplexV1EntrySourceAncestor>?
The entries representing the ancestors of the data resource in the source system.
getter/setter pair
createTime ↔ String?
The time when the resource was created in the source system.
getter/setter pair
description ↔ String?
A description of the data resource.
getter/setter pair
displayName ↔ String?
A user-friendly display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
User-defined labels.
getter/setter pair
location ↔ String?
Location of the resource in the source system.
getter/setter pair
platform ↔ String?
The platform containing the source system.
getter/setter pair
resource ↔ String?
The name of the resource in the source system.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
system ↔ String?
The name of the source system.
getter/setter pair
updateTime ↔ String?
The time when the resource was last updated in the source system.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited