GoogleCloudDataplexV1GraphProfileFieldExtractionHints class

Extraction hints (field-level).

Properties

hashCode → int
The hash code for this object.
no setterinherited
normalization ↔ String?
Standardizes extracted data (e.g., to ISO 3166-1 alpha-2).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
synthesis ↔ String?
Generates value from other data instead of direct extraction (e.g., hashing).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited