cardinality property
Expected occurrence frequency of this node type within a document.
Format: "Bounds - Description" Example: "0:N - A document may contain multiple people names."
Output only.
Implementation
core.String? cardinality;
Expected occurrence frequency of this node type within a document.
Format: "Bounds - Description" Example: "0:N - A document may contain multiple people names."
Output only.
core.String? cardinality;