GoogleCloudDataplexV1ListMetadataFeedsResponse class
Response message for ListMetadataFeeds.
Constructors
-
GoogleCloudDataplexV1ListMetadataFeedsResponse({List<
GoogleCloudDataplexV1MetadataFeed> ? metadataFeeds, String? nextPageToken, List<String> ? unreachable}) - GoogleCloudDataplexV1ListMetadataFeedsResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadataFeeds
↔ List<
GoogleCloudDataplexV1MetadataFeed> ? -
List of metadata feeds under the specified parent location.
getter/setter pair
- nextPageToken ↔ String?
-
A token to retrieve the next page of results.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
unreachable
↔ List<
String> ? -
Unordered list.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited