GoogleCloudDataplexV1LookupContextRequest class

Lookup Context using permissions in the source system.

Properties

hashCode int
The hash code for this object.
no setterinherited
options Map<String, String>?
Allows to configure the context.Supported options: format - The format of the context (one of yaml, xml, json, default is yaml).
getter/setter pair
resources List<String>?
The entry names to look up the context for.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited