GoogleCloudDataplexV1MetadataJobExportJobSpec class

Job specification for a metadata export job.

Properties

hashCode → int
The hash code for this object.
no setterinherited
outputPath ↔ String?
The root path of the Cloud Storage bucket to export the metadata to, in the format gs://{bucket}/.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ GoogleCloudDataplexV1MetadataJobExportJobSpecExportJobScope?
The scope of the export job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited