GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope class

A boundary on the scope of impact that the metadata import job can have.

Constructors

GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope({List<String>? aspectTypes, List<String>? entryGroups, List<String>? entryLinkTypes, List<String>? entryTypes, List<String>? glossaries, List<String>? referencedEntryScopes})
GoogleCloudDataplexV1MetadataJobImportJobSpecImportJobScope.fromJson(Map json_)

Properties

aspectTypes ↔ List<String>?
The aspect types that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/aspectTypes/{aspect_type_id}.
getter/setter pair
entryGroups ↔ List<String>?
The entry groups that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/entryGroups/{entry_group_id}.
getter/setter pair
entryLinkTypes ↔ List<String>?
The entry link types that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/entryLinkTypes/{entry_link_type_id}.
getter/setter pair
entryTypes ↔ List<String>?
The entry types that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/entryTypes/{entry_type_id}.
getter/setter pair
glossaries ↔ List<String>?
The glossaries that are in scope for the import job, specified as relative resource names in the format projects/{project_number_or_id}/locations/{location_id}/glossaries/{glossary_id}.While importing Business Glossary entries, the user must provide glossaries.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
referencedEntryScopes ↔ List<String>?
Defines the scope of entries that can be referenced in the entry links.Currently, projects are supported as valid scopes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited