deleteMissingAspects property
If set to true, any aspects not specified in the request will be deleted.
The default is false.
Optional.
Implementation
core.bool? deleteMissingAspects;
If set to true, any aspects not specified in the request will be deleted.
The default is false.
Optional.
core.bool? deleteMissingAspects;