GoogleCloudDataplexV1RequestDataProductAccessRequest class

Message for requesting access to a Data Product.

Properties

changeRequest GoogleCloudDataplexV1ChangeRequest?
The change request for the data product access request.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validateOnly bool?
Validates the request without actually creating the access change request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited