GoogleCloudDataplexV1StorageFormat class

Describes the format of the data within its storage location.

Properties

compressionFormat ↔ String?
The compression type associated with the stored data.
getter/setter pair
csv ↔ GoogleCloudDataplexV1StorageFormatCsvOptions?
Additional information about CSV formatted data.
getter/setter pair
format ↔ String?
The data format associated with the stored data, which represents content type values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iceberg ↔ GoogleCloudDataplexV1StorageFormatIcebergOptions?
Additional information about iceberg tables.
getter/setter pair
json ↔ GoogleCloudDataplexV1StorageFormatJsonOptions?
Additional information about CSV formatted data.
getter/setter pair
mimeType ↔ String?
The mime type descriptor for the data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited