GoogleCloudDataplexV1Task class

A task represents a user-visible job.

Properties

createTime ↔ String?
The time when the task was created.
getter/setter pair
description ↔ String?
Description of the task.
getter/setter pair
displayName ↔ String?
User friendly display name.
getter/setter pair
executionSpec ↔ GoogleCloudDataplexV1TaskExecutionSpec?
Spec related to how a task is executed.
getter/setter pair
executionStatus ↔ GoogleCloudDataplexV1TaskExecutionStatus?
Status of the latest task executions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
User-defined labels for the task.
getter/setter pair
name ↔ String?
The relative resource name of the task, of the form: projects/{project_number}/locations/{location_id}/lakes/{lake_id}/ tasks/{task_id}.
getter/setter pair
notebook ↔ GoogleCloudDataplexV1TaskNotebookTaskConfig?
Config related to running scheduled Notebooks.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spark ↔ GoogleCloudDataplexV1TaskSparkTaskConfig?
Config related to running custom Spark tasks.
getter/setter pair
state ↔ String?
Current state of the task.
getter/setter pair
triggerSpec ↔ GoogleCloudDataplexV1TaskTriggerSpec?
Spec related to how often and when a task should be triggered.
getter/setter pair
uid ↔ String?
System generated globally unique ID for the task.
getter/setter pair
updateTime ↔ String?
The time when the task was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited