GoogleCloudDataplexV1TaskInfrastructureSpecVpcNetwork class

Cloud VPC Network used to run the infrastructure.

Properties

hashCode → int
The hash code for this object.
no setterinherited
network ↔ String?
The Cloud VPC network in which the job is run.
getter/setter pair
networkTags ↔ List<String>?
List of network tags to apply to the job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subNetwork ↔ String?
The Cloud VPC sub-network in which the job is run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited