GoogleCloudDataplexV1TaskTriggerSpec class

Task scheduling and trigger settings.

Constructors

GoogleCloudDataplexV1TaskTriggerSpec({bool? disabled, int? maxRetries, String? schedule, String? startTime, String? type})
GoogleCloudDataplexV1TaskTriggerSpec.fromJson(Map json_)

Properties

disabled ↔ bool?
Prevent the task from executing.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxRetries ↔ int?
Number of retry attempts before aborting.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule ↔ String?
Cron schedule (https://en.wikipedia.org/wiki/Cron) for running tasks periodically.
getter/setter pair
startTime ↔ String?
The first run of the task will be after this time.
getter/setter pair
type ↔ String?
Trigger type of the user-specified Task.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited