customizedPrompt property

String? customizedPrompt
getter/setter pair

Customized prompt for unstructured data profile.

The field will be used as part of the prompt, could be some instruction, specifying skill, or specific area to focus.

Optional.

Implementation

core.String? customizedPrompt;