GoogleCloudDataplexV1UpdateEntryRequest class

Update Entry request.

Constructors

GoogleCloudDataplexV1UpdateEntryRequest({bool? allowMissing, List<String>? aspectKeys, bool? deleteMissingAspects, GoogleCloudDataplexV1Entry? entry, String? updateMask})
GoogleCloudDataplexV1UpdateEntryRequest.fromJson(Map json_)

Properties

allowMissing bool?
If set to true and the entry doesn't exist, the service will create it.
getter/setter pair
aspectKeys List<String>?
The map keys of the Aspects which the service should modify.
getter/setter pair
deleteMissingAspects bool?
If set to true and the aspect_keys specify aspect ranges, the service deletes any existing aspects from that range that weren't provided in the request.
getter/setter pair
entry GoogleCloudDataplexV1Entry?
Entry resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateMask String?
Mask of fields to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited