deleteMissingAspects property
If set to true and the aspect_keys specify aspect ranges, the service deletes any existing aspects from that range that weren't provided in the request.
Optional.
Implementation
core.bool? deleteMissingAspects;
If set to true and the aspect_keys specify aspect ranges, the service deletes any existing aspects from that range that weren't provided in the request.
Optional.
core.bool? deleteMissingAspects;