ProjectsLocationsChangeRequestsResource class

Constructors

ProjectsLocationsChangeRequestsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

approve(GoogleCloudDataplexV1ApproveChangeRequestRequest request, String name, {String? $fields}) Future<GoogleCloudDataplexV1ChangeRequest>
Approves a ChangeRequest.
delete(String name, {String? etag, String? $fields}) Future<Empty>
Deletes a ChangeRequest.Behavior depends on the caller's permissions and the resource's state: 1.
get(String name, {String? $fields}) Future<GoogleCloudDataplexV1ChangeRequest>
Gets a ChangeRequest.
getIamPolicy(String resource, {int? options_requestedPolicyVersion, String? $fields}) Future<GoogleIamV1Policy>
Gets the access control policy for a resource.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<GoogleCloudDataplexV1ListChangeRequestsResponse>
Lists ChangeRequests.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleCloudDataplexV1ChangeRequest request, String name, {String? updateMask, String? $fields}) Future<GoogleCloudDataplexV1ChangeRequest>
Updates a ChangeRequest.
reject(GoogleCloudDataplexV1RejectChangeRequestRequest request, String name, {String? $fields}) Future<GoogleCloudDataplexV1ChangeRequest>
Rejects a ChangeRequest.
setIamPolicy(GoogleIamV1SetIamPolicyRequest request, String resource, {String? $fields}) Future<GoogleIamV1Policy>
Sets the access control policy on the specified resource.
testIamPermissions(GoogleIamV1TestIamPermissionsRequest request, String resource, {String? $fields}) Future<GoogleIamV1TestIamPermissionsResponse>
Returns permissions that a caller has on the specified resource.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited