create method
- GoogleCloudDataplexV1DataDomain request,
- String parent, {
- String? dataDomainId,
- bool? validateOnly,
- String? $fields,
Creates a DataDomain resource.
request - The metadata request object.
Request parameters:
parent - Required. The resource name of the parent location:
projects/{project_id_or_number}/locations/{location_id}
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
dataDomainId - Required. DataDomain identifier. * Must contain only
lowercase letters, numbers and hyphens. * Must start with a letter. * Must
be between 1-63 characters. * Must end with a number or a letter. * Must
be unique within the project and location.
validateOnly - Optional. Only validate the request, but do not perform
mutations.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleLongrunningOperation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleLongrunningOperation> create(
GoogleCloudDataplexV1DataDomain request,
core.String parent, {
core.String? dataDomainId,
core.bool? validateOnly,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'dataDomainId': ?dataDomainId == null ? null : [dataDomainId],
'validateOnly': ?validateOnly == null ? null : ['${validateOnly}'],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/dataDomains';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleLongrunningOperation.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}