requestAccess method

Requests access to a data product.

This will trigger an access approval workflow, and the requester will need to wait for the approval to be granted before they will be able to access the data product assets.

request - The metadata request object.

Request parameters:

parent - Required. The resource name of the data product. Format: projects/{project_number}/locations/{location_id}/dataProducts/{data_product_id} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/dataProducts/\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleCloudDataplexV1RequestDataProductAccessResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleCloudDataplexV1RequestDataProductAccessResponse>
requestAccess(
  GoogleCloudDataplexV1RequestDataProductAccessRequest request,
  core.String parent, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$parent') + ':requestAccess';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return GoogleCloudDataplexV1RequestDataProductAccessResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}