ProjectsLocationsDataScansJobsResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(GoogleCloudDataplexV1CancelDataScanJobRequest request, String name, {String? $fields})
→ Future<Empty>
-
Cancels a running/pending DataScan job.
-
generateDataQualityRules(GoogleCloudDataplexV1GenerateDataQualityRulesRequest request, String name, {String? $fields})
→ Future<GoogleCloudDataplexV1GenerateDataQualityRulesResponse>
-
Generates recommended data quality rules based on the results of a data
profiling scan.Use the recommendations to build rules for a data quality
scan.
-
get(String name, {String? view, String? $fields})
→ Future<GoogleCloudDataplexV1DataScanJob>
-
Gets a DataScanJob resource.
-
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields})
→ Future<GoogleCloudDataplexV1ListDataScanJobsResponse>
-
Lists DataScanJobs under the given DataScan.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited