ProjectsLocationsEntryGroupsEntryLinksResource class

Constructors

ProjectsLocationsEntryGroupsEntryLinksResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(GoogleCloudDataplexV1EntryLink request, String parent, {String? entryLinkId, String? $fields}) Future<GoogleCloudDataplexV1EntryLink>
Creates an Entry Link.
delete(String name, {String? $fields}) Future<GoogleCloudDataplexV1EntryLink>
Deletes an Entry Link.
get(String name, {String? $fields}) Future<GoogleCloudDataplexV1EntryLink>
Gets an Entry Link.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleCloudDataplexV1EntryLink request, String name, {bool? allowMissing, List<String>? aspectKeys, String? $fields}) Future<GoogleCloudDataplexV1EntryLink>
Updates an Entry Link.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited