patch method

Future<GoogleCloudDataplexV1EntryLink> patch(
  1. GoogleCloudDataplexV1EntryLink request,
  2. String name, {
  3. bool? allowMissing,
  4. List<String>? aspectKeys,
  5. String? $fields,
})

Updates an Entry Link.

request - The metadata request object.

Request parameters:

name - Output only. Immutable. Identifier. The relative resource name of the Entry Link, of the form: projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entryLinks/{entry_link_id} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/entryGroups/\[^/\]+/entryLinks/.*$.

allowMissing - Optional. If set to true and the entry link doesn't exist, the service will create it.

aspectKeys - Optional. The map keys of the Aspects which the service should modify. It should be the aspect type reference in the format {project_id_or_number}.{location_id}.{aspect_type_id}.If this field is left empty, the service treats it as specifying exactly those Aspects present in the request.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleCloudDataplexV1EntryLink.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleCloudDataplexV1EntryLink> patch(
  GoogleCloudDataplexV1EntryLink request,
  core.String name, {
  core.bool? allowMissing,
  core.List<core.String>? aspectKeys,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'allowMissing': ?allowMissing == null ? null : ['${allowMissing}'],
    'aspectKeys': ?aspectKeys,
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'PATCH',
    body: body_,
    queryParams: queryParams_,
  );
  return GoogleCloudDataplexV1EntryLink.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}