lookupEntry method

Future<GoogleCloudDataplexV1Entry> lookupEntry(
  1. String name, {
  2. List<String>? aspectTypes_1,
  3. String? entry,
  4. List<String>? paths,
  5. String? view,
  6. String? $fields,
})

Looks up an entry by name using the permission on the source system.

Request parameters:

name - Required. The project to which the request should be attributed in the following form: projects/{project}/locations/{location}. Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.

aspectTypes_1 - Optional. Limits the aspects returned to the provided aspect types. It only works for CUSTOM view.

entry - Required. The resource name of the Entry: projects/{project}/locations/{location}/entryGroups/{entry_group}/entries/{entry}.

paths - Optional. Limits the aspects returned to those associated with the provided paths within the Entry. It only works for CUSTOM view.

view - Optional. View to control which parts of an entry the service should return. Please check the limitations on returned aspects in the Entry view documentation. Amount of returned aspects depends on the selected Entry View. Possible string values are:

  • "ENTRY_VIEW_UNSPECIFIED" : Unspecified EntryView. Defaults to FULL.
  • "BASIC" : Returns entry only, without aspects.
  • "FULL" : Returns all required aspects as well as the keys of all non-required aspects.
  • "CUSTOM" : Returns aspects matching custom fields in GetEntryRequest. If the number of aspects exceeds 100, the first 100 will be returned.
  • "ALL" : Returns all aspects. If the number of aspects exceeds 100, the first 100 will be returned.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleCloudDataplexV1Entry.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleCloudDataplexV1Entry> lookupEntry(
  core.String name, {
  core.List<core.String>? aspectTypes_1,
  core.String? entry,
  core.List<core.String>? paths,
  core.String? view,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'aspectTypes': ?aspectTypes_1,
    'entry': ?entry == null ? null : [entry],
    'paths': ?paths,
    'view': ?view == null ? null : [view],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':lookupEntry';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return GoogleCloudDataplexV1Entry.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}