modifyEntry method
Future<GoogleCloudDataplexV1Entry>
modifyEntry(
- GoogleCloudDataplexV1ModifyEntryRequest request,
- String name, {
- String? $fields,
Modifies an entry using the permission on the source system.
request - The metadata request object.
Request parameters:
name - Required. The project to which the request should be attributed
in the following form: projects/{project}/locations/{location}.
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudDataplexV1Entry.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleCloudDataplexV1Entry> modifyEntry(
GoogleCloudDataplexV1ModifyEntryRequest request,
core.String name, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':modifyEntry';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleCloudDataplexV1Entry.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}