AccessSessionSparkApplicationStageRddOperationGraphResponse class

RDD operation graph for a Spark Application Stage limited to maximum 10000 clusters.

Properties

hashCode → int
The hash code for this object.
no setterinherited
rddOperationGraph ↔ RddOperationGraph?
RDD operation graph for a Spark Application Stage.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited