ApplicationAttemptInfo class

Specific attempt of an application.

Constructors

ApplicationAttemptInfo({String? appSparkVersion, String? attemptId, bool? completed, String? durationMillis, String? endTime, String? lastUpdated, String? sparkUser, String? startTime})
ApplicationAttemptInfo.fromJson(Map json_)

Properties

appSparkVersion ↔ String?
getter/setter pair
attemptId ↔ String?
getter/setter pair
completed ↔ bool?
getter/setter pair
durationMillis ↔ String?
getter/setter pair
endTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdated ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkUser ↔ String?
getter/setter pair
startTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited