ApplicationEnvironmentInfo class

Details about the Environment that the application is running in.

Constructors

ApplicationEnvironmentInfo({Map<String, String>? classpathEntries, Map<String, String>? hadoopProperties, Map<String, String>? metricsProperties, List<ResourceProfileInfo>? resourceProfiles, SparkRuntimeInfo? runtime, Map<String, String>? sparkProperties, Map<String, String>? systemProperties})
ApplicationEnvironmentInfo.fromJson(Map json_)

Properties

classpathEntries ↔ Map<String, String>?
getter/setter pair
hadoopProperties ↔ Map<String, String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metricsProperties ↔ Map<String, String>?
getter/setter pair
resourceProfiles ↔ List<ResourceProfileInfo>?
getter/setter pair
runtime ↔ SparkRuntimeInfo?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkProperties ↔ Map<String, String>?
getter/setter pair
systemProperties ↔ Map<String, String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited