ApplicationInfo class

High level information corresponding to an application.

Constructors

ApplicationInfo({String? applicationContextIngestionStatus, String? applicationId, List<ApplicationAttemptInfo>? attempts, int? coresGranted, int? coresPerExecutor, int? maxCores, int? memoryPerExecutorMb, String? name, String? quantileDataStatus})
ApplicationInfo.fromJson(Map json_)

Properties

applicationContextIngestionStatus ↔ String?
Possible string values are:
getter/setter pair
applicationId ↔ String?
getter/setter pair
attempts ↔ List<ApplicationAttemptInfo>?
getter/setter pair
coresGranted ↔ int?
getter/setter pair
coresPerExecutor ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxCores ↔ int?
getter/setter pair
memoryPerExecutorMb ↔ int?
getter/setter pair
name ↔ String?
getter/setter pair
quantileDataStatus ↔ String?
Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited