AttachedDiskConfig class

Specifies the config of attached disk options for single VM instance.

Constructors

AttachedDiskConfig({int? diskSizeGb, String? diskType, String? provisionedIops, String? provisionedThroughput})
AttachedDiskConfig.fromJson(Map json_)

Properties

diskSizeGb ↔ int?
Disk size in GB.
getter/setter pair
diskType ↔ String?
Disk type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
provisionedIops ↔ String?
Indicates how many IOPS to provision for the attached disk.
getter/setter pair
provisionedThroughput ↔ String?
Indicates how much throughput to provision for the attached disk.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited