provisionedThroughput property

String? provisionedThroughput
getter/setter pair

Indicates how much throughput to provision for the attached disk.

This sets the number of throughput mb per second that the disk can handle. See https://cloud.google.com/compute/docs/disks/hyperdisks#hyperdisk-features

Optional.

Implementation

core.String? provisionedThroughput;