AutoscalingConfig class

Autoscaling Policy config associated with the cluster.

Constructors

AutoscalingConfig({String? policyUri})
AutoscalingConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
policyUri ↔ String?
The autoscaling policy used by the cluster.Only resource names including projectid and location (region) are valid.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited