AuxiliaryNodeGroup class

Node group identification and configuration information.

Constructors

AuxiliaryNodeGroup({NodeGroup? nodeGroup, String? nodeGroupId})
AuxiliaryNodeGroup.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodeGroup ↔ NodeGroup?
Node group configuration.
getter/setter pair
nodeGroupId ↔ String?
A node group ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited