AuxiliaryServicesConfig class

Auxiliary services configuration for a Cluster.

Constructors

AuxiliaryServicesConfig({MetastoreConfig? metastoreConfig, SparkHistoryServerConfig? sparkHistoryServerConfig})
AuxiliaryServicesConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metastoreConfig ↔ MetastoreConfig?
The Hive Metastore configuration for this workload.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkHistoryServerConfig ↔ SparkHistoryServerConfig?
The Spark History Server configuration for the workload.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited