BasicYarnAutoscalingConfig class

Basic autoscaling configurations for YARN.

Constructors

BasicYarnAutoscalingConfig({String? gracefulDecommissionTimeout, double? scaleDownFactor, double? scaleDownMinWorkerFraction, double? scaleUpFactor, double? scaleUpMinWorkerFraction})
BasicYarnAutoscalingConfig.fromJson(Map json_)

Properties

gracefulDecommissionTimeout ↔ String?
Timeout for YARN graceful decommissioning of Node Managers.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleDownFactor ↔ double?
Fraction of average YARN pending memory in the last cooldown period for which to remove workers.
getter/setter pair
scaleDownMinWorkerFraction ↔ double?
Minimum scale-down threshold as a fraction of total cluster size before scaling occurs.
getter/setter pair
scaleUpFactor ↔ double?
Fraction of average YARN pending memory in the last cooldown period for which to add workers.
getter/setter pair
scaleUpMinWorkerFraction ↔ double?
Minimum scale-up threshold as a fraction of total cluster size before scaling occurs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited