config property

ClusterConfig? config
getter/setter pair

The cluster config for a cluster of Compute Engine Instances.

Note that the service may set default values, and values may change when clusters are updated.Exactly one of ClusterConfig or VirtualClusterConfig must be specified.

Optional.

Implementation

ClusterConfig? config;