ClusterConfig class

The cluster config.

Constructors

ClusterConfig({AutoscalingConfig? autoscalingConfig, List<AuxiliaryNodeGroup>? auxiliaryNodeGroups, String? clusterTier, String? clusterType, String? configBucket, DataprocMetricConfig? dataprocMetricConfig, String? diagnosticBucket, EncryptionConfig? encryptionConfig, EndpointConfig? endpointConfig, GceClusterConfig? gceClusterConfig, GkeClusterConfig? gkeClusterConfig, List<NodeInitializationAction>? initializationActions, LifecycleConfig? lifecycleConfig, InstanceGroupConfig? masterConfig, MetastoreConfig? metastoreConfig, InstanceGroupConfig? secondaryWorkerConfig, SecurityConfig? securityConfig, SoftwareConfig? softwareConfig, String? tempBucket, InstanceGroupConfig? workerConfig})
ClusterConfig.fromJson(Map json_)

Properties

autoscalingConfig ↔ AutoscalingConfig?
Autoscaling config for the policy associated with the cluster.
getter/setter pair
auxiliaryNodeGroups ↔ List<AuxiliaryNodeGroup>?
The node group settings.
getter/setter pair
clusterTier ↔ String?
The cluster tier.
getter/setter pair
clusterType ↔ String?
The type of the cluster.
getter/setter pair
configBucket ↔ String?
A Cloud Storage bucket used to stage job dependencies, config files, and job driver console output.
getter/setter pair
dataprocMetricConfig ↔ DataprocMetricConfig?
The config for Dataproc metrics.
getter/setter pair
diagnosticBucket ↔ String?
A Cloud Storage bucket used to collect checkpoint diagnostic data (https://cloud.google.com/dataproc/docs/support/diagnose-clusters#checkpoint_diagnostic_data).
getter/setter pair
encryptionConfig ↔ EncryptionConfig?
Encryption settings for the cluster.
getter/setter pair
endpointConfig ↔ EndpointConfig?
Port/endpoint configuration for this cluster
getter/setter pair
gceClusterConfig ↔ GceClusterConfig?
The shared Compute Engine config settings for all instances in a cluster.
getter/setter pair
gkeClusterConfig ↔ GkeClusterConfig?
BETA.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initializationActions ↔ List<NodeInitializationAction>?
Commands to execute on each node after config is completed.
getter/setter pair
lifecycleConfig ↔ LifecycleConfig?
Lifecycle setting for the cluster.
getter/setter pair
masterConfig ↔ InstanceGroupConfig?
The Compute Engine config settings for the cluster's master instance.
getter/setter pair
metastoreConfig ↔ MetastoreConfig?
Metastore configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryWorkerConfig ↔ InstanceGroupConfig?
The Compute Engine config settings for a cluster's secondary worker instances
getter/setter pair
securityConfig ↔ SecurityConfig?
Security settings for the cluster.
getter/setter pair
softwareConfig ↔ SoftwareConfig?
The config settings for cluster software.
getter/setter pair
tempBucket ↔ String?
A Cloud Storage bucket used to store ephemeral cluster and jobs data, such as Spark and MapReduce history files.
getter/setter pair
workerConfig ↔ InstanceGroupConfig?
The Compute Engine config settings for the cluster's worker instances.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited