ClusterSelector class

A selector that chooses target cluster for jobs based on metadata.

Constructors

ClusterSelector({Map<String, String>? clusterLabels, String? zone})
ClusterSelector.fromJson(Map json_)

Properties

clusterLabels ↔ Map<String, String>?
The cluster labels.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zone ↔ String?
The zone where workflow process executes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited