ConsolidatedExecutorSummary class

Consolidated summary about executors used by the application.

Constructors

ConsolidatedExecutorSummary({int? activeTasks, int? completedTasks, int? count, String? diskUsed, int? failedTasks, int? isExcluded, String? maxMemory, MemoryMetrics? memoryMetrics, String? memoryUsed, int? rddBlocks, int? totalCores, String? totalDurationMillis, String? totalGcTimeMillis, String? totalInputBytes, String? totalShuffleRead, String? totalShuffleWrite, int? totalTasks})
ConsolidatedExecutorSummary.fromJson(Map json_)

Properties

activeTasks ↔ int?
getter/setter pair
completedTasks ↔ int?
getter/setter pair
count ↔ int?
getter/setter pair
diskUsed ↔ String?
getter/setter pair
failedTasks ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isExcluded ↔ int?
getter/setter pair
maxMemory ↔ String?
getter/setter pair
memoryMetrics ↔ MemoryMetrics?
getter/setter pair
memoryUsed ↔ String?
getter/setter pair
rddBlocks ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCores ↔ int?
getter/setter pair
totalDurationMillis ↔ String?
getter/setter pair
totalGcTimeMillis ↔ String?
getter/setter pair
totalInputBytes ↔ String?
getter/setter pair
totalShuffleRead ↔ String?
getter/setter pair
totalShuffleWrite ↔ String?
getter/setter pair
totalTasks ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited