DiskConfig class

Specifies the config of boot disk and attached disk options for a group of VM instances.

Constructors

DiskConfig({String? bootDiskProvisionedIops, String? bootDiskProvisionedThroughput, int? bootDiskSizeGb, String? bootDiskType, String? localSsdInterface, int? numLocalSsds})
DiskConfig.fromJson(Map json_)

Properties

bootDiskProvisionedIops ↔ String?
Indicates how many IOPS to provision for the disk.
getter/setter pair
bootDiskProvisionedThroughput ↔ String?
Indicates how much throughput to provision for the disk.
getter/setter pair
bootDiskSizeGb ↔ int?
Size in GB of the boot disk (default is 500GB).
getter/setter pair
bootDiskType ↔ String?
Type of the boot disk (default is "pd-standard").
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localSsdInterface ↔ String?
Interface type of local SSDs (default is "scsi").
getter/setter pair
numLocalSsds ↔ int?
Number of attached SSDs, from 0 to 8 (default is 0).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited