attachedDiskConfigs property
A list of attached disk configs for a group of VM instances.
Optional.
Implementation
core.List<AttachedDiskConfig>? attachedDiskConfigs;
A list of attached disk configs for a group of VM instances.
Optional.
core.List<AttachedDiskConfig>? attachedDiskConfigs;