EncryptionConfig class

Encryption settings for the cluster.

Constructors

EncryptionConfig({String? gcePdKmsKeyName, String? kmsKey})
EncryptionConfig.fromJson(Map json_)

Properties

gcePdKmsKeyName ↔ String?
The Cloud KMS key resource name to use for persistent disk encryption for all instances in the cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKey ↔ String?
The Cloud KMS key resource name to use for cluster persistent disk and job argument encryption.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited