EnvironmentConfig class

Environment configuration for a workload.

Constructors

EnvironmentConfig({ExecutionConfig? executionConfig, PeripheralsConfig? peripheralsConfig})
EnvironmentConfig.fromJson(Map json_)

Properties

executionConfig ↔ ExecutionConfig?
Execution configuration for a workload.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
peripheralsConfig ↔ PeripheralsConfig?
Peripherals configuration that workload has access to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited