ExecutionConfig class

Execution configuration for a workload.

Constructors

ExecutionConfig({AuthenticationConfig? authenticationConfig, String? idleTtl, String? kmsKey, List<String>? networkTags, String? networkUri, Map<String, String>? resourceManagerTags, String? serviceAccount, String? stagingBucket, String? subnetworkUri, String? ttl})
ExecutionConfig.fromJson(Map json_)

Properties

authenticationConfig ↔ AuthenticationConfig?
Authentication configuration used to set the default identity for the workload execution.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idleTtl ↔ String?
Applies to sessions only.
getter/setter pair
kmsKey ↔ String?
The Cloud KMS key to use for encryption.
getter/setter pair
networkTags ↔ List<String>?
Tags used for network traffic control.
getter/setter pair
networkUri ↔ String?
Network URI to connect workload to.
getter/setter pair
resourceManagerTags ↔ Map<String, String>?
Associates Resource Manager tags with the workload nodes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Service account that used to execute workload.
getter/setter pair
stagingBucket ↔ String?
A Cloud Storage bucket used to stage workload dependencies, config files, and store workload output and other ephemeral data, such as Spark history files.
getter/setter pair
subnetworkUri ↔ String?
Subnetwork URI to connect workload to.
getter/setter pair
ttl ↔ String?
The duration after which the workload will be terminated, specified as the JSON representation for Duration (https://protobuf.dev/programming-guides/proto3/#json).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited