ExecutorResourceRequest class

Resources used per executor used by the application.

Constructors

ExecutorResourceRequest({String? amount, String? discoveryScript, String? resourceName, String? vendor})
ExecutorResourceRequest.fromJson(Map json_)

Properties

amount ↔ String?
getter/setter pair
discoveryScript ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resourceName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vendor ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited