ExecutorStageSummary class

Executor resources consumed by a stage.

Constructors

ExecutorStageSummary({String? diskBytesSpilled, String? executorId, int? failedTasks, String? inputBytes, String? inputRecords, bool? isExcludedForStage, int? killedTasks, String? memoryBytesSpilled, String? outputBytes, String? outputRecords, ExecutorMetrics? peakMemoryMetrics, String? shuffleRead, String? shuffleReadRecords, String? shuffleWrite, String? shuffleWriteRecords, int? stageAttemptId, String? stageId, int? succeededTasks, String? taskTimeMillis})
ExecutorStageSummary.fromJson(Map json_)

Properties

diskBytesSpilled ↔ String?
getter/setter pair
executorId ↔ String?
getter/setter pair
failedTasks ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputBytes ↔ String?
getter/setter pair
inputRecords ↔ String?
getter/setter pair
isExcludedForStage ↔ bool?
getter/setter pair
killedTasks ↔ int?
getter/setter pair
memoryBytesSpilled ↔ String?
getter/setter pair
outputBytes ↔ String?
getter/setter pair
outputRecords ↔ String?
getter/setter pair
peakMemoryMetrics ↔ ExecutorMetrics?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleRead ↔ String?
getter/setter pair
shuffleReadRecords ↔ String?
getter/setter pair
shuffleWrite ↔ String?
getter/setter pair
shuffleWriteRecords ↔ String?
getter/setter pair
stageAttemptId ↔ int?
getter/setter pair
stageId ↔ String?
getter/setter pair
succeededTasks ↔ int?
getter/setter pair
taskTimeMillis ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited