ExecutorSummary class

Details about executors used by the application.

Constructors

ExecutorSummary({int? activeTasks, String? addTime, Map<String, String>? attributes, int? completedTasks, String? diskUsed, List<String>? excludedInStages, String? executorId, Map<String, String>? executorLogs, int? failedTasks, String? hostPort, bool? isActive, bool? isExcluded, String? maxMemory, int? maxTasks, MemoryMetrics? memoryMetrics, String? memoryUsed, ExecutorMetrics? peakMemoryMetrics, int? rddBlocks, String? removeReason, String? removeTime, int? resourceProfileId, Map<String, ResourceInformation>? resources, int? totalCores, String? totalDurationMillis, String? totalGcTimeMillis, String? totalInputBytes, String? totalShuffleRead, String? totalShuffleWrite, int? totalTasks})
ExecutorSummary.fromJson(Map json_)

Properties

activeTasks ↔ int?
getter/setter pair
addTime ↔ String?
getter/setter pair
attributes ↔ Map<String, String>?
getter/setter pair
completedTasks ↔ int?
getter/setter pair
diskUsed ↔ String?
getter/setter pair
excludedInStages ↔ List<String>?
getter/setter pair
executorId ↔ String?
getter/setter pair
executorLogs ↔ Map<String, String>?
getter/setter pair
failedTasks ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostPort ↔ String?
getter/setter pair
isActive ↔ bool?
getter/setter pair
isExcluded ↔ bool?
getter/setter pair
maxMemory ↔ String?
getter/setter pair
maxTasks ↔ int?
getter/setter pair
memoryMetrics ↔ MemoryMetrics?
getter/setter pair
memoryUsed ↔ String?
getter/setter pair
peakMemoryMetrics ↔ ExecutorMetrics?
getter/setter pair
rddBlocks ↔ int?
getter/setter pair
removeReason ↔ String?
getter/setter pair
removeTime ↔ String?
getter/setter pair
resourceProfileId ↔ int?
getter/setter pair
resources ↔ Map<String, ResourceInformation>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalCores ↔ int?
getter/setter pair
totalDurationMillis ↔ String?
getter/setter pair
totalGcTimeMillis ↔ String?
getter/setter pair
totalInputBytes ↔ String?
getter/setter pair
totalShuffleRead ↔ String?
getter/setter pair
totalShuffleWrite ↔ String?
getter/setter pair
totalTasks ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited