GkeClusterConfig class

The cluster's GKE config.

Constructors

GkeClusterConfig({String? gkeClusterTarget, NamespacedGkeDeploymentTarget? namespacedGkeDeploymentTarget, List<GkeNodePoolTarget>? nodePoolTarget})
GkeClusterConfig.fromJson(Map json_)

Properties

gkeClusterTarget ↔ String?
A target GKE cluster to deploy to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
namespacedGkeDeploymentTarget ↔ NamespacedGkeDeploymentTarget?
Use gkeClusterTarget.
getter/setter pair
nodePoolTarget ↔ List<GkeNodePoolTarget>?
GKE node pools where workloads will be scheduled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited