GkeNodeConfig class

Parameters that describe cluster nodes.

Constructors

GkeNodeConfig({List<GkeNodePoolAcceleratorConfig>? accelerators, String? bootDiskKmsKey, int? localSsdCount, String? machineType, String? minCpuPlatform, bool? preemptible, String? serviceAccount, bool? spot})
GkeNodeConfig.fromJson(Map json_)

Properties

accelerators ↔ List<GkeNodePoolAcceleratorConfig>?
A list of hardware accelerators (https://cloud.google.com/compute/docs/gpus) to attach to each node.
getter/setter pair
bootDiskKmsKey ↔ String?
The Customer Managed Encryption Key (CMEK) (https://cloud.google.com/kubernetes-engine/docs/how-to/using-cmek) used to encrypt the boot disk attached to each node in the node pool.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localSsdCount ↔ int?
The number of local SSD disks to attach to the node, which is limited by the maximum number of disks allowable per zone (see Adding Local SSDs (https://cloud.google.com/compute/docs/disks/local-ssd)).
getter/setter pair
machineType ↔ String?
The name of a Compute Engine machine type (https://cloud.google.com/compute/docs/machine-types).
getter/setter pair
minCpuPlatform ↔ String?
Minimum CPU platform (https://cloud.google.com/compute/docs/instances/specify-min-cpu-platform) to be used by this instance.
getter/setter pair
preemptible ↔ bool?
Whether the nodes are created as legacy preemptible VM instances (https://cloud.google.com/compute/docs/instances/preemptible).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Specifies the service account (https://cloud.google.com/dataproc/docs/guides/dpgke/dataproc-gke-iam) to be used by the node pools.
getter/setter pair
spot ↔ bool?
Whether the nodes are created as Spot VM instances (https://cloud.google.com/compute/docs/instances/spot).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited