GkeNodePoolAcceleratorConfig class

A GkeNodeConfigAcceleratorConfig represents a Hardware Accelerator request for a node pool.

Constructors

GkeNodePoolAcceleratorConfig({String? acceleratorCount, String? acceleratorType, String? gpuPartitionSize})
GkeNodePoolAcceleratorConfig.fromJson(Map json_)

Properties

acceleratorCount ↔ String?
The number of accelerator cards exposed to an instance.
getter/setter pair
acceleratorType ↔ String?
The accelerator type resource namename (see GPUs on Compute Engine).
getter/setter pair
gpuPartitionSize ↔ String?
Size of partitions to create on the GPU.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited