GkeNodePoolAutoscalingConfig class

GkeNodePoolAutoscaling contains information the cluster autoscaler needs to adjust the size of the node pool to the current cluster usage.

Constructors

GkeNodePoolAutoscalingConfig({int? maxNodeCount, int? minNodeCount})
GkeNodePoolAutoscalingConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxNodeCount ↔ int?
The maximum number of nodes in the node pool.
getter/setter pair
minNodeCount ↔ int?
The minimum number of nodes in the node pool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited