enableSsh property
Whether to enable SSH access for the cluster.
The default is true for image versions prior to 3.1 and false for image versions 3.1 and later. The default behavior can be changed when creating clusters using image versions 2.3.30 and later.
Optional.
Implementation
core.bool? enableSsh;