InstanceFlexibilityPolicy class

Instance flexibility Policy allowing a mixture of VM shapes and provisioning models.

Constructors

InstanceFlexibilityPolicy({Map<String, String>? instanceMachineTypes, List<InstanceSelection>? instanceSelectionList, List<InstanceSelectionResult>? instanceSelectionResults, ProvisioningModelMix? provisioningModelMix})
InstanceFlexibilityPolicy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceMachineTypes ↔ Map<String, String>?
A map of instance short name to machine type.
getter/setter pair
instanceSelectionList ↔ List<InstanceSelection>?
List of instance selection options that the group will use when creating new VMs.
getter/setter pair
instanceSelectionResults ↔ List<InstanceSelectionResult>?
A list of instance selection results in the group.
getter/setter pair
provisioningModelMix ↔ ProvisioningModelMix?
Defines how the Group selects the provisioning model to ensure required reliability.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited