instanceMachineTypes property

Map<String, String>? instanceMachineTypes
getter/setter pair

A map of instance short name to machine type.

The key is the short name of the Compute Engine instance, and the value is the full machine-type name (e.g., 'n1-standard-16'). See Machine types for more information on valid machine type strings.

Output only.

Implementation

core.Map<core.String, core.String>? instanceMachineTypes;