InstanceGroupConfig class

The config settings for Compute Engine resources in an instance group, such as a master or worker group.

Constructors

InstanceGroupConfig({List<AcceleratorConfig>? accelerators, DiskConfig? diskConfig, String? imageUri, InstanceFlexibilityPolicy? instanceFlexibilityPolicy, List<String>? instanceNames, List<InstanceReference>? instanceReferences, bool? isPreemptible, String? machineTypeUri, ManagedGroupConfig? managedGroupConfig, String? minCpuPlatform, int? minNumInstances, int? numInstances, String? preemptibility, StartupConfig? startupConfig})
InstanceGroupConfig.fromJson(Map json_)

Properties

accelerators ↔ List<AcceleratorConfig>?
The Compute Engine accelerator configuration for these instances.
getter/setter pair
diskConfig ↔ DiskConfig?
Disk option config settings.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageUri ↔ String?
The Compute Engine image resource used for cluster instances.The URI can represent an image or image family.Image examples: https://www.googleapis.com/compute/v1/projects/\[project_id\]/global/images/\[image-id\] projects/[project_id]/global/images/[image-id] image-idImage family examples.
getter/setter pair
instanceFlexibilityPolicy ↔ InstanceFlexibilityPolicy?
Instance flexibility Policy allowing a mixture of VM shapes and provisioning models.
getter/setter pair
instanceNames ↔ List<String>?
The list of instance names.
getter/setter pair
instanceReferences ↔ List<InstanceReference>?
List of references to Compute Engine instances.
getter/setter pair
isPreemptible ↔ bool?
Specifies that this instance group contains preemptible instances.
getter/setter pair
machineTypeUri ↔ String?
The Compute Engine machine type used for cluster instances.A full URL, partial URI, or short name are valid.
getter/setter pair
managedGroupConfig ↔ ManagedGroupConfig?
The config for Compute Engine Instance Group Manager that manages this group.
getter/setter pair
minCpuPlatform ↔ String?
Specifies the minimum cpu platform for the Instance Group.
getter/setter pair
minNumInstances ↔ int?
The minimum number of primary worker instances to create.
getter/setter pair
numInstances ↔ int?
The number of VM instances in the instance group.
getter/setter pair
preemptibility ↔ String?
Specifies the preemptibility of the instance group.The default value for master and worker groups is NON_PREEMPTIBLE.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startupConfig ↔ StartupConfig?
Configuration to handle the startup of instances during cluster create and update process.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited