InstantiateWorkflowTemplateRequest class

A request to instantiate a workflow template.

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameters ↔ Map<String, String>?
Map from parameter names to values that should be used for those parameters.
getter/setter pair
requestId ↔ String?
A tag that prevents multiple concurrent workflow instances with the same tag from running.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ int?
The version of workflow template to instantiate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited