JobPlacement class

Dataproc job config.

Constructors

JobPlacement({Map<String, String>? clusterLabels, String? clusterName, String? clusterUuid})
JobPlacement.fromJson(Map json_)

Properties

clusterLabels ↔ Map<String, String>?
Cluster labels to identify a cluster where the job will be submitted.
getter/setter pair
clusterName ↔ String?
The name of the cluster where the job will be submitted.
getter/setter pair
clusterUuid ↔ String?
A cluster UUID generated by the Dataproc service when the job is submitted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited