JobStatus class

Dataproc job status.

Constructors

JobStatus({String? details, String? state, String? stateStartTime, String? substate})
JobStatus.fromJson(Map json_)

Properties

details ↔ String?
Job state details, such as an error description if the state is ERROR.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
A state message specifying the overall job state.
getter/setter pair
stateStartTime ↔ String?
The time when this state was entered.
getter/setter pair
substate ↔ String?
Additional state information, which includes status reported by the agent.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited