JobsSummary class

Data related to Jobs page summary

Constructors

JobsSummary({int? activeJobs, String? applicationId, List<ApplicationAttemptInfo>? attempts, int? completedJobs, int? failedJobs, String? schedulingMode})
JobsSummary.fromJson(Map json_)

Properties

activeJobs ↔ int?
Number of active jobs
getter/setter pair
applicationId ↔ String?
Spark Application Id
getter/setter pair
attempts ↔ List<ApplicationAttemptInfo>?
Attempts info
getter/setter pair
completedJobs ↔ int?
Number of completed jobs
getter/setter pair
failedJobs ↔ int?
Number of failed jobs
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulingMode ↔ String?
Spark Scheduling mode
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited