KerberosConfig class

Specifies Kerberos related configuration.

Constructors

KerberosConfig({String? crossRealmTrustAdminServer, String? crossRealmTrustKdc, String? crossRealmTrustRealm, String? crossRealmTrustSharedPasswordUri, bool? enableKerberos, String? kdcDbKeyUri, String? keyPasswordUri, String? keystorePasswordUri, String? keystoreUri, String? kmsKeyUri, String? realm, String? rootPrincipalPasswordUri, int? tgtLifetimeHours, String? truststorePasswordUri, String? truststoreUri})
KerberosConfig.fromJson(Map json_)

Properties

crossRealmTrustAdminServer ↔ String?
The admin server (IP or hostname) for the remote trusted realm in a cross realm trust relationship.
getter/setter pair
crossRealmTrustKdc ↔ String?
The KDC (IP or hostname) for the remote trusted realm in a cross realm trust relationship.
getter/setter pair
crossRealmTrustRealm ↔ String?
The remote realm the on-cluster KDC will trust, should the user enable cross realm trust.
getter/setter pair
crossRealmTrustSharedPasswordUri ↔ String?
The Cloud Storage URI of a KMS encrypted file containing the shared password between the on-cluster Kerberos realm and the remote trusted realm, in a cross realm trust relationship.
getter/setter pair
enableKerberos ↔ bool?
Flag to indicate whether to Kerberize the cluster (default: false).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kdcDbKeyUri ↔ String?
The Cloud Storage URI of a KMS encrypted file containing the master key of the KDC database.
getter/setter pair
keyPasswordUri ↔ String?
The Cloud Storage URI of a KMS encrypted file containing the password to the user provided key.
getter/setter pair
keystorePasswordUri ↔ String?
The Cloud Storage URI of a KMS encrypted file containing the password to the user provided keystore.
getter/setter pair
keystoreUri ↔ String?
The Cloud Storage URI of the keystore file used for SSL encryption.
getter/setter pair
kmsKeyUri ↔ String?
The URI of the KMS key used to encrypt sensitive files.
getter/setter pair
realm ↔ String?
The name of the on-cluster Kerberos realm.
getter/setter pair
rootPrincipalPasswordUri ↔ String?
The Cloud Storage URI of a KMS encrypted file containing the root principal password.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tgtLifetimeHours ↔ int?
The lifetime of the ticket granting ticket, in hours.
getter/setter pair
truststorePasswordUri ↔ String?
The Cloud Storage URI of a KMS encrypted file containing the password to the user provided truststore.
getter/setter pair
truststoreUri ↔ String?
The Cloud Storage URI of the truststore file used for SSL encryption.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited