ListClustersResponse class

The list of all clusters in a project.

Constructors

ListClustersResponse({List<Cluster>? clusters, String? nextPageToken})
ListClustersResponse.fromJson(Map json_)

Properties

clusters ↔ List<Cluster>?
The clusters in the project.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
This token is included in the response if there are more results to fetch.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited