ManagedGroupConfig class

Specifies the resources used to actively manage an instance group.

Constructors

ManagedGroupConfig({String? instanceGroupManagerName, String? instanceGroupManagerUri, String? instanceTemplateName})
ManagedGroupConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceGroupManagerName ↔ String?
The name of the Instance Group Manager for this group.
getter/setter pair
instanceGroupManagerUri ↔ String?
The partial URI to the instance group manager for this group.
getter/setter pair
instanceTemplateName ↔ String?
The name of the Instance Template used for the Managed Instance Group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited