MemoryMetrics class

Constructors

MemoryMetrics({String? totalOffHeapStorageMemory, String? totalOnHeapStorageMemory, String? usedOffHeapStorageMemory, String? usedOnHeapStorageMemory})
MemoryMetrics.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalOffHeapStorageMemory ↔ String?
getter/setter pair
totalOnHeapStorageMemory ↔ String?
getter/setter pair
usedOffHeapStorageMemory ↔ String?
getter/setter pair
usedOnHeapStorageMemory ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited