MetastoreConfig class

Specifies a Metastore configuration.

Constructors

MetastoreConfig({String? dataprocMetastoreService})
MetastoreConfig.fromJson(Map json_)

Properties

dataprocMetastoreService ↔ String?
Resource name of an existing Metastore service.Example: projects/[project_id]/locations/[dataproc_region]/services/[service-name]
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited