NamespacedGkeDeploymentTarget class

Used only for the deprecated beta.

A full, namespace-isolated deployment target for an existing GKE cluster.

Deprecated.

Constructors

NamespacedGkeDeploymentTarget({String? clusterNamespace, String? targetGkeCluster})
NamespacedGkeDeploymentTarget.fromJson(Map json_)

Properties

clusterNamespace ↔ String?
A namespace within the GKE cluster to deploy into.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetGkeCluster ↔ String?
The target GKE cluster to deploy to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited