NativeBuildInfoUiData class

Constructors

NativeBuildInfoUiData({String? buildClass, List<BuildInfo>? buildInfo})
NativeBuildInfoUiData.fromJson(Map json_)

Properties

buildClass ↔ String?
Build class of Native.
getter/setter pair
buildInfo ↔ List<BuildInfo>?
Build related details.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited