PeripheralsConfig class

Auxiliary services configuration for a workload.

Constructors

PeripheralsConfig({String? metastoreService, SparkHistoryServerConfig? sparkHistoryServerConfig})
PeripheralsConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metastoreService ↔ String?
Resource name of an existing Dataproc Metastore service.Example: projects/[project_id]/locations/[region]/services/[service_id]
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkHistoryServerConfig ↔ SparkHistoryServerConfig?
The Spark History Server configuration for the workload.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited