PigJob class

A Dataproc job for running Apache Pig (https://pig.apache.org/) queries on YARN.

Constructors

PigJob({bool? continueOnFailure, List<String>? jarFileUris, LoggingConfig? loggingConfig, Map<String, String>? properties, String? queryFileUri, QueryList? queryList, Map<String, String>? scriptVariables})
PigJob.fromJson(Map json_)

Properties

continueOnFailure ↔ bool?
Whether to continue executing queries if a query fails.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jarFileUris ↔ List<String>?
HCFS URIs of jar files to add to the CLASSPATH of the Pig Client and Hadoop MapReduce (MR) tasks.
getter/setter pair
loggingConfig ↔ LoggingConfig?
The runtime log config for job execution.
getter/setter pair
properties ↔ Map<String, String>?
A mapping of property names to values, used to configure Pig.
getter/setter pair
queryFileUri ↔ String?
The HCFS URI of the script that contains the Pig queries.
getter/setter pair
queryList ↔ QueryList?
A list of queries.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scriptVariables ↔ Map<String, String>?
Mapping of query variable names to values (equivalent to the Pig command: name=[value]).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited