searchNativeSqlQueries method

Future<SearchSessionSparkApplicationNativeSqlQueriesResponse> searchNativeSqlQueries(
  1. String name, {
  2. int? pageSize,
  3. String? pageToken,
  4. String? parent,
  5. String? $fields,
})

Obtain data corresponding to Native SQL Queries for a Spark Application.

Request parameters:

name - Required. The fully qualified name of the session to retrieve in the format "projects/PROJECT_ID/locations/DATAPROC_REGION/sessions/SESSION_ID/sparkApplications/APPLICATION_ID" Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/sessions/\[^/\]+/sparkApplications/\[^/\]+$.

pageSize - Optional. Maximum number of queries to return in each response. The service may return fewer than this. The default page size is 10; the maximum page size is 100.

pageToken - Optional. A page token received from a previous SearchSessionSparkApplicationSqlQueries call. Provide this token to retrieve the subsequent page.

parent - Required. Parent (Session) resource reference.

$fields - Selector specifying which fields to include in a partial response.

Completes with a SearchSessionSparkApplicationNativeSqlQueriesResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<SearchSessionSparkApplicationNativeSqlQueriesResponse>
searchNativeSqlQueries(
  core.String name, {
  core.int? pageSize,
  core.String? pageToken,
  core.String? parent,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'pageSize': ?pageSize == null ? null : ['${pageSize}'],
    'pageToken': ?pageToken == null ? null : [pageToken],
    'parent': ?parent == null ? null : [parent],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'v1/' + core.Uri.encodeFull('$name') + ':searchNativeSqlQueries';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return SearchSessionSparkApplicationNativeSqlQueriesResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}