PropertiesInfo class

Properties of the workload organized by origin.

Constructors

PropertiesInfo({Map<String, ValueInfo>? autotuningProperties})
PropertiesInfo.fromJson(Map json_)

Properties

autotuningProperties ↔ Map<String, ValueInfo>?
Properties set by autotuning engine.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited