ProvisioningModelMix class

Defines how Dataproc should create VMs with a mixture of provisioning models.

Constructors

ProvisioningModelMix({int? standardCapacityBase, int? standardCapacityPercentAboveBase})
ProvisioningModelMix.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
standardCapacityBase ↔ int?
The base capacity that will always use Standard VMs to avoid risk of more preemption than the minimum capacity you need.
getter/setter pair
standardCapacityPercentAboveBase ↔ int?
The percentage of target capacity that should use Standard VM.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited