PySparkBatch class

A configuration for running an Apache PySpark (https://spark.apache.org/docs/latest/api/python/getting_started/quickstart.html) batch workload.

Constructors

PySparkBatch({List<String>? archiveUris, List<String>? args, List<String>? fileUris, List<String>? jarFileUris, String? mainPythonFileUri, List<String>? pythonFileUris})
PySparkBatch.fromJson(Map json_)

Properties

archiveUris ↔ List<String>?
HCFS URIs of archives to be extracted into the working directory of each executor.
getter/setter pair
args ↔ List<String>?
The arguments to pass to the driver.
getter/setter pair
fileUris ↔ List<String>?
HCFS URIs of files to be placed in the working directory of each executor.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jarFileUris ↔ List<String>?
HCFS URIs of jar files to add to the classpath of the Spark driver and tasks.
getter/setter pair
mainPythonFileUri ↔ String?
The HCFS URI of the main Python file to use as the Spark driver.
getter/setter pair
pythonFileUris ↔ List<String>?
HCFS file URIs of Python files to pass to the PySpark framework.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited