Quantiles class

Quantile metrics data related to Tasks.

Units can be seconds, bytes, milliseconds, etc depending on the message type.

Constructors

Quantiles({String? count, String? maximum, String? minimum, String? percentile25, String? percentile50, String? percentile75, String? sum})
Quantiles.fromJson(Map json_)

Properties

count ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maximum ↔ String?
getter/setter pair
minimum ↔ String?
getter/setter pair
percentile25 ↔ String?
getter/setter pair
percentile50 ↔ String?
getter/setter pair
percentile75 ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sum ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited