RddDataDistribution class

Details about RDD usage.

Constructors

RddDataDistribution({String? address, String? diskUsed, String? memoryRemaining, String? memoryUsed, String? offHeapMemoryRemaining, String? offHeapMemoryUsed, String? onHeapMemoryRemaining, String? onHeapMemoryUsed})
RddDataDistribution.fromJson(Map json_)

Properties

address ↔ String?
getter/setter pair
diskUsed ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memoryRemaining ↔ String?
getter/setter pair
memoryUsed ↔ String?
getter/setter pair
offHeapMemoryRemaining ↔ String?
getter/setter pair
offHeapMemoryUsed ↔ String?
getter/setter pair
onHeapMemoryRemaining ↔ String?
getter/setter pair
onHeapMemoryUsed ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited