RddOperationCluster class

A grouping of nodes representing higher level constructs (stage, job etc.).

Constructors

RddOperationCluster({List<RddOperationCluster>? childClusters, List<RddOperationNode>? childNodes, String? name, String? rddClusterId})
RddOperationCluster.fromJson(Map json_)

Properties

childClusters ↔ List<RddOperationCluster>?
getter/setter pair
childNodes ↔ List<RddOperationNode>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
rddClusterId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited