RddOperationGraph class

Graph representing RDD dependencies.

Consists of edges and a root cluster.

Constructors

RddOperationGraph({List<RddOperationEdge>? edges, List<RddOperationEdge>? incomingEdges, List<RddOperationEdge>? outgoingEdges, RddOperationCluster? rootCluster, String? stageId})
RddOperationGraph.fromJson(Map json_)

Properties

edges ↔ List<RddOperationEdge>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
incomingEdges ↔ List<RddOperationEdge>?
getter/setter pair
outgoingEdges ↔ List<RddOperationEdge>?
getter/setter pair
rootCluster ↔ RddOperationCluster?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stageId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited