RddOperationNode class

A node in the RDD operation graph.

Corresponds to a single RDD.

Constructors

RddOperationNode({bool? barrier, bool? cached, String? callsite, String? name, int? nodeId, String? outputDeterministicLevel})
RddOperationNode.fromJson(Map json_)

Properties

barrier ↔ bool?
getter/setter pair
cached ↔ bool?
getter/setter pair
callsite ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
nodeId ↔ int?
getter/setter pair
outputDeterministicLevel ↔ String?
Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited