RddStorageInfo class

Overall data about RDD storage.

Constructors

RddStorageInfo({List<RddDataDistribution>? dataDistribution, String? diskUsed, String? memoryUsed, String? name, int? numCachedPartitions, int? numPartitions, List<RddPartitionInfo>? partitions, int? rddStorageId, String? storageLevel})
RddStorageInfo.fromJson(Map json_)

Properties

dataDistribution ↔ List<RddDataDistribution>?
getter/setter pair
diskUsed ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memoryUsed ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
numCachedPartitions ↔ int?
getter/setter pair
numPartitions ↔ int?
getter/setter pair
partitions ↔ List<RddPartitionInfo>?
getter/setter pair
rddStorageId ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageLevel ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited