RegexValidation class

Validation based on regular expressions.

Constructors

RegexValidation({List<String>? regexes})
RegexValidation.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
regexes ↔ List<String>?
RE2 regular expressions used to validate the parameter's value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited