RepairClusterRequest class

A request to repair a cluster.

Constructors

RepairClusterRequest({ClusterToRepair? cluster, String? clusterUuid, bool? dataprocSuperUser, String? gracefulDecommissionTimeout, List<NodePool>? nodePools, String? parentOperationId, String? requestId})
RepairClusterRequest.fromJson(Map json_)

Properties

cluster ↔ ClusterToRepair?
Cluster to be repaired
getter/setter pair
clusterUuid ↔ String?
Specifying the cluster_uuid means the RPC will fail (with error NOT_FOUND) if a cluster with the specified UUID does not exist.
getter/setter pair
dataprocSuperUser ↔ bool?
Whether the request is submitted by a super user.
getter/setter pair
gracefulDecommissionTimeout ↔ String?
Timeout for graceful YARN decommissioning.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nodePools ↔ List<NodePool>?
Node pools and corresponding repair action to be taken.
getter/setter pair
parentOperationId ↔ String?
operation id of the parent operation sending the repair request
getter/setter pair
requestId ↔ String?
A unique ID used to identify the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited