RepairNodeGroupRequest class

Constructors

RepairNodeGroupRequest({List<String>? instanceNames, String? repairAction, String? requestId})
RepairNodeGroupRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceNames ↔ List<String>?
Name of instances to be repaired.
getter/setter pair
repairAction ↔ String?
Repair action to take on specified resources of the node pool.
getter/setter pair
requestId ↔ String?
A unique ID used to identify the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited