ResizeNodeGroupRequest class

A request to resize a node group.

Constructors

ResizeNodeGroupRequest({String? gracefulDecommissionTimeout, String? parentOperationId, String? requestId, int? size})
ResizeNodeGroupRequest.fromJson(Map json_)

Properties

gracefulDecommissionTimeout ↔ String?
Timeout for graceful YARN decommissioning.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parentOperationId ↔ String?
operation id of the parent operation sending the resize request
getter/setter pair
requestId ↔ String?
A unique ID used to identify the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
The number of running instances for the node group to maintain.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited