ResourceProfileInfo class

Resource profile that contains information about all the resources required by executors and tasks.

Constructors

ResourceProfileInfo({Map<String, ExecutorResourceRequest>? executorResources, int? resourceProfileId, Map<String, TaskResourceRequest>? taskResources})
ResourceProfileInfo.fromJson(Map json_)

Properties

executorResources ↔ Map<String, ExecutorResourceRequest>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resourceProfileId ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskResources ↔ Map<String, TaskResourceRequest>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited