RuntimeConfig class

Runtime configuration for a workload.

Constructors

RuntimeConfig({AutotuningConfig? autotuningConfig, String? cohort, String? containerImage, Map<String, String>? properties, RepositoryConfig? repositoryConfig, String? version})
RuntimeConfig.fromJson(Map json_)

Properties

autotuningConfig ↔ AutotuningConfig?
Autotuning configuration of the workload.
getter/setter pair
cohort ↔ String?
Cohort identifier.
getter/setter pair
containerImage ↔ String?
Optional custom container image for the job runtime environment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
properties ↔ Map<String, String>?
A mapping of property names to values, which are used to configure workload execution.
getter/setter pair
repositoryConfig ↔ RepositoryConfig?
Dependency repository configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
Version of the batch runtime.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited