SearchSparkApplicationNativeSqlQueriesResponse class
List of all Native SQL queries details for a Spark Application.
Constructors
-
SearchSparkApplicationNativeSqlQueriesResponse({String? nextPageToken, List<
NativeSqlExecutionUiData> ? sparkApplicationNativeSqlQueries}) - SearchSparkApplicationNativeSqlQueriesResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
This token is included in the response if there are more results to fetch.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sparkApplicationNativeSqlQueries
↔ List<
NativeSqlExecutionUiData> ? -
Native SQL Execution Data
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited