SecurityConfig class

Security related configuration, including encryption, Kerberos, etc.

Constructors

SecurityConfig({IdentityConfig? identityConfig, KerberosConfig? kerberosConfig})
SecurityConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
identityConfig ↔ IdentityConfig?
Identity related configuration, including service account based secure multi-tenancy user mappings.
getter/setter pair
kerberosConfig ↔ KerberosConfig?
Kerberos related configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited