SessionTemplate class

A representation of a session template.

Constructors

SessionTemplate({String? createTime, String? creator, String? description, EnvironmentConfig? environmentConfig, JupyterConfig? jupyterSession, Map<String, String>? labels, String? name, RuntimeConfig? runtimeConfig, SparkConnectConfig? sparkConnectSession, String? updateTime, String? uuid})
SessionTemplate.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the template was created.
getter/setter pair
creator ↔ String?
The email address of the user who created the template.
getter/setter pair
description ↔ String?
Brief description of the template.
getter/setter pair
environmentConfig ↔ EnvironmentConfig?
Environment configuration for session execution.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jupyterSession ↔ JupyterConfig?
Jupyter session config.
getter/setter pair
labels ↔ Map<String, String>?
Labels to associate with sessions created using this template.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeConfig ↔ RuntimeConfig?
Runtime configuration for session execution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkConnectSession ↔ SparkConnectConfig?
Spark connect session config.
getter/setter pair
updateTime ↔ String?
The time the template was last updated.
getter/setter pair
uuid ↔ String?
A session template UUID (Unique Universal Identifier).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited