ShuffleReadMetrics class

Shuffle data read by the task.

Constructors

ShuffleReadMetrics({String? fetchWaitTimeMillis, String? localBlocksFetched, String? localBytesRead, String? recordsRead, String? remoteBlocksFetched, String? remoteBytesRead, String? remoteBytesReadToDisk, String? remoteReqsDuration, ShufflePushReadMetrics? shufflePushReadMetrics})
ShuffleReadMetrics.fromJson(Map json_)

Properties

fetchWaitTimeMillis ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localBlocksFetched ↔ String?
getter/setter pair
localBytesRead ↔ String?
getter/setter pair
recordsRead ↔ String?
getter/setter pair
remoteBlocksFetched ↔ String?
getter/setter pair
remoteBytesRead ↔ String?
getter/setter pair
remoteBytesReadToDisk ↔ String?
getter/setter pair
remoteReqsDuration ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shufflePushReadMetrics ↔ ShufflePushReadMetrics?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited