SinkProgress class

Constructors

SinkProgress({String? description, Map<String, String>? metrics, String? numOutputRows})
SinkProgress.fromJson(Map json_)

Properties

description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ Map<String, String>?
getter/setter pair
numOutputRows ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited