SourceProgress class

Constructors

SourceProgress({String? description, String? endOffset, double? inputRowsPerSecond, String? latestOffset, Map<String, String>? metrics, String? numInputRows, double? processedRowsPerSecond, String? startOffset})
SourceProgress.fromJson(Map json_)

Properties

description ↔ String?
getter/setter pair
endOffset ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputRowsPerSecond ↔ double?
getter/setter pair
latestOffset ↔ String?
getter/setter pair
metrics ↔ Map<String, String>?
getter/setter pair
numInputRows ↔ String?
getter/setter pair
processedRowsPerSecond ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startOffset ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited