SparkConnectExecutionInfo class

Represents the lifecycle and details of an Execution via Spark Connect

Constructors

SparkConnectExecutionInfo({String? closeTimestamp, String? detail, String? finishTimestamp, List<String>? jobIds, String? jobTag, String? operationId, String? sessionId, List<String>? sparkSessionTags, List<String>? sqlExecIds, String? startTimestamp, String? state, String? statement, String? userId})
SparkConnectExecutionInfo.fromJson(Map json_)

Properties

closeTimestamp ↔ String?
Timestamp when the execution was closed.
getter/setter pair
detail ↔ String?
Detailed information about the execution.
getter/setter pair
finishTimestamp ↔ String?
Timestamp when the execution finished.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobIds ↔ List<String>?
List of job ids associated with the execution.
getter/setter pair
jobTag ↔ String?
Job tag of the execution.
getter/setter pair
operationId ↔ String?
Unique identifier for the operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String?
Session ID, ties the execution to a specific Spark Connect session.
getter/setter pair
sparkSessionTags ↔ List<String>?
Tags associated with the Spark session.
getter/setter pair
sqlExecIds ↔ List<String>?
List of sql execution ids associated with the execution.
getter/setter pair
startTimestamp ↔ String?
Timestamp when the execution started.
getter/setter pair
state ↔ String?
Current state of the execution.
getter/setter pair
statement ↔ String?
statement of the execution.
getter/setter pair
userId ↔ String?
User ID of the user who started the execution.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited