SparkConnectSessionInfo class

Represents session-level information for Spark Connect

Constructors

SparkConnectSessionInfo({String? finishTimestamp, String? sessionId, String? startTimestamp, String? totalExecution, String? userId})
SparkConnectSessionInfo.fromJson(Map json_)

Properties

finishTimestamp ↔ String?
Timestamp when the session finished.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId ↔ String?
Session ID of the session.
getter/setter pair
startTimestamp ↔ String?
Timestamp when the session started.
getter/setter pair
totalExecution ↔ String?
Total number of executions in the session.
getter/setter pair
userId ↔ String?
User ID of the user who started the session.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited