SparkPlanGraph class

A graph used for storing information of an executionPlan of DataFrame.

Properties

edges ↔ List<SparkPlanGraphEdge>?
getter/setter pair
executionId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nodes ↔ List<SparkPlanGraphNodeWrapper>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited