SparkPlanGraphNode class

Represents a node in the spark plan tree.

Constructors

SparkPlanGraphNode({String? desc, List<SqlPlanMetric>? metrics, String? name, String? sparkPlanGraphNodeId})
SparkPlanGraphNode.fromJson(Map json_)

Properties

desc ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ List<SqlPlanMetric>?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkPlanGraphNodeId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited