SparkWrapperObject class

Outer message that contains the data obtained from spark listener, packaged with information that is required to process it.

Constructors

SparkWrapperObject({AppSummary? appSummary, ApplicationEnvironmentInfo? applicationEnvironmentInfo, String? applicationId, ApplicationInfo? applicationInfo, String? eventTimestamp, ExecutorStageSummary? executorStageSummary, ExecutorSummary? executorSummary, JobData? jobData, NativeBuildInfoUiData? nativeBuildInfoUiData, NativeSqlExecutionUiData? nativeSqlExecutionUiData, PoolData? poolData, ProcessSummary? processSummary, RddOperationGraph? rddOperationGraph, RddStorageInfo? rddStorageInfo, ResourceProfileInfo? resourceProfileInfo, SparkConnectExecutionInfo? sparkConnectExecutionInfo, SparkConnectSessionInfo? sparkConnectSessionInfo, SparkPlanGraph? sparkPlanGraph, SpeculationStageSummary? speculationStageSummary, SqlExecutionUiData? sqlExecutionUiData, StageData? stageData, StreamBlockData? streamBlockData, StreamingQueryData? streamingQueryData, StreamingQueryProgress? streamingQueryProgress, TaskData? taskData})
SparkWrapperObject.fromJson(Map json_)

Properties

applicationEnvironmentInfo ↔ ApplicationEnvironmentInfo?
getter/setter pair
applicationId ↔ String?
Application Id created by Spark.
getter/setter pair
applicationInfo ↔ ApplicationInfo?
getter/setter pair
appSummary ↔ AppSummary?
getter/setter pair
eventTimestamp ↔ String?
VM Timestamp associated with the data object.
getter/setter pair
executorStageSummary ↔ ExecutorStageSummary?
getter/setter pair
executorSummary ↔ ExecutorSummary?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobData ↔ JobData?
getter/setter pair
nativeBuildInfoUiData ↔ NativeBuildInfoUiData?
Native Build Info
getter/setter pair
nativeSqlExecutionUiData ↔ NativeSqlExecutionUiData?
Native SQL Execution Info
getter/setter pair
poolData ↔ PoolData?
getter/setter pair
processSummary ↔ ProcessSummary?
getter/setter pair
rddOperationGraph ↔ RddOperationGraph?
getter/setter pair
rddStorageInfo ↔ RddStorageInfo?
getter/setter pair
resourceProfileInfo ↔ ResourceProfileInfo?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkConnectExecutionInfo ↔ SparkConnectExecutionInfo?
Spark Connect Execution Info
getter/setter pair
sparkConnectSessionInfo ↔ SparkConnectSessionInfo?
Spark Connect Session Info
getter/setter pair
sparkPlanGraph ↔ SparkPlanGraph?
getter/setter pair
speculationStageSummary ↔ SpeculationStageSummary?
getter/setter pair
sqlExecutionUiData ↔ SqlExecutionUiData?
getter/setter pair
stageData ↔ StageData?
getter/setter pair
streamBlockData ↔ StreamBlockData?
getter/setter pair
streamingQueryData ↔ StreamingQueryData?
getter/setter pair
streamingQueryProgress ↔ StreamingQueryProgress?
getter/setter pair
taskData ↔ TaskData?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited