SqlExecutionUiData class

SQL Execution Data

Constructors

SqlExecutionUiData({String? completionTime, String? description, String? details, String? errorMessage, String? executionId, Map<String, String>? jobs, Map<String, String>? metricValues, bool? metricValuesIsNull, List<SqlPlanMetric>? metrics, Map<String, String>? modifiedConfigs, String? physicalPlanDescription, String? rootExecutionId, List<String>? stages, String? submissionTime})
SqlExecutionUiData.fromJson(Map json_)

Properties

completionTime ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
details ↔ String?
getter/setter pair
errorMessage ↔ String?
getter/setter pair
executionId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobs ↔ Map<String, String>?
getter/setter pair
metrics ↔ List<SqlPlanMetric>?
getter/setter pair
metricValues ↔ Map<String, String>?
getter/setter pair
metricValuesIsNull ↔ bool?
getter/setter pair
modifiedConfigs ↔ Map<String, String>?
getter/setter pair
physicalPlanDescription ↔ String?
getter/setter pair
rootExecutionId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stages ↔ List<String>?
getter/setter pair
submissionTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited