StageAttemptTasksSummary class

Data related to tasks summary for a Spark Stage Attempt

Constructors

StageAttemptTasksSummary({String? applicationId, int? numFailedTasks, int? numKilledTasks, int? numPendingTasks, int? numRunningTasks, int? numSuccessTasks, int? numTasks, int? stageAttemptId, String? stageId})
StageAttemptTasksSummary.fromJson(Map json_)

Properties

applicationId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numFailedTasks ↔ int?
getter/setter pair
numKilledTasks ↔ int?
getter/setter pair
numPendingTasks ↔ int?
getter/setter pair
numRunningTasks ↔ int?
getter/setter pair
numSuccessTasks ↔ int?
getter/setter pair
numTasks ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stageAttemptId ↔ int?
getter/setter pair
stageId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited