StageShuffleReadMetrics class

Shuffle data read for the stage.

Constructors

StageShuffleReadMetrics({String? bytesRead, String? fetchWaitTimeMillis, String? localBlocksFetched, String? localBytesRead, String? recordsRead, String? remoteBlocksFetched, String? remoteBytesRead, String? remoteBytesReadToDisk, String? remoteReqsDuration, StageShufflePushReadMetrics? stageShufflePushReadMetrics})
StageShuffleReadMetrics.fromJson(Map json_)

Properties

bytesRead ↔ String?
getter/setter pair
fetchWaitTimeMillis ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localBlocksFetched ↔ String?
getter/setter pair
localBytesRead ↔ String?
getter/setter pair
recordsRead ↔ String?
getter/setter pair
remoteBlocksFetched ↔ String?
getter/setter pair
remoteBytesRead ↔ String?
getter/setter pair
remoteBytesReadToDisk ↔ String?
getter/setter pair
remoteReqsDuration ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stageShufflePushReadMetrics ↔ ShufflePushReadMetrics?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited