StagesSummary class

Data related to Stages page summary

Constructors

StagesSummary({String? applicationId, int? numActiveStages, int? numCompletedStages, int? numFailedStages, int? numPendingStages, int? numSkippedStages})
StagesSummary.fromJson(Map json_)

Properties

applicationId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numActiveStages ↔ int?
getter/setter pair
numCompletedStages ↔ int?
getter/setter pair
numFailedStages ↔ int?
getter/setter pair
numPendingStages ↔ int?
getter/setter pair
numSkippedStages ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited