StartupConfig class

Configuration to handle the startup of instances during cluster create and update process.

Constructors

StartupConfig({double? requiredRegistrationFraction})
StartupConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
requiredRegistrationFraction ↔ double?
The config setting to enable cluster creation/ updation to be successful only after required_registration_fraction of instances are up and running.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited