StateOperatorProgress class

Constructors

StateOperatorProgress({String? allRemovalsTimeMs, String? allUpdatesTimeMs, String? commitTimeMs, Map<String, String>? customMetrics, String? memoryUsedBytes, String? numRowsDroppedByWatermark, String? numRowsRemoved, String? numRowsTotal, String? numRowsUpdated, String? numShufflePartitions, String? numStateStoreInstances, String? operatorName})
StateOperatorProgress.fromJson(Map json_)

Properties

allRemovalsTimeMs ↔ String?
getter/setter pair
allUpdatesTimeMs ↔ String?
getter/setter pair
commitTimeMs ↔ String?
getter/setter pair
customMetrics ↔ Map<String, String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memoryUsedBytes ↔ String?
getter/setter pair
numRowsDroppedByWatermark ↔ String?
getter/setter pair
numRowsRemoved ↔ String?
getter/setter pair
numRowsTotal ↔ String?
getter/setter pair
numRowsUpdated ↔ String?
getter/setter pair
numShufflePartitions ↔ String?
getter/setter pair
numStateStoreInstances ↔ String?
getter/setter pair
operatorName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited