StreamBlockData class

Stream Block Data.

Constructors

StreamBlockData({bool? deserialized, String? diskSize, String? executorId, String? hostPort, String? memSize, String? name, String? storageLevel, bool? useDisk, bool? useMemory})
StreamBlockData.fromJson(Map json_)

Properties

deserialized ↔ bool?
getter/setter pair
diskSize ↔ String?
getter/setter pair
executorId ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostPort ↔ String?
getter/setter pair
memSize ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageLevel ↔ String?
getter/setter pair
useDisk ↔ bool?
getter/setter pair
useMemory ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited