StreamingQueryData class

Streaming

Constructors

StreamingQueryData({String? endTimestamp, String? exception, bool? isActive, String? name, String? runId, String? startTimestamp, String? streamingQueryId})
StreamingQueryData.fromJson(Map json_)

Properties

endTimestamp ↔ String?
getter/setter pair
exception ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isActive ↔ bool?
getter/setter pair
name ↔ String?
getter/setter pair
runId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimestamp ↔ String?
getter/setter pair
streamingQueryId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited