StreamingQueryProgress class

Constructors

StreamingQueryProgress({String? batchDuration, String? batchId, Map<String, String>? durationMillis, Map<String, String>? eventTime, String? name, Map<String, String>? observedMetrics, String? runId, SinkProgress? sink, List<SourceProgress>? sources, List<StateOperatorProgress>? stateOperators, String? streamingQueryProgressId, String? timestamp})
StreamingQueryProgress.fromJson(Map json_)

Properties

batchDuration ↔ String?
getter/setter pair
batchId ↔ String?
getter/setter pair
durationMillis ↔ Map<String, String>?
getter/setter pair
eventTime ↔ Map<String, String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
observedMetrics ↔ Map<String, String>?
getter/setter pair
runId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sink ↔ SinkProgress?
getter/setter pair
sources ↔ List<SourceProgress>?
getter/setter pair
stateOperators ↔ List<StateOperatorProgress>?
getter/setter pair
streamingQueryProgressId ↔ String?
getter/setter pair
timestamp ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited