SummarizeSessionSparkApplicationExecutorsResponse class

Consolidated summary of executors for a Spark Application.

Properties

activeExecutorSummary ↔ ConsolidatedExecutorSummary?
Consolidated summary for active executors.
getter/setter pair
applicationId ↔ String?
Spark Application Id
getter/setter pair
deadExecutorSummary ↔ ConsolidatedExecutorSummary?
Consolidated summary for dead executors.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalExecutorSummary ↔ ConsolidatedExecutorSummary?
Overall consolidated summary for all executors.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited