TaskData class

Data corresponding to tasks created by spark.

Constructors

TaskData({List<AccumulableInfo>? accumulatorUpdates, int? attempt, String? durationMillis, String? errorMessage, String? executorId, Map<String, String>? executorLogs, String? gettingResultTimeMillis, bool? hasMetrics, String? host, int? index, String? launchTime, int? partitionId, String? resultFetchStart, String? schedulerDelayMillis, bool? speculative, int? stageAttemptId, String? stageId, String? status, String? taskId, String? taskLocality, TaskMetrics? taskMetrics})
TaskData.fromJson(Map json_)

Properties

accumulatorUpdates ↔ List<AccumulableInfo>?
getter/setter pair
attempt ↔ int?
getter/setter pair
durationMillis ↔ String?
getter/setter pair
errorMessage ↔ String?
getter/setter pair
executorId ↔ String?
getter/setter pair
executorLogs ↔ Map<String, String>?
getter/setter pair
gettingResultTimeMillis ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasMetrics ↔ bool?
getter/setter pair
host ↔ String?
getter/setter pair
index ↔ int?
getter/setter pair
launchTime ↔ String?
getter/setter pair
partitionId ↔ int?
getter/setter pair
resultFetchStart ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedulerDelayMillis ↔ String?
getter/setter pair
speculative ↔ bool?
getter/setter pair
stageAttemptId ↔ int?
getter/setter pair
stageId ↔ String?
getter/setter pair
status ↔ String?
getter/setter pair
taskId ↔ String?
getter/setter pair
taskLocality ↔ String?
getter/setter pair
taskMetrics ↔ TaskMetrics?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited