TaskMetrics class

Executor Task Metrics

Constructors

TaskMetrics({String? diskBytesSpilled, String? executorCpuTimeNanos, String? executorDeserializeCpuTimeNanos, String? executorDeserializeTimeMillis, String? executorRunTimeMillis, InputMetrics? inputMetrics, String? jvmGcTimeMillis, String? memoryBytesSpilled, OutputMetrics? outputMetrics, String? peakExecutionMemoryBytes, String? resultSerializationTimeMillis, String? resultSize, ShuffleReadMetrics? shuffleReadMetrics, ShuffleWriteMetrics? shuffleWriteMetrics})
TaskMetrics.fromJson(Map json_)

Properties

diskBytesSpilled ↔ String?
getter/setter pair
executorCpuTimeNanos ↔ String?
getter/setter pair
executorDeserializeCpuTimeNanos ↔ String?
getter/setter pair
executorDeserializeTimeMillis ↔ String?
getter/setter pair
executorRunTimeMillis ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputMetrics ↔ StageInputMetrics?
getter/setter pair
jvmGcTimeMillis ↔ String?
getter/setter pair
memoryBytesSpilled ↔ String?
getter/setter pair
outputMetrics ↔ StageOutputMetrics?
getter/setter pair
peakExecutionMemoryBytes ↔ String?
getter/setter pair
resultSerializationTimeMillis ↔ String?
getter/setter pair
resultSize ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleReadMetrics ↔ ShuffleReadMetrics?
getter/setter pair
shuffleWriteMetrics ↔ StageShuffleWriteMetrics?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited