UsageMetrics class

Usage metrics represent approximate total resources consumed by a workload.

Constructors

UsageMetrics({String? acceleratorType, String? milliAcceleratorSeconds, String? milliAcceleratorSecondsA10040, String? milliAcceleratorSecondsA10080, String? milliAcceleratorSecondsL4, String? milliDcuSeconds, String? shuffleStorageGbSeconds, String? updateTime})
UsageMetrics.fromJson(Map json_)

Properties

acceleratorType String?
Accelerator type being used, if any Deprecated: This field is only used in runtime versions below 3.0.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
milliAcceleratorSeconds String?
Accelerator usage in (milliAccelerator x seconds) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)).
getter/setter pair
milliAcceleratorSecondsA10040 String?
A100-40 accelerator usage in (milliAccelerator x seconds) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)).
getter/setter pair
milliAcceleratorSecondsA10080 String?
A100-80 accelerator usage in (milliAccelerator x seconds) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)).
getter/setter pair
milliAcceleratorSecondsL4 String?
L4 accelerator usage in (milliAccelerator x seconds) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)).
getter/setter pair
milliDcuSeconds String?
DCU (Dataproc Compute Units) usage in (milliDCU x seconds) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shuffleStorageGbSeconds String?
Shuffle storage usage in (GB x seconds) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)).
getter/setter pair
updateTime String?
The timestamp of the usage metrics.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited