UsageSnapshot class

The usage snapshot represents the resources consumed by a workload at a specified time.

Constructors

UsageSnapshot({String? acceleratorType, String? milliAccelerator, String? milliAcceleratorA10040, String? milliAcceleratorA10080, String? milliAcceleratorL4, String? milliDcu, String? milliDcuPremium, String? shuffleStorageGb, String? shuffleStorageGbPremium, String? snapshotTime})
UsageSnapshot.fromJson(Map json_)

Properties

acceleratorType ↔ String?
Accelerator type being used, if any Deprecated: This field is only used in runtime versions below 3.0.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
milliAccelerator ↔ String?
Milli (one-thousandth) accelerator.
getter/setter pair
milliAcceleratorA10040 ↔ String?
Milli (one-thousandth) accelerator for A100-40 accelerators.
getter/setter pair
milliAcceleratorA10080 ↔ String?
Milli (one-thousandth) accelerator for A100-80 accelerators.
getter/setter pair
milliAcceleratorL4 ↔ String?
Milli (one-thousandth) accelerator for L4 accelerators.
getter/setter pair
milliDcu ↔ String?
Milli (one-thousandth) Dataproc Compute Units (DCUs) (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)).
getter/setter pair
milliDcuPremium ↔ String?
Milli (one-thousandth) Dataproc Compute Units (DCUs) charged at premium tier (see Dataproc Serverless pricing (https://cloud.google.com/dataproc-serverless/pricing)).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleStorageGb ↔ String?
Shuffle Storage in gigabytes (GB).
getter/setter pair
shuffleStorageGbPremium ↔ String?
Shuffle Storage in gigabytes (GB) charged at premium tier.
getter/setter pair
snapshotTime ↔ String?
The timestamp of the usage snapshot.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited