ValueInfo class

Annotatated property value.

Constructors

ValueInfo({String? annotation, String? overriddenValue, String? value})
ValueInfo.fromJson(Map json_)

Properties

annotation ↔ String?
Annotation, comment or explanation why the property was set.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
overriddenValue ↔ String?
Value which was replaced by the corresponding component.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
Property value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited