WriteSessionSparkApplicationContextRequest class

Write Spark Application data to internal storage systems

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent ↔ String?
Parent (Batch) resource reference.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sparkWrapperObjects ↔ List<SparkWrapperObject>?
The batch of spark application context objects sent for ingestion.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited