YarnApplication class

A YARN application created by a job.

Application information is a subset of org.apache.hadoop.yarn.proto.YarnProtos.ApplicationReportProto.Beta Feature: This report is available for testing purposes only. It may be changed before final release.

Constructors

YarnApplication({String? memoryMbSeconds, String? name, double? progress, String? state, String? trackingUrl, String? vcoreSeconds})
YarnApplication.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
memoryMbSeconds ↔ String?
The cumulative memory usage of the application for a job, measured in mb-seconds.
getter/setter pair
name ↔ String?
The application name.
getter/setter pair
progress ↔ double?
The numerical progress of the application, from 1 to 100.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The application state.
getter/setter pair
trackingUrl ↔ String?
The HTTP URL of the ApplicationMaster, HistoryServer, or TimelineServer that provides application-specific information.
getter/setter pair
vcoreSeconds ↔ String?
The cumulative CPU time consumed by the application for a job, measured in vcore-seconds.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited