Aggregation class

Defines an aggregation that produces a single result.

Constructors

Aggregation({String? alias, Avg? avg, Count? count, Sum? sum})
Aggregation.fromJson(Map json_)

Properties

alias ↔ String?
Optional name of the property to store the result of the aggregation.
getter/setter pair
avg ↔ Avg?
Average aggregator.
getter/setter pair
count ↔ Count?
Count aggregator.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sum ↔ Sum?
Sum aggregator.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited