BeginTransactionRequest class

The request for Datastore.BeginTransaction.

Constructors

BeginTransactionRequest({String? databaseId, RequestOptions? requestOptions, TransactionOptions? transactionOptions})
BeginTransactionRequest.fromJson(Map json_)

Properties

databaseId ↔ String?
The ID of the database against which to make the request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestOptions ↔ RequestOptions?
The options for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionOptions ↔ TransactionOptions?
Options for a new transaction.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited