CommitRequest class

The request for Datastore.Commit.

Constructors

CommitRequest({String? databaseId, String? mode, List<Mutation>? mutations, RequestOptions? requestOptions, TransactionOptions? singleUseTransaction, String? transaction})
CommitRequest.fromJson(Map json_)

Properties

databaseId ↔ String?
The ID of the database against which to make the request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?
The type of commit to perform.
getter/setter pair
mutations ↔ List<Mutation>?
The mutations to perform.
getter/setter pair
requestOptions ↔ RequestOptions?
The options for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleUseTransaction ↔ TransactionOptions?
Options for beginning a new transaction for this request.
getter/setter pair
transaction ↔ String?
The identifier of the transaction associated with the commit.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited