CommitResponse class

The response for Datastore.Commit.

Constructors

CommitResponse({String? commitTime, int? indexUpdates, List<MutationResult>? mutationResults})
CommitResponse.fromJson(Map json_)

Properties

commitTime ↔ String?
The transaction commit timestamp.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indexUpdates ↔ int?
The number of index entries updated during the commit, or zero if none were updated.
getter/setter pair
mutationResults ↔ List<MutationResult>?
The result of performing the mutations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited