Count class

Count of entities that match the query.

The COUNT(*) aggregation function operates on the entire entity so it does not require a field reference.

Constructors

Count({String? upTo})
Count.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upTo ↔ String?
Optional constraint on the maximum number of entities to count.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited