Entity class

A Datastore data object.

Must not exceed 1 MiB - 4 bytes.

Constructors

Entity({Key? key, Map<String, Value>? properties})
Entity.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ Key?
The entity's key.
getter/setter pair
properties ↔ Map<String, Value>?
The entity's properties.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited