EntityResult class

The result of fetching an entity from Datastore.

Constructors

EntityResult({String? createTime, String? cursor, Entity? entity, String? updateTime, String? version})
EntityResult.fromJson(Map json_)

Properties

createTime ↔ String?
The time at which the entity was created.
getter/setter pair
cursor ↔ String?
A cursor that points to the position after the result entity.
getter/setter pair
cursorAsBytes ↔ List<int>
getter/setter pair
entity ↔ Entity?
The resulting entity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The time at which the entity was last changed.
getter/setter pair
version ↔ String?
The version of the entity, a strictly positive number that monotonically increases with changes to the entity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited