ExplainMetrics class

Explain metrics for the query.

Constructors

ExplainMetrics({ExecutionStats? executionStats, PlanSummary? planSummary})
ExplainMetrics.fromJson(Map json_)

Properties

executionStats ↔ ExecutionStats?
Aggregated stats from the execution of the query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
planSummary ↔ PlanSummary?
Planning phase information for the query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited