Filter class

A holder for any type of filter.

Constructors

Filter({CompositeFilter? compositeFilter, PropertyFilter? propertyFilter})
Filter.fromJson(Map json_)

Properties

compositeFilter ↔ CompositeFilter?
A composite filter.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
propertyFilter ↔ PropertyFilter?
A filter on a property.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited