GqlQueryParameter class

A binding parameter for a GQL query.

Constructors

GqlQueryParameter({String? cursor, Value? value})
GqlQueryParameter.fromJson(Map json_)

Properties

cursor ↔ String?
A query cursor.
getter/setter pair
cursorAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Value?
A value parameter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited