LookupRequest class

The request for Datastore.Lookup.

Constructors

LookupRequest({String? databaseId, List<Key>? keys, PropertyMask? propertyMask, ReadOptions? readOptions, RequestOptions? requestOptions})
LookupRequest.fromJson(Map json_)

Properties

databaseId ↔ String?
The ID of the database against which to make the request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keys ↔ List<Key>?
Keys of entities to look up.
getter/setter pair
propertyMask ↔ PropertyMask?
The properties to return.
getter/setter pair
readOptions ↔ ReadOptions?
The options for this lookup request.
getter/setter pair
requestOptions ↔ RequestOptions?
The options for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited