MutationResult class

The result of applying a mutation.

Constructors

MutationResult({bool? conflictDetected, String? createTime, Key? key, List<Value>? transformResults, String? updateTime, String? version})
MutationResult.fromJson(Map json_)

Properties

conflictDetected ↔ bool?
Whether a conflict was detected for this mutation.
getter/setter pair
createTime ↔ String?
The create time of the entity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ Key?
The automatically allocated key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformResults ↔ List<Value>?
The results of applying each PropertyTransform, in the same order of the request.
getter/setter pair
updateTime ↔ String?
The update time of the entity on the server after processing the mutation.
getter/setter pair
version ↔ String?
The version of the entity on the server after processing the mutation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited