ProjectsIndexesResource class

Constructors

ProjectsIndexesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(GoogleDatastoreAdminV1Index request, String projectId, {String? $fields}) → Future<GoogleLongrunningOperation>
Creates the specified index.
delete(String projectId, String indexId, {String? $fields}) → Future<GoogleLongrunningOperation>
Deletes an existing index.
get(String projectId, String indexId, {String? $fields}) → Future<GoogleDatastoreAdminV1Index>
Gets an index.
list(String projectId, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<GoogleDatastoreAdminV1ListIndexesResponse>
Lists the indexes that match the specified filters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited