PropertyFilter class

A filter on a specific property.

Constructors

PropertyFilter({String? op, PropertyReference? property, Value? value})
PropertyFilter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
op ↔ String?
The operator to filter by. Possible string values are:
getter/setter pair
property ↔ PropertyReference?
The property to filter by.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ Value?
The value to compare the property to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited