PropertyMask class

The set of arbitrarily nested property paths used to restrict an operation to only a subset of properties in an entity.

Constructors

PropertyMask({List<String>? paths})
PropertyMask.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
paths ↔ List<String>?
The paths to the properties covered by this mask.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited