PropertyOrder class

The desired order for a specific property.

Constructors

PropertyOrder({String? direction, PropertyReference? property})
PropertyOrder.fromJson(Map json_)

Properties

direction ↔ String?
The direction to order by.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
property ↔ PropertyReference?
The property to order by.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited