QueryResultBatch class

A batch of results produced by a query.

Constructors

QueryResultBatch({String? endCursor, String? entityResultType, List<EntityResult>? entityResults, String? moreResults, String? readTime, String? skippedCursor, int? skippedResults, String? snapshotVersion})
QueryResultBatch.fromJson(Map json_)

Properties

endCursor ↔ String?
A cursor that points to the position after the last result in the batch.
getter/setter pair
endCursorAsBytes ↔ List<int>
getter/setter pair
entityResults ↔ List<EntityResult>?
The results for this batch.
getter/setter pair
entityResultType ↔ String?
The result type for every entity in entity_results. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
moreResults ↔ String?
The state of the query after the current batch. Possible string values are:
getter/setter pair
readTime ↔ String?
Read timestamp this batch was returned from.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedCursor ↔ String?
A cursor that points to the position after the last skipped result.
getter/setter pair
skippedCursorAsBytes ↔ List<int>
getter/setter pair
skippedResults ↔ int?
The number of results skipped, typically because of an offset.
getter/setter pair
snapshotVersion ↔ String?
The version number of the snapshot this batch was returned from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited