ReadOptions class

The options shared by read requests.

Constructors

ReadOptions({TransactionOptions? newTransaction, String? readConsistency, String? readTime, String? transaction})
ReadOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
newTransaction ↔ TransactionOptions?
Options for beginning a new transaction for this request.
getter/setter pair
readConsistency ↔ String?
The non-transactional read consistency to use. Possible string values are:
getter/setter pair
readTime ↔ String?
Reads entities as they were at the given time.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction ↔ String?
The identifier of the transaction in which to read.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited