RunAggregationQueryRequest class

The request for Datastore.RunAggregationQuery.

Constructors

RunAggregationQueryRequest({AggregationQuery? aggregationQuery, String? databaseId, ExplainOptions? explainOptions, GqlQuery? gqlQuery, PartitionId? partitionId, ReadOptions? readOptions, RequestOptions? requestOptions})
RunAggregationQueryRequest.fromJson(Map json_)

Properties

aggregationQuery ↔ AggregationQuery?
The query to run.
getter/setter pair
databaseId ↔ String?
The ID of the database against which to make the request.
getter/setter pair
explainOptions ↔ ExplainOptions?
Explain options for the query.
getter/setter pair
gqlQuery ↔ GqlQuery?
The GQL query to run.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partitionId ↔ PartitionId?
Entities are partitioned into subsets, identified by a partition ID.
getter/setter pair
readOptions ↔ ReadOptions?
The options for this query.
getter/setter pair
requestOptions ↔ RequestOptions?
The options for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited