RunQueryResponse class

The response for Datastore.RunQuery.

Constructors

RunQueryResponse({QueryResultBatch? batch, ExplainMetrics? explainMetrics, Query? query, String? transaction})
RunQueryResponse.fromJson(Map json_)

Properties

batch ↔ QueryResultBatch?
A batch of query results.
getter/setter pair
explainMetrics ↔ ExplainMetrics?
Query explain metrics.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
query ↔ Query?
The parsed form of the GqlQuery from the request, if it was set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction ↔ String?
The identifier of the transaction that was started as part of this RunQuery request.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited