Value class

A message that can hold any of the supported value types and associated metadata.

Constructors

Value({ArrayValue? arrayValue, String? blobValue, bool? booleanValue, double? doubleValue, Entity? entityValue, bool? excludeFromIndexes, LatLng? geoPointValue, String? integerValue, Key? keyValue, int? meaning, String? nullValue, String? stringValue, String? timestampValue})
Value.fromJson(Map json_)

Properties

arrayValue ↔ ArrayValue?
An array value.
getter/setter pair
blobValue ↔ String?
A blob value.
getter/setter pair
blobValueAsBytes ↔ List<int>
getter/setter pair
booleanValue ↔ bool?
A boolean value.
getter/setter pair
doubleValue ↔ double?
A double value.
getter/setter pair
entityValue ↔ Entity?
An entity value.
getter/setter pair
excludeFromIndexes ↔ bool?
If the value should be excluded from all indexes including those defined explicitly.
getter/setter pair
geoPointValue ↔ LatLng?
A geo point value representing a point on the surface of Earth.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integerValue ↔ String?
An integer value.
getter/setter pair
keyValue ↔ Key?
A key value.
getter/setter pair
meaning ↔ int?
The meaning field should only be populated for backwards compatibility.
getter/setter pair
nullValue ↔ String?
A null value. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue ↔ String?
A UTF-8 encoded string value.
getter/setter pair
timestampValue ↔ String?
A timestamp value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited