BigQueryDestinationConfig class

BigQuery destination configuration

Constructors

BigQueryDestinationConfig({AppendOnly? appendOnly, BlmtConfig? blmtConfig, String? dataFreshness, Merge? merge, SingleTargetDataset? singleTargetDataset, SourceHierarchyDatasets? sourceHierarchyDatasets})
BigQueryDestinationConfig.fromJson(Map json_)

Properties

appendOnly ↔ AppendOnly?
Append only mode
getter/setter pair
blmtConfig ↔ BlmtConfig?
Big Lake Managed Tables (BLMT) configuration.
getter/setter pair
dataFreshness ↔ String?
The guaranteed data freshness (in seconds) when querying tables created by the stream.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merge ↔ AppendOnly?
The standard mode
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleTargetDataset ↔ SingleTargetDataset?
Single destination dataset.
getter/setter pair
sourceHierarchyDatasets ↔ SourceHierarchyDatasets?
Source hierarchy datasets.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited