BinaryLogParser class

Configuration to use Binary Log Parser CDC technique.

Constructors

BinaryLogParser({LogFileDirectories? logFileDirectories, OracleAsmLogFileAccess? oracleAsmLogFileAccess})
BinaryLogParser.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logFileDirectories ↔ LogFileDirectories?
Use Oracle directories.
getter/setter pair
oracleAsmLogFileAccess ↔ AppendOnly?
Use Oracle ASM.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited