DestinationConfig class

The configuration of the stream destination.

Constructors

DestinationConfig({BigQueryDestinationConfig? bigqueryDestinationConfig, String? destinationConnectionProfile, GcsDestinationConfig? gcsDestinationConfig})
DestinationConfig.fromJson(Map json_)

Properties

bigqueryDestinationConfig ↔ BigQueryDestinationConfig?
BigQuery destination configuration.
getter/setter pair
destinationConnectionProfile ↔ String?
Destination connection profile resource.
getter/setter pair
gcsDestinationConfig ↔ GcsDestinationConfig?
A configuration for how data should be loaded to Cloud Storage.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited