sourceCatalog property
Source catalog to enrich with child data objects and metadata.
This is mainly used to represent SaaS sources databases.
Optional.
Implementation
SourceCatalog? sourceCatalog;
Source catalog to enrich with child data objects and metadata.
This is mainly used to represent SaaS sources databases.
Optional.
SourceCatalog? sourceCatalog;