GcsDestinationConfig class

Google Cloud Storage destination configuration

Constructors

GcsDestinationConfig({AvroFileFormat? avroFileFormat, String? fileRotationInterval, int? fileRotationMb, JsonFileFormat? jsonFileFormat, String? path})
GcsDestinationConfig.fromJson(Map json_)

Properties

avroFileFormat ↔ AppendOnly?
AVRO file format configuration.
getter/setter pair
fileRotationInterval ↔ String?
The maximum duration for which new events are added before a file is closed and a new file is created.
getter/setter pair
fileRotationMb ↔ int?
The maximum file size to be saved in the bucket.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonFileFormat ↔ JsonFileFormat?
JSON file format configuration.
getter/setter pair
path ↔ String?
Path inside the Cloud Storage bucket to write data to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited