OauthRefreshTokenCredentials class

OAuth Refresh Token Credentials.

Constructors

OauthRefreshTokenCredentials({OauthClientCredentials? oauthClientCredentials, Secret? refreshToken})
OauthRefreshTokenCredentials.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
oauthClientCredentials OauthClientCredentials?
Specifies the OAuth Client Credentials.
getter/setter pair
refreshToken Secret?
Specifies the OAuth Refresh Token.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited