OracleSslConfig class

Oracle SSL configuration information.

Constructors

OracleSslConfig({String? caCertificate, bool? caCertificateSet, String? serverCertificateDistinguishedName})
OracleSslConfig.fromJson(Map json_)

Properties

caCertificate ↔ String?
Input only.
getter/setter pair
caCertificateSet ↔ bool?
Indicates whether the ca_certificate field has been set for this Connection-Profile.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverCertificateDistinguishedName ↔ String?
The distinguished name (DN) mentioned in the server certificate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited