OracleTable class

Oracle table.

Constructors

OracleTable({List<OracleColumn>? oracleColumns, String? table})
OracleTable.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
oracleColumns ↔ List<OracleColumn>?
Oracle columns in the schema.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table ↔ String?
The table name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited