PostgresqlProfile class

Profile for connecting to a PostgreSQL source.

Constructors

PostgresqlProfile({String? database, String? hostname, String? password, int? port, String? secretManagerStoredPassword, PostgresqlSslConfig? sslConfig, String? username})
PostgresqlProfile.fromJson(Map json_)

Properties

database ↔ String?
Database for the PostgreSQL connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
Hostname for the PostgreSQL connection.
getter/setter pair
password ↔ String?
Password for the PostgreSQL connection.
getter/setter pair
port ↔ int?
Port for the PostgreSQL connection, default value is 5432.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretManagerStoredPassword ↔ String?
A reference to a Secret Manager resource name storing the PostgreSQL connection password.
getter/setter pair
sslConfig ↔ PostgresqlSslConfig?
SSL configuration for the PostgreSQL connection.
getter/setter pair
username ↔ String?
Username for the PostgreSQL connection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited