PostgresqlSourceConfig class

Configuration for syncing data from a PostgreSQL source.

Constructors

PostgresqlSourceConfig({PostgresqlRdbms? excludeObjects, PostgresqlRdbms? includeObjects, int? maxConcurrentBackfillTasks, String? publication, String? replicationSlot})
PostgresqlSourceConfig.fromJson(Map json_)

Properties

excludeObjects ↔ PostgresqlRdbms?
The PostgreSQL objects to exclude from the stream.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeObjects ↔ PostgresqlRdbms?
The PostgreSQL objects to include in the stream.
getter/setter pair
maxConcurrentBackfillTasks ↔ int?
Maximum number of concurrent backfill tasks.
getter/setter pair
publication ↔ String?
The name of the publication that includes the set of all tables that are defined in the stream's include_objects.
getter/setter pair
replicationSlot ↔ String?
The name of the logical replication slot that's configured with the pgoutput plugin.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited