PostgresqlSslConfig class

PostgreSQL SSL configuration information.

Constructors

PostgresqlSslConfig({ServerAndClientVerification? serverAndClientVerification, ServerVerification? serverVerification})
PostgresqlSslConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverAndClientVerification ↔ ServerAndClientVerification?
If this field is set, the communication will be encrypted with TLS encryption and both the server identity and the client identity will be authenticated.
getter/setter pair
serverVerification ↔ ServerVerification?
If this field is set, the communication will be encrypted with TLS encryption and the server identity will be authenticated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited