RuleSet class

A set of rules to apply to a set of objects.

Constructors

RuleSet({List<CustomizationRule>? customizationRules, ObjectFilter? objectFilter})
RuleSet.fromJson(Map json_)

Properties

customizationRules ↔ List<CustomizationRule>?
List of customization rules to apply.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectFilter ↔ ObjectFilter?
Object filter to apply the customization rules to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited