SalesforceMarketingCloudSourceConfig class

Configuration for syncing data from a Salesforce Marketing Cloud source.

Constructors

SalesforceMarketingCloudSourceConfig({SourceCatalog? excludeObjects, String? fullRefreshPollingInterval, SourceCatalog? includeObjects, String? pollingInterval})
SalesforceMarketingCloudSourceConfig.fromJson(Map json_)

Properties

excludeObjects SourceCatalog?
The objects to exclude from the stream.
getter/setter pair
fullRefreshPollingInterval String?
Specifies the polling interval for a full refresh of objects that do not support incremental sync.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
includeObjects SourceCatalog?
The objects to retrieve from the source.
getter/setter pair
pollingInterval String?
Incremental sync polling interval for all objects.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited