Secret class

A confidential piece of information where the actual value is either directly specified in the message as a raw string or stored in GCP secret manager.

Constructors

Secret({String? rawValue, String? secretVersion})
Secret.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
rawValue String?
Input only.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretVersion String?
A Secret Manager resource name storing the actual value of the secret.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited