ServiceNowProfile class
Profile for connecting to a ServiceNow source.
Constructors
- ServiceNowProfile({String? instance, OauthClientCredentials? oauthClientCredentials, UserPasswordCredentials? userPasswordCredentials})
- ServiceNowProfile.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance ↔ String?
-
The instance of the ServiceNow account.
getter/setter pair
- oauthClientCredentials ↔ OauthClientCredentials?
-
Credentials for authenticating with the ServiceNow API.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userPasswordCredentials ↔ UserPasswordCredentials?
-
User-password authentication.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited