SourceConfig class

The configuration of the stream source.

Constructors

SourceConfig({DataverseSourceConfig? dataverseSourceConfig, MongodbSourceConfig? mongodbSourceConfig, MysqlSourceConfig? mysqlSourceConfig, OracleSourceConfig? oracleSourceConfig, PostgresqlSourceConfig? postgresqlSourceConfig, SalesforceMarketingCloudSourceConfig? salesforceMarketingCloudSourceConfig, SalesforceSourceConfig? salesforceSourceConfig, ServiceNowSourceConfig? serviceNowSourceConfig, String? sourceConnectionProfile, SpannerSourceConfig? spannerSourceConfig, SqlServerSourceConfig? sqlServerSourceConfig, WorkdaySourceConfig? workdaySourceConfig})
SourceConfig.fromJson(Map json_)

Properties

dataverseSourceConfig DataverseSourceConfig?
Dataverse data source configuration.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mongodbSourceConfig MongodbSourceConfig?
MongoDB data source configuration.
getter/setter pair
mysqlSourceConfig MysqlSourceConfig?
MySQL data source configuration.
getter/setter pair
oracleSourceConfig OracleSourceConfig?
Oracle data source configuration.
getter/setter pair
postgresqlSourceConfig PostgresqlSourceConfig?
PostgreSQL data source configuration.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salesforceMarketingCloudSourceConfig SalesforceMarketingCloudSourceConfig?
Salesforce Marketing Cloud data source configuration.
getter/setter pair
salesforceSourceConfig SalesforceSourceConfig?
Salesforce data source configuration.
getter/setter pair
serviceNowSourceConfig ServiceNowSourceConfig?
ServiceNow data source configuration.
getter/setter pair
sourceConnectionProfile String?
Source connection profile resource.
getter/setter pair
spannerSourceConfig SpannerSourceConfig?
Spanner data source configuration.
getter/setter pair
sqlServerSourceConfig SqlServerSourceConfig?
SQLServer data source configuration.
getter/setter pair
workdaySourceConfig WorkdaySourceConfig?
Workday data source configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited