SourceObject class
Source object.
Constructors
-
SourceObject({String? objectName, List<
SourceProperty> ? properties}) - SourceObject.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- objectName ↔ String?
-
The object name.
getter/setter pair
-
properties
↔ List<
SourceProperty> ? -
Source properties.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited