properties property

List<SourceProperty>? properties
getter/setter pair

Source properties.

When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing.

Optional.

Implementation

core.List<SourceProperty>? properties;