SourceProperty class

Source property.

Constructors

SourceProperty({bool? primaryKey, List<SourceProperty>? properties, String? propertyName})
SourceProperty.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
primaryKey bool?
Whether or not the property is a primary key.
getter/setter pair
properties List<SourceProperty>?
Source properties.
getter/setter pair
propertyName String?
The property name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited