properties property
Source properties.
When specified, it means that the current property contains nested properties of its own. When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing.
Optional.
Implementation
core.List<SourceProperty>? properties;