SpannerSourceConfig class

Configuration for syncing data from a Spanner source.

Constructors

SpannerSourceConfig({bool? backfillDataBoostEnabled, String? changeStreamName, SpannerDatabase? excludeObjects, String? fgacRole, SpannerDatabase? includeObjects, int? maxConcurrentBackfillTasks, int? maxConcurrentCdcTasks, String? spannerRpcPriority})
SpannerSourceConfig.fromJson(Map json_)

Properties

backfillDataBoostEnabled ↔ bool?
Whether to use Data Boost for Spanner backfills.
getter/setter pair
changeStreamName ↔ String?
The change stream name to use for the stream.
getter/setter pair
excludeObjects ↔ SpannerDatabase?
The Spanner objects to avoid retrieving.
getter/setter pair
fgacRole ↔ String?
The FGAC role to use for the stream.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeObjects ↔ SpannerDatabase?
The Spanner objects to retrieve from the data source.
getter/setter pair
maxConcurrentBackfillTasks ↔ int?
Maximum number of concurrent backfill tasks.
getter/setter pair
maxConcurrentCdcTasks ↔ int?
Maximum number of concurrent CDC tasks.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spannerRpcPriority ↔ String?
The RPC priority to use for the stream.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited