SqlServerSourceConfig class

Configuration for syncing data from a SQLServer source.

Constructors

SqlServerSourceConfig({SqlServerChangeTables? changeTables, SqlServerRdbms? excludeObjects, SqlServerRdbms? includeObjects, int? maxConcurrentBackfillTasks, int? maxConcurrentCdcTasks, SqlServerTransactionLogs? transactionLogs})
SqlServerSourceConfig.fromJson(Map json_)

Properties

changeTables ↔ AppendOnly?
CDC reader reads from change tables.
getter/setter pair
excludeObjects ↔ SqlServerRdbms?
The SQLServer objects to exclude from the stream.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeObjects ↔ SqlServerRdbms?
The SQLServer objects to include in the stream.
getter/setter pair
maxConcurrentBackfillTasks ↔ int?
Max concurrent backfill tasks.
getter/setter pair
maxConcurrentCdcTasks ↔ int?
Max concurrent CDC tasks.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transactionLogs ↔ AppendOnly?
CDC reader reads from transaction logs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited