SqlServerSslConfig class

SQL Server SSL configuration information.

Constructors

SqlServerSslConfig({BasicEncryption? basicEncryption, EncryptionAndServerValidation? encryptionAndServerValidation, EncryptionNotEnforced? encryptionNotEnforced})
SqlServerSslConfig.fromJson(Map json_)

Properties

basicEncryption ↔ AppendOnly?
If set, Datastream will enforce encryption without authenticating server identity.
getter/setter pair
encryptionAndServerValidation ↔ EncryptionAndServerValidation?
If set, Datastream will enforce encryption and authenticate server identity.
getter/setter pair
encryptionNotEnforced ↔ AppendOnly?
If set, Datastream will not enforce encryption.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited