SqlServerTable class

SQLServer table.

Constructors

SqlServerTable({List<SqlServerColumn>? columns, String? table})
SqlServerTable.fromJson(Map json_)

Properties

columns ↔ List<SqlServerColumn>?
SQLServer columns in the schema.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table ↔ String?
The table name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited