StandardConnectionFormat class

Standard connection format.

Constructors

StandardConnectionFormat({bool? directConnection})
StandardConnectionFormat.fromJson(Map json_)

Properties

directConnection ↔ bool?
Deprecated: Use the additional_options map to specify the directConnection parameter instead.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited