eventFilter property
Optional event filter.
If not set, or empty, the backfill will be performed on the entire object. This is currently used for partial backfill and only supported for SQL sources.
Optional.
Implementation
EventFilter? eventFilter;
Optional event filter.
If not set, or empty, the backfill will be performed on the entire object. This is currently used for partial backfill and only supported for SQL sources.
Optional.
EventFilter? eventFilter;