Stream class

A resource representing streaming data from a source to a destination.

Constructors

Stream({BackfillAllStrategy? backfillAll, BackfillNoneStrategy? backfillNone, String? createTime, String? customerManagedEncryptionKey, DestinationConfig? destinationConfig, String? displayName, List<Error>? errors, Map<String, String>? labels, String? lastRecoveryTime, String? name, List<RuleSet>? ruleSets, bool? satisfiesPzi, bool? satisfiesPzs, SourceConfig? sourceConfig, String? state, String? updateTime})
Stream.fromJson(Map json_)

Properties

backfillAll ↔ BackfillAllStrategy?
Automatically backfill objects included in the stream source configuration.
getter/setter pair
backfillNone ↔ AppendOnly?
Do not automatically backfill any objects.
getter/setter pair
createTime ↔ String?
The creation time of the stream.
getter/setter pair
customerManagedEncryptionKey ↔ String?
A reference to a KMS encryption key.
getter/setter pair
destinationConfig ↔ DestinationConfig?
Destination connection profile configuration.
getter/setter pair
displayName ↔ String?
Display name.
getter/setter pair
errors ↔ List<Error>?
Errors on the Stream.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels.
getter/setter pair
lastRecoveryTime ↔ String?
If the stream was recovered, the time of the last recovery.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
ruleSets ↔ List<RuleSet>?
Rule sets to apply to the stream.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
sourceConfig ↔ SourceConfig?
Source connection profile configuration.
getter/setter pair
state ↔ String?
The state of the stream. Possible string values are:
getter/setter pair
updateTime ↔ String?
The last update time of the stream.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited