StreamObject class

A specific stream object (e.g a specific DB table).

Constructors

StreamObject({BackfillJob? backfillJob, String? createTime, List<CustomizationRule>? customizationRules, String? displayName, List<Error>? errors, String? name, SourceObjectIdentifier? sourceObject, String? updateTime})
StreamObject.fromJson(Map json_)

Properties

backfillJob ↔ BackfillJob?
The latest backfill job that was initiated for the stream object.
getter/setter pair
createTime ↔ String?
The creation time of the object.
getter/setter pair
customizationRules ↔ List<CustomizationRule>?
The customization rules for the object.
getter/setter pair
displayName ↔ String?
Display name.
getter/setter pair
errors ↔ List<Error>?
Active errors on the object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceObject ↔ SourceObjectIdentifier?
The object identifier in the data source.
getter/setter pair
updateTime ↔ String?
The last update time of the object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited