UserCredentials class

Deprecated: Salesforce is retiring Username-Password authentication.

Use Oauth2ClientCredentials instead.

Constructors

UserCredentials({String? password, String? secretManagerStoredPassword, String? secretManagerStoredSecurityToken, String? securityToken, String? username})
UserCredentials.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
password ↔ String?
Password for the Salesforce connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretManagerStoredPassword ↔ String?
A reference to a Secret Manager resource name storing the Salesforce connection's password.
getter/setter pair
secretManagerStoredSecurityToken ↔ String?
A reference to a Secret Manager resource name storing the Salesforce connection's security token.
getter/setter pair
securityToken ↔ String?
Security token for the Salesforce connection.
getter/setter pair
username ↔ String?
Username for the Salesforce connection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited