UserPasswordCredentials class

User-password credentials.

Constructors

UserPasswordCredentials({Secret? password, String? username})
UserPasswordCredentials.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
password Secret?
Password for the connection.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String?
Username for the connection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited