WorkdayProfile class

Profile for connecting to a Workday source.

Constructors

WorkdayProfile({String? host, OauthRefreshTokenCredentials? oauthRefreshTokenCredentials, String? tenant})
WorkdayProfile.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
host String?
Host for the Workday connection.
getter/setter pair
oauthRefreshTokenCredentials OauthRefreshTokenCredentials?
Credentials for authenticating with the Workday API.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenant String?
Tenant for the Workday connection (e.g., google12).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited