oauthRefreshTokenCredentials property
Credentials for authenticating with the Workday API.
OAuth Refresh Token credentials for authenticating with the Workday API.
Required.
Implementation
OauthRefreshTokenCredentials? oauthRefreshTokenCredentials;
Credentials for authenticating with the Workday API.
OAuth Refresh Token credentials for authenticating with the Workday API.
Required.
OauthRefreshTokenCredentials? oauthRefreshTokenCredentials;