allocatedPriority property
The priority allocated for the firewall policy rule if query parameters specified minPriority/maxPriority.
Implementation
core.int? allocatedPriority;
The priority allocated for the firewall policy rule if query parameters specified minPriority/maxPriority.
core.int? allocatedPriority;