ResourcesListResponse class

A response containing a partial list of resources and a page token used to build the next request if the request has been truncated.

Constructors

ResourcesListResponse({String? nextPageToken, List<Resource>? resources})
ResourcesListResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token used to continue a truncated list request.
getter/setter pair
resources ↔ List<Resource>?
Resources contained in this list response.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited