Connection class

Message describing Connection object

Constructors

Connection({Map<String, String>? annotations, BitbucketCloudConfig? bitbucketCloudConfig, BitbucketDataCenterConfig? bitbucketDataCenterConfig, String? createTime, CryptoKeyConfig? cryptoKeyConfig, String? deleteTime, bool? disabled, String? etag, GitProxyConfig? gitProxyConfig, GitHubConfig? githubConfig, GitHubEnterpriseConfig? githubEnterpriseConfig, GitLabConfig? gitlabConfig, GitLabEnterpriseConfig? gitlabEnterpriseConfig, GenericHTTPEndpointConfig? httpConfig, InstallationState? installationState, Map<String, String>? labels, String? name, bool? reconciling, SecureSourceManagerInstanceConfig? secureSourceManagerInstanceConfig, String? uid, String? updateTime})
Connection.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Allows clients to store small amounts of arbitrary data.
getter/setter pair
bitbucketCloudConfig ↔ BitbucketCloudConfig?
Configuration for connections to an instance of Bitbucket Clouds.
getter/setter pair
bitbucketDataCenterConfig ↔ BitbucketDataCenterConfig?
Configuration for connections to an instance of Bitbucket Data Center.
getter/setter pair
createTime ↔ String?
Create timestamp
getter/setter pair
cryptoKeyConfig ↔ CryptoKeyConfig?
The crypto key configuration.
getter/setter pair
deleteTime ↔ String?
Delete timestamp
getter/setter pair
disabled ↔ bool?
If disabled is set to true, functionality is disabled for this connection.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
githubConfig ↔ GitHubConfig?
Configuration for connections to github.com.
getter/setter pair
githubEnterpriseConfig ↔ GitHubEnterpriseConfig?
Configuration for connections to an instance of GitHub Enterprise.
getter/setter pair
gitlabConfig ↔ GitLabConfig?
Configuration for connections to gitlab.com.
getter/setter pair
gitlabEnterpriseConfig ↔ GitLabEnterpriseConfig?
Configuration for connections to an instance of GitLab Enterprise.
getter/setter pair
gitProxyConfig ↔ GitProxyConfig?
Configuration for the git proxy feature.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpConfig ↔ GenericHTTPEndpointConfig?
Configuration for connections to an HTTP service provider.
getter/setter pair
installationState ↔ InstallationState?
Installation state of the Connection.
getter/setter pair
labels ↔ Map<String, String>?
Labels as key value pairs
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
reconciling ↔ bool?
Set to true when the connection is being set up or updated in the background.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureSourceManagerInstanceConfig ↔ SecureSourceManagerInstanceConfig?
Configuration for connections to an instance of Secure Source Manager.
getter/setter pair
uid ↔ String?
A system-assigned unique identifier for the Connection.
getter/setter pair
updateTime ↔ String?
Update timestamp
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited