gitProxyConfig property

GitProxyConfig? gitProxyConfig
getter/setter pair

Configuration for the git proxy feature.

Enabling the git proxy allows clients to perform git operations on the repositories linked in the connection. Learn more.

Optional.

Implementation

GitProxyConfig? gitProxyConfig;