CryptoKeyConfig class

The crypto key configuration.

This field is used by the Customer-managed encryption keys (CMEK) feature.

Constructors

CryptoKeyConfig({String? keyReference})
CryptoKeyConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyReference ↔ String?
The name of the key which is used to encrypt/decrypt customer data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited