CustomOAuthConfig class

Message for a customized OAuth config.

Constructors

CustomOAuthConfig({String? authUri, String? clientId, String? clientSecret, String? hostUri, bool? pkceDisabled, String? scmProvider, List<String>? scopes, String? serverVersion, ServiceDirectoryConfig? serviceDirectoryConfig, String? sslCaCertificate, String? tokenUri})
CustomOAuthConfig.fromJson(Map json_)

Properties

authUri String?
The OAuth2 authorization server URL.
getter/setter pair
clientId String?
The client ID of the OAuth application.
getter/setter pair
clientSecret String?
Input only.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hostUri String?
The host URI of the OAuth application.
getter/setter pair
pkceDisabled bool?
Disable PKCE for this OAuth config.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scmProvider String?
The type of the SCM provider.
getter/setter pair
scopes List<String>?
The scopes to be requested during OAuth.
getter/setter pair
serverVersion String?
SCM server version installed at the host URI.
getter/setter pair
serviceDirectoryConfig ServiceDirectoryConfig?
Configuration for using Service Directory to connect to a private service.
getter/setter pair
sslCaCertificate String?
SSL certificate to use for requests to a private service.
getter/setter pair
tokenUri String?
The OAuth2 token request URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited