clientSecret property

String? clientSecret
getter/setter pair

Input only.

The client secret of the OAuth application. It will be provided as plain text, but encrypted and stored in developer connect. As INPUT_ONLY field, it will not be included in the output.

Required.

Implementation

core.String? clientSecret;