ExchangeError class

Message for representing an error from exchanging OAuth tokens.

Constructors

ExchangeError({String? code, String? description})
ExchangeError.fromJson(Map json_)

Properties

code ↔ String?
https://datatracker.ietf.org/doc/html/rfc6749#section-5.2 - error
getter/setter pair
description ↔ String?
https://datatracker.ietf.org/doc/html/rfc6749#section-5.2 - error_description
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited