FetchAccessTokenResponse class

Message for responding to getting an OAuth access token.

Constructors

FetchAccessTokenResponse({ExchangeError? exchangeError, String? expirationTime, List<String>? scopes, String? token})
FetchAccessTokenResponse.fromJson(Map json_)

Properties

exchangeError ↔ ExchangeError?
The error resulted from exchanging OAuth tokens from the service provider.
getter/setter pair
expirationTime ↔ String?
Expiration timestamp.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>?
The scopes of the access token.
getter/setter pair
token ↔ String?
The token content.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited