FetchLinkableGitRepositoriesResponse class

Response message for FetchLinkableGitRepositories.

Properties

hashCode → int
The hash code for this object.
no setterinherited
linkableGitRepositories ↔ List<LinkableGitRepository>?
The git repositories that can be linked to the connection.
getter/setter pair
nextPageToken ↔ String?
A token identifying a page of results the server should return.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited