userRepos property
The repositories that the user can access with this account connector.
Implementation
core.List<UserRepository>? userRepos;
The repositories that the user can access with this account connector.
core.List<UserRepository>? userRepos;