GKEWorkload class

GKEWorkload represents the Google Kubernetes Engine runtime.

Constructors

GKEWorkload({String? cluster, String? deployment})
GKEWorkload.fromJson(Map json_)

Properties

cluster ↔ String?
The name of the GKE cluster.
getter/setter pair
deployment ↔ String?
The name of the GKE deployment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited