GenericHTTPEndpointConfig class

Defines the configuration for connections to an HTTP service provider.

Constructors

GenericHTTPEndpointConfig({BasicAuthentication? basicAuthentication, BearerTokenAuthentication? bearerTokenAuthentication, String? hostUri, ServiceDirectoryConfig? serviceDirectoryConfig, String? sslCaCertificate})
GenericHTTPEndpointConfig.fromJson(Map json_)

Properties

basicAuthentication ↔ BasicAuthentication?
Basic authentication with username and password.
getter/setter pair
bearerTokenAuthentication ↔ BearerTokenAuthentication?
Bearer token authentication with a token.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostUri ↔ String?
The service provider's https endpoint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceDirectoryConfig ↔ ServiceDirectoryConfig?
Configuration for using Service Directory to privately connect to a HTTP service provider.
getter/setter pair
sslCaCertificate ↔ String?
The SSL certificate to use for requests to the HTTP service provider.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited