GitHubEnterpriseConfig class

Configuration for connections to an instance of GitHub Enterprise.

Constructors

GitHubEnterpriseConfig({String? appId, String? appInstallationId, String? appSlug, String? hostUri, String? installationUri, String? organization, String? privateKeySecretVersion, String? serverVersion, ServiceDirectoryConfig? serviceDirectoryConfig, String? sslCaCertificate, String? webhookSecretSecretVersion})
GitHubEnterpriseConfig.fromJson(Map json_)

Properties

appId ↔ String?
ID of the GitHub App created from the manifest.
getter/setter pair
appInstallationId ↔ String?
ID of the installation of the GitHub App.
getter/setter pair
appSlug ↔ String?
The URL-friendly name of the GitHub App.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostUri ↔ String?
The URI of the GitHub Enterprise host this connection is for.
getter/setter pair
installationUri ↔ String?
The URI to navigate to in order to manage the installation associated with this GitHubEnterpriseConfig.
getter/setter pair
organization ↔ String?
GitHub Enterprise organization in which the GitHub App is created.
getter/setter pair
privateKeySecretVersion ↔ String?
SecretManager resource containing the private key of the GitHub App, formatted as projects / * /secrets / * /versions / * or projects / * /locations / * /secrets / * /versions / * (if regional secrets are supported in that location).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverVersion ↔ String?
GitHub Enterprise version installed at the host_uri.
getter/setter pair
serviceDirectoryConfig ↔ ServiceDirectoryConfig?
Configuration for using Service Directory to privately connect to a GitHub Enterprise server.
getter/setter pair
sslCaCertificate ↔ String?
SSL certificate to use for requests to GitHub Enterprise.
getter/setter pair
webhookSecretSecretVersion ↔ String?
SecretManager resource containing the webhook secret of the GitHub App, formatted as projects / * /secrets / * /versions / * or projects / * /locations / * /secrets / * /versions / * (if regional secrets are supported in that location).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited