GoogleArtifactRegistry class

Google Artifact Registry configurations.

Constructors

GoogleArtifactRegistry({String? artifactRegistryPackage, String? projectId})
GoogleArtifactRegistry.fromJson(Map json_)

Properties

artifactRegistryPackage ↔ String?
The name of the artifact registry package.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
projectId ↔ String?
The host project of Artifact Registry.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited