ListConnectionsResponse class

Message for response to listing Connections

Constructors

ListConnectionsResponse({List<Connection>? connections, String? nextPageToken, List<String>? unreachable})
ListConnectionsResponse.fromJson(Map json_)

Properties

connections ↔ List<Connection>?
The list of Connection
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token identifying a page of results the server should return.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited