ListInsightsConfigsResponse class

Request for response to listing InsightsConfigs.

Constructors

ListInsightsConfigsResponse({List<InsightsConfig>? insightsConfigs, String? nextPageToken, List<String>? unreachable})
ListInsightsConfigsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
insightsConfigs ↔ List<InsightsConfig>?
The list of InsightsConfigs.
getter/setter pair
nextPageToken ↔ String?
A token identifying a page of results the server should return.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited