list method
Lists Deployment Events in a given insights config.
Request parameters:
parent - Required. The parent insights config that owns this collection
of deployment events. Format:
projects/{project}/locations/{location}/insightsConfigs/{insights_config}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/insightsConfigs/\[^/\]+$.
filter - Optional. Filter expression that matches a subset of the
DeploymentEvents. https://google.aip.dev/160.
orderBy - Optional. Field to use to order the list of DeploymentEvents.
Expects AIP-132 format "field_name asc" or "field_name desc", e.g.
"deploy_time desc" Supported fields for ordering are: deploy_time,
update_time. Currently, only sorting by a single field is supported. If
this field is not provided, the list will be sorted by "deploy_time desc".
For more details on the ordering syntax, see
https://google.aip.dev/132#ordering.
pageSize - Optional. The maximum number of deployment events to return.
The service may return fewer than this value. If unspecified, at most 50
deployment events will be returned. The maximum value is 1000; values
above 1000 will be coerced to 1000.
pageToken - Optional. A page token, received from a previous
ListDeploymentEvents call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListDeploymentEvents
must match the call that provided the page token.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListDeploymentEventsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListDeploymentEventsResponse> list(
core.String parent, {
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/deploymentEvents';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListDeploymentEventsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}