RuntimeConfig class

RuntimeConfig represents the runtimes where the application is deployed.

Constructors

RuntimeConfig({AppHubService? appHubService, AppHubWorkload? appHubWorkload, GKEWorkload? gkeWorkload, GoogleCloudRun? googleCloudRun, String? state, String? uri})
RuntimeConfig.fromJson(Map json_)

Properties

appHubService ↔ AppHubService?
App Hub Service.
getter/setter pair
appHubWorkload ↔ AppHubWorkload?
App Hub Workload.
getter/setter pair
gkeWorkload ↔ GKEWorkload?
Google Kubernetes Engine runtime.
getter/setter pair
googleCloudRun ↔ GoogleCloudRun?
Cloud Run runtime.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the Runtime.
getter/setter pair
uri ↔ String?
The URI of the runtime configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited