SecureSourceManagerInstanceConfig class

Configuration for connections to Secure Source Manager instance

Properties

hashCode → int
The hash code for this object.
no setterinherited
instance ↔ String?
Secure Source Manager instance resource, formatted as projects / * /locations / * /instances / *
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited