UserRepository class

A user repository that can be linked to the account connector.

Consists of the repo name and the git proxy URL to forward requests to this repo.

Constructors

UserRepository({String? cloneUri, String? displayName, String? gitProxyUri})
UserRepository.fromJson(Map json_)

Properties

cloneUri String?
The git clone URL of the repo.
getter/setter pair
displayName String?
The user friendly repo name (e.g., myuser/myrepo)
getter/setter pair
gitProxyUri String?
The Git proxy URL for this repo.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited