gitProxyUri property

String? gitProxyUri
getter/setter pair

The Git proxy URL for this repo.

For example: https://us-west1-git.developerconnect.dev/a/my-proj/my-ac/myuser/myrepo.git. Populated only when proxy_config.enabled is set to true in the Account Connector. This URL is used by other Google services that integrate with Developer Connect.

Output only.

Implementation

core.String? gitProxyUri;