Answer class
An answer to a query.
Constructors
-
Answer({String? answerText, List<
AnswerCitation> ? citations, List<AnswerReference> ? references}) - Answer.fromJson(Map json_)
Properties
- answerText ↔ String?
-
Contains the text of the answer.
getter/setter pair
-
citations
↔ List<
AnswerCitation> ? -
Contains citations for the answer.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
references
↔ List<
AnswerReference> ? -
Contains references for the answer.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited