AnswerCitation class
Citation info for a segment.
Constructors
-
AnswerCitation({int? endIndex, List<
CitationSource> ? sources, int? startIndex}) - AnswerCitation.fromJson(Map json_)
Properties
- endIndex ↔ int?
-
Indicates the end of the segment, measured in bytes (UTF-8 unicode),
exclusive.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sources
↔ List<
CitationSource> ? -
Contains citation sources for the attributed segment.
getter/setter pair
- startIndex ↔ int?
-
Indicates the start of the segment, measured in bytes (UTF-8 unicode),
inclusive.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited