endIndex property

int? endIndex
getter/setter pair

Indicates the end of the segment, measured in bytes (UTF-8 unicode), exclusive.

If there are multi-byte characters, such as non-ASCII characters, the index measurement is longer than the string length.

Output only.

Implementation

core.int? endIndex;