AnswerReference class

Represents a reference to a source.

Constructors

AnswerReference({DocumentReference? documentReference})
AnswerReference.fromJson(Map json_)

Properties

documentReference DocumentReference?
The reference document.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited