CitationSource class
Citation source.
Constructors
- CitationSource({int? referenceIndex})
- CitationSource.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- referenceIndex ↔ int?
-
Contains the index of the Answer.AnswerReference in the
referencesrepeated field.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited