Document class

A Document represents a page of documentation in the Developer Knowledge corpus, like the page at https://docs.cloud.google.com/storage/docs/creating-buckets.

Constructors

Document({String? content, int? contentLengthBytes, String? dataSource, String? description, String? name, String? title, String? updateTime, String? uri, String? view})
Document.fromJson(Map json_)

Properties

content String?
Contains the full content of the document in Markdown format.
getter/setter pair
contentLengthBytes int?
The length of the content field in bytes.
getter/setter pair
dataSource String?
Specifies the data source of the document.
getter/setter pair
description String?
Provides a description of the document.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Provides the title of the document.
getter/setter pair
updateTime String?
Represents the timestamp when the content or metadata of the document was last updated.
getter/setter pair
uri String?
Provides the URI of the content, such as docs.cloud.google.com/storage/docs/creating-buckets.
getter/setter pair
view String?
Specifies the DocumentView of the document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited