updateTime property
Represents the timestamp when the content or metadata of the document was last updated.
Output only.
Implementation
core.String? updateTime;
Represents the timestamp when the content or metadata of the document was last updated.
Output only.
core.String? updateTime;