DocumentChunk class

A DocumentChunk represents a piece of content from a Document in the DeveloperKnowledge corpus.

To fetch the entire document content, pass the parent to DeveloperKnowledge.GetDocument or DeveloperKnowledge.BatchGetDocuments.

Constructors

DocumentChunk({String? content, Document? document, String? id, String? parent, double? relevanceScore})
DocumentChunk.fromJson(Map json_)

Properties

content String?
Contains the content of the document chunk.
getter/setter pair
document Document?
Represents metadata about the Document this chunk is from.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
Specifies the ID of this chunk within the document.
getter/setter pair
parent String?
Contains the resource name of the document this chunk is from.
getter/setter pair
relevanceScore double?
Represents the relevance score of the chunk to the search query.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited