parent property
Contains the resource name of the document this chunk is from.
Format: documents/{uri_without_scheme} Example:
documents/docs.cloud.google.com/storage/docs/creating-buckets
Output only.
Implementation
core.String? parent;
Contains the resource name of the document this chunk is from.
Format: documents/{uri_without_scheme} Example:
documents/docs.cloud.google.com/storage/docs/creating-buckets
Output only.
core.String? parent;