relevanceScore property
Represents the relevance score of the chunk to the search query.
Higher score indicates higher chunk relevance. The score is in range [0.0, 1.0].
Output only.
Implementation
core.double? relevanceScore;
Represents the relevance score of the chunk to the search query.
Higher score indicates higher chunk relevance. The score is in range [0.0, 1.0].
Output only.
core.double? relevanceScore;