DocumentReference class

Represents a reference to a document.

Constructors

DocumentReference({DocumentChunk? documentChunk})
DocumentReference.fromJson(Map json_)

Properties

documentChunk DocumentChunk?
Contains the document chunk.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited