documentChunk property
Contains the document chunk.
The document_chunk.id field is not set and will be empty.
Output only.
Implementation
DocumentChunk? documentChunk;
Contains the document chunk.
The document_chunk.id field is not set and will be empty.
Output only.
DocumentChunk? documentChunk;