nextPageToken property
Provides a token that can be sent as page_token to retrieve the next
page.
If this field is omitted, there are no subsequent pages.
Implementation
core.String? nextPageToken;
Provides a token that can be sent as page_token to retrieve the next
page.
If this field is omitted, there are no subsequent pages.
core.String? nextPageToken;