ClickTag class

Creative Click Tag.

Constructors

ClickTag({CreativeClickThroughUrl? clickThroughUrl, String? eventName, String? name})
ClickTag.fromJson(Map json_)

Properties

clickThroughUrl ↔ CreativeClickThroughUrl?
Parameter value for the specified click tag.
getter/setter pair
eventName ↔ String?
Advertiser event name associated with the click tag.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Parameter name for the specified click tag.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited