CreativeAssetMetadata class

CreativeAssets contains properties of a creative asset file which will be uploaded or has already been uploaded.

Refer to the creative sample code for how to upload assets and insert a creative.

Constructors

CreativeAssetMetadata({CreativeAssetId? assetIdentifier, List<ClickTag>? clickTags, List<CreativeCustomEvent>? counterCustomEvents, List<String>? detectedFeatures, List<CreativeCustomEvent>? exitCustomEvents, String? id, DimensionValue? idDimensionValue, String? kind, bool? richMedia, List<CreativeCustomEvent>? timerCustomEvents, List<String>? warnedValidationRules})
CreativeAssetMetadata.fromJson(Map json_)

Properties

assetIdentifier ↔ CreativeAssetId?
ID of the creative asset.
getter/setter pair
clickTags ↔ List<ClickTag>?
List of detected click tags for assets.
getter/setter pair
counterCustomEvents ↔ List<CreativeCustomEvent>?
List of counter events configured for the asset.
getter/setter pair
detectedFeatures ↔ List<String>?
List of feature dependencies for the creative asset that are detected by Campaign Manager.
getter/setter pair
exitCustomEvents ↔ List<CreativeCustomEvent>?
List of exit events configured for the asset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Numeric ID of the asset.
getter/setter pair
idDimensionValue ↔ DimensionValue?
Dimension value for the numeric ID of the asset.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
richMedia ↔ bool?
True if the uploaded asset is a rich media asset.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timerCustomEvents ↔ List<CreativeCustomEvent>?
List of timer events configured for the asset.
getter/setter pair
warnedValidationRules ↔ List<String>?
Rules validated during code generation that generated a warning.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited