CreativeCustomEvent class

Creative Custom Event.

Constructors

CreativeCustomEvent({String? advertiserCustomEventId, String? advertiserCustomEventName, String? advertiserCustomEventType, String? artworkLabel, String? artworkType, CreativeClickThroughUrl? exitClickThroughUrl, String? id, PopupWindowProperties? popupWindowProperties, String? targetType, String? videoReportingId})
CreativeCustomEvent.fromJson(Map json_)

Properties

advertiserCustomEventId ↔ String?
Unique ID of this event used by Reporting and Data Transfer.
getter/setter pair
advertiserCustomEventName ↔ String?
User-entered name for the event.
getter/setter pair
advertiserCustomEventType ↔ String?
Type of the event.
getter/setter pair
artworkLabel ↔ String?
Artwork label column, used to link events in Campaign Manager back to events in Studio.
getter/setter pair
artworkType ↔ String?
Artwork type used by the creative.This is a read-only field. Possible string values are:
getter/setter pair
exitClickThroughUrl ↔ CreativeClickThroughUrl?
Exit click-through URL for the event.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this event.
getter/setter pair
popupWindowProperties ↔ PopupWindowProperties?
Properties for rich media popup windows.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetType ↔ String?
Target type used by the event. Possible string values are:
getter/setter pair
videoReportingId ↔ String?
Video reporting ID, used to differentiate multiple videos in a single creative.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited