CartData class

Beta: This feature is currently in beta.

Contains additional information about cart data. This field may only be used when calling batchinsert; it is not supported by batchupdate. Cart data reporting is only supported in SA360. Learn more

Constructors

CartData({List<CartDataItem>? items, String? merchantFeedLabel, String? merchantFeedLanguage, String? merchantId})
CartData.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<CartDataItem>?
Data of the items purchased.
getter/setter pair
merchantFeedLabel ↔ String?
The feed labels associated with the feed where your items are uploaded.
getter/setter pair
merchantFeedLanguage ↔ String?
The language associated with the feed where your items are uploaded.
getter/setter pair
merchantId ↔ String?
The Merchant Center ID where the items are uploaded.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited