CompatibleFields class

Represents a response to the queryCompatibleFields method.

Next ID: 10

Constructors

CompatibleFields({CrossDimensionReachReportCompatibleFields? crossDimensionReachReportCompatibleFields, CrossMediaReachReportCompatibleFields? crossMediaReachReportCompatibleFields, FloodlightReportCompatibleFields? floodlightReportCompatibleFields, String? kind, PathToConversionReportCompatibleFields? pathToConversionReportCompatibleFields, ReachReportCompatibleFields? reachReportCompatibleFields, ReportCompatibleFields? reportCompatibleFields})
CompatibleFields.fromJson(Map json_)

Properties

crossDimensionReachReportCompatibleFields ↔ CrossDimensionReachReportCompatibleFields?
Contains items that are compatible to be selected for a report of type "CROSS_DIMENSION_REACH".
getter/setter pair
crossMediaReachReportCompatibleFields ↔ CrossMediaReachReportCompatibleFields?
Contains items that are compatible to be selected for a report of type "CROSS_MEDIA_REACH".
getter/setter pair
floodlightReportCompatibleFields ↔ FloodlightReportCompatibleFields?
Contains items that are compatible to be selected for a report of type "FLOODLIGHT".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of resource this is, in this case dfareporting#compatibleFields.
getter/setter pair
pathToConversionReportCompatibleFields ↔ PathToConversionReportCompatibleFields?
Contains items that are compatible to be selected for a report of type "PATH_TO_CONVERSION".
getter/setter pair
reachReportCompatibleFields ↔ ReachReportCompatibleFields?
Contains items that are compatible to be selected for a report of type "REACH".
getter/setter pair
reportCompatibleFields ↔ ReportCompatibleFields?
Contains items that are compatible to be selected for a report of type "STANDARD".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited