ContentSource class

Contains the content source of the dynamic feed.

Constructors

ContentSource({String? contentSourceName, LastModifiedInfo? createInfo, LastModifiedInfo? lastModifiedInfo, ContentSourceMetaData? metaData, String? resourceLink, String? resourceType})
ContentSource.fromJson(Map json_)

Properties

contentSourceName ↔ String?
The name of the content source.
getter/setter pair
createInfo ↔ LastModifiedInfo?
The creation timestamp of the content source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedInfo ↔ LastModifiedInfo?
The last modified timestamp of the content source.
getter/setter pair
metaData ↔ ContentSourceMetaData?
Metadata of the content source.
getter/setter pair
The link to the file of the content source.
getter/setter pair
resourceType ↔ String?
The resource type of the content source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited