ConversionsBatchUpdateRequest class

Update Conversions Request.

Properties

conversions ↔ List<Conversion>?
The set of conversions to update.
getter/setter pair
encryptionInfo ↔ EncryptionInfo?
Describes how encryptedUserId is encrypted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited