Creative class

Contains properties of a Creative.

Constructors

Creative({String? accountId, bool? active, String? adParameters, List<String>? adTagKeys, List<Size>? additionalSizes, String? advertiserId, bool? allowScriptAccess, bool? archived, String? artworkType, String? authoringSource, String? authoringTool, bool? autoAdvanceImages, String? backgroundColor, CreativeClickThroughUrl? backupImageClickThroughUrl, List<String>? backupImageFeatures, String? backupImageReportingLabel, TargetWindow? backupImageTargetWindow, List<ClickTag>? clickTags, String? commercialId, List<String>? companionCreatives, List<String>? compatibility, bool? convertFlashToHtml5, List<CreativeCustomEvent>? counterCustomEvents, CreativeAssetSelection? creativeAssetSelection, List<CreativeAsset>? creativeAssets, List<CreativeFieldAssignment>? creativeFieldAssignments, List<String>? customKeyValues, bool? dynamicAssetSelection, List<CreativeCustomEvent>? exitCustomEvents, FsCommand? fsCommand, String? htmlCode, bool? htmlCodeLocked, String? id, DimensionValue? idDimensionValue, String? kind, LastModifiedInfo? lastModifiedInfo, String? latestTraffickedCreativeId, String? mediaDescription, double? mediaDuration, String? name, ObaIcon? obaIcon, String? overrideCss, VideoOffset? progressOffset, String? redirectUrl, String? renderingId, DimensionValue? renderingIdDimensionValue, String? requiredFlashPluginVersion, int? requiredFlashVersion, Size? size, VideoOffset? skipOffset, bool? skippable, bool? sslCompliant, bool? sslOverride, String? studioAdvertiserId, String? studioCreativeId, String? studioTraffickedCreativeId, String? subaccountId, String? thirdPartyBackupImageImpressionsUrl, String? thirdPartyRichMediaImpressionsUrl, List<ThirdPartyTrackingUrl>? thirdPartyUrls, List<CreativeCustomEvent>? timerCustomEvents, String? totalFileSize, String? type, UniversalAdId? universalAdId, int? version})
Creative.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of this creative.
getter/setter pair
active ↔ bool?
Whether the creative is active.
getter/setter pair
additionalSizes ↔ List<Size>?
Additional sizes associated with a responsive creative.
getter/setter pair
adParameters ↔ String?
Ad parameters user for VPAID creative.
getter/setter pair
adTagKeys ↔ List<String>?
Keywords for a Rich Media creative.
getter/setter pair
advertiserId ↔ String?
Advertiser ID of this creative.
getter/setter pair
allowScriptAccess ↔ bool?
Whether script access is allowed for this creative.
getter/setter pair
archived ↔ bool?
Whether the creative is archived.
getter/setter pair
artworkType ↔ String?
Type of artwork used for the creative.
getter/setter pair
authoringSource ↔ String?
Source application where creative was authored.
getter/setter pair
authoringTool ↔ String?
Authoring tool for HTML5 banner creatives.
getter/setter pair
autoAdvanceImages ↔ bool?
Whether images are automatically advanced for image gallery creatives.
getter/setter pair
backgroundColor ↔ String?
The 6-character HTML color code, beginning with #, for the background of the window area where the Flash file is displayed.
getter/setter pair
backupImageClickThroughUrl ↔ CreativeClickThroughUrl?
Click-through URL for backup image.
getter/setter pair
backupImageFeatures ↔ List<String>?
List of feature dependencies that will cause a backup image to be served if the browser that serves the ad does not support them.
getter/setter pair
backupImageReportingLabel ↔ String?
Reporting label used for HTML5 banner backup image.
getter/setter pair
backupImageTargetWindow ↔ TargetWindow?
Target window for backup image.
getter/setter pair
clickTags ↔ List<ClickTag>?
Click tags of the creative.
getter/setter pair
commercialId ↔ String?
Industry standard ID assigned to creative for reach and frequency.
getter/setter pair
companionCreatives ↔ List<String>?
List of companion creatives assigned to an in-Stream video creative.
getter/setter pair
compatibility ↔ List<String>?
Compatibilities associated with this creative.
getter/setter pair
convertFlashToHtml5 ↔ bool?
Whether Flash assets associated with the creative need to be automatically converted to HTML5.
getter/setter pair
counterCustomEvents ↔ List<CreativeCustomEvent>?
List of counter events configured for the creative.
getter/setter pair
creativeAssets ↔ List<CreativeAsset>?
Assets associated with a creative.
getter/setter pair
creativeAssetSelection ↔ CreativeAssetSelection?
Required if dynamicAssetSelection is true.
getter/setter pair
creativeFieldAssignments ↔ List<CreativeFieldAssignment>?
Creative field assignments for this creative.
getter/setter pair
customKeyValues ↔ List<String>?
Custom key-values for a Rich Media creative.
getter/setter pair
dynamicAssetSelection ↔ bool?
Set this to true to enable the use of rules to target individual assets in this creative.
getter/setter pair
exitCustomEvents ↔ List<CreativeCustomEvent>?
List of exit events configured for the creative.
getter/setter pair
fsCommand ↔ FsCommand?
OpenWindow FSCommand of this creative.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
htmlCode ↔ String?
HTML code for the creative.
getter/setter pair
htmlCodeLocked ↔ bool?
Whether HTML code is generated by Campaign Manager or manually entered.
getter/setter pair
id ↔ String?
ID of this creative.
getter/setter pair
idDimensionValue ↔ DimensionValue?
Dimension value for the ID of this creative.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lastModifiedInfo ↔ LastModifiedInfo?
Creative last modification information.
getter/setter pair
latestTraffickedCreativeId ↔ String?
Latest Studio trafficked creative ID associated with rich media and VPAID creatives.
getter/setter pair
mediaDescription ↔ String?
Description of the audio or video ad.
getter/setter pair
mediaDuration ↔ double?
Creative audio or video duration in seconds.
getter/setter pair
name ↔ String?
Name of the creative.
getter/setter pair
obaIcon ↔ ObaIcon?
Online behavioral advertising icon to be added to the creative.
getter/setter pair
overrideCss ↔ String?
Override CSS value for rich media creatives.
getter/setter pair
progressOffset ↔ VideoOffset?
Amount of time to play the video before counting a view.
getter/setter pair
redirectUrl ↔ String?
URL of hosted image or hosted video or another ad tag.
getter/setter pair
renderingId ↔ String?
ID of current rendering version.
getter/setter pair
renderingIdDimensionValue ↔ DimensionValue?
Dimension value for the rendering ID of this creative.
getter/setter pair
requiredFlashPluginVersion ↔ String?
The minimum required Flash plugin version for this creative.
getter/setter pair
requiredFlashVersion ↔ int?
The internal Flash version for this creative as calculated by Studio.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size?
Size associated with this creative.
getter/setter pair
skipOffset ↔ VideoOffset?
Amount of time to play the video before the skip button appears.
getter/setter pair
skippable ↔ bool?
Whether the user can choose to skip the creative.
getter/setter pair
sslCompliant ↔ bool?
Whether the creative is SSL-compliant.
getter/setter pair
sslOverride ↔ bool?
Whether creative should be treated as SSL compliant even if the system scan shows it's not.
getter/setter pair
studioAdvertiserId ↔ String?
Studio advertiser ID associated with rich media and VPAID creatives.
getter/setter pair
studioCreativeId ↔ String?
Studio creative ID associated with rich media and VPAID creatives.
getter/setter pair
studioTraffickedCreativeId ↔ String?
Studio trafficked creative ID associated with rich media and VPAID creatives.
getter/setter pair
subaccountId ↔ String?
Subaccount ID of this creative.
getter/setter pair
thirdPartyBackupImageImpressionsUrl ↔ String?
Third-party URL used to record backup image impressions.
getter/setter pair
thirdPartyRichMediaImpressionsUrl ↔ String?
Third-party URL used to record rich media impressions.
getter/setter pair
thirdPartyUrls ↔ List<ThirdPartyTrackingUrl>?
Third-party URLs for tracking in-stream creative events.
getter/setter pair
timerCustomEvents ↔ List<CreativeCustomEvent>?
List of timer events configured for the creative.
getter/setter pair
totalFileSize ↔ String?
Combined size of all creative assets.
getter/setter pair
type ↔ String?
Type of this creative.
getter/setter pair
universalAdId ↔ UniversalAdId?
A Universal Ad ID as per the VAST 4.0 spec.
getter/setter pair
version ↔ int?
The version number helps you keep track of multiple versions of your creative in your reports.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited