CreativeAsset class

Creative Asset.

Constructors

CreativeAsset({bool? actionScript3, bool? active, List<Size>? additionalSizes, String? alignment, String? artworkType, CreativeAssetId? assetIdentifier, int? audioBitRate, int? audioSampleRate, CreativeCustomEvent? backupImageExit, int? bitRate, String? childAssetType, Size? collapsedSize, List<String>? companionCreativeIds, int? customStartTimeValue, List<String>? detectedFeatures, String? displayType, int? duration, String? durationType, Size? expandedDimension, String? fileSize, int? flashVersion, double? frameRate, bool? hideFlashObjects, bool? hideSelectionBoxes, bool? horizontallyLocked, String? id, DimensionValue? idDimensionValue, double? mediaDuration, String? mimeType, OffsetPosition? offset, String? orientation, bool? originalBackup, bool? politeLoad, OffsetPosition? position, String? positionLeftUnit, String? positionTopUnit, String? progressiveServingUrl, bool? pushdown, double? pushdownDuration, String? role, Size? size, bool? sslCompliant, String? startTimeType, String? streamingServingUrl, bool? transparency, bool? verticallyLocked, String? windowMode, int? zIndex, String? zipFilename, String? zipFilesize})
CreativeAsset.fromJson(Map json_)

Properties

actionScript3 ↔ bool?
Whether ActionScript3 is enabled for the flash asset.
getter/setter pair
active ↔ bool?
Whether the video or audio asset is active.
getter/setter pair
additionalSizes ↔ List<Size>?
Additional sizes associated with this creative asset.
getter/setter pair
alignment ↔ String?
Possible alignments for an asset.
getter/setter pair
artworkType ↔ String?
Artwork type of rich media creative.
getter/setter pair
assetIdentifier ↔ CreativeAssetId?
Identifier of this asset.
getter/setter pair
audioBitRate ↔ int?
Audio stream bit rate in kbps.
getter/setter pair
audioSampleRate ↔ int?
Audio sample bit rate in hertz.
getter/setter pair
backupImageExit ↔ CreativeCustomEvent?
Exit event configured for the backup image.
getter/setter pair
bitRate ↔ int?
Detected bit-rate for audio or video asset.
getter/setter pair
childAssetType ↔ String?
Rich media child asset type.
getter/setter pair
collapsedSize ↔ Size?
Size of an asset when collapsed.
getter/setter pair
companionCreativeIds ↔ List<String>?
List of companion creatives assigned to an in-stream video creative asset.
getter/setter pair
customStartTimeValue ↔ int?
Custom start time in seconds for making the asset visible.
getter/setter pair
detectedFeatures ↔ List<String>?
List of feature dependencies for the creative asset that are detected by Campaign Manager.
getter/setter pair
displayType ↔ String?
Type of rich media asset.
getter/setter pair
duration ↔ int?
Duration in seconds for which an asset will be displayed.
getter/setter pair
durationType ↔ String?
Duration type for which an asset will be displayed.
getter/setter pair
expandedDimension ↔ Size?
Detected expanded dimension for video asset.
getter/setter pair
fileSize ↔ String?
File size associated with this creative asset.
getter/setter pair
flashVersion ↔ int?
Flash version of the asset.
getter/setter pair
frameRate ↔ double?
Video frame rate for video asset in frames per second.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideFlashObjects ↔ bool?
Whether to hide Flash objects flag for an asset.
getter/setter pair
hideSelectionBoxes ↔ bool?
Whether to hide selection boxes flag for an asset.
getter/setter pair
horizontallyLocked ↔ bool?
Whether the asset is horizontally locked.
getter/setter pair
id ↔ String?
Numeric ID of this creative asset.
getter/setter pair
idDimensionValue ↔ DimensionValue?
Dimension value for the ID of the asset.
getter/setter pair
mediaDuration ↔ double?
Detected duration for audio or video asset.
getter/setter pair
mimeType ↔ String?
Detected MIME type for audio or video asset.
getter/setter pair
offset ↔ OffsetPosition?
Offset position for an asset in collapsed mode.
getter/setter pair
orientation ↔ String?
Orientation of video asset.
getter/setter pair
originalBackup ↔ bool?
Whether the backup asset is original or changed by the user in Campaign Manager.
getter/setter pair
politeLoad ↔ bool?
Whether this asset is used as a polite load asset.
getter/setter pair
position ↔ OffsetPosition?
Offset position for an asset.
getter/setter pair
positionLeftUnit ↔ String?
Offset left unit for an asset.
getter/setter pair
positionTopUnit ↔ String?
Offset top unit for an asset.
getter/setter pair
progressiveServingUrl ↔ String?
Progressive URL for video asset.
getter/setter pair
pushdown ↔ bool?
Whether the asset pushes down other content.
getter/setter pair
pushdownDuration ↔ double?
Pushdown duration in seconds for an asset.
getter/setter pair
role ↔ String?
Role of the asset in relation to creative.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ Size?
Size associated with this creative asset.
getter/setter pair
sslCompliant ↔ bool?
Whether the asset is SSL-compliant.
getter/setter pair
startTimeType ↔ String?
Initial wait time type before making the asset visible.
getter/setter pair
streamingServingUrl ↔ String?
Streaming URL for video asset.
getter/setter pair
transparency ↔ bool?
Whether the asset is transparent.
getter/setter pair
verticallyLocked ↔ bool?
Whether the asset is vertically locked.
getter/setter pair
windowMode ↔ String?
Window mode options for flash assets.
getter/setter pair
zIndex ↔ int?
zIndex value of an asset.
getter/setter pair
zipFilename ↔ String?
File name of zip file.
getter/setter pair
zipFilesize ↔ String?
Size of zip file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited