CreativeAssetSelection class

Encapsulates the list of rules for asset selection and a default asset in case none of the rules match.

Applicable to INSTREAM_VIDEO creatives.

Constructors

CreativeAssetSelection({String? defaultAssetId, List<Rule>? rules})
CreativeAssetSelection.fromJson(Map json_)

Properties

defaultAssetId ↔ String?
A creativeAssets[].id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rules ↔ List<Rule>?
Rules determine which asset will be served to a viewer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited