CreativeFieldValuesResource class

Constructors

CreativeFieldValuesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String profileId, String creativeFieldId, String id, {String? $fields}) → Future<void>
Deletes an existing creative field value.
get(String profileId, String creativeFieldId, String id, {String? $fields}) → Future<CreativeFieldValue>
Gets one creative field value by ID.
insert(CreativeFieldValue request, String profileId, String creativeFieldId, {String? $fields}) → Future<CreativeFieldValue>
Inserts a new creative field value.
list(String profileId, String creativeFieldId, {List<String>? ids, int? maxResults, String? pageToken, String? searchString, String? sortField, String? sortOrder, String? $fields}) → Future<CreativeFieldValuesListResponse>
Retrieves a list of creative field values, possibly filtered.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(CreativeFieldValue request, String profileId, String creativeFieldId, String id, {String? $fields}) → Future<CreativeFieldValue>
Updates an existing creative field value.
toString() → String
A string representation of this object.
inherited
update(CreativeFieldValue request, String profileId, String creativeFieldId, {String? $fields}) → Future<CreativeFieldValue>
Updates an existing creative field value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited