DynamicFeed class

Contains dynamic feed information.

Constructors

DynamicFeed({ContentSource? contentSource, LastModifiedInfo? createInfo, String? dynamicFeedId, String? dynamicFeedName, Element? element, FeedIngestionStatus? feedIngestionStatus, FeedSchedule? feedSchedule, bool? hasPublished, LastModifiedInfo? lastModifiedInfo, String? status, String? studioAdvertiserId})
DynamicFeed.fromJson(Map json_)

Properties

contentSource ↔ ContentSource?
The content source of the dynamic feed.
getter/setter pair
createInfo ↔ LastModifiedInfo?
The creation timestamp of the dynamic feed.
getter/setter pair
dynamicFeedId ↔ String?
Unique ID of this dynamic feed.
getter/setter pair
dynamicFeedName ↔ String?
Name of this dynamic feed.
getter/setter pair
element ↔ Element?
The element of the dynamic feed that is to specify the schema of the feed.
getter/setter pair
feedIngestionStatus ↔ FeedIngestionStatus?
The ingestion status of the dynamic feed.
getter/setter pair
feedSchedule ↔ FeedSchedule?
The schedule of the dynamic feed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasPublished ↔ bool?
Indicates whether the dynamic feed has a published version.
getter/setter pair
lastModifiedInfo ↔ LastModifiedInfo?
The last modified timestamp of the dynamic feed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status of the feed.
getter/setter pair
studioAdvertiserId ↔ String?
Advertiser ID of this dynamic feed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited