DynamicProfile class

Contains dynamic profile information.

Constructors

DynamicProfile({DynamicProfileVersion? active, String? archiveStatus, LastModifiedInfo? createInfo, String? description, DynamicProfileVersion? draft, String? dynamicProfileId, String? kind, LastModifiedInfo? lastModifiedInfo, String? name, String? status, String? studioAdvertiserId})
DynamicProfile.fromJson(Map json_)

Properties

active ↔ DynamicProfileVersion?
Active version of the dynamic profile.
getter/setter pair
archiveStatus ↔ String?
Archive status of this dynamic profile.
getter/setter pair
createInfo ↔ LastModifiedInfo?
The creation timestamp of the dynamic profile.
getter/setter pair
description ↔ String?
Description of this dynamic profile.
getter/setter pair
draft ↔ DynamicProfileVersion?
Draft version of the dynamic profile.
getter/setter pair
dynamicProfileId ↔ String?
Unique ID of this dynamic profile.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lastModifiedInfo ↔ LastModifiedInfo?
The last modified timestamp of the dynamic profile.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Status of this dynamic profile.
getter/setter pair
studioAdvertiserId ↔ String?
Advertiser ID of this dynamic profile.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited