DynamicProfileFeedSettings class

Contains dynamic profile specific settings for an associated dynamic feed.

Constructors

DynamicProfileFeedSettings({String? dynamicFeedId, DynamicRules? dynamicRules, int? quantity})
DynamicProfileFeedSettings.fromJson(Map json_)

Properties

dynamicFeedId ↔ String?
Dynamic feed ID associated with dynamic profile version.
getter/setter pair
dynamicRules ↔ DynamicRules?
Dynamic rules for row selection for the given dynamic feed in the given dynamic profile.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
quantity ↔ int?
The number of this dynamic feed rows needed by the dynamic profile, default value is 1.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited