FileUrls class

The URLs where the completed report file can be downloaded.

Constructors

FileUrls({String? apiUrl, String? browserUrl})
FileUrls.fromJson(Map json_)

Properties

apiUrl ↔ String?
The URL for downloading the report data through the API.
getter/setter pair
browserUrl ↔ String?
The URL for downloading the report data through a browser.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited