Flight class

Flight

Constructors

Flight({DateTime? endDate, String? rateOrCost, DateTime? startDate, String? units})
Flight.fromJson(Map json_)

Properties

endDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rateOrCost ↔ String?
Rate or cost of this flight.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ DateTime?
getter/setter pair
units ↔ String?
Units of this flight.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited