Invoice class

Contains information about a single invoice

Constructors

Invoice({List<CampaignSummary>? campaignSummaries, String? correctedInvoiceId, String? currencyCode, String? dueDate, String? id, String? invoiceType, String? issueDate, String? kind, String? paymentsAccountId, String? paymentsProfileId, String? pdfUrl, String? purchaseOrderNumber, List<String>? replacedInvoiceIds, String? serviceEndDate, String? serviceStartDate, String? subtotalAmountMicros, String? totalAmountMicros, String? totalTaxAmountMicros})
Invoice.fromJson(Map json_)

Properties

campaignSummaries ↔ List<CampaignSummary>?
The list of summarized campaign information associated with this invoice.
getter/setter pair
correctedInvoiceId ↔ String?
The originally issued invoice that is being adjusted by this invoice, if applicable.
getter/setter pair
currencyCode ↔ String?
Invoice currency code in ISO 4217 format.
getter/setter pair
dueDate ↔ String?
The invoice due date.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this invoice.
getter/setter pair
invoiceType ↔ String?
The type of invoice document. Possible string values are:
getter/setter pair
issueDate ↔ String?
The date when the invoice was issued.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
paymentsAccountId ↔ String?
The ID of the payments account the invoice belongs to.
getter/setter pair
paymentsProfileId ↔ String?
The ID of the payments profile the invoice belongs to.
getter/setter pair
pdfUrl ↔ String?
The URL to download a PDF copy of the invoice.
getter/setter pair
purchaseOrderNumber ↔ String?
Purchase order number associated with the invoice.
getter/setter pair
replacedInvoiceIds ↔ List<String>?
The originally issued invoice(s) that is being cancelled by this invoice, if applicable.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceEndDate ↔ String?
The invoice service end date.
getter/setter pair
serviceStartDate ↔ String?
The invoice service start date.
getter/setter pair
subtotalAmountMicros ↔ String?
The pre-tax subtotal amount, in micros of the invoice's currency.
getter/setter pair
totalAmountMicros ↔ String?
The invoice total amount, in micros of the invoice's currency.
getter/setter pair
totalTaxAmountMicros ↔ String?
The sum of all taxes in invoice, in micros of the invoice's currency.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited