Order class

Describes properties of a Planning order.

Constructors

Order({String? accountId, String? advertiserId, List<String>? approverUserProfileIds, String? buyerInvoiceId, String? buyerOrganizationName, String? comments, List<OrderContact>? contacts, String? id, String? kind, LastModifiedInfo? lastModifiedInfo, String? name, String? notes, String? planningTermId, String? projectId, String? sellerOrderId, String? sellerOrganizationName, List<String>? siteId, List<String>? siteNames, String? subaccountId, String? termsAndConditions})
Order.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of this order.
getter/setter pair
advertiserId ↔ String?
Advertiser ID of this order.
getter/setter pair
approverUserProfileIds ↔ List<String>?
IDs for users that have to approve documents created for this order.
getter/setter pair
buyerInvoiceId ↔ String?
Buyer invoice ID associated with this order.
getter/setter pair
buyerOrganizationName ↔ String?
Name of the buyer organization.
getter/setter pair
comments ↔ String?
Comments in this order.
getter/setter pair
contacts ↔ List<OrderContact>?
Contacts for this order.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this order.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lastModifiedInfo ↔ LastModifiedInfo?
Information about the most recent modification of this order.
getter/setter pair
name ↔ String?
Name of this order.
getter/setter pair
notes ↔ String?
Notes of this order.
getter/setter pair
planningTermId ↔ String?
ID of the terms and conditions template used in this order.
getter/setter pair
projectId ↔ String?
Project ID of this order.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sellerOrderId ↔ String?
Seller order ID associated with this order.
getter/setter pair
sellerOrganizationName ↔ String?
Name of the seller organization.
getter/setter pair
siteId ↔ List<String>?
Site IDs this order is associated with.
getter/setter pair
siteNames ↔ List<String>?
Free-form site names this order is associated with.
getter/setter pair
subaccountId ↔ String?
Subaccount ID of this order.
getter/setter pair
termsAndConditions ↔ String?
Terms and conditions of this order.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited