OrderContact class

Contact of an order.

Constructors

OrderContact({String? contactInfo, String? contactName, String? contactTitle, String? contactType, String? signatureUserProfileId})
OrderContact.fromJson(Map json_)

Properties

contactInfo ↔ String?
Free-form information about this contact.
getter/setter pair
contactName ↔ String?
Name of this contact.
getter/setter pair
contactTitle ↔ String?
Title of this contact.
getter/setter pair
contactType ↔ String?
Type of this contact. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureUserProfileId ↔ String?
ID of the user profile containing the signature that will be embedded into order documents.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited