Placement class

Contains properties of a placement.

Constructors

Placement({String? accountId, String? activeStatus, bool? adBlockingOptOut, String? adServingPlatformId, List<Size>? additionalSizes, String? advertiserId, DimensionValue? advertiserIdDimensionValue, bool? allowOnYoutube, String? campaignId, DimensionValue? campaignIdDimensionValue, String? comment, String? compatibility, String? contentCategoryId, PlacementConversionDomainOverride? conversionDomainOverride, LastModifiedInfo? createInfo, String? directorySiteId, DimensionValue? directorySiteIdDimensionValue, String? externalId, String? id, DimensionValue? idDimensionValue, String? keyName, String? kind, LastModifiedInfo? lastModifiedInfo, LookbackConfiguration? lookbackConfiguration, String? name, MeasurementPartnerWrappingData? partnerWrappingData, bool? paymentApproved, String? paymentSource, String? placementGroupId, DimensionValue? placementGroupIdDimensionValue, String? placementStrategyId, PricingSchedule? pricingSchedule, bool? primary, LastModifiedInfo? publisherUpdateInfo, String? siteId, DimensionValue? siteIdDimensionValue, bool? siteServed, Size? size, bool? sslRequired, String? status, String? subaccountId, List<String>? tagFormats, TagSetting? tagSetting, bool? videoActiveViewOptOut, VideoSettings? videoSettings, String? vpaidAdapterChoice, bool? wrappingOptOut, YoutubeSettings? youtubeSettings})
Placement.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of this placement.
getter/setter pair
activeStatus ↔ String?
Whether this placement is active, inactive, archived or permanently archived. Possible string values are:
getter/setter pair
adBlockingOptOut ↔ bool?
Whether this placement opts out of ad blocking.
getter/setter pair
additionalSizes ↔ List<Size>?
Additional sizes associated with this placement.
getter/setter pair
adServingPlatformId ↔ String?
Ad serving platform ID to identify the ad serving platform used by the placement.
getter/setter pair
advertiserId ↔ String?
Advertiser ID of this placement.
getter/setter pair
advertiserIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the advertiser.
getter/setter pair
allowOnYoutube ↔ bool?
Whether the placement is enabled for YouTube integration.
getter/setter pair
campaignId ↔ String?
Campaign ID of this placement.
getter/setter pair
campaignIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the campaign.
getter/setter pair
comment ↔ String?
Comments for this placement.
getter/setter pair
compatibility ↔ String?
Placement compatibility.
getter/setter pair
contentCategoryId ↔ String?
ID of the content category assigned to this placement.
getter/setter pair
conversionDomainOverride ↔ PlacementConversionDomainOverride?
Conversion domain overrides for a placement.
getter/setter pair
createInfo ↔ LastModifiedInfo?
Information about the creation of this placement.
getter/setter pair
directorySiteId ↔ String?
Directory site ID of this placement.
getter/setter pair
directorySiteIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the directory site.
getter/setter pair
externalId ↔ String?
External ID for this placement.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this placement.
getter/setter pair
idDimensionValue ↔ DimensionValue?
Dimension value for the ID of this placement.
getter/setter pair
keyName ↔ String?
Key name of this placement.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lastModifiedInfo ↔ LastModifiedInfo?
Information about the most recent modification of this placement.
getter/setter pair
lookbackConfiguration ↔ LookbackConfiguration?
Lookback window settings for this placement.
getter/setter pair
name ↔ String?
Name of this placement.This is a required field and must be less than or equal to 512 characters long.
getter/setter pair
partnerWrappingData ↔ MeasurementPartnerWrappingData?
Measurement partner provided settings for a wrapped placement.
getter/setter pair
paymentApproved ↔ bool?
Whether payment was approved for this placement.
getter/setter pair
paymentSource ↔ String?
Payment source for this placement.
getter/setter pair
placementGroupId ↔ String?
ID of this placement's group, if applicable.
getter/setter pair
placementGroupIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the placement group.
getter/setter pair
placementStrategyId ↔ String?
ID of the placement strategy assigned to this placement.
getter/setter pair
pricingSchedule ↔ PricingSchedule?
Pricing schedule of this placement.
getter/setter pair
primary ↔ bool?
Whether this placement is the primary placement of a roadblock (placement group).
getter/setter pair
publisherUpdateInfo ↔ LastModifiedInfo?
Information about the last publisher update.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteId ↔ String?
Site ID associated with this placement.
getter/setter pair
siteIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the site.
getter/setter pair
siteServed ↔ bool?
Whether the ads in the placement are served by another platform and CM is only used for tracking or they are served by CM.
getter/setter pair
size ↔ Size?
Size associated with this placement.
getter/setter pair
sslRequired ↔ bool?
Whether creatives assigned to this placement must be SSL-compliant.
getter/setter pair
status ↔ String?
Third-party placement status. Possible string values are:
getter/setter pair
subaccountId ↔ String?
Subaccount ID of this placement.
getter/setter pair
tagFormats ↔ List<String>?
Tag formats to generate for this placement.
getter/setter pair
tagSetting ↔ TagSetting?
Tag settings for this placement.
getter/setter pair
videoActiveViewOptOut ↔ bool?
Whether Verification and ActiveView are disabled for in-stream video creatives for this placement.
getter/setter pair
videoSettings ↔ VideoSettings?
A collection of settings which affect video creatives served through this placement.
getter/setter pair
vpaidAdapterChoice ↔ String?
VPAID adapter setting for this placement.
getter/setter pair
wrappingOptOut ↔ bool?
Whether this placement opts out of tag wrapping.
getter/setter pair
youtubeSettings ↔ YoutubeSettings?
YouTube settings for the placement.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited