PlacementAssignment class

Placement Assignment.

Constructors

PlacementAssignment({bool? active, String? placementId, DimensionValue? placementIdDimensionValue, bool? sslRequired})
PlacementAssignment.fromJson(Map json_)

Properties

active ↔ bool?
Whether this placement assignment is active.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
placementId ↔ String?
ID of the placement to be assigned.
getter/setter pair
placementIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the placement.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sslRequired ↔ bool?
Whether the placement to be assigned requires SSL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited