PlacementGroup class

Contains properties of a package or roadblock.

Constructors

PlacementGroup({String? accountId, String? activeStatus, String? advertiserId, DimensionValue? advertiserIdDimensionValue, String? campaignId, DimensionValue? campaignIdDimensionValue, List<String>? childPlacementIds, String? comment, String? contentCategoryId, LastModifiedInfo? createInfo, String? directorySiteId, DimensionValue? directorySiteIdDimensionValue, String? externalId, String? id, DimensionValue? idDimensionValue, String? kind, LastModifiedInfo? lastModifiedInfo, String? name, String? placementGroupType, String? placementStrategyId, PricingSchedule? pricingSchedule, String? primaryPlacementId, DimensionValue? primaryPlacementIdDimensionValue, String? siteId, DimensionValue? siteIdDimensionValue, String? subaccountId})
PlacementGroup.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of this placement group.
getter/setter pair
activeStatus ↔ String?
Whether this placement group is active, inactive, archived or permanently archived. Possible string values are:
getter/setter pair
advertiserId ↔ String?
Advertiser ID of this placement group.
getter/setter pair
advertiserIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the advertiser.
getter/setter pair
campaignId ↔ String?
Campaign ID of this placement group.
getter/setter pair
campaignIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the campaign.
getter/setter pair
childPlacementIds ↔ List<String>?
IDs of placements which are assigned to this placement group.
getter/setter pair
comment ↔ String?
Comments for this placement group.
getter/setter pair
contentCategoryId ↔ String?
ID of the content category assigned to this placement group.
getter/setter pair
createInfo ↔ LastModifiedInfo?
Information about the creation of this placement group.
getter/setter pair
directorySiteId ↔ String?
Directory site ID associated with this placement group.
getter/setter pair
directorySiteIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the directory site.
getter/setter pair
externalId ↔ String?
External ID for this placement.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this placement group.
getter/setter pair
idDimensionValue ↔ DimensionValue?
Dimension value for the ID of this placement group.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lastModifiedInfo ↔ LastModifiedInfo?
Information about the most recent modification of this placement group.
getter/setter pair
name ↔ String?
Name of this placement group.
getter/setter pair
placementGroupType ↔ String?
Type of this placement group.
getter/setter pair
placementStrategyId ↔ String?
ID of the placement strategy assigned to this placement group.
getter/setter pair
pricingSchedule ↔ PricingSchedule?
Pricing schedule of this placement group.
getter/setter pair
primaryPlacementId ↔ String?
ID of the primary placement, used to calculate the media cost of a roadblock (placement group).
getter/setter pair
primaryPlacementIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the primary placement.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteId ↔ String?
Site ID associated with this placement group.
getter/setter pair
siteIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the site.
getter/setter pair
subaccountId ↔ String?
Subaccount ID of this placement group.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited