Project class

Contains properties of a Planning project.

Constructors

Project({String? accountId, String? advertiserId, String? audienceAgeGroup, String? audienceGender, String? budget, String? clientBillingCode, String? clientName, DateTime? endDate, String? id, String? kind, LastModifiedInfo? lastModifiedInfo, String? name, String? overview, DateTime? startDate, String? subaccountId, String? targetClicks, String? targetConversions, String? targetCpaNanos, String? targetCpcNanos, String? targetCpmActiveViewNanos, String? targetCpmNanos, String? targetImpressions})
Project.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of this project.
getter/setter pair
advertiserId ↔ String?
Advertiser ID of this project.
getter/setter pair
audienceAgeGroup ↔ String?
Audience age group of this project. Possible string values are:
getter/setter pair
audienceGender ↔ String?
Audience gender of this project. Possible string values are:
getter/setter pair
budget ↔ String?
Budget of this project in the currency specified by the current account.
getter/setter pair
clientBillingCode ↔ String?
Client billing code of this project.
getter/setter pair
clientName ↔ String?
Name of the project client.
getter/setter pair
endDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this project.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lastModifiedInfo ↔ LastModifiedInfo?
Information about the most recent modification of this project.
getter/setter pair
name ↔ String?
Name of this project.
getter/setter pair
overview ↔ String?
Overview of this project.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ DateTime?
getter/setter pair
subaccountId ↔ String?
Subaccount ID of this project.
getter/setter pair
targetClicks ↔ String?
Number of clicks that the advertiser is targeting.
getter/setter pair
targetConversions ↔ String?
Number of conversions that the advertiser is targeting.
getter/setter pair
targetCpaNanos ↔ String?
CPA that the advertiser is targeting.
getter/setter pair
targetCpcNanos ↔ String?
CPC that the advertiser is targeting.
getter/setter pair
targetCpmActiveViewNanos ↔ String?
vCPM from Active View that the advertiser is targeting.
getter/setter pair
targetCpmNanos ↔ String?
CPM that the advertiser is targeting.
getter/setter pair
targetImpressions ↔ String?
Number of impressions that the advertiser is targeting.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited