ProjectsListResponse class

Project List Response

Constructors

ProjectsListResponse({String? kind, String? nextPageToken, List<Project>? projects})
ProjectsListResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
nextPageToken ↔ String?
Pagination token to be used for the next list operation.
getter/setter pair
projects ↔ List<Project>?
Project collection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited