Report class

Represents a Report resource.

Constructors

Report({String? accountId, ReportCriteria? criteria, ReportCrossDimensionReachCriteria? crossDimensionReachCriteria, ReportCrossMediaReachCriteria? crossMediaReachCriteria, ReportDelivery? delivery, String? etag, String? fileName, ReportFloodlightCriteria? floodlightCriteria, String? format, String? id, String? kind, String? lastModifiedTime, String? name, String? ownerProfileId, ReportPathToConversionCriteria? pathToConversionCriteria, ReportReachCriteria? reachCriteria, ReportSchedule? schedule, String? subAccountId, String? type})
Report.fromJson(Map json_)

Properties

accountId ↔ String?
The account ID to which this report belongs.
getter/setter pair
criteria ↔ ReportCriteria?
The report criteria for a report of type "STANDARD".
getter/setter pair
crossDimensionReachCriteria ↔ ReportCrossDimensionReachCriteria?
The report criteria for a report of type "CROSS_DIMENSION_REACH".
getter/setter pair
crossMediaReachCriteria ↔ ReportCrossMediaReachCriteria?
The report criteria for a report of type "CROSS_MEDIA_REACH".
getter/setter pair
delivery ↔ ReportDelivery?
The report's email delivery settings.
getter/setter pair
etag ↔ String?
The eTag of this response for caching purposes.
getter/setter pair
fileName ↔ String?
The filename used when generating report files for this report.
getter/setter pair
floodlightCriteria ↔ ReportFloodlightCriteria?
The report criteria for a report of type "FLOODLIGHT".
getter/setter pair
format ↔ String?
The output format of the report.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique ID identifying this report resource.
getter/setter pair
kind ↔ String?
The kind of resource this is, in this case dfareporting#report.
getter/setter pair
lastModifiedTime ↔ String?
The timestamp (in milliseconds since epoch) of when this report was last modified.
getter/setter pair
name ↔ String?
The name of the report.
getter/setter pair
ownerProfileId ↔ String?
The user profile id of the owner of this report.
getter/setter pair
pathToConversionCriteria ↔ ReportPathToConversionCriteria?
The report criteria for a report of type "PATH_TO_CONVERSION".
getter/setter pair
reachCriteria ↔ ReportReachCriteria?
The report criteria for a report of type "REACH".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule ↔ ReportSchedule?
The report's schedule.
getter/setter pair
subAccountId ↔ String?
The subaccount ID to which this report belongs if applicable.
getter/setter pair
type ↔ String?
The type of the report. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited