ReportPathToConversionCriteria class

The report criteria for a report of type "PATH_TO_CONVERSION".

Constructors

ReportPathToConversionCriteria({List<DimensionValue>? activityFilters, List<SortedDimension>? conversionDimensions, List<SortedDimension>? customFloodlightVariables, List<DimensionValue>? customRichMediaEvents, DateRange? dateRange, DimensionValue? floodlightConfigId, List<String>? metricNames, List<SortedDimension>? perInteractionDimensions, ReportPathToConversionCriteriaReportProperties? reportProperties})
ReportPathToConversionCriteria.fromJson(Map json_)

Properties

activityFilters ↔ List<DimensionValue>?
The list of 'dfa:activity' values to filter on.
getter/setter pair
conversionDimensions ↔ List<SortedDimension>?
The list of conversion dimensions the report should include.
getter/setter pair
customFloodlightVariables ↔ List<SortedDimension>?
The list of custom floodlight variables the report should include.
getter/setter pair
customRichMediaEvents ↔ List<DimensionValue>?
The list of custom rich media events to include.
getter/setter pair
dateRange ↔ DateRange?
The date range this report should be run for.
getter/setter pair
floodlightConfigId ↔ DimensionValue?
The floodlight ID for which to show data in this report.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metricNames ↔ List<String>?
The list of names of metrics the report should include.
getter/setter pair
perInteractionDimensions ↔ List<SortedDimension>?
The list of per interaction dimensions the report should include.
getter/setter pair
reportProperties ↔ ReportPathToConversionCriteriaReportProperties?
The properties of the report.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited