Rule class

A rule associates an asset with a targeting template for asset-level targeting.

Applicable to INSTREAM_VIDEO creatives.

Constructors

Rule({String? assetId, String? name, String? targetingTemplateId})
Rule.fromJson(Map json_)

Properties

assetId ↔ String?
A creativeAssets[].id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
A user-friendly name for this rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetingTemplateId ↔ String?
A targeting template ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited