RuleBlock class

Contains a list of field filters that the given custom rule will apply.

Constructors

RuleBlock({List<FieldFilter>? fieldFilter})
RuleBlock.fromJson(Map json_)

Properties

fieldFilter ↔ List<FieldFilter>?
A list of non-auto field filters
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited