SkippableSetting class

Skippable Settings

Constructors

SkippableSetting({String? kind, VideoOffset? progressOffset, VideoOffset? skipOffset, bool? skippable})
SkippableSetting.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
progressOffset ↔ VideoOffset?
Amount of time to play videos served to this placement before counting a view.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipOffset ↔ VideoOffset?
Amount of time to play videos served to this placement before the skip button should appear.
getter/setter pair
skippable ↔ bool?
Whether the user can skip creatives served to this placement.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited