TargetingTemplate class

Contains properties of a targeting template.

A targeting template encapsulates targeting information which can be reused across multiple ads.

Constructors

TargetingTemplate({String? accountId, String? advertiserId, DimensionValue? advertiserIdDimensionValue, ContextualKeywordTargeting? contextualKeywordTargeting, DayPartTargeting? dayPartTargeting, GeoTargeting? geoTargeting, String? id, KeyValueTargetingExpression? keyValueTargetingExpression, String? kind, LanguageTargeting? languageTargeting, ListTargetingExpression? listTargetingExpression, String? name, String? subaccountId, TechnologyTargeting? technologyTargeting})
TargetingTemplate.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of this targeting template.
getter/setter pair
advertiserId ↔ String?
Advertiser ID of this targeting template.
getter/setter pair
advertiserIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the advertiser.
getter/setter pair
contextualKeywordTargeting ↔ ContextualKeywordTargeting?
Contextual keyword targeting criteria.
getter/setter pair
dayPartTargeting ↔ DayPartTargeting?
Time and day targeting criteria.
getter/setter pair
geoTargeting ↔ GeoTargeting?
Geographical targeting criteria.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this targeting template.
getter/setter pair
keyValueTargetingExpression ↔ KeyValueTargetingExpression?
Key-value targeting criteria.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
languageTargeting ↔ LanguageTargeting?
Language targeting criteria.
getter/setter pair
listTargetingExpression ↔ ListTargetingExpression?
Remarketing list targeting criteria.
getter/setter pair
name ↔ String?
Name of this targeting template.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subaccountId ↔ String?
Subaccount ID of this targeting template.
getter/setter pair
technologyTargeting ↔ TechnologyTargeting?
Technology platform targeting criteria.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited