VideoSettings class

Video Settings

Constructors

VideoSettings({CompanionSetting? companionSettings, int? durationSeconds, String? kind, bool? obaEnabled, ObaIcon? obaSettings, String? orientation, String? publisherSpecificationId, SkippableSetting? skippableSettings, TranscodeSetting? transcodeSettings})
VideoSettings.fromJson(Map json_)

Properties

companionSettings ↔ CompanionSetting?
Settings for the companion creatives of video creatives served to this placement.
getter/setter pair
durationSeconds ↔ int?
Duration of a video placement in seconds.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
obaEnabled ↔ bool?
Whether OBA icons are enabled for this placement.
getter/setter pair
obaSettings ↔ ObaIcon?
Settings for the OBA icon of video creatives served to this placement.
getter/setter pair
orientation ↔ String?
Orientation of a video placement.
getter/setter pair
publisherSpecificationId ↔ String?
Publisher specification ID of a video placement.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippableSettings ↔ SkippableSetting?
Settings for the skippability of video creatives served to this placement.
getter/setter pair
transcodeSettings ↔ TranscodeSetting?
Settings for the transcodes of video creatives served to this placement.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited