Account class

Contains properties of a Campaign Manager account.

Constructors

Account({List<String>? accountPermissionIds, String? accountProfile, bool? active, String? activeAdsLimitTier, bool? activeViewOptOut, List<String>? availablePermissionIds, String? countryId, String? currencyId, String? defaultCreativeSizeId, String? description, String? id, String? kind, String? locale, String? maximumImageSize, String? name, bool? nielsenOcrEnabled, ReportsConfiguration? reportsConfiguration, bool? shareReportsWithTwitter, String? teaserSizeLimit})
Account.fromJson(Map json_)

Properties

accountPermissionIds ↔ List<String>?
Account permissions assigned to this account.
getter/setter pair
accountProfile ↔ String?
Profile for this account.
getter/setter pair
active ↔ bool?
Whether this account is active.
getter/setter pair
activeAdsLimitTier ↔ String?
Maximum number of active ads allowed for this account. Possible string values are:
getter/setter pair
activeViewOptOut ↔ bool?
Whether to serve creatives with Active View tags.
getter/setter pair
availablePermissionIds ↔ List<String>?
User role permissions available to the user roles of this account.
getter/setter pair
countryId ↔ String?
ID of the country associated with this account.
getter/setter pair
currencyId ↔ String?
ID of currency associated with this account.
getter/setter pair
defaultCreativeSizeId ↔ String?
Default placement dimensions for this account.
getter/setter pair
description ↔ String?
Description of this account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this account.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
locale ↔ String?
Locale of this account.
getter/setter pair
maximumImageSize ↔ String?
Maximum image size allowed for this account, in kilobytes.
getter/setter pair
name ↔ String?
Name of this account.
getter/setter pair
nielsenOcrEnabled ↔ bool?
Whether campaigns created in this account will be enabled for Nielsen OCR reach ratings by default.
getter/setter pair
reportsConfiguration ↔ ReportsConfiguration?
Reporting configuration of this account.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareReportsWithTwitter ↔ bool?
Share Path to Conversion reports with Twitter.
getter/setter pair
teaserSizeLimit ↔ String?
File size limit in kilobytes of Rich Media teaser creatives.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited