Activities class

Represents an activity group.

Constructors

Activities({List<DimensionValue>? filters, String? kind, List<String>? metricNames})
Activities.fromJson(Map json_)

Properties

filters ↔ List<DimensionValue>?
List of activity filters.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of resource this is, in this case dfareporting#activities.
getter/setter pair
metricNames ↔ List<String>?
List of names of floodlight activity metrics.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited