ContextualKeyword class
Contains information about a Contextual Keyword that can be targeted by ads.
Constructors
- ContextualKeyword({String? keyword})
- ContextualKeyword.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited