Conversion class

A Conversion represents when a user successfully performs a desired action after seeing an ad.

Constructors

Conversion({String? adUserDataConsent, CartData? cartData, bool? childDirectedTreatment, List<CustomFloodlightVariable>? customVariables, String? dclid, String? encryptedUserId, List<String>? encryptedUserIdCandidates, String? floodlightActivityId, String? floodlightConfigurationId, String? gclid, String? impressionId, String? kind, bool? limitAdTracking, String? matchId, String? mobileDeviceId, bool? nonPersonalizedAd, String? ordinal, String? quantity, String? sessionAttributesEncoded, String? timestampMicros, bool? treatmentForUnderage, List<UserIdentifier>? userIdentifiers, double? value})
Conversion.fromJson(Map json_)

Properties

adUserDataConsent ↔ String?
This represents consent for ad user data. Possible string values are:
getter/setter pair
cartData ↔ CartData?
The cart data associated with this conversion.
getter/setter pair
childDirectedTreatment ↔ bool?
Whether this particular request may come from a user under the age of 13, under COPPA compliance.
getter/setter pair
customVariables ↔ List<CustomFloodlightVariable>?
Custom floodlight variables.
getter/setter pair
dclid ↔ String?
The display click ID.
getter/setter pair
encryptedUserId ↔ String?
The alphanumeric encrypted user ID.
getter/setter pair
encryptedUserIdCandidates ↔ List<String>?
A list of the alphanumeric encrypted user IDs.
getter/setter pair
floodlightActivityId ↔ String?
Floodlight Activity ID of this conversion.
getter/setter pair
floodlightConfigurationId ↔ String?
Floodlight Configuration ID of this conversion.
getter/setter pair
gclid ↔ String?
The Google click ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
impressionId ↔ String?
The impression ID.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
limitAdTracking ↔ bool?
Whether Limit Ad Tracking is enabled.
getter/setter pair
matchId ↔ String?
The match ID field.
getter/setter pair
mobileDeviceId ↔ String?
The mobile device ID.
getter/setter pair
nonPersonalizedAd ↔ bool?
Whether the conversion was for a non personalized ad.
getter/setter pair
ordinal ↔ String?
The ordinal of the conversion.
getter/setter pair
quantity ↔ String?
The quantity of the conversion.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionAttributesEncoded ↔ String?
Session attributes for the conversion, encoded as based64 bytes.
getter/setter pair
sessionAttributesEncodedAsBytes ↔ List<int>
getter/setter pair
timestampMicros ↔ String?
The timestamp of conversion, in Unix epoch micros.
getter/setter pair
treatmentForUnderage ↔ bool?
Whether this particular request may come from a user under the age of 16 (may differ by country), under compliance with the European Union's General Data Protection Regulation (GDPR).
getter/setter pair
userIdentifiers ↔ List<UserIdentifier>?
The user identifiers to enhance the conversion.
getter/setter pair
value ↔ double?
The value of the conversion.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited