CreativeFieldAssignment class

Creative Field Assignment.

Constructors

CreativeFieldAssignment({String? creativeFieldId, String? creativeFieldValueId})
CreativeFieldAssignment.fromJson(Map json_)

Properties

creativeFieldId ↔ String?
ID of the creative field.
getter/setter pair
creativeFieldValueId ↔ String?
ID of the creative field value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited