CreativeRotation class

Creative Rotation.

Constructors

CreativeRotation({List<CreativeAssignment>? creativeAssignments, String? creativeOptimizationConfigurationId, String? type, String? weightCalculationStrategy})
CreativeRotation.fromJson(Map json_)

Properties

creativeAssignments ↔ List<CreativeAssignment>?
Creative assignments in this creative rotation.
getter/setter pair
creativeOptimizationConfigurationId ↔ String?
Creative optimization configuration that is used by this ad.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of creative rotation.
getter/setter pair
weightCalculationStrategy ↔ String?
Strategy for calculating weights.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited