CustomFloodlightVariable class

A custom floodlight variable.

Can be used in both batchinsert and batchupdate. Adding this in batchupdate will update or append the variable to the existing list.

Properties

hashCode int
The hash code for this object.
no setterinherited
kind String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of custom floodlight variable to supply a value for.
getter/setter pair
value String?
The value of the custom floodlight variable.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited