DependentFieldValue class

Contains dependent field value information.

Constructors

DependentFieldValue({String? dynamicFeedId, String? elementId, int? fieldId})
DependentFieldValue.fromJson(Map json_)

Properties

dynamicFeedId String?
The ID of the dynamic feed that value's field will match against.
getter/setter pair
elementId String?
The ID of the element that value's field will match against.
getter/setter pair
fieldId int?
The field id of the dependent field.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited