DimensionValueList class

Represents the list of DimensionValue resources.

Constructors

DimensionValueList({String? etag, List<DimensionValue>? items, String? kind, String? nextPageToken})
DimensionValueList.fromJson(Map json_)

Properties

etag ↔ String?
The eTag of this response for caching purposes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<DimensionValue>?
The dimension values returned in this response.
getter/setter pair
kind ↔ String?
The kind of list this is, in this case dfareporting#dimensionValueList.
getter/setter pair
nextPageToken ↔ String?
Continuation token used to page through dimension values.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited