DynamicRules class

Contains dynamic rules information.

Constructors

DynamicRules({List<int>? autoTargetedFieldIds, List<CustomRule>? customRules, List<CustomValueField>? customValueFields, ProximityFilter? proximityFilter, List<RemarketingValueAttribute>? remarketingValueAttributes, String? rotationType, String? ruleType, int? weightFieldId})
DynamicRules.fromJson(Map json_)

Properties

autoTargetedFieldIds ↔ List<int>?
List of field IDs in this element that should be auto-targeted.
getter/setter pair
customRules ↔ List<CustomRule>?
The custom rules of the dynamic feed, only applicable when rule type is CUSTOM.
getter/setter pair
customValueFields ↔ List<CustomValueField>?
Mapping between field ID and custom key that are used to match for auto filtering.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
proximityFilter ↔ ProximityFilter?
The proximity targeting rules of the dynamic feed, only applicable when rule type is PROXIMITY_TARGETING.
getter/setter pair
remarketingValueAttributes ↔ List<RemarketingValueAttribute>?
The link between an element field ID and a list of user attribute IDs.
getter/setter pair
rotationType ↔ String?
The rotation type to select from eligible rows.
getter/setter pair
ruleType ↔ String?
The type of the rule, the default value is OPEN.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weightFieldId ↔ int?
The field ID for the feed that will be used for weighted rotation, only applicable when rotation type is WEIGHTED.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited