DynamicTargetingKey class

Contains properties of a dynamic targeting key.

Dynamic targeting keys are unique, user-friendly labels, created at the advertiser level in DCM, that can be assigned to ads, creatives, and placements and used for targeting with Studio dynamic creatives. Use these labels instead of numeric Campaign Manager IDs (such as placement IDs) to save time and avoid errors in your dynamic feeds.

Constructors

DynamicTargetingKey({String? kind, String? name, String? objectId, String? objectType})
DynamicTargetingKey.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
name ↔ String?
Name of this dynamic targeting key.
getter/setter pair
objectId ↔ String?
ID of the object of this dynamic targeting key.
getter/setter pair
objectType ↔ String?
Type of the object of this dynamic targeting key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited