Element class

Contains the element of the dynamic feed.

Constructors

Element({int? activeFieldId, LastModifiedInfo? createInfo, int? defaultFieldId, String? elementName, int? endTimestampFieldId, int? externalIdFieldId, List<FeedField>? feedFields, bool? isLocalTimestamp, LastModifiedInfo? lastModifiedInfo, int? proximityTargetingFieldId, int? reportingLabelFieldId, int? startTimestampFieldId})
Element.fromJson(Map json_)

Properties

activeFieldId ↔ int?
The field ID to specify the active field in the feed.
getter/setter pair
createInfo ↔ LastModifiedInfo?
The creation timestamp of the element.
getter/setter pair
defaultFieldId ↔ int?
The field ID to specify the field that represents the default field in the feed.
getter/setter pair
elementName ↔ String?
The name of the element.
getter/setter pair
endTimestampFieldId ↔ int?
The field ID to specify the field that represents the end timestamp.
getter/setter pair
externalIdFieldId ↔ int?
The field ID to specify the field used for uniquely identifying the feed row.
getter/setter pair
feedFields ↔ List<FeedField>?
The list of fields of the element.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isLocalTimestamp ↔ bool?
Whether the start and end timestamp is local timestamp.
getter/setter pair
lastModifiedInfo ↔ LastModifiedInfo?
The last modified timestamp of the element.
getter/setter pair
proximityTargetingFieldId ↔ int?
The field ID that specify field used for proximity targeting.
getter/setter pair
reportingLabelFieldId ↔ int?
The field ID to specify the field used for dynamic reporting in Campaign Manager 360.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimestampFieldId ↔ int?
The field ID to specify the field that represents the start timestamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited