EventTag class

Contains properties of an event tag.

Constructors

EventTag({String? accountId, String? advertiserId, DimensionValue? advertiserIdDimensionValue, String? campaignId, DimensionValue? campaignIdDimensionValue, bool? enabledByDefault, bool? excludeFromAdxRequests, String? id, String? kind, String? name, String? siteFilterType, List<String>? siteIds, bool? sslCompliant, String? status, String? subaccountId, String? type, String? url, int? urlEscapeLevels})
EventTag.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of this event tag.
getter/setter pair
advertiserId ↔ String?
Advertiser ID of this event tag.
getter/setter pair
advertiserIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the advertiser.
getter/setter pair
campaignId ↔ String?
Campaign ID of this event tag.
getter/setter pair
campaignIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the campaign.
getter/setter pair
enabledByDefault ↔ bool?
Whether this event tag should be automatically enabled for all of the advertiser's campaigns and ads.
getter/setter pair
excludeFromAdxRequests ↔ bool?
Whether to remove this event tag from ads that are trafficked through Display & Video 360 to Ad Exchange.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this event tag.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
name ↔ String?
Name of this event tag.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
siteFilterType ↔ String?
Site filter type for this event tag.
getter/setter pair
siteIds ↔ List<String>?
Filter list of site IDs associated with this event tag.
getter/setter pair
sslCompliant ↔ bool?
Whether this tag is SSL-compliant or not.
getter/setter pair
status ↔ String?
Status of this event tag.
getter/setter pair
subaccountId ↔ String?
Subaccount ID of this event tag.
getter/setter pair
type ↔ String?
Event tag type.
getter/setter pair
url ↔ String?
Payload URL for this event tag.
getter/setter pair
urlEscapeLevels ↔ int?
Number of times the landing page URL should be URL-escaped before being appended to the click-through event tag URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited