EventTagOverride class

Event tag override information.

Constructors

EventTagOverride({bool? enabled, String? id})
EventTagOverride.fromJson(Map json_)

Properties

enabled ↔ bool?
Whether this override is enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this event tag override.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited