FloodlightConfiguration class

Contains properties of a Floodlight configuration.

Constructors

FloodlightConfiguration({String? accountId, String? advertiserId, DimensionValue? advertiserIdDimensionValue, bool? analyticsDataSharingEnabled, CustomViewabilityMetric? customViewabilityMetric, bool? exposureToConversionEnabled, String? firstDayOfWeek, String? id, DimensionValue? idDimensionValue, bool? inAppAttributionTrackingEnabled, String? kind, LookbackConfiguration? lookbackConfiguration, String? naturalSearchConversionAttributionOption, OmnitureSettings? omnitureSettings, String? subaccountId, TagSettings? tagSettings, List<ThirdPartyAuthenticationToken>? thirdPartyAuthenticationTokens, List<UserDefinedVariableConfiguration>? userDefinedVariableConfigurations})
FloodlightConfiguration.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of this floodlight configuration.
getter/setter pair
advertiserId ↔ String?
Advertiser ID of the parent advertiser of this floodlight configuration.
getter/setter pair
advertiserIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the advertiser.
getter/setter pair
analyticsDataSharingEnabled ↔ bool?
Whether advertiser data is shared with Google Analytics.
getter/setter pair
customViewabilityMetric ↔ CustomViewabilityMetric?
Custom Viewability metric for the floodlight configuration.
getter/setter pair
exposureToConversionEnabled ↔ bool?
Whether the exposure-to-conversion report is enabled.
getter/setter pair
firstDayOfWeek ↔ String?
Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this floodlight configuration.
getter/setter pair
idDimensionValue ↔ DimensionValue?
Dimension value for the ID of this floodlight configuration.
getter/setter pair
inAppAttributionTrackingEnabled ↔ bool?
Whether in-app attribution tracking is enabled.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lookbackConfiguration ↔ LookbackConfiguration?
Lookback window settings for this floodlight configuration.
getter/setter pair
naturalSearchConversionAttributionOption ↔ String?
Types of attribution options for natural search conversions. Possible string values are:
getter/setter pair
omnitureSettings ↔ OmnitureSettings?
Settings for Campaign Manager Omniture integration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subaccountId ↔ String?
Subaccount ID of this floodlight configuration.
getter/setter pair
tagSettings ↔ TagSettings?
Configuration settings for dynamic and image floodlight tags.
getter/setter pair
thirdPartyAuthenticationTokens ↔ List<ThirdPartyAuthenticationToken>?
List of third-party authentication tokens enabled for this configuration.
getter/setter pair
userDefinedVariableConfigurations ↔ List<UserDefinedVariableConfiguration>?
List of user defined variables enabled for this configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited