OptimizationActivity class

Creative optimization activity.

Constructors

OptimizationActivity({String? floodlightActivityId, DimensionValue? floodlightActivityIdDimensionValue, int? weight})
OptimizationActivity.fromJson(Map json_)

Properties

floodlightActivityId ↔ String?
Floodlight activity ID of this optimization activity.
getter/setter pair
floodlightActivityIdDimensionValue ↔ DimensionValue?
Dimension value for the ID of the floodlight activity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weight ↔ int?
Weight associated with this optimization.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited