ProximityFilter class
Contains proximity filter information.
Constructors
- ProximityFilter({int? fieldId, String? radiusBucketType, String? radiusUnitType, int? radiusValue})
- ProximityFilter.fromJson(Map json_)
Properties
- fieldId ↔ int?
-
Field ID in the element.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- radiusBucketType ↔ String?
-
The radius bucket type of the proximity filter
getter/setter pair
- radiusUnitType ↔ String?
-
The units of the radius value
getter/setter pair
- radiusValue ↔ int?
-
Radius length in units defined by radius_units.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited