ReportDataQueryRequest class

The request body containing ad-hoc query parameters.

Constructors

ReportDataQueryRequest({DateRange? dateRange, List<DimensionValue>? dimensionFilters, List<String>? dimensionNames, int? maxResults, List<String>? metricNames, String? pageToken, List<SortBy>? sortBys})
ReportDataQueryRequest.fromJson(Map json_)

Properties

dateRange DateRange?
The requested date range covering the report duration.
getter/setter pair
dimensionFilters List<DimensionValue>?
The list of dimension values on which report lines are filtered.
getter/setter pair
dimensionNames List<String>?
The list of dimension names to group by.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxResults int?
Maximum number of result rows to return per page.
getter/setter pair
metricNames List<String>?
The list of metric names to include.
getter/setter pair
pageToken String?
Continuation token for paginating results.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBys List<SortBy>?
Sort options across either requested dimensions or metrics.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited