SortBy class

Specifies the sort configuration for a specific field in the report.

Constructors

SortBy({String? name, String? sortOrder})
SortBy.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The dimension or metric field name to sort on.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortOrder String?
The sort order of this column.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited