VideoProcessingData class

Contains processing data for a video asset.

Constructors

VideoProcessingData({String? errorReason, String? processingState})
VideoProcessingData.fromJson(Map json_)

Properties

errorReason String?
For a FAILED processing state, the error reason discovered.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
processingState String?
The processing state of the studio creative asset.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited