GoogleCloudDialogflowV2AgentAssistantRecord class

Properties

articleSuggestionAnswer ↔ GoogleCloudDialogflowV2ArticleAnswer?
getter/setter pair
dialogflowAssistAnswer ↔ GoogleCloudDialogflowV2DialogflowAssistAnswer?
getter/setter pair
faqAnswer ↔ GoogleCloudDialogflowV2FaqAnswer?
getter/setter pair
generatorSuggestion ↔ GoogleCloudDialogflowV2GeneratorSuggestion?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited