GoogleCloudDialogflowV2AnswerFeedback class

Constructors

GoogleCloudDialogflowV2AnswerFeedback({GoogleCloudDialogflowV2AgentAssistantFeedback? agentAssistantDetailFeedback, String? clickTime, bool? clicked, String? correctnessLevel, String? displayTime, bool? displayed})
GoogleCloudDialogflowV2AnswerFeedback.fromJson(Map json_)

Properties

agentAssistantDetailFeedback ↔ GoogleCloudDialogflowV2AgentAssistantFeedback?
getter/setter pair
clicked ↔ bool?
getter/setter pair
clickTime ↔ String?
getter/setter pair
correctnessLevel ↔ String?
Possible string values are:
getter/setter pair
displayed ↔ bool?
getter/setter pair
displayTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited