GoogleCloudDialogflowV2ArticleAnswer class

Constructors

GoogleCloudDialogflowV2ArticleAnswer({String? answerRecord, double? confidence, Map<String, String>? metadata, List<String>? snippets, String? title, String? uri})
GoogleCloudDialogflowV2ArticleAnswer.fromJson(Map json_)

Properties

answerRecord ↔ String?
getter/setter pair
confidence ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippets ↔ List<String>?
getter/setter pair
title ↔ String?
getter/setter pair
uri ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited