GoogleCloudDialogflowV2BatchCreateEntitiesRequest class

The request message for EntityTypes.BatchCreateEntities.

Properties

entities ↔ List<GoogleCloudDialogflowV2EntityTypeEntity>?
The entities to create.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The language used to access language-specific data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited