GoogleCloudDialogflowV2CesAppSpec class

Constructors

GoogleCloudDialogflowV2CesAppSpec({String? cesApp, String? confirmationRequirement, bool? proactiveEnabled, bool? reactiveEnabled})
GoogleCloudDialogflowV2CesAppSpec.fromJson(Map json_)

Properties

cesApp String?
getter/setter pair
confirmationRequirement String?
Possible string values are:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
proactiveEnabled bool?
getter/setter pair
reactiveEnabled bool?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited