GoogleCloudDialogflowV2Conversation class

Constructors

GoogleCloudDialogflowV2Conversation({String? conversationProfile, String? conversationStage, String? endTime, Map<String, GoogleCloudDialogflowV2ConversationContextReference>? ingestedContextReferences, GoogleCloudDialogflowV2ConversationProfile? initialConversationProfile, Map<String, GoogleCloudDialogflowV2ConversationGeneratorContext>? initialGeneratorContexts, String? lifecycleState, String? name, GoogleCloudDialogflowV2ConversationPhoneNumber? phoneNumber, String? startTime, GoogleCloudDialogflowV2ConversationTelephonyConnectionInfo? telephonyConnectionInfo})
GoogleCloudDialogflowV2Conversation.fromJson(Map json_)

Properties

conversationProfile ↔ String?
getter/setter pair
conversationStage ↔ String?
Possible string values are:
getter/setter pair
endTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ingestedContextReferences ↔ Map<String, GoogleCloudDialogflowV2ConversationContextReference>?
getter/setter pair
initialConversationProfile ↔ GoogleCloudDialogflowV2ConversationProfile?
getter/setter pair
initialGeneratorContexts ↔ Map<String, GoogleCloudDialogflowV2ConversationGeneratorContext>?
getter/setter pair
lifecycleState ↔ String?
Possible string values are:
getter/setter pair
name ↔ String?
getter/setter pair
phoneNumber ↔ GoogleCloudDialogflowV2ConversationPhoneNumber?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
getter/setter pair
telephonyConnectionInfo ↔ GoogleCloudDialogflowV2ConversationTelephonyConnectionInfo?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited