GoogleCloudDialogflowV2ConversationModel class

Constructors

GoogleCloudDialogflowV2ConversationModel({GoogleCloudDialogflowV2ArticleSuggestionModelMetadata? articleSuggestionModelMetadata, String? createTime, List<GoogleCloudDialogflowV2InputDataset>? datasets, String? displayName, String? languageCode, String? name, bool? satisfiesPzi, bool? satisfiesPzs, GoogleCloudDialogflowV2SmartReplyModelMetadata? smartReplyModelMetadata, String? state})
GoogleCloudDialogflowV2ConversationModel.fromJson(Map json_)

Properties

articleSuggestionModelMetadata ↔ GoogleCloudDialogflowV2ArticleSuggestionModelMetadata?
getter/setter pair
createTime ↔ String?
getter/setter pair
datasets ↔ List<GoogleCloudDialogflowV2InputDataset>?
getter/setter pair
displayName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
getter/setter pair
satisfiesPzs ↔ bool?
getter/setter pair
smartReplyModelMetadata ↔ GoogleCloudDialogflowV2ArticleSuggestionModelMetadata?
getter/setter pair
state ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited