GoogleCloudDialogflowV2DetectIntentRequest class

Properties

hashCode → int
The hash code for this object.
no setterinherited
inputAudio ↔ String?
getter/setter pair
inputAudioAsBytes ↔ List<int>
getter/setter pair
outputAudioConfig ↔ GoogleCloudDialogflowV2OutputAudioConfig?
getter/setter pair
outputAudioConfigMask ↔ String?
getter/setter pair
queryInput ↔ GoogleCloudDialogflowV2QueryInput?
getter/setter pair
queryParams ↔ GoogleCloudDialogflowV2QueryParameters?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited