GoogleCloudDialogflowV2Document class

Constructors

GoogleCloudDialogflowV2Document({String? contentUri, String? displayName, bool? enableAutoReload, List<String>? knowledgeTypes, GoogleCloudDialogflowV2DocumentReloadStatus? latestReloadStatus, Map<String, String>? metadata, String? mimeType, String? name, String? rawContent, String? state})
GoogleCloudDialogflowV2Document.fromJson(Map json_)

Properties

contentUri ↔ String?
getter/setter pair
displayName ↔ String?
getter/setter pair
enableAutoReload ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
knowledgeTypes ↔ List<String>?
getter/setter pair
latestReloadStatus ↔ GoogleCloudDialogflowV2DocumentReloadStatus?
getter/setter pair
metadata ↔ Map<String, String>?
getter/setter pair
mimeType ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
rawContent ↔ String?
getter/setter pair
rawContentAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited