GoogleCloudDialogflowV2EncryptionSpec class

A customer-managed encryption key specification that can be applied to all created resources (e.g. Conversation).

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKey ↔ String?
The name of customer-managed encryption key that is used to secure a resource and its sub-resources.
getter/setter pair
name ↔ String?
The resource name of the encryption key specification resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited