GoogleCloudDialogflowV2EntityType class

Constructors

GoogleCloudDialogflowV2EntityType({String? autoExpansionMode, String? displayName, bool? enableFuzzyExtraction, List<GoogleCloudDialogflowV2EntityTypeEntity>? entities, String? kind, String? name})
GoogleCloudDialogflowV2EntityType.fromJson(Map json_)

Properties

autoExpansionMode ↔ String?
Possible string values are:
getter/setter pair
displayName ↔ String?
getter/setter pair
enableFuzzyExtraction ↔ bool?
getter/setter pair
entities ↔ List<GoogleCloudDialogflowV2EntityTypeEntity>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Possible string values are:
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited