GoogleCloudDialogflowV2Environment class

Constructors

GoogleCloudDialogflowV2Environment({String? agentVersion, String? description, GoogleCloudDialogflowV2Fulfillment? fulfillment, String? name, String? state, GoogleCloudDialogflowV2TextToSpeechSettings? textToSpeechSettings, String? updateTime})
GoogleCloudDialogflowV2Environment.fromJson(Map json_)

Properties

agentVersion ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
fulfillment ↔ GoogleCloudDialogflowV2Fulfillment?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Possible string values are:
getter/setter pair
textToSpeechSettings ↔ GoogleCloudDialogflowV2TextToSpeechSettings?
getter/setter pair
updateTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited