GoogleCloudDialogflowV2EventInput class

Events allow for matching intents by event name instead of the natural language input.

For instance, input `` can trigger a personalized welcome response. The parameter name may be used by the agent in the response: "Hello #welcome_event.name! What can I do for you today?".

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The language of this query.
getter/setter pair
name ↔ String?
The unique identifier of the event.
getter/setter pair
parameters ↔ Map<String, Object?>?
The collection of parameters associated with the event.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited