GoogleCloudDialogflowV2FewShotExample class

Properties

conversationContext ↔ GoogleCloudDialogflowV2ConversationContext?
getter/setter pair
extraInfo ↔ Map<String, String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
output ↔ GoogleCloudDialogflowV2GeneratorSuggestion?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summarizationSectionList ↔ GoogleCloudDialogflowV2SummarizationSectionList?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited