GoogleCloudDialogflowV2Generator class

Properties

agentCoachingContext ↔ GoogleCloudDialogflowV2AgentCoachingContext?
getter/setter pair
cesAppSpecs ↔ List<GoogleCloudDialogflowV2CesAppSpec>?
getter/setter pair
cesToolSpecs ↔ List<GoogleCloudDialogflowV2CesToolSpec>?
getter/setter pair
createTime ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
freeFormContext ↔ GoogleCloudDialogflowV2FreeFormContext?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inferenceParameter ↔ GoogleCloudDialogflowV2InferenceParameter?
getter/setter pair
name ↔ String?
getter/setter pair
publishedModel ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestionDedupingConfig ↔ GoogleCloudDialogflowV2SuggestionDedupingConfig?
getter/setter pair
summarizationContext ↔ GoogleCloudDialogflowV2SummarizationContext?
getter/setter pair
tools ↔ List<String>?
getter/setter pair
toolsetTools ↔ List<GoogleCloudDialogflowV2ToolsetTool>?
getter/setter pair
triggerEvent ↔ String?
Possible string values are:
getter/setter pair
updateTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited