GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionConfig class

Constructors

GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionConfig({bool? disableHighLatencyFeaturesSyncDelivery, bool? enableAsyncToolCall, List<GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig>? featureConfigs, List<String>? generators, bool? groupSuggestionResponses, bool? skipEmptyEventBasedSuggestion, bool? useUnredactedConversationData})
GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionConfig.fromJson(Map json_)

Properties

disableHighLatencyFeaturesSyncDelivery ↔ bool?
getter/setter pair
enableAsyncToolCall ↔ bool?
getter/setter pair
featureConfigs ↔ List<GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig>?
getter/setter pair
generators ↔ List<String>?
getter/setter pair
groupSuggestionResponses ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipEmptyEventBasedSuggestion ↔ bool?
getter/setter pair
useUnredactedConversationData ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited