GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig class

Constructors

GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig({GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationModelConfig? conversationModelConfig, GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationProcessConfig? conversationProcessConfig, bool? disableAgentQueryLogging, bool? disableQuerySearchContext, bool? enableConversationAugmentedQuery, bool? enableEventBasedSuggestion, bool? enableQuerySuggestionOnly, bool? enableQuerySuggestionWhenNoAnswer, bool? enableResponseDebugInfo, GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfig? queryConfig, GoogleCloudDialogflowV2RaiSettings? raiSettings, GoogleCloudDialogflowV2SuggestionFeature? suggestionFeature, String? suggestionTriggerEvent, GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionTriggerSettings? suggestionTriggerSettings})
GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig.fromJson(Map json_)

Properties

conversationModelConfig ↔ GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationModelConfig?
getter/setter pair
conversationProcessConfig ↔ GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationProcessConfig?
getter/setter pair
disableAgentQueryLogging ↔ bool?
getter/setter pair
disableQuerySearchContext ↔ bool?
getter/setter pair
enableConversationAugmentedQuery ↔ bool?
getter/setter pair
enableEventBasedSuggestion ↔ bool?
getter/setter pair
enableQuerySuggestionOnly ↔ bool?
getter/setter pair
enableQuerySuggestionWhenNoAnswer ↔ bool?
getter/setter pair
enableResponseDebugInfo ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
queryConfig ↔ GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfig?
getter/setter pair
raiSettings ↔ GoogleCloudDialogflowV2RaiSettings?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestionFeature ↔ GoogleCloudDialogflowV2SuggestionFeature?
getter/setter pair
suggestionTriggerEvent ↔ String?
Possible string values are:
getter/setter pair
suggestionTriggerSettings ↔ GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionTriggerSettings?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited