GoogleCloudDialogflowV2InitializeEncryptionSpecRequest class

The request to initialize a location-level encryption specification.

Properties

encryptionSpec ↔ GoogleCloudDialogflowV2EncryptionSpec?
The encryption spec used for CMEK encryption.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited