GoogleCloudDialogflowV2InputAudioConfig class

Constructors

GoogleCloudDialogflowV2InputAudioConfig({String? audioEncoding, bool? disableNoSpeechRecognizedEvent, bool? enableAutomaticPunctuation, bool? enableVoiceActivityEvents, bool? enableWordInfo, String? languageCode, String? model, String? modelVariant, bool? optOutConformerModelMigration, List<String>? phraseHints, List<String>? phraseSets, int? sampleRateHertz, bool? singleUtterance, List<GoogleCloudDialogflowV2SpeechContext>? speechContexts})
GoogleCloudDialogflowV2InputAudioConfig.fromJson(Map json_)

Properties

audioEncoding ↔ String?
Possible string values are:
getter/setter pair
disableNoSpeechRecognizedEvent ↔ bool?
getter/setter pair
enableAutomaticPunctuation ↔ bool?
getter/setter pair
enableVoiceActivityEvents ↔ bool?
getter/setter pair
enableWordInfo ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
getter/setter pair
model ↔ String?
getter/setter pair
modelVariant ↔ String?
Possible string values are:
getter/setter pair
optOutConformerModelMigration ↔ bool?
getter/setter pair
phraseHints ↔ List<String>?
getter/setter pair
phraseSets ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRateHertz ↔ int?
getter/setter pair
singleUtterance ↔ bool?
getter/setter pair
speechContexts ↔ List<GoogleCloudDialogflowV2SpeechContext>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited