GoogleCloudDialogflowV2IntentMessageBasicCard class

The basic card message.

Useful for displaying information.

Properties

buttons ↔ List<GoogleCloudDialogflowV2IntentMessageBasicCardButton>?
The collection of card buttons.
getter/setter pair
formattedText ↔ String?
Required, unless image is present.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ GoogleCloudDialogflowV2IntentMessageImage?
The image for the card.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ String?
The subtitle of the card.
getter/setter pair
title ↔ String?
The title of the card.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited