GoogleCloudDialogflowV2IntentMessageMediaContentResponseMediaObject class

Properties

contentUrl ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icon ↔ GoogleCloudDialogflowV2IntentMessageImage?
getter/setter pair
largeImage ↔ GoogleCloudDialogflowV2IntentMessageImage?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited