GoogleCloudDialogflowV2IntentMessageTableCard class

Properties

buttons ↔ List<GoogleCloudDialogflowV2IntentMessageBasicCardButton>?
getter/setter pair
columnProperties ↔ List<GoogleCloudDialogflowV2IntentMessageColumnProperties>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ GoogleCloudDialogflowV2IntentMessageImage?
getter/setter pair
rows ↔ List<GoogleCloudDialogflowV2IntentMessageTableCardRow>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subtitle ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited