GoogleCloudDialogflowV2IntentParameter class

Constructors

GoogleCloudDialogflowV2IntentParameter({String? defaultValue, String? displayName, String? entityTypeDisplayName, bool? isList, bool? mandatory, String? name, List<String>? prompts, String? value})
GoogleCloudDialogflowV2IntentParameter.fromJson(Map json_)

Properties

defaultValue ↔ String?
getter/setter pair
displayName ↔ String?
getter/setter pair
entityTypeDisplayName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isList ↔ bool?
getter/setter pair
mandatory ↔ bool?
getter/setter pair
name ↔ String?
getter/setter pair
prompts ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited