GoogleCloudDialogflowV2KnowledgeAssistDebugInfoKnowledgeAssistBehavior class

Constructors

GoogleCloudDialogflowV2KnowledgeAssistDebugInfoKnowledgeAssistBehavior({bool? answerGenerationRewriterOn, int? appendedSearchContextCount, bool? conversationTranscriptHasMixedLanguages, bool? disableSyncDelivery, bool? endUserMetadataIncluded, bool? invalidItemsQuerySuggestionSkipped, bool? multipleQueriesGenerated, bool? previousQueriesIncluded, bool? primaryQueryRedactedAndReplaced, bool? queryContainedSearchContext, bool? queryGenerationAgentLanguageMismatch, bool? queryGenerationEndUserLanguageMismatch, bool? returnQueryOnly, bool? thirdPartyConnectorAllowed, bool? useCustomSafetyFilterLevel, bool? usePubsubDelivery, bool? useTranslatedMessage})
GoogleCloudDialogflowV2KnowledgeAssistDebugInfoKnowledgeAssistBehavior.fromJson(Map json_)

Properties

answerGenerationRewriterOn ↔ bool?
getter/setter pair
appendedSearchContextCount ↔ int?
getter/setter pair
conversationTranscriptHasMixedLanguages ↔ bool?
getter/setter pair
disableSyncDelivery ↔ bool?
getter/setter pair
endUserMetadataIncluded ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invalidItemsQuerySuggestionSkipped ↔ bool?
getter/setter pair
multipleQueriesGenerated ↔ bool?
getter/setter pair
previousQueriesIncluded ↔ bool?
getter/setter pair
primaryQueryRedactedAndReplaced ↔ bool?
getter/setter pair
queryContainedSearchContext ↔ bool?
getter/setter pair
queryGenerationAgentLanguageMismatch ↔ bool?
getter/setter pair
queryGenerationEndUserLanguageMismatch ↔ bool?
getter/setter pair
returnQueryOnly ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thirdPartyConnectorAllowed ↔ bool?
getter/setter pair
useCustomSafetyFilterLevel ↔ bool?
getter/setter pair
usePubsubDelivery ↔ bool?
getter/setter pair
useTranslatedMessage ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited