GoogleCloudDialogflowV2KnowledgeAssistDebugInfoQueryGenerationDebugInfo class

Constructors

GoogleCloudDialogflowV2KnowledgeAssistDebugInfoQueryGenerationDebugInfo({int? candidatesTokenCount, int? promptTokenCount, double? similarityToLastQuery, double? similarityToLastQueryThreshold, int? thinkingBudgetTokens, String? thinkingLevel, int? totalTokenCount})
GoogleCloudDialogflowV2KnowledgeAssistDebugInfoQueryGenerationDebugInfo.fromJson(Map json_)

Properties

candidatesTokenCount ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
promptTokenCount ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
similarityToLastQuery ↔ double?
getter/setter pair
similarityToLastQueryThreshold ↔ double?
getter/setter pair
thinkingBudgetTokens ↔ int?
getter/setter pair
thinkingLevel ↔ String?
getter/setter pair
totalTokenCount ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited