GoogleCloudDialogflowV2Message class

Constructors

GoogleCloudDialogflowV2Message({String? content, String? createTime, String? languageCode, GoogleCloudDialogflowV2MessageAnnotation? messageAnnotation, String? name, String? participant, String? participantRole, String? sendTime, GoogleCloudDialogflowV2SentimentAnalysisResult? sentimentAnalysis})
GoogleCloudDialogflowV2Message.fromJson(Map json_)

Properties

content ↔ String?
getter/setter pair
createTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
getter/setter pair
messageAnnotation ↔ GoogleCloudDialogflowV2MessageAnnotation?
getter/setter pair
name ↔ String?
getter/setter pair
participant ↔ String?
getter/setter pair
participantRole ↔ String?
Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendTime ↔ String?
getter/setter pair
sentimentAnalysis ↔ GoogleCloudDialogflowV2SentimentAnalysisResult?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited