GoogleCloudDialogflowV2MessageEntry class

Constructors

GoogleCloudDialogflowV2MessageEntry({String? createTime, String? languageCode, String? role, String? text})
GoogleCloudDialogflowV2MessageEntry.fromJson(Map json_)

Properties

createTime ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
getter/setter pair
role ↔ String?
Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited