GoogleCloudDialogflowV2ProbeDetails class
Constructors
- GoogleCloudDialogflowV2ProbeDetails({String? initTime, String? optionsLatency, String? probeStatus})
- GoogleCloudDialogflowV2ProbeDetails.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initTime ↔ String?
-
getter/setter pair
- optionsLatency ↔ String?
-
getter/setter pair
- probeStatus ↔ String?
-
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited