GoogleCloudDialogflowV2QueryResult class

Constructors

GoogleCloudDialogflowV2QueryResult({String? action, bool? allRequiredParamsPresent, bool? cancelsSlotFilling, Map<String, Object?>? diagnosticInfo, List<GoogleCloudDialogflowV2IntentMessage>? fulfillmentMessages, String? fulfillmentText, GoogleCloudDialogflowV2Intent? intent, double? intentDetectionConfidence, String? languageCode, List<GoogleCloudDialogflowV2Context>? outputContexts, Map<String, Object?>? parameters, String? queryText, GoogleCloudDialogflowV2SentimentAnalysisResult? sentimentAnalysisResult, double? speechRecognitionConfidence, Map<String, Object?>? webhookPayload, String? webhookSource})
GoogleCloudDialogflowV2QueryResult.fromJson(Map json_)

Properties

action ↔ String?
getter/setter pair
allRequiredParamsPresent ↔ bool?
getter/setter pair
cancelsSlotFilling ↔ bool?
getter/setter pair
diagnosticInfo ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
fulfillmentMessages ↔ List<GoogleCloudDialogflowV2IntentMessage>?
getter/setter pair
fulfillmentText ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intent ↔ GoogleCloudDialogflowV2Intent?
getter/setter pair
intentDetectionConfidence ↔ double?
getter/setter pair
languageCode ↔ String?
getter/setter pair
outputContexts ↔ List<GoogleCloudDialogflowV2Context>?
getter/setter pair
parameters ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
queryText ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentimentAnalysisResult ↔ GoogleCloudDialogflowV2SentimentAnalysisResult?
getter/setter pair
speechRecognitionConfidence ↔ double?
getter/setter pair
webhookPayload ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
webhookSource ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited