GoogleCloudDialogflowV2SearchKnowledgeAnswerAnswerSource class

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet ↔ String?
getter/setter pair
title ↔ String?
getter/setter pair
uri ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited