GoogleCloudDialogflowV2SearchKnowledgeDebugInfo class
Constructors
-
GoogleCloudDialogflowV2SearchKnowledgeDebugInfo({Map<
String, Object?> ? cesDebugInfo, String? datastoreResponseReason, GoogleCloudDialogflowV2IngestedContextReferenceDebugInfo? ingestedContextReferenceDebugInfo, GoogleCloudDialogflowV2SearchKnowledgeDebugInfoSearchKnowledgeBehavior? searchKnowledgeBehavior, GoogleCloudDialogflowV2ServiceLatency? serviceLatency}) - GoogleCloudDialogflowV2SearchKnowledgeDebugInfo.fromJson(Map json_)
Properties
-
cesDebugInfo
↔ Map<
String, Object?> ? -
The values for Object must be JSON objects. It can consist of
num,String,boolandnullas well asMapandListvalues.getter/setter pair - datastoreResponseReason ↔ String?
-
Possible string values are:
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ingestedContextReferenceDebugInfo ↔ GoogleCloudDialogflowV2IngestedContextReferenceDebugInfo?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchKnowledgeBehavior ↔ GoogleCloudDialogflowV2SearchKnowledgeDebugInfoSearchKnowledgeBehavior?
-
getter/setter pair
- serviceLatency ↔ GoogleCloudDialogflowV2ServiceLatency?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited