GoogleCloudDialogflowV2SearchKnowledgeRequest class

Constructors

GoogleCloudDialogflowV2SearchKnowledgeRequest({String? conversation, String? conversationProfile, Map<String, Object?>? endUserMetadata, bool? exactSearch, String? latestMessage, String? parent, GoogleCloudDialogflowV2TextInput? query, String? querySource, GoogleCloudDialogflowV2SearchKnowledgeRequestSearchConfig? searchConfig, String? sessionId})
GoogleCloudDialogflowV2SearchKnowledgeRequest.fromJson(Map json_)

Properties

conversation ↔ String?
getter/setter pair
conversationProfile ↔ String?
getter/setter pair
endUserMetadata ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
exactSearch ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latestMessage ↔ String?
getter/setter pair
parent ↔ String?
getter/setter pair
query ↔ GoogleCloudDialogflowV2TextInput?
getter/setter pair
querySource ↔ String?
Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchConfig ↔ GoogleCloudDialogflowV2SearchKnowledgeRequestSearchConfig?
getter/setter pair
sessionId ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited