GoogleCloudDialogflowV2SipConfig class

Constructors

GoogleCloudDialogflowV2SipConfig({bool? allowVirtualAgentInteraction, List<String>? copyInboundCallLegHeaders, bool? createConversationOnTheFly, bool? ignoreReinviteMediaDirection, bool? inactiveStart, bool? keepConversationRunning, String? maxAudioRecordingDuration})
GoogleCloudDialogflowV2SipConfig.fromJson(Map json_)

Properties

allowVirtualAgentInteraction bool?
getter/setter pair
copyInboundCallLegHeaders List<String>?
getter/setter pair
createConversationOnTheFly bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ignoreReinviteMediaDirection bool?
getter/setter pair
inactiveStart bool?
getter/setter pair
keepConversationRunning bool?
getter/setter pair
maxAudioRecordingDuration String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited