GoogleCloudDialogflowV2SipHostname class

Constructors

GoogleCloudDialogflowV2SipHostname({String? connectionState, bool? enabledSipPing, GoogleCloudDialogflowV2SipHostnameHostnameErrorDetails? errorDetails, String? peerHostname, String? peerSocketAddress, String? pingInterval, GoogleCloudDialogflowV2ProbeDetails? probeDetails})
GoogleCloudDialogflowV2SipHostname.fromJson(Map json_)

Properties

connectionState String?
Possible string values are:
getter/setter pair
enabledSipPing bool?
getter/setter pair
errorDetails GoogleCloudDialogflowV2SipHostnameHostnameErrorDetails?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
peerHostname String?
getter/setter pair
peerSocketAddress String?
getter/setter pair
pingInterval String?
getter/setter pair
probeDetails GoogleCloudDialogflowV2ProbeDetails?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited