GoogleCloudDialogflowV2SuggestionDedupingConfig class
Constructors
- GoogleCloudDialogflowV2SuggestionDedupingConfig({bool? enableDeduping, double? similarityThreshold})
- GoogleCloudDialogflowV2SuggestionDedupingConfig.fromJson(Map json_)
Properties
- enableDeduping ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- similarityThreshold ↔ double?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited