GoogleCloudDialogflowV2SuggestionResult class

Properties

error GoogleRpcStatus?
getter/setter pair
generateSuggestionsResponse GoogleCloudDialogflowV2GenerateSuggestionsResponse?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
suggestArticlesResponse GoogleCloudDialogflowV2SuggestArticlesResponse?
getter/setter pair
suggestFaqAnswersResponse GoogleCloudDialogflowV2SuggestFaqAnswersResponse?
getter/setter pair
suggestKnowledgeAssistResponse GoogleCloudDialogflowV2SuggestKnowledgeAssistResponse?
getter/setter pair
suggestSmartRepliesResponse GoogleCloudDialogflowV2SuggestSmartRepliesResponse?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited