GoogleCloudDialogflowV2SummarizationEvaluationMetricsConversationDetail class

Properties

hashCode int
The hash code for this object.
no setterinherited
messageEntries List<GoogleCloudDialogflowV2MessageEntry>?
getter/setter pair
metricDetails List<GoogleCloudDialogflowV2SummarizationEvaluationMetricsConversationDetailMetricDetail>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionTokens List<GoogleCloudDialogflowV2SummarizationEvaluationMetricsSectionToken>?
getter/setter pair
summarySections List<GoogleCloudDialogflowV2SummarySuggestionSummarySection>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited