GoogleCloudDialogflowV2SummarizationEvaluationMetricsEvaluationResult class
Constructors
- GoogleCloudDialogflowV2SummarizationEvaluationMetricsEvaluationResult({GoogleCloudDialogflowV2SummarizationEvaluationMetricsAccuracyDecomposition? accuracyDecomposition, GoogleCloudDialogflowV2SummarizationEvaluationMetricsAdherenceRubric? adherenceRubric, GoogleCloudDialogflowV2SummarizationEvaluationMetricsCompletenessRubric? completenessRubric})
- GoogleCloudDialogflowV2SummarizationEvaluationMetricsEvaluationResult.fromJson(Map json_)
Properties
- accuracyDecomposition ↔ GoogleCloudDialogflowV2SummarizationEvaluationMetricsAccuracyDecomposition?
-
getter/setter pair
- adherenceRubric ↔ GoogleCloudDialogflowV2SummarizationEvaluationMetricsAdherenceRubric?
-
getter/setter pair
- completenessRubric ↔ GoogleCloudDialogflowV2SummarizationEvaluationMetricsCompletenessRubric?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited