GoogleCloudDialogflowV2SummarizationEvaluationMetricsSummarizationEvaluationResult class

Properties

decompositions List<GoogleCloudDialogflowV2SummarizationEvaluationMetricsDecomposition>?
getter/setter pair
evaluationResults List<GoogleCloudDialogflowV2SummarizationEvaluationMetricsEvaluationResult>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metric String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double?
getter/setter pair
section String?
getter/setter pair
sectionSummary String?
getter/setter pair
sessionId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited