GoogleCloudDialogflowV2SynthesizeSpeechConfig class
Constructors
-
GoogleCloudDialogflowV2SynthesizeSpeechConfig({List<
String> ? effectsProfileId, double? pitch, List<GoogleCloudDialogflowV2CustomPronunciationParams> ? pronunciations, double? speakingRate, GoogleCloudDialogflowV2VoiceSelectionParams? voice, double? volumeGainDb}) - GoogleCloudDialogflowV2SynthesizeSpeechConfig.fromJson(Map json_)
Properties
-
effectsProfileId
↔ List<
String> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pitch ↔ double?
-
getter/setter pair
-
pronunciations
↔ List<
GoogleCloudDialogflowV2CustomPronunciationParams> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speakingRate ↔ double?
-
getter/setter pair
- voice ↔ GoogleCloudDialogflowV2VoiceSelectionParams?
-
getter/setter pair
- volumeGainDb ↔ double?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited