GoogleCloudDialogflowV2TextInput class

Auxiliary proto messages.

Represents the natural language text to be processed.

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The language of this conversational query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The UTF-8 encoded natural language text to be processed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited