GoogleCloudDialogflowV2ToolCallResult class

Constructors

GoogleCloudDialogflowV2ToolCallResult({String? action, String? answerRecord, String? cesApp, String? cesTool, String? cesToolset, String? content, String? createTime, GoogleCloudDialogflowV2ToolCallResultError? error, String? rawContent, String? tool})
GoogleCloudDialogflowV2ToolCallResult.fromJson(Map json_)

Properties

action String?
getter/setter pair
answerRecord String?
getter/setter pair
cesApp String?
getter/setter pair
cesTool String?
getter/setter pair
cesToolset String?
getter/setter pair
content String?
getter/setter pair
createTime String?
getter/setter pair
error GoogleCloudDialogflowV2ToolCallResultError?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rawContent String?
getter/setter pair
rawContentAsBytes List<int>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tool String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited