GoogleCloudDialogflowV2ToolConnectorToolAction class
Constructors
-
GoogleCloudDialogflowV2ToolConnectorToolAction({String? connectionActionId, GoogleCloudDialogflowV2ToolConnectorToolActionEntityOperation? entityOperation, List<
String> ? inputFields, List<String> ? outputFields}) - GoogleCloudDialogflowV2ToolConnectorToolAction.fromJson(Map json_)
Properties
- connectionActionId ↔ String?
-
getter/setter pair
- entityOperation ↔ GoogleCloudDialogflowV2ToolConnectorToolActionEntityOperation?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputFields
↔ List<
String> ? -
getter/setter pair
-
outputFields
↔ List<
String> ? -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited