GoogleCloudDialogflowV2ToolOpenApiTool class

Properties

authentication GoogleCloudDialogflowV2ToolAuthentication?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceDirectoryConfig GoogleCloudDialogflowV2ToolServiceDirectoryConfig?
getter/setter pair
textSchema String?
getter/setter pair
tlsConfig GoogleCloudDialogflowV2ToolTLSConfig?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited