GoogleCloudDialogflowV2Version class

Constructors

GoogleCloudDialogflowV2Version({String? createTime, String? description, String? name, String? status, int? versionNumber})
GoogleCloudDialogflowV2Version.fromJson(Map json_)

Properties

createTime ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Possible string values are:
getter/setter pair
versionNumber ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited