GoogleCloudDialogflowCxV3Action class
Constructors
- GoogleCloudDialogflowCxV3Action({GoogleCloudDialogflowCxV3AgentUtterance? agentUtterance, GoogleCloudDialogflowCxV3FlowInvocation? flowInvocation, GoogleCloudDialogflowCxV3FlowTransition? flowTransition, GoogleCloudDialogflowCxV3PlaybookInvocation? playbookInvocation, GoogleCloudDialogflowCxV3PlaybookTransition? playbookTransition, GoogleCloudDialogflowCxV3ToolUse? toolUse, GoogleCloudDialogflowCxV3UserUtterance? userUtterance})
- GoogleCloudDialogflowCxV3Action.fromJson(Map json_)
Properties
- agentUtterance ↔ GoogleCloudDialogflowCxV3AgentUtterance?
-
getter/setter pair
- flowInvocation ↔ GoogleCloudDialogflowCxV3FlowInvocation?
-
getter/setter pair
- flowTransition ↔ GoogleCloudDialogflowCxV3FlowTransition?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- playbookInvocation ↔ GoogleCloudDialogflowCxV3PlaybookInvocation?
-
getter/setter pair
- playbookTransition ↔ GoogleCloudDialogflowCxV3PlaybookTransition?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolUse ↔ GoogleCloudDialogflowCxV3ToolUse?
-
getter/setter pair
- userUtterance ↔ GoogleCloudDialogflowCxV3UserUtterance?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited