GoogleCloudDialogflowCxV3Agent class
Constructors
-
GoogleCloudDialogflowCxV3Agent({GoogleCloudDialogflowCxV3AdvancedSettings? advancedSettings, GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings? answerFeedbackSettings, String? avatarUri, GoogleCloudDialogflowCxV3AgentClientCertificateSettings? clientCertificateSettings, String? defaultLanguageCode, String? description, String? displayName, bool? enableMultiLanguageTraining, bool? enableSpellCorrection, bool? enableStackdriverLogging, GoogleCloudDialogflowCxV3AgentGenAppBuilderSettings? genAppBuilderSettings, GoogleCloudDialogflowCxV3AgentGitIntegrationSettings? gitIntegrationSettings, bool? locked, String? name, GoogleCloudDialogflowCxV3AgentPersonalizationSettings? personalizationSettings, bool? satisfiesPzi, bool? satisfiesPzs, String? securitySettings, GoogleCloudDialogflowCxV3SpeechToTextSettings? speechToTextSettings, String? startFlow, String? startPlaybook, List<
String> ? supportedLanguageCodes, GoogleCloudDialogflowCxV3TextToSpeechSettings? textToSpeechSettings, String? timeZone}) - GoogleCloudDialogflowCxV3Agent.fromJson(Map json_)
Properties
- advancedSettings ↔ GoogleCloudDialogflowCxV3AdvancedSettings?
-
getter/setter pair
- answerFeedbackSettings ↔ GoogleCloudDialogflowCxV3AgentAnswerFeedbackSettings?
-
getter/setter pair
- avatarUri ↔ String?
-
getter/setter pair
- clientCertificateSettings ↔ GoogleCloudDialogflowCxV3AgentClientCertificateSettings?
-
getter/setter pair
- defaultLanguageCode ↔ String?
-
getter/setter pair
- description ↔ String?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- enableMultiLanguageTraining ↔ bool?
-
getter/setter pair
- enableSpellCorrection ↔ bool?
-
getter/setter pair
- enableStackdriverLogging ↔ bool?
-
getter/setter pair
- genAppBuilderSettings ↔ GoogleCloudDialogflowCxV3AgentGenAppBuilderSettings?
-
getter/setter pair
- gitIntegrationSettings ↔ GoogleCloudDialogflowCxV3AgentGitIntegrationSettings?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- locked ↔ bool?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- personalizationSettings ↔ GoogleCloudDialogflowCxV3AgentPersonalizationSettings?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- satisfiesPzi ↔ bool?
-
getter/setter pair
- satisfiesPzs ↔ bool?
-
getter/setter pair
- securitySettings ↔ String?
-
getter/setter pair
- speechToTextSettings ↔ GoogleCloudDialogflowCxV3SpeechToTextSettings?
-
getter/setter pair
- startFlow ↔ String?
-
getter/setter pair
- startPlaybook ↔ String?
-
getter/setter pair
-
supportedLanguageCodes
↔ List<
String> ? -
getter/setter pair
- textToSpeechSettings ↔ GoogleCloudDialogflowCxV3TextToSpeechSettings?
-
getter/setter pair
- timeZone ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited