GoogleCloudDialogflowCxV3BargeInConfig class
Constructors
- GoogleCloudDialogflowCxV3BargeInConfig({String? noBargeInDuration, String? totalDuration})
- GoogleCloudDialogflowCxV3BargeInConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- noBargeInDuration ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalDuration ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited