GoogleCloudDialogflowCxV3DataStoreConnection class

A data store connection.

It represents a data store in Discovery Engine and the type of the contents it contains.

Constructors

GoogleCloudDialogflowCxV3DataStoreConnection({String? dataStore, String? dataStoreType, String? documentProcessingMode})
GoogleCloudDialogflowCxV3DataStoreConnection.fromJson(Map json_)

Properties

dataStore ↔ String?
The full name of the referenced data store.
getter/setter pair
dataStoreType ↔ String?
The type of the connected data store. Possible string values are:
getter/setter pair
documentProcessingMode ↔ String?
The document processing mode for the data store connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited