GoogleCloudDialogflowCxV3DataStoreConnectionSignals class

Data store connection feature output signals.

Might be only partially field if processing stop before the final answer. Reasons for this can be, but are not limited to: empty UCS search results, positive RAI check outcome, grounding failure, ...

Properties

answer ↔ String?
The final compiled answer.
getter/setter pair
answerGenerationModelCallSignals ↔ GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerGenerationModelCallSignals?
Diagnostic info related to the answer generation model call.
getter/setter pair
answerParts ↔ List<GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerPart>?
Answer parts with relevant citations.
getter/setter pair
citedSnippets ↔ List<GoogleCloudDialogflowCxV3DataStoreConnectionSignalsCitedSnippet>?
Snippets cited by the answer generation model from the most to least relevant.
getter/setter pair
groundingSignals ↔ GoogleCloudDialogflowCxV3DataStoreConnectionSignalsGroundingSignals?
Grounding signals.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rewriterModelCallSignals ↔ GoogleCloudDialogflowCxV3DataStoreConnectionSignalsAnswerGenerationModelCallSignals?
Diagnostic info related to the rewriter model call.
getter/setter pair
rewrittenQuery ↔ String?
Rewritten string query used for search.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safetySignals ↔ GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSafetySignals?
Safety check result.
getter/setter pair
searchSnippets ↔ List<GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSearchSnippet>?
Search snippets included in the answer generation prompt.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited