GoogleCloudDialogflowCxV3DataStoreConnectionSignalsCitedSnippet class

Snippet cited by the answer generation model.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchSnippet ↔ GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSearchSnippet?
Details of the snippet.
getter/setter pair
snippetIndex ↔ int?
Index of the snippet in search_snippets field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited