GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSafetySignals class

Properties

bannedPhraseMatch ↔ String?
Possible string values are:
getter/setter pair
decision ↔ String?
Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchedBannedPhrase ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited