GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSearchSnippet class

Search snippet details.

Properties

documentTitle ↔ String?
Title of the enclosing document.
getter/setter pair
documentUri ↔ String?
Uri for the document.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, Object?>?
Metadata associated with the document.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
Text included in the prompt.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited