GoogleCloudDialogflowCxV3EntityType class

Constructors

GoogleCloudDialogflowCxV3EntityType({String? autoExpansionMode, String? displayName, bool? enableFuzzyExtraction, List<GoogleCloudDialogflowCxV3EntityTypeEntity>? entities, List<GoogleCloudDialogflowCxV3EntityTypeExcludedPhrase>? excludedPhrases, String? kind, String? name, bool? redact})
GoogleCloudDialogflowCxV3EntityType.fromJson(Map json_)

Properties

autoExpansionMode ↔ String?
Possible string values are:
getter/setter pair
displayName ↔ String?
getter/setter pair
enableFuzzyExtraction ↔ bool?
getter/setter pair
entities ↔ List<GoogleCloudDialogflowCxV3EntityTypeEntity>?
getter/setter pair
excludedPhrases ↔ List<GoogleCloudDialogflowCxV3EntityTypeExcludedPhrase>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Possible string values are:
getter/setter pair
name ↔ String?
getter/setter pair
redact ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited