GoogleCloudDialogflowCxV3Example class

Constructors

GoogleCloudDialogflowCxV3Example({List<GoogleCloudDialogflowCxV3Action>? actions, String? conversationState, String? createTime, String? description, String? displayName, String? languageCode, String? name, GoogleCloudDialogflowCxV3PlaybookInput? playbookInput, GoogleCloudDialogflowCxV3PlaybookOutput? playbookOutput, String? tokenCount, String? updateTime})
GoogleCloudDialogflowCxV3Example.fromJson(Map json_)

Properties

actions ↔ List<GoogleCloudDialogflowCxV3Action>?
getter/setter pair
conversationState ↔ String?
Possible string values are:
getter/setter pair
createTime ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
displayName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
playbookInput ↔ GoogleCloudDialogflowCxV3PlaybookInput?
getter/setter pair
playbookOutput ↔ GoogleCloudDialogflowCxV3PlaybookOutput?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenCount ↔ String?
getter/setter pair
updateTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited