GoogleCloudDialogflowCxV3ExperimentResultMetric class
Constructors
- GoogleCloudDialogflowCxV3ExperimentResultMetric({GoogleCloudDialogflowCxV3ExperimentResultConfidenceInterval? confidenceInterval, double? count, String? countType, double? ratio, String? type})
- GoogleCloudDialogflowCxV3ExperimentResultMetric.fromJson(Map json_)
Properties
- confidenceInterval ↔ GoogleCloudDialogflowCxV3ExperimentResultConfidenceInterval?
-
getter/setter pair
- count ↔ double?
-
getter/setter pair
- countType ↔ String?
-
Possible string values are:
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ratio ↔ double?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited