GoogleCloudDialogflowCxV3Fulfillment class
Constructors
-
GoogleCloudDialogflowCxV3Fulfillment({GoogleCloudDialogflowCxV3AdvancedSettings? advancedSettings, List<
GoogleCloudDialogflowCxV3FulfillmentConditionalCases> ? conditionalCases, bool? enableGenerativeFallback, List<GoogleCloudDialogflowCxV3FulfillmentGeneratorSettings> ? generators, List<GoogleCloudDialogflowCxV3ResponseMessage> ? messages, bool? returnPartialResponses, List<GoogleCloudDialogflowCxV3FulfillmentSetParameterAction> ? setParameterActions, String? tag, String? webhook}) - GoogleCloudDialogflowCxV3Fulfillment.fromJson(Map json_)
Properties
- advancedSettings ↔ GoogleCloudDialogflowCxV3AdvancedSettings?
-
getter/setter pair
-
conditionalCases
↔ List<
GoogleCloudDialogflowCxV3FulfillmentConditionalCases> ? -
getter/setter pair
- enableGenerativeFallback ↔ bool?
-
getter/setter pair
-
generators
↔ List<
GoogleCloudDialogflowCxV3FulfillmentGeneratorSettings> ? -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
↔ List<
GoogleCloudDialogflowCxV3ResponseMessage> ? -
getter/setter pair
- returnPartialResponses ↔ bool?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
setParameterActions
↔ List<
GoogleCloudDialogflowCxV3FulfillmentSetParameterAction> ? -
getter/setter pair
- tag ↔ String?
-
getter/setter pair
- webhook ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited