GoogleCloudDialogflowCxV3ImportEntityTypesRequest class

The request message for EntityTypes.ImportEntityTypes.

Properties

entityTypesContent ↔ GoogleCloudDialogflowCxV3InlineSource?
Uncompressed byte content of entity types.
getter/setter pair
entityTypesUri ↔ String?
The Google Cloud Storage URI to import entity types from.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mergeOption ↔ String?
Merge option for importing entity types.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetEntityType ↔ String?
The target entity type to import into.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited