GoogleCloudDialogflowCxV3QueryParameters class

Constructors

GoogleCloudDialogflowCxV3QueryParameters({bool? analyzeQueryTextSentiment, String? channel, String? currentPage, String? currentPlaybook, bool? disableWebhook, Map<String, Object?>? endUserMetadata, List<String>? flowVersions, GoogleTypeLatLng? geoLocation, GoogleCloudDialogflowCxV3LlmModelSettings? llmModelSettings, String? parameterScope, Map<String, Object?>? parameters, Map<String, Object?>? payload, bool? populateDataStoreConnectionSignals, GoogleCloudDialogflowCxV3SearchConfig? searchConfig, List<GoogleCloudDialogflowCxV3SessionEntityType>? sessionEntityTypes, String? sessionTtl, String? timeZone, Map<String, String>? webhookHeaders})
GoogleCloudDialogflowCxV3QueryParameters.fromJson(Map json_)

Properties

analyzeQueryTextSentiment ↔ bool?
getter/setter pair
channel ↔ String?
getter/setter pair
currentPage ↔ String?
getter/setter pair
currentPlaybook ↔ String?
getter/setter pair
disableWebhook ↔ bool?
getter/setter pair
endUserMetadata ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
flowVersions ↔ List<String>?
getter/setter pair
geoLocation ↔ GoogleTypeLatLng?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
llmModelSettings ↔ GoogleCloudDialogflowCxV3LlmModelSettings?
getter/setter pair
parameters ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
parameterScope ↔ String?
getter/setter pair
payload ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
populateDataStoreConnectionSignals ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchConfig ↔ GoogleCloudDialogflowCxV3SearchConfig?
getter/setter pair
sessionEntityTypes ↔ List<GoogleCloudDialogflowCxV3SessionEntityType>?
getter/setter pair
sessionTtl ↔ String?
getter/setter pair
timeZone ↔ String?
getter/setter pair
webhookHeaders ↔ Map<String, String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited