GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText class

A text or ssml response that is preferentially used for TTS output audio synthesis, as described in the comment on the ResponseMessage message.

Properties

allowPlaybackInterruption ↔ bool?
Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ssml ↔ String?
The SSML text to be synthesized.
getter/setter pair
text ↔ String?
The raw text to be synthesized.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited