GoogleCloudDialogflowCxV3SecuritySettings class

Constructors

GoogleCloudDialogflowCxV3SecuritySettings({GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings? audioExportSettings, String? deidentifyTemplate, String? displayName, GoogleCloudDialogflowCxV3SecuritySettingsInsightsExportSettings? insightsExportSettings, String? inspectTemplate, String? name, List<String>? purgeDataTypes, String? redactionScope, String? redactionStrategy, String? retentionStrategy, int? retentionWindowDays})
GoogleCloudDialogflowCxV3SecuritySettings.fromJson(Map json_)

Properties

audioExportSettings GoogleCloudDialogflowCxV3SecuritySettingsAudioExportSettings?
getter/setter pair
deidentifyTemplate String?
getter/setter pair
displayName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
insightsExportSettings GoogleCloudDialogflowCxV3SecuritySettingsInsightsExportSettings?
getter/setter pair
inspectTemplate String?
getter/setter pair
name String?
getter/setter pair
purgeDataTypes List<String>?
getter/setter pair
redactionScope String?
Possible string values are:
getter/setter pair
redactionStrategy String?
Possible string values are:
getter/setter pair
retentionStrategy String?
Possible string values are:
getter/setter pair
retentionWindowDays int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited