GoogleCloudDialogflowCxV3ToolAuthenticationServiceAgentAuthConfig class

Config for auth using Diglogflow service agent.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAgentAuth ↔ String?
Indicate the auth token type generated from the Diglogflow service agent.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited