GoogleCloudDialogflowCxV3ToolCallResult class
Constructors
-
GoogleCloudDialogflowCxV3ToolCallResult({String? action, GoogleCloudDialogflowCxV3ToolCallResultError? error, Map<
String, Object?> ? outputParameters, String? tool}) - GoogleCloudDialogflowCxV3ToolCallResult.fromJson(Map json_)
Properties
- action ↔ String?
-
getter/setter pair
- error ↔ GoogleCloudDialogflowCxV3ToolCallResultError?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
outputParameters
↔ Map<
String, Object?> ? -
The values for Object must be JSON objects. It can consist of
num,String,boolandnullas well asMapandListvalues.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tool ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited