GoogleCloudDialogflowCxV3TraceBlock class

Constructors

GoogleCloudDialogflowCxV3TraceBlock({List<GoogleCloudDialogflowCxV3Action>? actions, String? completeTime, String? endState, GoogleCloudDialogflowCxV3FlowTraceMetadata? flowTraceMetadata, Map<String, Object?>? inputParameters, Map<String, Object?>? outputParameters, GoogleCloudDialogflowCxV3PlaybookTraceMetadata? playbookTraceMetadata, GoogleCloudDialogflowCxV3SpeechProcessingMetadata? speechProcessingMetadata, String? startTime})
GoogleCloudDialogflowCxV3TraceBlock.fromJson(Map json_)

Properties

actions ↔ List<GoogleCloudDialogflowCxV3Action>?
getter/setter pair
completeTime ↔ String?
getter/setter pair
endState ↔ String?
Possible string values are:
getter/setter pair
flowTraceMetadata ↔ GoogleCloudDialogflowCxV3FlowTransition?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputParameters ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
outputParameters ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
playbookTraceMetadata ↔ GoogleCloudDialogflowCxV3PlaybookTransition?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speechProcessingMetadata ↔ GoogleCloudDialogflowCxV3SpeechProcessingMetadata?
getter/setter pair
startTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited