GoogleCloudDialogflowCxV3TransitionRoute class

Constructors

GoogleCloudDialogflowCxV3TransitionRoute({String? condition, String? description, String? intent, String? name, String? targetFlow, String? targetPage, GoogleCloudDialogflowCxV3Fulfillment? triggerFulfillment})
GoogleCloudDialogflowCxV3TransitionRoute.fromJson(Map json_)

Properties

condition String?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
intent String?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetFlow String?
getter/setter pair
targetPage String?
getter/setter pair
triggerFulfillment GoogleCloudDialogflowCxV3Fulfillment?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited