GoogleCloudDialogflowCxV3WebhookGenericWebService class

Constructors

GoogleCloudDialogflowCxV3WebhookGenericWebService({List<String>? allowedCaCerts, String? httpMethod, GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig? oauthConfig, Map<String, String>? parameterMapping, String? password, String? requestBody, Map<String, String>? requestHeaders, String? secretVersionForUsernamePassword, Map<String, GoogleCloudDialogflowCxV3WebhookGenericWebServiceSecretVersionHeaderValue>? secretVersionsForRequestHeaders, GoogleCloudDialogflowCxV3WebhookGenericWebServiceServiceAccountAuthConfig? serviceAccountAuthConfig, String? serviceAgentAuth, String? uri, String? username, String? webhookType})
GoogleCloudDialogflowCxV3WebhookGenericWebService.fromJson(Map json_)

Properties

allowedCaCerts ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpMethod ↔ String?
Possible string values are:
getter/setter pair
oauthConfig ↔ GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig?
getter/setter pair
parameterMapping ↔ Map<String, String>?
getter/setter pair
password ↔ String?
getter/setter pair
requestBody ↔ String?
getter/setter pair
requestHeaders ↔ Map<String, String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretVersionForUsernamePassword ↔ String?
getter/setter pair
secretVersionsForRequestHeaders ↔ Map<String, GoogleCloudDialogflowCxV3WebhookGenericWebServiceSecretVersionHeaderValue>?
getter/setter pair
serviceAccountAuthConfig ↔ GoogleCloudDialogflowCxV3ToolAuthenticationServiceAccountAuthConfig?
getter/setter pair
serviceAgentAuth ↔ String?
Possible string values are:
getter/setter pair
uri ↔ String?
getter/setter pair
username ↔ String?
getter/setter pair
webhookType ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited