GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig class

Constructors

GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig({String? clientId, String? clientSecret, List<String>? scopes, String? secretVersionForClientSecret, String? tokenEndpoint})
GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig.fromJson(Map json_)

Properties

clientId ↔ String?
getter/setter pair
clientSecret ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>?
getter/setter pair
secretVersionForClientSecret ↔ String?
getter/setter pair
tokenEndpoint ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited