ProjectsLocationsAgentsEnvironmentsResource class

Constructors

ProjectsLocationsAgentsEnvironmentsResource(ApiRequester client)

Properties

continuousTestResults ProjectsLocationsAgentsEnvironmentsContinuousTestResultsResource
no setter
deployments ProjectsLocationsAgentsEnvironmentsDeploymentsResource
no setter
experiments ProjectsLocationsAgentsEnvironmentsExperimentsResource
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions ProjectsLocationsAgentsEnvironmentsSessionsResource
no setter

Methods

create(GoogleCloudDialogflowCxV3Environment request, String parent, {String? $fields}) Future<GoogleLongrunningOperation>
request - The metadata request object.
delete(String name, {String? $fields}) Future<GoogleProtobufEmpty>
Request parameters:
deployFlow(GoogleCloudDialogflowCxV3DeployFlowRequest request, String environment, {String? $fields}) Future<GoogleLongrunningOperation>
request - The metadata request object.
get(String name, {String? $fields}) Future<GoogleCloudDialogflowCxV3Environment>
Request parameters:
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<GoogleCloudDialogflowCxV3ListEnvironmentsResponse>
Request parameters:
lookupEnvironmentHistory(String name, {int? pageSize, String? pageToken, String? $fields}) Future<GoogleCloudDialogflowCxV3LookupEnvironmentHistoryResponse>
Request parameters:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleCloudDialogflowCxV3Environment request, String name, {String? updateMask, String? $fields}) Future<GoogleLongrunningOperation>
request - The metadata request object.
runContinuousTest(GoogleCloudDialogflowCxV3RunContinuousTestRequest request, String environment, {String? $fields}) Future<GoogleLongrunningOperation>
request - The metadata request object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited