ProjectsLocationsAgentsEnvironmentsSessionsResource class
Constructors
- ProjectsLocationsAgentsEnvironmentsSessionsResource(ApiRequester client)
Properties
- entityTypes → ProjectsLocationsAgentsEnvironmentsSessionsEntityTypesResource
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
detectIntent(
GoogleCloudDialogflowCxV3DetectIntentRequest request, String session, {String? $fields}) → Future< GoogleCloudDialogflowCxV3DetectIntentResponse> -
request- The metadata request object. -
fulfillIntent(
GoogleCloudDialogflowCxV3FulfillIntentRequest request, String session, {String? $fields}) → Future< GoogleCloudDialogflowCxV3FulfillIntentResponse> -
request- The metadata request object. -
matchIntent(
GoogleCloudDialogflowCxV3MatchIntentRequest request, String session, {String? $fields}) → Future< GoogleCloudDialogflowCxV3MatchIntentResponse> -
request- The metadata request object. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
serverStreamingDetectIntent(
GoogleCloudDialogflowCxV3DetectIntentRequest request, String session, {String? $fields}) → Future< GoogleCloudDialogflowCxV3DetectIntentResponse> -
request- The metadata request object. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited