ProjectsLocationsAgentsPlaybooksResource class

Constructors

ProjectsLocationsAgentsPlaybooksResource(ApiRequester client)

Properties

examples ProjectsLocationsAgentsPlaybooksExamplesResource
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versions ProjectsLocationsAgentsPlaybooksVersionsResource
no setter

Methods

create(GoogleCloudDialogflowCxV3Playbook request, String parent, {String? $fields}) Future<GoogleCloudDialogflowCxV3Playbook>
request - The metadata request object.
delete(String name, {String? $fields}) Future<GoogleProtobufEmpty>
Request parameters:
export(GoogleCloudDialogflowCxV3ExportPlaybookRequest request, String name, {String? $fields}) Future<GoogleLongrunningOperation>
request - The metadata request object.
get(String name, {String? $fields}) Future<GoogleCloudDialogflowCxV3Playbook>
Request parameters:
import(GoogleCloudDialogflowCxV3ImportPlaybookRequest request, String parent, {String? $fields}) Future<GoogleLongrunningOperation>
request - The metadata request object.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<GoogleCloudDialogflowCxV3ListPlaybooksResponse>
Request parameters:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleCloudDialogflowCxV3Playbook request, String name, {String? updateMask, String? $fields}) Future<GoogleCloudDialogflowCxV3Playbook>
request - The metadata request object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited