BulkCheckRequest class

Message used to check for the existence of multiple digital asset links within a single RPC.

Constructors

BulkCheckRequest({String? defaultRelation, Asset? defaultSource, Asset? defaultTarget, bool? returnRelationExtensions, List<StatementTemplate>? statements})
BulkCheckRequest.fromJson(Map json_)

Properties

defaultRelation ↔ String?
If specified, will be used in any given template statement that doesn’t specify a relation.
getter/setter pair
defaultSource ↔ Asset?
If specified, will be used in any given template statement that doesn’t specify a source.
getter/setter pair
defaultTarget ↔ Asset?
If specified, will be used in any given template statement that doesn’t specify a target.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
returnRelationExtensions ↔ bool?
Same configuration as in CheckRequest; all statement checks will use the same configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statements ↔ List<StatementTemplate>?
List of statements to check.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited