CheckResponse class

Response message for the CheckAssetLinks call.

Constructors

CheckResponse({String? debugString, List<String>? errorCode, bool? linked, String? maxAge, List<Map<String, Object?>>? relationExtensions})
CheckResponse.fromJson(Map json_)

Properties

debugString ↔ String?
Human-readable message containing information intended to help end users understand, reproduce and debug the result.
getter/setter pair
errorCode ↔ List<String>?
Error codes that describe the result of the Check operation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
linked ↔ bool?
Set to true if the assets specified in the request are linked by the relation specified in the request.
getter/setter pair
maxAge ↔ String?
From serving time, how much longer the response should be considered valid barring further updates.
getter/setter pair
relationExtensions ↔ List<Map<String, Object?>>?
Statements may specify relation level extensions/payloads to express more details when declaring permissions to grant from the source asset to the target asset.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited