Statement class

Describes a reliable statement that has been made about the relationship between a source asset and a target asset.

Statements are always made by the source asset, either directly or by delegating to a statement list that is stored elsewhere. For more detailed definitions of statements and assets, please refer to our [API documentation landing page](/digital-asset-links/v1/getting-started).

Constructors

Statement({String? relation, Map<String, Object?>? relationExtensions, Asset? source, Asset? target})
Statement.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
relation ↔ String?
The relation identifies the use of the statement as intended by the source asset's owner (that is, the person or entity who issued the statement).
getter/setter pair
relationExtensions ↔ Map<String, Object?>?
Statements may specify relation level extensions/payloads to express more details when declaring permissions to grant from the source asset to the target asset.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Asset?
Every statement has a source asset.
getter/setter pair
target ↔ Asset?
Every statement has a target asset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited