JsonSchemaVariantMap class

Constructors

JsonSchemaVariantMap({String? P_ref, String? typeValue})
JsonSchemaVariantMap.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
P_ref ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeValue ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited