RestDescription class

Constructors

RestDescription({RestDescriptionAuth? auth, String? basePath, String? baseUrl, String? batchPath, String? canonicalName, String? description, String? discoveryVersion, String? documentationLink, List<RestDescriptionEndpoints>? endpoints, String? etag, bool? exponentialBackoffDefault, List<String>? features, RestDescriptionIcons? icons, String? id, String? kind, List<String>? labels, Map<String, RestMethod>? methods, String? name, String? ownerDomain, String? ownerName, String? packagePath, Map<String, JsonSchema>? parameters, String? protocol, Map<String, RestResource>? resources, String? revision, String? rootUrl, Map<String, JsonSchema>? schemas, String? servicePath, String? title, String? version, bool? versionModule})
RestDescription.fromJson(Map json_)

Properties

auth ↔ RestDescriptionAuth?
Authentication information.
getter/setter pair
basePath ↔ String?
The base path for REST requests.
getter/setter pair
baseUrl ↔ String?
The base URL for REST requests.
getter/setter pair
batchPath ↔ String?
The path for REST batch requests.
getter/setter pair
canonicalName ↔ String?
Indicates how the API name should be capitalized and split into various parts.
getter/setter pair
description ↔ String?
The description of this API.
getter/setter pair
discoveryVersion ↔ String?
Indicate the version of the Discovery API used to generate this doc.
getter/setter pair
A link to human readable documentation for the API.
getter/setter pair
endpoints ↔ List<RestDescriptionEndpoints>?
A list of location-based endpoint objects for this API.
getter/setter pair
etag ↔ String?
The ETag for this response.
getter/setter pair
exponentialBackoffDefault ↔ bool?
Enable exponential backoff for suitable methods in the generated clients.
getter/setter pair
features ↔ List<String>?
A list of supported features for this API.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
icons ↔ RestDescriptionIcons?
Links to 16x16 and 32x32 icons representing the API.
getter/setter pair
id ↔ String?
The ID of this API.
getter/setter pair
kind ↔ String?
The kind for this response.
getter/setter pair
labels ↔ List<String>?
Labels for the status of this API, such as labs or deprecated.
getter/setter pair
methods ↔ Map<String, RestMethod>?
API-level methods for this API.
getter/setter pair
name ↔ String?
The name of this API.
getter/setter pair
ownerDomain ↔ String?
The domain of the owner of this API.
getter/setter pair
ownerName ↔ String?
The name of the owner of this API.
getter/setter pair
packagePath ↔ String?
The package of the owner of this API.
getter/setter pair
parameters ↔ Map<String, JsonSchema>?
Common parameters that apply across all apis.
getter/setter pair
protocol ↔ String?
The protocol described by this document.
getter/setter pair
resources ↔ Map<String, RestResource>?
The resources in this API.
getter/setter pair
revision ↔ String?
The version of this API.
getter/setter pair
rootUrl ↔ String?
The root URL under which all API services live.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemas ↔ Map<String, JsonSchema>?
The schemas for this API.
getter/setter pair
servicePath ↔ String?
The base path for all REST requests.
getter/setter pair
title ↔ String?
The title of this API.
getter/setter pair
version ↔ String?
The version of this API.
getter/setter pair
versionModule ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited