RestDescriptionEndpoints class

A single endpoint object

Constructors

RestDescriptionEndpoints({bool? deprecated, String? description, String? endpointUrl, String? location})
RestDescriptionEndpoints.fromJson(Map json_)

Properties

deprecated ↔ bool?
Whether this endpoint is deprecated
getter/setter pair
description ↔ String?
A string describing the host designated by the URL
getter/setter pair
endpointUrl ↔ String?
The URL of the endpoint target host
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
The location of the endpoint
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited