RestMethodMediaUploadProtocols class

Supported upload protocols.

Properties

hashCode → int
The hash code for this object.
no setterinherited
resumable ↔ RestMethodMediaUploadProtocolsResumable?
Supports the Resumable Media Upload protocol.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
simple ↔ RestMethodMediaUploadProtocolsSimple?
Supports uploading as a single HTTP request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited