RestMethodMediaUploadProtocolsSimple class

Supports uploading as a single HTTP request.

Properties

hashCode → int
The hash code for this object.
no setterinherited
multipart ↔ bool?
True if this endpoint supports upload multipart media.
getter/setter pair
path ↔ String?
The URI path to be used for upload.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited