RestMethodRequest class

The schema for the request.

Constructors

RestMethodRequest({String? P_ref, String? parameterName})
RestMethodRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
P_ref ↔ String?
Schema ID for the request schema.
getter/setter pair
parameterName ↔ String?
parameter name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited