Adloox class

Details of Scope3 (previously known as Adloox) brand safety settings.

Constructors

Adloox({List<String>? excludedAdlooxCategories})
Adloox.fromJson(Map json_)

Properties

excludedAdlooxCategories ↔ List<String>?
Scope3 categories to exclude.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited