AssetAssociation class

Asset association for the creative.

Constructors

AssetAssociation({Asset? asset, String? role})
AssetAssociation.fromJson(Map json_)

Properties

asset ↔ Asset?
The associated asset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
role ↔ String?
The role of this asset for the creative.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited