AudioAd class

Details for an audio ad.

Constructors

AudioAd({String? displayUrl, String? finalUrl, String? trackingUrl, YoutubeVideoDetails? video})
AudioAd.fromJson(Map json_)

Properties

displayUrl ↔ String?
The webpage address that appears with the ad.
getter/setter pair
finalUrl ↔ String?
The URL address of the webpage that people reach after they click the ad.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackingUrl ↔ String?
The URL address loaded in the background for tracking purposes.
getter/setter pair
video ↔ YoutubeVideoDetails?
The YouTube video of the ad.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited