BudgetSummary class

Summarized information of an individual campaign budget.

Constructors

BudgetSummary({String? externalBudgetId, String? preTaxAmountMicros, PrismaCpeCode? prismaCpeCode, String? taxAmountMicros, String? totalAmountMicros})
BudgetSummary.fromJson(Map json_)

Properties

externalBudgetId ↔ String?
Corresponds to the external_budget_id of a campaign budget.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
preTaxAmountMicros ↔ String?
The sum of charges made under this budget before taxes, in micros of the invoice's currency.
getter/setter pair
prismaCpeCode ↔ PrismaCpeCode?
Relevant client, product, and estimate codes from the Mediaocean Prisma tool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taxAmountMicros ↔ String?
The amount of tax applied to charges under this budget, in micros of the invoice's currency.
getter/setter pair
totalAmountMicros ↔ String?
The total sum of charges made under this budget, including tax, in micros of the invoice's currency.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited