BulkEditAssignedInventorySourcesRequest class

Request message for AssignedInventorySourceService.BulkEdit.

Constructors

BulkEditAssignedInventorySourcesRequest({String? advertiserId, List<AssignedInventorySource>? createdAssignedInventorySources, List<String>? deletedAssignedInventorySources, String? partnerId})
BulkEditAssignedInventorySourcesRequest.fromJson(Map json_)

Properties

advertiserId ↔ String?
The ID of the advertiser that owns the parent inventory source group.
getter/setter pair
createdAssignedInventorySources ↔ List<AssignedInventorySource>?
The assigned inventory sources to create in bulk, specified as a list of AssignedInventorySources.
getter/setter pair
deletedAssignedInventorySources ↔ List<String>?
The IDs of the assigned inventory sources to delete in bulk, specified as a list of assigned_inventory_source_ids.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partnerId ↔ String?
The ID of the partner that owns the inventory source group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited