BulkEditAssignedLocationsRequest class

Request message for AssignedLocationService.BulkEditAssignedLocations.

Constructors

BulkEditAssignedLocationsRequest({List<AssignedLocation>? createdAssignedLocations, List<String>? deletedAssignedLocations})
BulkEditAssignedLocationsRequest.fromJson(Map json_)

Properties

createdAssignedLocations ↔ List<AssignedLocation>?
The assigned locations to create in bulk, specified as a list of AssignedLocation resources.
getter/setter pair
deletedAssignedLocations ↔ List<String>?
The IDs of the assigned locations to delete in bulk, specified as a list of assignedLocationId values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited