BulkEditAssignedTargetingOptionsRequest class

Request message for BulkEditLineItemsAssignedTargetingOptions.

Properties

createRequests ↔ List<CreateAssignedTargetingOptionsRequest>?
The assigned targeting options to create in batch, specified as a list of CreateAssignedTargetingOptionsRequest.
getter/setter pair
deleteRequests ↔ List<DeleteAssignedTargetingOptionsRequest>?
The assigned targeting options to delete in batch, specified as a list of DeleteAssignedTargetingOptionsRequest.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineItemIds ↔ List<String>?
The ID of the line items whose targeting is being updated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited