BulkEditAssignedTargetingOptionsResponse class

Constructors

BulkEditAssignedTargetingOptionsResponse({List<Status>? errors, List<String>? failedLineItemIds, List<String>? updatedLineItemIds})
BulkEditAssignedTargetingOptionsResponse.fromJson(Map json_)

Properties

errors ↔ List<Status>?
The error information for each line item that failed to update.
getter/setter pair
failedLineItemIds ↔ List<String>?
The IDs of the line items which failed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedLineItemIds ↔ List<String>?
The IDs of the line items which successfully updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited