BulkEditAssignedUserRolesRequest class

Request message for BulkEditAssignedUserRoles.

Constructors

BulkEditAssignedUserRolesRequest({List<AssignedUserRole>? createdAssignedUserRoles, List<String>? deletedAssignedUserRoles})
BulkEditAssignedUserRolesRequest.fromJson(Map json_)

Properties

createdAssignedUserRoles ↔ List<AssignedUserRole>?
The assigned user roles to create in batch, specified as a list of AssignedUserRoles.
getter/setter pair
deletedAssignedUserRoles ↔ List<String>?
The assigned user roles to delete in batch, specified as a list of assigned_user_role_ids.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited