BulkEditNegativeKeywordsRequest class

Request message for NegativeKeywordService.BulkEditNegativeKeywords.

Constructors

BulkEditNegativeKeywordsRequest({List<NegativeKeyword>? createdNegativeKeywords, List<String>? deletedNegativeKeywords})
BulkEditNegativeKeywordsRequest.fromJson(Map json_)

Properties

createdNegativeKeywords ↔ List<NegativeKeyword>?
The negative keywords to create in batch, specified as a list of NegativeKeywords.
getter/setter pair
deletedNegativeKeywords ↔ List<String>?
The negative keywords to delete in batch, specified as a list of keyword_values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited