BulkEditSitesRequest class

Request message for SiteService.BulkEditSites.

Constructors

BulkEditSitesRequest({String? advertiserId, List<Site>? createdSites, List<String>? deletedSites, String? partnerId})
BulkEditSitesRequest.fromJson(Map json_)

Properties

advertiserId ↔ String?
The ID of the advertiser that owns the parent channel.
getter/setter pair
createdSites ↔ List<Site>?
The sites to create in batch, specified as a list of Sites.
getter/setter pair
deletedSites ↔ List<String>?
The sites to delete in batch, specified as a list of site url_or_app_ids.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partnerId ↔ String?
The ID of the partner that owns the parent channel.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited