BulkListAssignedTargetingOptionsResponse class

Properties

hashCode → int
The hash code for this object.
no setterinherited
lineItemAssignedTargetingOptions ↔ List<LineItemAssignedTargetingOption>?
The list of wrapper objects, each providing an assigned targeting option and the line item it is assigned to.
getter/setter pair
nextPageToken ↔ String?
A token identifying the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited