BulkUpdateLineItemsResponse class

Response message for LineItemService.BulkUpdateLineItems.

Constructors

BulkUpdateLineItemsResponse({List<Status>? errors, List<String>? failedLineItemIds, List<String>? skippedLineItemIds, List<String>? updatedLineItemIds})
BulkUpdateLineItemsResponse.fromJson(Map json_)

Properties

errors ↔ List<Status>?
Errors returned by line items that failed to update.
getter/setter pair
failedLineItemIds ↔ List<String>?
The IDs of line items that failed to update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skippedLineItemIds ↔ List<String>?
The IDs of line items that are skipped for updates.
getter/setter pair
updatedLineItemIds ↔ List<String>?
The IDs of successfully updated line items.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited