CampaignFlight class

Settings that track the planned spend and duration of a campaign.

Constructors

CampaignFlight({DateRange? plannedDates, String? plannedSpendAmountMicros})
CampaignFlight.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
plannedDates ↔ DateRange?
The dates that the campaign is expected to run.
getter/setter pair
plannedSpendAmountMicros ↔ String?
The amount the campaign is expected to spend for its given planned_dates.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited