CreateAssignedTargetingOptionsRequest class

A request listing which assigned targeting options of a given targeting type should be created and added.

Properties

assignedTargetingOptions ↔ List<AssignedTargetingOption>?
The assigned targeting options to create and add.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetingType ↔ String?
Identifies the type of this assigned targeting option.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited