Creative class

A single Creative.

Constructors

Creative({List<Dimensions>? additionalDimensions, String? advertiserId, String? appendedTag, List<AssetAssociation>? assets, String? cmPlacementId, CmTrackingAd? cmTrackingAd, List<String>? companionCreativeIds, List<CounterEvent>? counterEvents, String? createTime, List<String>? creativeAttributes, String? creativeId, String? creativeType, Dimensions? dimensions, String? displayName, bool? dynamic, String? entityStatus, List<ExitEvent>? exitEvents, bool? expandOnHover, String? expandingDirection, String? hostingSource, bool? html5Video, bool? iasCampaignMonitoring, String? integrationCode, String? jsTrackerUrl, List<String>? lineItemIds, String? mediaDuration, bool? mp3Audio, String? name, String? notes, ObaIcon? obaIcon, bool? oggAudio, AudioVideoOffset? progressOffset, bool? requireHtml5, bool? requireMraid, bool? requirePingForAttribution, ReviewStatusInfo? reviewStatus, AudioVideoOffset? skipOffset, bool? skippable, String? syntheticContentAttestationStatus, String? thirdPartyTag, List<ThirdPartyUrl>? thirdPartyUrls, List<TimerEvent>? timerEvents, List<String>? trackerUrls, List<Transcode>? transcodes, UniversalAdId? universalAdId, String? updateTime, String? vastTagUrl, bool? vpaid})
Creative.fromJson(Map json_)

Properties

additionalDimensions ↔ List<Dimensions>?
Additional dimensions.
getter/setter pair
advertiserId ↔ String?
The unique ID of the advertiser the creative belongs to.
getter/setter pair
appendedTag ↔ String?
Third-party HTML tracking tag to be appended to the creative tag.
getter/setter pair
assets ↔ List<AssetAssociation>?
Assets associated to this creative.
getter/setter pair
cmPlacementId ↔ String?
The unique ID of the Campaign Manager 360 placement associated with the creative.
getter/setter pair
cmTrackingAd ↔ CmTrackingAd?
The Campaign Manager 360 tracking ad associated with the creative.
getter/setter pair
companionCreativeIds ↔ List<String>?
The IDs of companion creatives for a video creative.
getter/setter pair
counterEvents ↔ List<CounterEvent>?
Counter events for a rich media creative.
getter/setter pair
createTime ↔ String?
The timestamp when the creative was created.
getter/setter pair
creativeAttributes ↔ List<String>?
A list of attributes of the creative that is generated by the system.
getter/setter pair
creativeId ↔ String?
The unique ID of the creative.
getter/setter pair
creativeType ↔ String?
The type of the creative.
getter/setter pair
dimensions ↔ Dimensions?
Primary dimensions of the creative.
getter/setter pair
displayName ↔ String?
The display name of the creative.
getter/setter pair
dynamic ↔ bool?
Indicates whether the creative is dynamic.
getter/setter pair
entityStatus ↔ String?
Controls whether or not the creative can serve.
getter/setter pair
exitEvents ↔ List<ExitEvent>?
Exit events for this creative.
getter/setter pair
expandingDirection ↔ String?
Specifies the expanding direction of the creative.
getter/setter pair
expandOnHover ↔ bool?
Indicates the creative will automatically expand on hover.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostingSource ↔ String?
Indicates where the creative is hosted.
getter/setter pair
html5Video ↔ bool?
Indicates the third-party VAST tag creative requires HTML5 Video support.
getter/setter pair
iasCampaignMonitoring ↔ bool?
Indicates whether Integral Ad Science (IAS) campaign monitoring is enabled.
getter/setter pair
integrationCode ↔ String?
ID information used to link this creative to an external system.
getter/setter pair
jsTrackerUrl ↔ String?
JavaScript measurement URL from supported third-party verification providers (ComScore, DoubleVerify, IAS, Moat).
getter/setter pair
lineItemIds ↔ List<String>?
The IDs of the line items this creative is associated with.
getter/setter pair
mediaDuration ↔ String?
Media duration of the creative.
getter/setter pair
mp3Audio ↔ bool?
Indicates the third-party audio creative supports MP3.
getter/setter pair
name ↔ String?
The resource name of the creative.
getter/setter pair
notes ↔ String?
User notes for this creative.
getter/setter pair
obaIcon ↔ ObaIcon?
Specifies the OBA icon for a video creative.
getter/setter pair
oggAudio ↔ bool?
Indicates the third-party audio creative supports OGG.
getter/setter pair
progressOffset ↔ AudioVideoOffset?
Amount of time to play the video before counting a view.
getter/setter pair
requireHtml5 ↔ bool?
Indicates that the creative relies on HTML5 to render properly.
getter/setter pair
requireMraid ↔ bool?
Indicates that the creative requires MRAID (Mobile Rich Media Ad Interface Definitions system).
getter/setter pair
requirePingForAttribution ↔ bool?
Indicates that the creative will wait for a return ping for attribution.
getter/setter pair
reviewStatus ↔ ReviewStatusInfo?
The current status of the creative review process.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipOffset ↔ AudioVideoOffset?
Amount of time to play the video before the skip button appears.
getter/setter pair
skippable ↔ bool?
Whether the user can choose to skip a video creative.
getter/setter pair
syntheticContentAttestationStatus ↔ String?
Whether to add a label to the creative as created or edited using AI when served in regions with local AI labeling regulations.
getter/setter pair
thirdPartyTag ↔ String?
The original third-party tag used for the creative.
getter/setter pair
thirdPartyUrls ↔ List<ThirdPartyUrl>?
Tracking URLs from third parties to track interactions with a video creative.
getter/setter pair
timerEvents ↔ List<TimerEvent>?
Timer custom events for a rich media creative.
getter/setter pair
trackerUrls ↔ List<String>?
Tracking URLs for analytics providers or third-party ad technology vendors.
getter/setter pair
transcodes ↔ List<Transcode>?
Audio/Video transcodes.
getter/setter pair
universalAdId ↔ UniversalAdId?
An optional creative identifier provided by a registry that is unique across all platforms.
getter/setter pair
updateTime ↔ String?
The timestamp when the creative was last updated, either by the user or system (e.g. creative review).
getter/setter pair
vastTagUrl ↔ String?
The URL of the VAST tag for a third-party VAST tag creative.
getter/setter pair
vpaid ↔ bool?
Indicates the third-party VAST tag creative requires VPAID (Digital Video Player-Ad Interface).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited