CreativeConfig class

Creative requirements configuration for the inventory source.

Constructors

CreativeConfig({String? creativeType, InventorySourceDisplayCreativeConfig? displayCreativeConfig, InventorySourceVideoCreativeConfig? videoCreativeConfig})
CreativeConfig.fromJson(Map json_)

Properties

creativeType ↔ String?
The type of creative that can be assigned to the inventory source.
getter/setter pair
displayCreativeConfig ↔ InventorySourceDisplayCreativeConfig?
The configuration for display creatives.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoCreativeConfig ↔ InventorySourceVideoCreativeConfig?
The configuration for video creatives.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited