CustomBiddingModelDetails class

The details of a custom bidding algorithm model for a single shared advertiser.

Constructors

CustomBiddingModelDetails({String? advertiserId, String? readinessState, String? suspensionState})
CustomBiddingModelDetails.fromJson(Map json_)

Properties

advertiserId ↔ String?
The unique ID of the relevant advertiser.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readinessState ↔ String?
The readiness state of custom bidding model. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suspensionState ↔ String?
The suspension state of custom bidding model.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited