geoLanguageTargetingEnabled property

bool? geoLanguageTargetingEnabled
getter/setter pair

Whether location and language targeting can be set at the line item level.

Otherwise, relevant targeting types must be assigned directly to ad groups.

Optional. Immutable.

Implementation

core.bool? geoLanguageTargetingEnabled;