linkedMerchantId property

String? linkedMerchantId
getter/setter pair

The ID of the Merchant Center account used to provide a product feed.

This Merchant Center account must already be linked to the advertiser.

Optional.

Implementation

core.String? linkedMerchantId;