thirdPartyMeasurementConfigs property
The third party measurement settings for the Demand Gen line item.
Optional.
Implementation
ThirdPartyMeasurementConfigs? thirdPartyMeasurementConfigs;
The third party measurement settings for the Demand Gen line item.
Optional.
ThirdPartyMeasurementConfigs? thirdPartyMeasurementConfigs;