DisplayVideoApi class

Display & Video 360 API allows users to automate complex Display & Video 360 workflows, such as creating insertion orders and setting targeting options for individual line items.

Constructors

DisplayVideoApi(Client client, {String rootUrl = 'https://displayvideo.googleapis.com/', String servicePath = ''})

Properties

advertisers → AdvertisersResource
no setter
combinedAudiences → CombinedAudiencesResource
no setter
customBiddingAlgorithms → CustomBiddingAlgorithmsResource
no setter
customLists → CustomListsResource
no setter
floodlightGroups → FloodlightGroupsResource
no setter
googleAudiences → GoogleAudiencesResource
no setter
guaranteedOrders → GuaranteedOrdersResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
inventorySourceGroups → InventorySourceGroupsResource
no setter
media → MediaResource
no setter
partners → PartnersResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sdfdownloadtasks → SdfdownloadtasksResource
no setter
targetingTypes → TargetingTypesResource
no setter
users → UsersResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

displayVideoMediaplanningScope → const String
Create, see, and edit Display & Video 360 Campaign entities and see billing invoices
displayVideoScope → const String
Create, see, edit, and permanently delete your Display & Video 360 entities and reports
displayVideoUserManagementScope → const String
Private Service: https://www.googleapis.com/auth/display-video-user-management
doubleclickbidmanagerScope → const String
View and manage your reports in DoubleClick Bid Manager