DoubleVerify class

Details of DoubleVerify settings.

Constructors

DoubleVerify({DoubleVerifyAppStarRating? appStarRating, List<String>? avoidedAgeRatings, DoubleVerifyBrandSafetyCategories? brandSafetyCategories, String? customSegmentId, DoubleVerifyDisplayViewability? displayViewability, DoubleVerifyFraudInvalidTraffic? fraudInvalidTraffic, DoubleVerifyVideoViewability? videoViewability})
DoubleVerify.fromJson(Map json_)

Properties

appStarRating ↔ DoubleVerifyAppStarRating?
Avoid bidding on apps with the star ratings.
getter/setter pair
avoidedAgeRatings ↔ List<String>?
Avoid bidding on apps with the age rating.
getter/setter pair
brandSafetyCategories ↔ DoubleVerifyBrandSafetyCategories?
DV Brand Safety Controls.
getter/setter pair
customSegmentId ↔ String?
The custom segment ID provided by DoubleVerify.
getter/setter pair
displayViewability ↔ DoubleVerifyDisplayViewability?
Display viewability settings (applicable to display line items only).
getter/setter pair
fraudInvalidTraffic ↔ DoubleVerifyFraudInvalidTraffic?
Avoid Sites and Apps with historical Fraud & IVT Rates.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoViewability ↔ DoubleVerifyVideoViewability?
Video viewability settings (applicable to video line items only).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited