FloodlightGroup class

A single Floodlight group.

Constructors

FloodlightGroup({ActiveViewVideoViewabilityMetricConfig? activeViewConfig, Map<String, Object?>? customVariables, String? displayName, String? floodlightGroupId, LookbackWindow? lookbackWindow, String? name, String? webTagType})
FloodlightGroup.fromJson(Map json_)

Properties

activeViewConfig ↔ ActiveViewVideoViewabilityMetricConfig?
The Active View video viewability metric configuration for the Floodlight group.
getter/setter pair
customVariables ↔ Map<String, Object?>?
User-defined custom variables owned by the Floodlight group.
getter/setter pair
displayName ↔ String?
The display name of the Floodlight group.
getter/setter pair
floodlightGroupId ↔ String?
The unique ID of the Floodlight group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lookbackWindow ↔ LookbackWindow?
The lookback window for the Floodlight group.
getter/setter pair
name ↔ String?
The resource name of the Floodlight group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webTagType ↔ String?
The web tag type enabled for the Floodlight group.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited