GuaranteedOrder class

A guaranteed order.

Guaranteed orders are parent entity of guaranteed inventory sources. When creating a guaranteed inventory source, a guaranteed order ID must be assigned to the inventory source.

Constructors

GuaranteedOrder({String? defaultAdvertiserId, String? defaultCampaignId, String? displayName, String? exchange, String? guaranteedOrderId, String? legacyGuaranteedOrderId, String? name, String? publisherName, bool? readAccessInherited, List<String>? readAdvertiserIds, String? readWriteAdvertiserId, String? readWritePartnerId, GuaranteedOrderStatus? status, String? updateTime})
GuaranteedOrder.fromJson(Map json_)

Properties

defaultAdvertiserId ↔ String?
The ID of default advertiser of the guaranteed order.
getter/setter pair
defaultCampaignId ↔ String?
The ID of the default campaign that is assigned to the guaranteed order.
getter/setter pair
displayName ↔ String?
The display name of the guaranteed order.
getter/setter pair
exchange ↔ String?
The exchange where the guaranteed order originated.
getter/setter pair
guaranteedOrderId ↔ String?
The unique identifier of the guaranteed order.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
legacyGuaranteedOrderId ↔ String?
The legacy ID of the guaranteed order.
getter/setter pair
name ↔ String?
The resource name of the guaranteed order.
getter/setter pair
publisherName ↔ String?
The publisher name of the guaranteed order.
getter/setter pair
readAccessInherited ↔ bool?
Whether all advertisers of read_write_partner_id have read access to the guaranteed order.
getter/setter pair
readAdvertiserIds ↔ List<String>?
The IDs of advertisers with read access to the guaranteed order.
getter/setter pair
readWriteAdvertiserId ↔ String?
The advertiser with read/write access to the guaranteed order.
getter/setter pair
readWritePartnerId ↔ String?
The partner with read/write access to the guaranteed order.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ GuaranteedOrderStatus?
The status settings of the guaranteed order.
getter/setter pair
updateTime ↔ String?
The timestamp when the guaranteed order was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited