InStreamAd class

Details for an in-stream ad.

Constructors

InStreamAd({CommonInStreamAttribute? commonInStreamAttribute, Map<String, String>? customParameters})
InStreamAd.fromJson(Map json_)

Properties

commonInStreamAttribute ↔ CommonInStreamAttribute?
Common ad attributes.
getter/setter pair
customParameters ↔ Map<String, String>?
The custom parameters and accompanying values to add to the tracking URL.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited