ListGoogleAudiencesResponse class

Constructors

ListGoogleAudiencesResponse({List<GoogleAudience>? googleAudiences, String? nextPageToken})
ListGoogleAudiencesResponse.fromJson(Map json_)

Properties

googleAudiences ↔ List<GoogleAudience>?
The list of Google audiences.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to retrieve the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited