ListLineItemsResponse class

Constructors

ListLineItemsResponse({List<LineItem>? lineItems, String? nextPageToken})
ListLineItemsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lineItems ↔ List<LineItem>?
The list of line items.
getter/setter pair
nextPageToken ↔ String?
A token to retrieve the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited