ManualTrigger class

A single manual trigger in Display & Video 360.

Warning: Line Items using manual triggers no longer serve in Display & Video 360. This resource will sunset on August 1, 2023. Read our [feature deprecation announcement](/display-video/api/deprecations#features.manual_triggers) for more information.

Constructors

ManualTrigger({String? activationDurationMinutes, String? advertiserId, String? displayName, String? latestActivationTime, String? name, String? state, String? triggerId})
ManualTrigger.fromJson(Map json_)

Properties

activationDurationMinutes ↔ String?
The maximum duration of each activation in minutes.
getter/setter pair
advertiserId ↔ String?
The unique ID of the advertiser that the manual trigger belongs to.
getter/setter pair
displayName ↔ String?
The display name of the manual trigger.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latestActivationTime ↔ String?
The timestamp of the trigger's latest activation.
getter/setter pair
name ↔ String?
The resource name of the manual trigger.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the manual trigger.
getter/setter pair
triggerId ↔ String?
The unique ID of the manual trigger.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited