MediaResource class

Constructors

MediaResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

download(String resourceName, {String? $fields, DownloadOptions downloadOptions = commons.DownloadOptions.metadata}) → Future<Object>
Downloads media.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
upload(GoogleBytestreamMedia request, String resourceName, {String? $fields, Media? uploadMedia}) → Future<GoogleBytestreamMedia>
Uploads media.

Operators

operator ==(Object other) → bool
The equality operator.
inherited