PartnerAdServerConfig class

Ad server related settings of a partner.

Properties

hashCode → int
The hash code for this object.
no setterinherited
measurementConfig ↔ MeasurementConfig?
Measurement settings of a partner.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited