PartnersResource class

Constructors

PartnersResource(ApiRequester client)

Properties

channels → PartnersChannelsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetingTypes → PartnersTargetingTypesResource
no setter

Methods

editAssignedTargetingOptions(BulkEditPartnerAssignedTargetingOptionsRequest request, String partnerId, {String? $fields}) → Future<BulkEditPartnerAssignedTargetingOptionsResponse>
Edits targeting options under a single partner.
get(String partnerId, {String? $fields}) → Future<Partner>
Gets a partner.
list({String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) → Future<ListPartnersResponse>
Lists partners that are accessible to the current user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited