PrismaConfig class

Settings specific to the Mediaocean Prisma tool.

Constructors

PrismaConfig({PrismaCpeCode? prismaCpeCode, String? prismaType, String? supplier})
PrismaConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
prismaCpeCode ↔ PrismaCpeCode?
Relevant client, product, and estimate codes from the Mediaocean Prisma tool.
getter/setter pair
prismaType ↔ String?
The Prisma type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supplier ↔ String?
The entity allocated this budget (DSP, site, etc.).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited