ProductFeedData class

The details of product feed.

Constructors

ProductFeedData({bool? isFeedDisabled, List<ProductMatchDimension>? productMatchDimensions, String? productMatchType})
ProductFeedData.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isFeedDisabled ↔ bool?
Whether the product feed has opted-out of showing products.
getter/setter pair
productMatchDimensions ↔ List<ProductMatchDimension>?
A list of dimensions used to match products.
getter/setter pair
productMatchType ↔ String?
How products are selected by the product feed. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited