ReviewStatusInfo class

Review statuses for the creative.

Constructors

ReviewStatusInfo({String? approvalStatus, String? contentAndPolicyReviewStatus, String? creativeAndLandingPageReviewStatus, List<ExchangeReviewStatus>? exchangeReviewStatuses, List<PublisherReviewStatus>? publisherReviewStatuses})
ReviewStatusInfo.fromJson(Map json_)

Properties

approvalStatus ↔ String?
Represents the basic approval needed for a creative to begin serving.
getter/setter pair
contentAndPolicyReviewStatus ↔ String?
Content and policy review status for the creative. Possible string values are:
getter/setter pair
creativeAndLandingPageReviewStatus ↔ String?
Creative and landing page review status for the creative. Possible string values are:
getter/setter pair
exchangeReviewStatuses ↔ List<ExchangeReviewStatus>?
Exchange review statuses for the creative.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
publisherReviewStatuses ↔ List<PublisherReviewStatus>?
Publisher review statuses for the creative.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited