VideoDiscoveryAd class

Details for a video discovery ad.

Constructors

VideoDiscoveryAd({String? description1, String? description2, String? headline, String? thumbnail, YoutubeVideoDetails? video})
VideoDiscoveryAd.fromJson(Map json_)

Properties

description1 ↔ String?
First text line for the ad.
getter/setter pair
description2 ↔ String?
Second text line for the ad.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headline ↔ String?
The headline of ad.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ String?
Thumbnail image used in the ad. Possible string values are:
getter/setter pair
video ↔ YoutubeVideoDetails?
The YouTube video the ad promotes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited