bidStrategy property
The bidding strategy used by the ad group.
Only the youtubeAndPartnersBid and demandGenBid field can be used in the bidding strategy.
Optional.
Implementation
BiddingStrategy? bidStrategy;
The bidding strategy used by the ad group.
Only the youtubeAndPartnersBid and demandGenBid field can be used in the bidding strategy.
Optional.
BiddingStrategy? bidStrategy;