AdPolicyTopicEvidence class

Evidence information used in the policy decision.

Properties

counterfeit ↔ AdPolicyTopicEvidenceCounterfeit?
Counterfeit enforcement that caused a policy violation.
getter/setter pair
destinationMismatch ↔ AdPolicyTopicEvidenceDestinationMismatch?
A mismatch between the ad destination URLs.
getter/setter pair
destinationNotWorking ↔ AdPolicyTopicEvidenceDestinationNotWorking?
Information on HTTP or DNS errors related to the ad destination.
getter/setter pair
destinationTextList ↔ AdPolicyTopicEvidenceDestinationTextList?
The text in the destination of the ad that is causing a policy violation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpCode ↔ int?
HTTP code returned when the final URL was crawled.
getter/setter pair
languageCode ↔ String?
The language the ad was detected to be written in.
getter/setter pair
legalRemoval ↔ AdPolicyTopicEvidenceLegalRemoval?
Legal related regulation enforcement that caused a policy violation.
getter/setter pair
regionalRequirements ↔ AdPolicyTopicEvidenceRegionalRequirements?
T&S proactive enforcement that caused a policy violation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textList ↔ AdPolicyTopicEvidenceTextList?
List of evidence found in the text of the ad.
getter/setter pair
trademark ↔ AdPolicyTopicEvidenceTrademark?
Trademark terms that caused a policy violation.
getter/setter pair
websiteList ↔ AdPolicyTopicEvidenceWebsiteList?
List of websites linked with the ad.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited