AdPolicyTopicEvidenceTextList typedef
AdPolicyTopicEvidenceTextList = $TextList
A list of fragments of text that violated the policy.
Implementation
typedef AdPolicyTopicEvidenceTextList = $TextList;
A list of fragments of text that violated the policy.
typedef AdPolicyTopicEvidenceTextList = $TextList;