CustomBiddingScript class

A single custom bidding script.

Constructors

CustomBiddingScript({bool? active, String? createTime, String? customBiddingAlgorithmId, String? customBiddingScriptId, List<ScriptError>? errors, String? name, CustomBiddingScriptRef? script, String? state})
CustomBiddingScript.fromJson(Map json_)

Properties

active ↔ bool?
Whether the script is currently being used for scoring by the parent algorithm.
getter/setter pair
createTime ↔ String?
The time when the script was created.
getter/setter pair
customBiddingAlgorithmId ↔ String?
The unique ID of the custom bidding algorithm the script belongs to.
getter/setter pair
customBiddingScriptId ↔ String?
The unique ID of the custom bidding script.
getter/setter pair
errors ↔ List<ScriptError>?
Error details of a rejected custom bidding script.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the custom bidding script.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script ↔ CustomBiddingScriptRef?
The reference to the uploaded script file.
getter/setter pair
state ↔ String?
The state of the custom bidding script.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited