DemandGenCarouselAd class

Details for a Demand Gen carousel ad.

Constructors

DemandGenCarouselAd({String? businessName, List<CarouselCard>? cards, Map<String, String>? customParameters, String? description, String? finalUrl, String? finalUrlSuffix, String? headline, String? trackingUrl, String? userSpecifiedTrackingUrl})
DemandGenCarouselAd.fromJson(Map json_)

Properties

businessName String?
The business name shown on the ad.
getter/setter pair
cards List<CarouselCard>?
The list of cards shown on the ad.
getter/setter pair
customParameters Map<String, String>?
The custom parameters and accompanying values to add to the tracking URL.
getter/setter pair
description String?
The description of the ad.
getter/setter pair
finalUrl String?
The URL address of the webpage that people reach after they click the ad.
getter/setter pair
finalUrlSuffix String?
The suffix to append to landing page URLs.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headline String?
The headline of the ad.
getter/setter pair
The logo image used by this ad.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingUrl String?
The URL address loaded in the background for tracking purposes.
getter/setter pair
userSpecifiedTrackingUrl String?
The tracking URL specified by the user manually.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited