AdPolicyTopicConstraintAdPolicyGlobalCertificateDomainMismatchConstraint typedef

AdPolicyTopicConstraintAdPolicyGlobalCertificateDomainMismatchConstraint = $Empty

Certificate is required to serve in any country and the existing certificate does not cover the ad's domain.

Implementation

typedef AdPolicyTopicConstraintAdPolicyGlobalCertificateDomainMismatchConstraint =
    $Empty;