AdPolicyTopicEntry class

An entry describing how an ad has been identified as relating to an ad policy.

Constructors

AdPolicyTopicEntry({AdPolicyTopicAppealInfo? appealInfo, String? helpCenterLink, String? policyDecisionType, String? policyEnforcementMeans, String? policyLabel, String? policyTopic, List<AdPolicyTopicConstraint>? policyTopicConstraints, String? policyTopicDescription, List<AdPolicyTopicEvidence>? policyTopicEvidences, String? policyTopicType})
AdPolicyTopicEntry.fromJson(Map json_)

Properties

appealInfo ↔ AdPolicyTopicAppealInfo?
Information on how to appeal the policy decision.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Ad policy help center link for the policy topic.
getter/setter pair
policyDecisionType ↔ String?
The source of the policy decision. Possible string values are:
getter/setter pair
policyEnforcementMeans ↔ String?
The policy enforcement means used in the policy review. Possible string values are:
getter/setter pair
policyLabel ↔ String?
Localized label text for policy.
getter/setter pair
policyTopic ↔ String?
The policy topic.
getter/setter pair
policyTopicConstraints ↔ List<AdPolicyTopicConstraint>?
The serving constraints relevant to the policy decision.
getter/setter pair
policyTopicDescription ↔ String?
A short summary description of the policy topic.
getter/setter pair
policyTopicEvidences ↔ List<AdPolicyTopicEvidence>?
The evidence used in the policy decision.
getter/setter pair
policyTopicType ↔ String?
How ad serving will be affected due to the relation to the ad policy topic. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited