AdvancedProductTargeting class

Product-specific targeting overrides.

Constructors

AdvancedProductTargeting({String? ageRange, DateRange? dateRange, List<String>? devices, FrequencyCap? frequencyCap, List<String>? genders, String? network, List<String>? plannableLocationIds, SurfaceTargetingSettings? surfaceTargetingSettings, TargetFrequency? targetFrequency, List<String>? userInterestIds, List<String>? userListIds, YouTubeSelectSettings? youtubeSelectSettings})
AdvancedProductTargeting.fromJson(Map json_)

Properties

ageRange String?
The age range to target.
getter/setter pair
dateRange DateRange?
The date range to target.
getter/setter pair
devices List<String>?
The devices to target.
getter/setter pair
frequencyCap FrequencyCap?
The frequency cap for the specific product.
getter/setter pair
genders List<String>?
The gender options to target.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
network String?
The network to target.
getter/setter pair
plannableLocationIds List<String>?
Plannable location IDs to target.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
surfaceTargetingSettings SurfaceTargetingSettings?
Plannable surfaces to target.
getter/setter pair
targetFrequency TargetFrequency?
The average number of times the ads will show to the same person over a certain period of time.
getter/setter pair
userInterestIds List<String>?
The user interest IDs to target.
getter/setter pair
userListIds List<String>?
The user list IDs to target.
getter/setter pair
youtubeSelectSettings YouTubeSelectSettings?
YouTube Select settings.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited