AdvertisersAdAssetsResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
bulkCreate(BulkCreateAdAssetsRequest request, String advertiserId, {String? $fields})
→ Future<BulkCreateAdAssetsResponse>
-
Creates multiple ad assets in a single request.
-
create(CreateAdAssetRequest request, String advertiserId, {String? $fields})
→ Future<AdAsset>
-
Creates an ad asset.
-
get(String advertiserId, String adAssetId, {String? $fields})
→ Future<AdAsset>
-
Gets an ad asset.
-
list(String advertiserId, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields})
→ Future<ListAdAssetsResponse>
-
Lists ad assets under an advertiser ID.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
upload(UploadAdAssetRequest request, String advertiserId, {String? $fields, Media? uploadMedia})
→ Future<UploadAdAssetResponse>
-
Uploads and creates an ad asset.