demandGenBid property
A bid strategy used by Demand Gen resources.
It can only be used for a Demand Gen line item or ad group entity.
Implementation
DemandGenBiddingStrategy? demandGenBid;
A bid strategy used by Demand Gen resources.
It can only be used for a Demand Gen line item or ad group entity.
DemandGenBiddingStrategy? demandGenBid;