BulkEditAdGroupAssignedTargetingOptionsRequest class

Request message for BulkEditAdGroupAssignedTargetingOptions.

Properties

adGroupIds ↔ List<String>?
The IDs of the ad groups the assigned targeting options will belong to.
getter/setter pair
createRequests ↔ List<CreateAssignedTargetingOptionsRequest>?
The assigned targeting options to create in batch, specified as a list of CreateAssignedTargetingOptionRequest.
getter/setter pair
deleteRequests ↔ List<DeleteAssignedTargetingOptionsRequest>?
The assigned targeting options to delete in batch, specified as a list of DeleteAssignedTargetingOptionsRequest.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited