BulkEditAdGroupAssignedTargetingOptionsResponse class

Response message for BulkEditAssignedTargetingOptions.

Properties

errors ↔ List<Status>?
The error information for each ad group that failed to update.
getter/setter pair
failedAdGroupIds ↔ List<String>?
The IDs of the ad groups which failed to update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAdGroupIds ↔ List<String>?
The IDs of the ad groups which were successfully updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited