CampaignDuration class
The duration of the reach plan.
Constructors
- CampaignDuration({DateRange? dateRange, int? durationDays})
- CampaignDuration.fromJson(Map json_)
Properties
- dateRange ↔ DateRange?
-
The date range the plan covers.
getter/setter pair
- durationDays ↔ int?
-
The number of days the plan covers.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited