CarouselCard class

Details for a Demand Gen carousel card.

Constructors

CarouselCard({String? callToAction, String? finalMobileUrl, String? finalUrl, String? headline, ImageAsset? marketingImage, ImageAsset? portraitMarketingImage, ImageAsset? squareMarketingImage})
CarouselCard.fromJson(Map json_)

Properties

callToAction String?
The text on the call-to-action button shown on the card.
getter/setter pair
finalMobileUrl String?
The URL address of the webpage that people reach after they click the card on a mobile device.
getter/setter pair
finalUrl String?
The URL address of the webpage that people reach after they click the card.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headline String?
The headline of the card.
getter/setter pair
marketingImage ImageAsset?
The marketing image shown on the card.
getter/setter pair
portraitMarketingImage ImageAsset?
The portrait marketing image shown on the card.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
squareMarketingImage ImageAsset?
The square marketing image shown on the card.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited