finalUrl property
The URL address of the webpage that people reach after they click the card.
Required.
Implementation
core.String? finalUrl;
The URL address of the webpage that people reach after they click the card.
Required.
core.String? finalUrl;