CombinedAudiencesResource class

Constructors

CombinedAudiencesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String combinedAudienceId, {String? advertiserId, String? partnerId, String? $fields}) → Future<CombinedAudience>
Gets a combined audience.
list({String? advertiserId, String? filter, String? orderBy, int? pageSize, String? pageToken, String? partnerId, String? $fields}) → Future<ListCombinedAudiencesResponse>
Lists combined audiences.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited