Consent class

User consent status.

Constructors

Consent({String? adPersonalization, String? adUserData})
Consent.fromJson(Map json_)

Properties

adPersonalization ↔ String?
Represents consent for ad personalization. Possible string values are:
getter/setter pair
adUserData ↔ String?
Represents consent for ad user data. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited