primaryAttributionModelId property

String? primaryAttributionModelId
getter/setter pair

The attribution model to use for conversion measurement.

This attribution model will determine how conversions are counted. The Primary model can be set by you for a floodlight config or group. More details here. Only applicable to Demand Gen line items.

Optional.

Implementation

core.String? primaryAttributionModelId;