DemandGenImageAd class

Details for a Demand Gen image ad.

Constructors

DemandGenImageAd({String? businessName, String? callToAction, Map<String, String>? customParameters, List<String>? descriptions, String? finalMobileUrl, String? finalUrl, String? finalUrlSuffix, List<String>? headlines, List<ImageAsset>? logoImages, List<ImageAsset>? marketingImages, List<ImageAsset>? portraitMarketingImages, List<ImageAsset>? squareMarketingImages, String? trackingUrl, String? userSpecifiedTrackingUrl})
DemandGenImageAd.fromJson(Map json_)

Properties

businessName String?
The business name shown on the ad.
getter/setter pair
callToAction String?
The call-to-action button shown on the ad.
getter/setter pair
customParameters Map<String, String>?
The custom parameters and accompanying values to add to the tracking URL.
getter/setter pair
descriptions List<String>?
The list of descriptions shown on the ad.
getter/setter pair
finalMobileUrl String?
The URL address of the webpage that people reach after they click the ad on a mobile device.
getter/setter pair
finalUrl String?
The URL address of the webpage that people reach after they click the ad.
getter/setter pair
finalUrlSuffix String?
The suffix to append to landing page URLs.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headlines List<String>?
The list of headlines shown on the ad.
getter/setter pair
logoImages List<ImageAsset>?
The list of logo images shown on the ad.
getter/setter pair
marketingImages List<ImageAsset>?
The list of marketing images shown on the ad.
getter/setter pair
portraitMarketingImages List<ImageAsset>?
The list of portrait marketing images shown on the ad.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
squareMarketingImages List<ImageAsset>?
The list of square marketing images shown on the ad.
getter/setter pair
trackingUrl String?
The URL address loaded in the background for tracking purposes.
getter/setter pair
userSpecifiedTrackingUrl String?
The tracking URL specified by the user manually.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited