finalMobileUrl property

String? finalMobileUrl
getter/setter pair

The URL address of the webpage that people reach after they click the ad on a mobile device.

Optional.

Implementation

core.String? finalMobileUrl;