logoImages property
The list of logo images shown on the ad.
This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied.
Implementation
core.List<ImageAsset>? logoImages;
The list of logo images shown on the ad.
This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied.
core.List<ImageAsset>? logoImages;