DemandGenVideoAd class

Details for a Demand Gen video ad.

Constructors

DemandGenVideoAd({String? businessName, String? callToAction, ImageAsset? companionBanner, Map<String, String>? customParameters, List<String>? descriptions, String? displayUrlBreadcrumb1, String? displayUrlBreadcrumb2, String? finalMobileUrl, String? finalUrl, String? finalUrlSuffix, List<String>? headlines, List<String>? longHeadlines, String? trackingUrl, String? userSpecifiedTrackingUrl, List<YoutubeVideoDetails>? videos})
DemandGenVideoAd.fromJson(Map json_)

Properties

businessName String?
The business name shown on the ad.
getter/setter pair
callToAction String?
The call-to-action button shown on the ad.
getter/setter pair
companionBanner ImageAsset?
The companion banner used by this ad.
getter/setter pair
customParameters Map<String, String>?
The custom parameters and accompanying values to add to the tracking URL.
getter/setter pair
descriptions List<String>?
The list of descriptions shown on the ad.
getter/setter pair
displayUrlBreadcrumb1 String?
The first piece after the domain in the display URL.
getter/setter pair
displayUrlBreadcrumb2 String?
The second piece after the domain in the display URL.
getter/setter pair
finalMobileUrl String?
The URL address of the webpage that people reach after they click the ad on a mobile device.
getter/setter pair
finalUrl String?
The URL address of the webpage that people reach after they click the ad.
getter/setter pair
finalUrlSuffix String?
The suffix to append to landing page URLs.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headlines List<String>?
The list of headlines shown on the ad.
getter/setter pair
The logo image used by this ad.
getter/setter pair
longHeadlines List<String>?
The list of long headlines shown on the ad.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingUrl String?
The URL address loaded in the background for tracking purposes.
getter/setter pair
userSpecifiedTrackingUrl String?
The tracking URL specified by the user manually.
getter/setter pair
videos List<YoutubeVideoDetails>?
The list of YouTube video assets used by this ad.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited