logo property
The logo image used by this ad.
This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied.
Optional.
Implementation
ImageAsset? logo;
The logo image used by this ad.
This setting is required unless a default value is set at the advertiser level. If left unset, the default value will be applied.
Optional.
ImageAsset? logo;