EditInventorySourceReadWriteAccessorsRequest class

Request message for InventorySourceService.EditInventorySourceReadWriteAccessors.

Properties

advertisersUpdate ↔ EditInventorySourceReadWriteAccessorsRequestAdvertisersUpdate?
The advertisers to add or remove from the list of advertisers that have read/write access to the inventory source.
getter/setter pair
assignPartner ↔ bool?
Set the partner context as read/write accessor of the inventory source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partnerId ↔ String?
The partner context by which the accessors change is being made.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited