FirstPartyAndPartnerAudience class

Describes a first or partner audience list used for targeting.

First party audiences are created via usage of client data. Partner audiences are provided by Third Party data providers and can only be licensed to customers.

Constructors

FirstPartyAndPartnerAudience({String? activeDisplayAudienceSize, String? appId, String? audienceSource, String? audienceType, ContactInfoList? contactInfoList, String? description, String? displayAudienceSize, String? displayDesktopAudienceSize, String? displayMobileAppAudienceSize, String? displayMobileWebAudienceSize, String? displayName, String? firstPartyAndPartnerAudienceId, String? firstPartyAndPartnerAudienceType, String? gmailAudienceSize, String? membershipDurationDays, MobileDeviceIdList? mobileDeviceIdList, String? name, String? youtubeAudienceSize})
FirstPartyAndPartnerAudience.fromJson(Map json_)

Properties

activeDisplayAudienceSize ↔ String?
The estimated audience size for the Display network in the past month.
getter/setter pair
appId ↔ String?
The app_id matches with the type of the mobile_device_ids being uploaded.
getter/setter pair
audienceSource ↔ String?
The source of the audience.
getter/setter pair
audienceType ↔ String?
The type of the audience.
getter/setter pair
contactInfoList ↔ ContactInfoList?
Input only.
getter/setter pair
description ↔ String?
The user-provided description of the audience.
getter/setter pair
displayAudienceSize ↔ String?
The estimated audience size for the Display network.
getter/setter pair
displayDesktopAudienceSize ↔ String?
The estimated desktop audience size in Display network.
getter/setter pair
displayMobileAppAudienceSize ↔ String?
The estimated mobile app audience size in Display network.
getter/setter pair
displayMobileWebAudienceSize ↔ String?
The estimated mobile web audience size in Display network.
getter/setter pair
displayName ↔ String?
The display name of the first party and partner audience.
getter/setter pair
firstPartyAndPartnerAudienceId ↔ String?
Identifier.
getter/setter pair
firstPartyAndPartnerAudienceType ↔ String?
Whether the audience is a first party and partner audience.
getter/setter pair
gmailAudienceSize ↔ String?
The estimated audience size for Gmail network.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
membershipDurationDays ↔ String?
The duration in days that an entry remains in the audience after the qualifying event.
getter/setter pair
mobileDeviceIdList ↔ MobileDeviceIdList?
Input only.
getter/setter pair
name ↔ String?
The resource name of the first party and partner audience.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
youtubeAudienceSize ↔ String?
The estimated audience size for YouTube network.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited