GenerateReachForecastRequest class

Request message for ReachForecastService.GenerateReachForecast.

Constructors

GenerateReachForecastRequest({CampaignDuration? campaignDuration, String? currencyCode, int? minEffectiveFrequency, List<PlannedProduct>? plannedProducts, Targeting? targeting})
GenerateReachForecastRequest.fromJson(Map json_)

Properties

campaignDuration CampaignDuration?
The duration of the planned campaign.
getter/setter pair
currencyCode String?
The currency code for the plan in ISO 4217 format.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
minEffectiveFrequency int?
The minimum effective frequency for the reported reach metrics.
getter/setter pair
plannedProducts List<PlannedProduct>?
The list of line items to include in the forecast.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targeting Targeting?
The targeting parameters of the planned campaign.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited