GenerateReachForecastResponse class
Response message for ReachForecastService.GenerateReachForecast.
Constructors
- GenerateReachForecastResponse({OnTargetAudienceMetrics? onTargetAudienceMetrics, ReachCurve? reachCurve})
- GenerateReachForecastResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onTargetAudienceMetrics ↔ OnTargetAudienceMetrics?
-
The estimated audience sizes for the targeted geography.
getter/setter pair
- reachCurve ↔ ReachCurve?
-
The generated forecast curve.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited