InventorySourceGroupsAssignedInventorySourcesResource class

Constructors

InventorySourceGroupsAssignedInventorySourcesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

bulkEdit(BulkEditAssignedInventorySourcesRequest request, String inventorySourceGroupId, {String? $fields}) → Future<BulkEditAssignedInventorySourcesResponse>
Bulk edits multiple assignments between inventory sources and a single inventory source group.
create(AssignedInventorySource request, String inventorySourceGroupId, {String? advertiserId, String? partnerId, String? $fields}) → Future<AssignedInventorySource>
Creates an assignment between an inventory source and an inventory source group.
delete(String inventorySourceGroupId, String assignedInventorySourceId, {String? advertiserId, String? partnerId, String? $fields}) → Future<Empty>
Deletes the assignment between an inventory source and an inventory source group.
list(String inventorySourceGroupId, {String? advertiserId, String? filter, String? orderBy, int? pageSize, String? pageToken, String? partnerId, String? $fields}) → Future<ListAssignedInventorySourcesResponse>
Lists inventory sources assigned to an inventory source group.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited