optimizeFixedBidding property

bool? optimizeFixedBidding
getter/setter pair

Whether to enable DV360's bid optimization for fixed bid line items.

By default, DV360 optimizes your fixed bid by automatically lowering bids for impressions that are less likely to perform well. This optimization is enabled by default (value is true). When this field is set to false, this optimization is disabled, and the bid will not be lowered for any reason. This setting only applies to line items with a bidding_strategy of type FIXED_BID.

Optional.

Implementation

core.bool? optimizeFixedBidding;