OnTargetAudienceMetrics class

Estimated audience sizes for a targeted geography.

Constructors

OnTargetAudienceMetrics({String? censusAudienceSize, String? youtubeAudienceSize})
OnTargetAudienceMetrics.fromJson(Map json_)

Properties

censusAudienceSize String?
Size of the audience based on the census data of the targeted geography.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
youtubeAudienceSize String?
Estimated size of the YouTube audience.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited