PlannableLocation class

A plannable location used for forecasting.

Constructors

PlannableLocation({String? displayName, String? geoRegionType, String? name, String? parentPlannableLocationId, String? plannableLocationId, String? regionCode})
PlannableLocation.fromJson(Map json_)

Properties

displayName String?
The display name of the location, for example "Algeria".
getter/setter pair
geoRegionType String?
The type of location.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The resource name of the plannable location.
getter/setter pair
parentPlannableLocationId String?
The parent plannable location ID, for example the country ID for subgeos.
getter/setter pair
plannableLocationId String?
The plannable location ID.
getter/setter pair
regionCode String?
The region code of the location, for example "DZ" for Algeria.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited