PlannableUserInterest class

A plannable user interest used for targeting.

Constructors

PlannableUserInterest({UserInterest? userInterest, String? userInterestDisplayName, String? userInterestPath, String? userInterestType})
PlannableUserInterest.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userInterest UserInterest?
The identifier for the user interest.
getter/setter pair
userInterestDisplayName String?
The display name of the interest, for example "Outdoor Enthusiasts".
getter/setter pair
userInterestPath String?
The category path of the interest.
getter/setter pair
userInterestType String?
The type of audience, e.g., "AFFINITY", "IN_MARKET".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited