userInterestDisplayName property
The display name of the interest, for example "Outdoor Enthusiasts".
Output only.
Implementation
core.String? userInterestDisplayName;
The display name of the interest, for example "Outdoor Enthusiasts".
Output only.
core.String? userInterestDisplayName;