ProductMetadata class

Metadata for a plannable product.

Constructors

ProductMetadata({String? displayName, String? plannableProductCode, PlannableProductCoreAttributes? plannableProductCoreAttributes, String? plannableProductDescription, PlannableTargeting? plannableTargeting})
ProductMetadata.fromJson(Map json_)

Properties

displayName String?
The name associated with the ad product.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
plannableProductCode String?
The plannable product code (e.g. "YOUTUBE_REACH_MIX").
getter/setter pair
plannableProductCoreAttributes PlannableProductCoreAttributes?
Core attributes for this product.
getter/setter pair
plannableProductDescription String?
The plain-text description of the ad product.
getter/setter pair
plannableTargeting PlannableTargeting?
The targeting capabilities available for this product.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited