SurfaceTargetingCombinations class

Surface targeting rules.

Constructors

SurfaceTargetingCombinations({List<String>? availableSurfaceTypes, List<String>? defaultSurfaceTypes, List<SurfaceTargetingCombination>? validSurfaceCombinations})
SurfaceTargetingCombinations.fromJson(Map json_)

Properties

availableSurfaceTypes ↔ List<String>?
The surface types available.
getter/setter pair
defaultSurfaceTypes ↔ List<String>?
The default surface types for this product.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validSurfaceCombinations ↔ List<SurfaceTargetingCombination>?
Valid combinations of surfaces that can be selected together.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited