validSurfaceCombinations property
Valid combinations of surfaces that can be selected together.
Output only.
Implementation
core.List<SurfaceTargetingCombination>? validSurfaceCombinations;
Valid combinations of surfaces that can be selected together.
Output only.
core.List<SurfaceTargetingCombination>? validSurfaceCombinations;