UserInterest class

The identifier for a user interest.

Constructors

UserInterest({String? userInterestCategory, String? userInterestUserList})
UserInterest.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userInterestCategory String?
The resource name of the interest category.
getter/setter pair
userInterestUserList String?
The resource name of the user list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited