YoutubeAndPartnersSettings class

Settings for YouTube and Partners line items.

Constructors

YoutubeAndPartnersSettings({String? contentCategory, String? effectiveContentCategory, YoutubeAndPartnersInventorySourceConfig? inventorySourceSettings, String? leadFormId, String? linkedMerchantId, List<String>? relatedVideoIds, TargetFrequency? targetFrequency, ThirdPartyMeasurementConfigs? thirdPartyMeasurementConfigs, VideoAdInventoryControl? videoAdInventoryControl, VideoAdSequenceSettings? videoAdSequenceSettings, FrequencyCap? viewFrequencyCap})
YoutubeAndPartnersSettings.fromJson(Map json_)

Properties

contentCategory ↔ String?
The kind of content on which the YouTube and Partners ads will be shown.
getter/setter pair
effectiveContentCategory ↔ String?
The content category which takes effect when serving the line item.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inventorySourceSettings ↔ YoutubeAndPartnersInventorySourceConfig?
Settings that control what YouTube and Partners inventories the line item will target.
getter/setter pair
leadFormId ↔ String?
The ID of the form to generate leads.
getter/setter pair
linkedMerchantId ↔ String?
The ID of the merchant which is linked to the line item for product feed.
getter/setter pair
relatedVideoIds ↔ List<String>?
The IDs of the videos appear below the primary video ad when the ad is playing in the YouTube app on mobile devices.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetFrequency ↔ TargetFrequency?
The average number of times you want ads from this line item to show to the same person over a certain period of time.
getter/setter pair
thirdPartyMeasurementConfigs ↔ ThirdPartyMeasurementConfigs?
The third-party measurement configs of the line item.
getter/setter pair
videoAdInventoryControl ↔ VideoAdInventoryControl?
The settings to control which inventory is allowed for this line item.
getter/setter pair
videoAdSequenceSettings ↔ VideoAdSequenceSettings?
The settings related to VideoAdSequence.
getter/setter pair
viewFrequencyCap ↔ FrequencyCap?
The view frequency cap settings of the line item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited