YoutubeAssetAssociationAffiliateLocationAssetFilter class

An asset filter that matches eligible affiliate location assets for serving.

Properties

affiliateLocationMatchingFunction YoutubeAssetAssociationAffiliateLocationAssetFilterAffiliateLocationMatchingFunction?
The matching function that determines how the affiliate location asset filter matches affiliate location assets.
getter/setter pair
affiliateLocationMatchingType String?
The matching type of this affiliate location asset filter.
getter/setter pair
assetSetId String?
The ID of the asset set that matches the affiliate location assets eligible for serving.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited