YoutubeAssetAssociationLocationAssetFilter class

An asset filter that matches eligible location assets for serving.

Properties

assetSetId String?
The ID of the asset set that matches the location assets eligible for serving.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
locationMatchingFunction YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction?
The matching function that determines how the location asset filter matches location assets.
getter/setter pair
locationMatchingType String?
The matching type of this location asset filter.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited