YoutubeAssetAssociationLocationAssetFilterLocationMatchingFunction class

The matching function for a location asset filter.

Properties

business ↔ String?
The business name to match with.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ List<String>?
The labels to match with.
getter/setter pair
locationAssetIds ↔ List<String>?
The selected location asset IDs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited