business property
The business name to match with.
This field is optional and can only be set if location_matching_type is
FILTER.
Optional.
Implementation
core.String? business;
The business name to match with.
This field is optional and can only be set if location_matching_type is
FILTER.
Optional.
core.String? business;