GooglePrivacyDlpV2Action class

A task to execute on the completion of a job.

See https://docs.cloud.google.com/sensitive-data-protection/docs/concepts-actions to learn more.

Properties

deidentify ↔ GooglePrivacyDlpV2Deidentify?
Create a de-identified copy of the input data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobNotificationEmails ↔ GooglePrivacyDlpV2JobNotificationEmails?
Sends an email when the job completes.
getter/setter pair
publishFindingsToCloudDataCatalog ↔ GooglePrivacyDlpV2JobNotificationEmails?
Deprecated because Data Catalog is being turned down.
getter/setter pair
publishFindingsToDataplexCatalog ↔ GooglePrivacyDlpV2JobNotificationEmails?
Publish findings as an aspect to Dataplex Universal Catalog.
getter/setter pair
publishSummaryToCscc ↔ GooglePrivacyDlpV2JobNotificationEmails?
Publish summary to Cloud Security Command Center (Alpha).
getter/setter pair
publishToStackdriver ↔ GooglePrivacyDlpV2JobNotificationEmails?
Enable Stackdriver metric dlp.googleapis.com/finding_count.
getter/setter pair
pubSub ↔ GooglePrivacyDlpV2PublishToPubSub?
Publish a notification to a Pub/Sub topic.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveFindings ↔ GooglePrivacyDlpV2SaveFindings?
Save resulting findings in a provided location.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited