GooglePrivacyDlpV2AdjustmentRule class

Rule that specifies conditions when a certain infoType's finding details should be adjusted.

Properties

adjustByImageFindings ↔ GooglePrivacyDlpV2AdjustByImageFindings?
AdjustmentRule condition for image findings.
getter/setter pair
adjustByMatchingInfoTypes ↔ GooglePrivacyDlpV2AdjustByMatchingInfoTypes?
Set of infoTypes for which findings would affect this rule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
likelihoodAdjustment ↔ GooglePrivacyDlpV2LikelihoodAdjustment?
Likelihood adjustment to apply to the infoType.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited