GooglePrivacyDlpV2AllMessages typedef
GooglePrivacyDlpV2AllMessages = $Empty
If set, indicates that the finding applies to all messages in the conversation.
Implementation
typedef GooglePrivacyDlpV2AllMessages = $Empty;
If set, indicates that the finding applies to all messages in the conversation.
typedef GooglePrivacyDlpV2AllMessages = $Empty;