GooglePrivacyDlpV2BatchContentItem class
Represents a batch of content to inspect or redact.
Constructors
- GooglePrivacyDlpV2BatchContentItem({GooglePrivacyDlpV2StringValueBatch? stringValueBatch})
- GooglePrivacyDlpV2BatchContentItem.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValueBatch ↔ GooglePrivacyDlpV2StringValueBatch?
-
Represents a batch of string values to inspect or redact.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited