stringValueBatch property
Represents a batch of string values to inspect or redact.
Optional.
Implementation
GooglePrivacyDlpV2StringValueBatch? stringValueBatch;
Represents a batch of string values to inspect or redact.
Optional.
GooglePrivacyDlpV2StringValueBatch? stringValueBatch;