GooglePrivacyDlpV2BigQueryDiscoveryTarget class

Target used to match against for discovery with BigQuery tables

Properties

cadence ↔ GooglePrivacyDlpV2DiscoveryGenerationCadence?
How often and when to update profiles.
getter/setter pair
conditions ↔ GooglePrivacyDlpV2DiscoveryBigQueryConditions?
In addition to matching the filter, these conditions must be true before a profile is generated.
getter/setter pair
disabled ↔ GooglePrivacyDlpV2JobNotificationEmails?
Tables that match this filter will not have profiles created.
getter/setter pair
filter ↔ GooglePrivacyDlpV2DiscoveryBigQueryFilter?
The tables the discovery cadence applies to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited