GooglePrivacyDlpV2BigQueryField class

Message defining a field of a BigQuery table.

Properties

field ↔ GooglePrivacyDlpV2FieldId?
Designated field in the BigQuery table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table ↔ GooglePrivacyDlpV2BigQueryTable?
Source table of the field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited