GooglePrivacyDlpV2BigQueryOptions class

Options defining BigQuery table and row identifiers.

Constructors

GooglePrivacyDlpV2BigQueryOptions({List<GooglePrivacyDlpV2FieldId>? excludedFields, List<GooglePrivacyDlpV2FieldId>? identifyingFields, List<GooglePrivacyDlpV2FieldId>? includedFields, String? rowsLimit, int? rowsLimitPercent, String? sampleMethod, GooglePrivacyDlpV2BigQueryTable? tableReference})
GooglePrivacyDlpV2BigQueryOptions.fromJson(Map json_)

Properties

excludedFields ↔ List<GooglePrivacyDlpV2FieldId>?
References to fields excluded from scanning.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identifyingFields ↔ List<GooglePrivacyDlpV2FieldId>?
Table fields that may uniquely identify a row within the table.
getter/setter pair
includedFields ↔ List<GooglePrivacyDlpV2FieldId>?
Limit scanning only to these fields.
getter/setter pair
rowsLimit ↔ String?
Max number of rows to scan.
getter/setter pair
rowsLimitPercent ↔ int?
Max percentage of rows to scan.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleMethod ↔ String?
How to sample the data. Possible string values are:
getter/setter pair
tableReference ↔ GooglePrivacyDlpV2BigQueryTable?
Complete BigQuery table reference.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited