GooglePrivacyDlpV2BigQueryTableCollection class

Specifies a collection of BigQuery tables.

Used for Discovery.

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeRegexes ↔ GooglePrivacyDlpV2BigQueryRegexes?
A collection of regular expressions to match a BigQuery table against.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited