GooglePrivacyDlpV2ColumnDataProfile class

The profile for a scanned column within a table.

Constructors

GooglePrivacyDlpV2ColumnDataProfile({String? column, GooglePrivacyDlpV2InfoTypeSummary? columnInfoType, String? columnType, GooglePrivacyDlpV2DataRiskLevel? dataRiskLevel, String? datasetId, String? datasetLocation, String? datasetProjectId, String? estimatedNullPercentage, String? estimatedUniquenessScore, double? freeTextScore, String? name, List<GooglePrivacyDlpV2OtherInfoTypeSummary>? otherMatches, String? policyState, String? profileLastGenerated, GooglePrivacyDlpV2ProfileStatus? profileStatus, GooglePrivacyDlpV2SensitivityScore? sensitivityScore, String? state, String? tableDataProfile, String? tableFullResource, String? tableId})
GooglePrivacyDlpV2ColumnDataProfile.fromJson(Map json_)

Properties

column ↔ String?
The name of the column.
getter/setter pair
columnInfoType ↔ GooglePrivacyDlpV2InfoTypeSummary?
If it's been determined this column can be identified as a single type, this will be set.
getter/setter pair
columnType ↔ String?
The data type of a given column. Possible string values are:
getter/setter pair
dataRiskLevel ↔ GooglePrivacyDlpV2DataRiskLevel?
The data risk level for this column.
getter/setter pair
datasetId ↔ String?
The BigQuery dataset ID, if the resource profiled is a BigQuery table.
getter/setter pair
datasetLocation ↔ String?
If supported, the location where the dataset's data is stored.
getter/setter pair
datasetProjectId ↔ String?
The Google Cloud project ID that owns the profiled resource.
getter/setter pair
estimatedNullPercentage ↔ String?
Approximate percentage of entries being null in the column. Possible string values are:
getter/setter pair
estimatedUniquenessScore ↔ String?
Approximate uniqueness of the column. Possible string values are:
getter/setter pair
freeTextScore ↔ double?
The likelihood that this column contains free-form text.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the profile.
getter/setter pair
otherMatches ↔ List<GooglePrivacyDlpV2OtherInfoTypeSummary>?
Other types found within this column.
getter/setter pair
policyState ↔ String?
Indicates if a policy tag has been applied to the column. Possible string values are:
getter/setter pair
profileLastGenerated ↔ String?
The last time the profile was generated.
getter/setter pair
profileStatus ↔ GooglePrivacyDlpV2ProfileStatus?
Success or error status from the most recent profile generation attempt.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitivityScore ↔ GooglePrivacyDlpV2SensitivityScore?
The sensitivity of this column.
getter/setter pair
state ↔ String?
State of a profile. Possible string values are:
getter/setter pair
tableDataProfile ↔ String?
The resource name of the table data profile.
getter/setter pair
tableFullResource ↔ String?
The resource name of the resource this column is within.
getter/setter pair
tableId ↔ String?
The table ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited