GooglePrivacyDlpV2ContentMetadata class

Metadata on content to be scanned.

Properties

fileLabels List<GooglePrivacyDlpV2FileLabel>?
The file labels associated with the content.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
properties List<GooglePrivacyDlpV2KeyValueMetadataProperty>?
User provided key-value pairs of content metadata.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited