GooglePrivacyDlpV2ContentPolicy class
A policy to apply to content based on its inspection findings.
Constructors
-
GooglePrivacyDlpV2ContentPolicy({String? createTime, GooglePrivacyDlpV2PolicyAction? defaultAction, String? displayName, List<
GooglePrivacyDlpV2Error> ? errors, GooglePrivacyDlpV2PolicyAction? failedToScanSupportedFileType, GooglePrivacyDlpV2PolicyAction? inputTooLarge, GooglePrivacyDlpV2InspectConfig? inspectConfig, GooglePrivacyDlpV2InspectTemplate? inspectTemplate, List<GooglePrivacyDlpV2LoggingConfig> ? loggingConfigs, String? name, List<GooglePrivacyDlpV2PolicyRule> ? rules, GooglePrivacyDlpV2PolicyAction? unsupportedFileType, String? updateTime}) - GooglePrivacyDlpV2ContentPolicy.fromJson(Map json_)
Properties
- createTime ↔ String?
-
The creation timestamp of a contentPolicy; output-only field.
getter/setter pair
- defaultAction ↔ GooglePrivacyDlpV2PolicyAction?
-
Action to take if the content is scanned and no rules match.
getter/setter pair
- displayName ↔ String?
-
Display name (max 63 chars)
getter/setter pair
-
errors
↔ List<
GooglePrivacyDlpV2Error> ? -
A stream of errors encountered when the policy was applied.
getter/setter pair
- failedToScanSupportedFileType ↔ GooglePrivacyDlpV2PolicyAction?
-
Action to take if the content is a supported file type and size but fails
to be scanned, for example because the file is encrypted or corrupted.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTooLarge ↔ GooglePrivacyDlpV2PolicyAction?
-
Action to take if the content is a supported file type but is too large to
be scanned.
getter/setter pair
- inspectConfig ↔ GooglePrivacyDlpV2InspectConfig?
-
InspectConfig to use to produce findings.
getter/setter pair
- inspectTemplate ↔ GooglePrivacyDlpV2InspectTemplate?
-
InspectTemplate to use to produce findings.
getter/setter pair
-
loggingConfigs
↔ List<
GooglePrivacyDlpV2LoggingConfig> ? -
Log the actions taken by the content policy to external systems.
getter/setter pair
- name ↔ String?
-
Resource name of the policy.
getter/setter pair
-
rules
↔ List<
GooglePrivacyDlpV2PolicyRule> ? -
Policies to apply, based on the findings returned by inspection.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unsupportedFileType ↔ GooglePrivacyDlpV2PolicyAction?
-
Action to take if the content is an unsupported file type.
getter/setter pair
- updateTime ↔ String?
-
The last update timestamp of a contentPolicy; output-only field.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited