defaultAction property
Action to take if the content is scanned and no rules match.
Defaults to returning an ALLOW verdict if not set.
Implementation
GooglePrivacyDlpV2PolicyAction? defaultAction;
Action to take if the content is scanned and no rules match.
Defaults to returning an ALLOW verdict if not set.
GooglePrivacyDlpV2PolicyAction? defaultAction;