failedToScanSupportedFileType property

GooglePrivacyDlpV2PolicyAction? failedToScanSupportedFileType
getter/setter pair

Action to take if the content is a supported file type and size but fails to be scanned, for example because the file is encrypted or corrupted.

Optional.

Implementation

GooglePrivacyDlpV2PolicyAction? failedToScanSupportedFileType;