inputTooLarge property

GooglePrivacyDlpV2PolicyAction? inputTooLarge
getter/setter pair

Action to take if the content is a supported file type but is too large to be scanned.

Optional.

Implementation

GooglePrivacyDlpV2PolicyAction? inputTooLarge;