loggingConfigs property
Log the actions taken by the content policy to external systems.
Optional.
Implementation
core.List<GooglePrivacyDlpV2LoggingConfig>? loggingConfigs;
Log the actions taken by the content policy to external systems.
Optional.
core.List<GooglePrivacyDlpV2LoggingConfig>? loggingConfigs;