GooglePrivacyDlpV2ConversationMessage class

Single message in a conversation.

Properties

content ↔ String?
The contents of this message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageType ↔ String?
The type of message. Possible string values are:
getter/setter pair
participantId ↔ String?
The identifier of the participant, for example 'test-user' or 'gemini'.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited