messageType property

String? messageType
getter/setter pair

The type of message. Possible string values are:

  • "MESSAGE_TYPE_UNSPECIFIED" : Unused.
  • "CONTENT" : Message contains content to be inspected.
  • "CONTEXT" : Message contains context only and will not have findings reported from it during inspection or redacted from it during de-identification.

Implementation

core.String? messageType;