contentPolicyId property

String? contentPolicyId
getter/setter pair

The content policy ID can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+.

The maximum length is 100 characters. If empty, the system will generate a random id.

Optional.

Implementation

core.String? contentPolicyId;