GooglePrivacyDlpV2CreateDiscoveryConfigRequest class

Request message for CreateDiscoveryConfig.

Properties

configId ↔ String?
The config ID can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+.
getter/setter pair
discoveryConfig ↔ GooglePrivacyDlpV2DiscoveryConfig?
The DiscoveryConfig to create.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited