GooglePrivacyDlpV2CreateDlpJobRequest class

Request message for CreateDlpJobRequest.

Used to initiate long running jobs such as calculating risk metrics or inspecting Google Cloud Storage.

Properties

hashCode → int
The hash code for this object.
no setterinherited
inspectJob ↔ GooglePrivacyDlpV2InspectJobConfig?
An inspection job scans a storage repository for InfoTypes.
getter/setter pair
jobId ↔ String?
The job id can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+.
getter/setter pair
locationId ↔ String?
This field has no effect.
getter/setter pair
riskJob ↔ GooglePrivacyDlpV2RiskAnalysisJobConfig?
A risk analysis job calculates re-identification risk metrics for a BigQuery table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited