GooglePrivacyDlpV2CryptoKey class

This is a data encryption key (DEK) (as opposed to a key encryption key (KEK) stored by Cloud Key Management Service (Cloud KMS).

When using Cloud KMS to wrap or unwrap a DEK, be sure to set an appropriate IAM policy on the KEK to ensure an attacker cannot unwrap the DEK.

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsWrapped ↔ GooglePrivacyDlpV2KmsWrappedCryptoKey?
Key wrapped using Cloud KMS
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transient ↔ GooglePrivacyDlpV2TransientCryptoKey?
Transient crypto key
getter/setter pair
unwrapped ↔ GooglePrivacyDlpV2UnwrappedCryptoKey?
Unwrapped crypto key
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited