GooglePrivacyDlpV2CustomInfoType class

Custom information type provided by the user.

Used to find domain-specific sensitive information configurable to the data in question.

Properties

detectionRules ↔ List<GooglePrivacyDlpV2DetectionRule>?
Set of detection rules to apply to all findings of this CustomInfoType.
getter/setter pair
dictionary ↔ GooglePrivacyDlpV2Dictionary?
A list of phrases to detect as a CustomInfoType.
getter/setter pair
exclusionType ↔ String?
If set to EXCLUSION_TYPE_EXCLUDE this infoType will not cause a finding to be returned.
getter/setter pair
fileLabelInfoType ↔ GooglePrivacyDlpV2FileLabelInfoType?
File label to detect.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infoType ↔ GooglePrivacyDlpV2InfoType?
CustomInfoType can either be a new infoType, or an extension of built-in infoType, when the name matches one of existing infoTypes and that infoType is specified in InspectContent.info_types field.
getter/setter pair
likelihood ↔ String?
Likelihood to return for this CustomInfoType.
getter/setter pair
metadataKeyValueExpression ↔ GooglePrivacyDlpV2MetadataKeyValueExpression?
Key-value pair to detect in the metadata.
getter/setter pair
regex ↔ GooglePrivacyDlpV2Regex?
Regular expression based CustomInfoType.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitivityScore ↔ GooglePrivacyDlpV2SensitivityScore?
Sensitivity for this CustomInfoType.
getter/setter pair
storedType ↔ GooglePrivacyDlpV2StoredType?
Loads an existing StoredInfoType resource.
getter/setter pair
surrogateType ↔ GooglePrivacyDlpV2JobNotificationEmails?
Message for detecting output from deidentification transformations that support reversing.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited