GooglePrivacyDlpV2DataProfileAction class

A task to execute when a data profile has been generated.

Properties

exportData ↔ GooglePrivacyDlpV2Export?
Export data profiles into a provided location.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
publishToChronicle ↔ GooglePrivacyDlpV2JobNotificationEmails?
Publishes generated data profiles to Google Security Operations.
getter/setter pair
publishToDataplexCatalog ↔ GooglePrivacyDlpV2PublishToDataplexCatalog?
Publishes a portion of each profile to Dataplex Universal Catalog with the aspect type Sensitive Data Protection Profile.
getter/setter pair
publishToScc ↔ GooglePrivacyDlpV2JobNotificationEmails?
Publishes findings to Security Command Center for each data profile.
getter/setter pair
pubSubNotification ↔ GooglePrivacyDlpV2PubSubNotification?
Publish a message into the Pub/Sub topic.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagResources ↔ GooglePrivacyDlpV2TagResources?
Tags the profiled resources with the specified tag values.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited