GooglePrivacyDlpV2DataProfileConfigSnapshot class

Snapshot of the configurations used to generate the profile.

Properties

dataProfileJob ↔ GooglePrivacyDlpV2DataProfileJobConfig?
A copy of the configuration used to generate this profile.
getter/setter pair
discoveryConfig ↔ GooglePrivacyDlpV2DiscoveryConfig?
A copy of the configuration used to generate this profile.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inspectConfig ↔ GooglePrivacyDlpV2InspectConfig?
A copy of the inspection config used to generate this profile.
getter/setter pair
inspectTemplateModifiedTime ↔ String?
Timestamp when the template was modified
getter/setter pair
inspectTemplateName ↔ String?
Name of the inspection template used to generate this profile
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited