GooglePrivacyDlpV2DataProfileJobConfig class

Configuration for setting up a job to scan resources for profile generation.

Only one data profile configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.

Properties

dataProfileActions ↔ List<GooglePrivacyDlpV2DataProfileAction>?
Actions to execute at the completion of the job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inspectTemplates ↔ List<String>?
Detection logic for profile generation.
getter/setter pair
location ↔ GooglePrivacyDlpV2DataProfileLocation?
The data to scan.
getter/setter pair
otherCloudStartingLocation ↔ GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation?
Must be set only when scanning other clouds.
getter/setter pair
projectId ↔ String?
The project that will run the scan.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited