GooglePrivacyDlpV2DatabaseResourceRegex class

A pattern to match against one or more database resources.

At least one pattern must be specified. Regular expressions use RE2 syntax; a guide can be found under the google/re2 repository on GitHub.

Constructors

GooglePrivacyDlpV2DatabaseResourceRegex({String? databaseRegex, String? databaseResourceNameRegex, String? instanceRegex, String? projectIdRegex})
GooglePrivacyDlpV2DatabaseResourceRegex.fromJson(Map json_)

Properties

databaseRegex ↔ String?
Regex to test the database name against.
getter/setter pair
databaseResourceNameRegex ↔ String?
Regex to test the database resource's name against.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceRegex ↔ String?
Regex to test the instance name against.
getter/setter pair
projectIdRegex ↔ String?
For organizations, if unset, will match all projects.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited