GooglePrivacyDlpV2DatastoreKey class

Record key for a finding in Cloud Datastore.

Properties

entityKey ↔ GooglePrivacyDlpV2Key?
Datastore entity key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited