GooglePrivacyDlpV2DeidentifyDataSourceStats class

Summary of what was modified during a transformation.

Constructors

GooglePrivacyDlpV2DeidentifyDataSourceStats({String? transformationCount, String? transformationErrorCount, String? transformedBytes})
GooglePrivacyDlpV2DeidentifyDataSourceStats.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformationCount ↔ String?
Number of successfully applied transformations.
getter/setter pair
transformationErrorCount ↔ String?
Number of errors encountered while trying to apply transformations.
getter/setter pair
transformedBytes ↔ String?
Total size in bytes that were transformed in some way.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited