GooglePrivacyDlpV2DiscoveryConfig class

Configuration for discovery to scan resources for profile generation.

Only one discovery configuration may exist per organization, folder, or project. The generated data profiles are retained according to the data retention policy.

Properties

actions ↔ List<GooglePrivacyDlpV2DataProfileAction>?
Actions to execute at the completion of scanning.
getter/setter pair
createTime ↔ String?
The creation timestamp of a DiscoveryConfig.
getter/setter pair
displayName ↔ String?
Display name (max 100 chars)
getter/setter pair
errors ↔ List<GooglePrivacyDlpV2Error>?
A stream of errors encountered when the config was activated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inspectTemplates ↔ List<String>?
Detection logic for profile generation.
getter/setter pair
lastRunTime ↔ String?
The timestamp of the last time this config was executed.
getter/setter pair
name ↔ String?
Unique resource name for the DiscoveryConfig, assigned by the service when the DiscoveryConfig is created, for example projects/dlp-test-project/locations/global/discoveryConfigs/53234423.
getter/setter pair
orgConfig ↔ GooglePrivacyDlpV2OrgConfig?
Only set when the parent is an org.
getter/setter pair
otherCloudStartingLocation ↔ GooglePrivacyDlpV2OtherCloudDiscoveryStartingLocation?
Must be set only when scanning other clouds.
getter/setter pair
processingLocation ↔ GooglePrivacyDlpV2ProcessingLocation?
Processing location configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
A status for this configuration.
getter/setter pair
targets ↔ List<GooglePrivacyDlpV2DiscoveryTarget>?
Target to match against for determining what to scan and how frequently.
getter/setter pair
updateTime ↔ String?
The last update timestamp of a DiscoveryConfig.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited