GooglePrivacyDlpV2Error class

Details information about an error encountered during job execution or the results of an unsuccessful activation of the JobTrigger.

Constructors

GooglePrivacyDlpV2Error({GoogleRpcStatus? details, String? extraInfo, List<String>? timestamps})
GooglePrivacyDlpV2Error.fromJson(Map json_)

Properties

details ↔ GoogleRpcStatus?
Detailed error codes and messages.
getter/setter pair
extraInfo ↔ String?
Additional information about the error. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamps ↔ List<String>?
The times the error occurred.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited