GooglePrivacyDlpV2ExcludeInfoTypes class

List of excluded infoTypes.

Properties

hashCode → int
The hash code for this object.
no setterinherited
infoTypes ↔ List<GooglePrivacyDlpV2InfoType>?
InfoType list in ExclusionRule rule drops a finding when it overlaps or contained within with a finding of an infoType from this list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited