GooglePrivacyDlpV2ExclusionRule class

The rule that specifies conditions when findings of infoTypes specified in InspectionRuleSet are removed from results.

Properties

dictionary ↔ GooglePrivacyDlpV2Dictionary?
Dictionary which defines the rule.
getter/setter pair
excludeByHotword ↔ GooglePrivacyDlpV2ExcludeByHotword?
Drop if the hotword rule is contained in the proximate context.
getter/setter pair
excludeByImageFindings ↔ GooglePrivacyDlpV2ExcludeByImageFindings?
Exclude findings based on image containment rules.
getter/setter pair
excludeInfoTypes ↔ GooglePrivacyDlpV2ExcludeInfoTypes?
Set of infoTypes for which findings would affect this rule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchingType ↔ String?
How the rule is applied, see MatchingType documentation for details. Possible string values are:
getter/setter pair
regex ↔ GooglePrivacyDlpV2Regex?
Regular expression which defines the rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited