GooglePrivacyDlpV2Export class

If set, the detailed data profiles will be persisted to the location of your choice whenever updated.

Properties

hashCode → int
The hash code for this object.
no setterinherited
profileTable ↔ GooglePrivacyDlpV2BigQueryTable?
Store all profiles to BigQuery.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleFindingsTable ↔ GooglePrivacyDlpV2BigQueryTable?
Store sample data profile findings in an existing table or a new table in an existing dataset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited