GooglePrivacyDlpV2FileClusterSummary class

The file cluster summary.

Properties

dataRiskLevel ↔ GooglePrivacyDlpV2DataRiskLevel?
The data risk level of this cluster.
getter/setter pair
errors ↔ List<GooglePrivacyDlpV2Error>?
A list of errors detected while scanning this cluster.
getter/setter pair
fileClusterType ↔ GooglePrivacyDlpV2FileClusterType?
The file cluster type.
getter/setter pair
fileExtensionsScanned ↔ List<GooglePrivacyDlpV2FileExtensionInfo>?
A sample of file types scanned in this cluster.
getter/setter pair
fileExtensionsSeen ↔ List<GooglePrivacyDlpV2FileExtensionInfo>?
A sample of file types seen in this cluster.
getter/setter pair
fileStoreInfoTypeSummaries ↔ List<GooglePrivacyDlpV2FileStoreInfoTypeSummary>?
InfoTypes detected in this cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
noFilesExist ↔ bool?
True if no files exist in this cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitivityScore ↔ GooglePrivacyDlpV2SensitivityScore?
The sensitivity score of this cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited