GooglePrivacyDlpV2FileLabel class
Represents a file label.
Constructors
- GooglePrivacyDlpV2FileLabel({GooglePrivacyDlpV2GoogleDriveLabelMetadata? googleDriveLabel, GooglePrivacyDlpV2SensitivityLabelMetadata? sensitivityLabel})
- GooglePrivacyDlpV2FileLabel.fromJson(Map json_)
Properties
- googleDriveLabel ↔ GooglePrivacyDlpV2GoogleDriveLabelMetadata?
-
Google Drive labels published by Google.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitivityLabel ↔ GooglePrivacyDlpV2SensitivityLabelMetadata?
-
Sensitivity labels published by Microsoft.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited