GooglePrivacyDlpV2FileLabelInfoType class
Configuration for a custom infoType that detects file labels.
Constructors
- GooglePrivacyDlpV2FileLabelInfoType({GooglePrivacyDlpV2GoogleDriveLabel? googleDriveLabel, GooglePrivacyDlpV2SensitivityLabel? sensitivityLabel})
- GooglePrivacyDlpV2FileLabelInfoType.fromJson(Map json_)
Properties
- googleDriveLabel ↔ GooglePrivacyDlpV2GoogleDriveLabel?
-
Google Drive labels published by Google.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitivityLabel ↔ GooglePrivacyDlpV2SensitivityLabel?
-
Sensitivity labels published by Microsoft.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited