GooglePrivacyDlpV2FileSet class

Set of files to scan.

Properties

hashCode → int
The hash code for this object.
no setterinherited
regexFileSet ↔ GooglePrivacyDlpV2CloudStorageRegexFileSet?
The regex-filtered set of files to scan.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The Cloud Storage url of the file(s) to scan, in the format gs:///.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited