GooglePrivacyDlpV2FileStoreDataProfile class

The profile for a file store.

  • Cloud Storage: maps 1:1 with a bucket. * Amazon S3: maps 1:1 with a bucket.

Constructors

GooglePrivacyDlpV2FileStoreDataProfile({GooglePrivacyDlpV2DataProfileConfigSnapshot? configSnapshot, String? createTime, GooglePrivacyDlpV2DataRiskLevel? dataRiskLevel, GooglePrivacyDlpV2DataSourceType? dataSourceType, List<String>? dataStorageLocations, List<GooglePrivacyDlpV2Domain>? domains, List<GooglePrivacyDlpV2FileClusterSummary>? fileClusterSummaries, List<GooglePrivacyDlpV2FileStoreInfoTypeSummary>? fileStoreInfoTypeSummaries, bool? fileStoreIsEmpty, String? fileStoreLocation, String? fileStorePath, String? fullResource, String? lastModifiedTime, String? locationType, String? name, String? profileLastGenerated, GooglePrivacyDlpV2ProfileStatus? profileStatus, String? projectDataProfile, String? projectId, List<GooglePrivacyDlpV2RelatedResource>? relatedResources, Map<String, GooglePrivacyDlpV2Value>? resourceAttributes, Map<String, String>? resourceLabels, String? resourceVisibility, GooglePrivacyDlpV2BigQueryTable? sampleFindingsTable, GooglePrivacyDlpV2SensitivityScore? sensitivityScore, String? state, List<GooglePrivacyDlpV2Tag>? tags})
GooglePrivacyDlpV2FileStoreDataProfile.fromJson(Map json_)

Properties

configSnapshot ↔ GooglePrivacyDlpV2DataProfileConfigSnapshot?
The snapshot of the configurations used to generate the profile.
getter/setter pair
createTime ↔ String?
The time the file store was first created.
getter/setter pair
dataRiskLevel ↔ GooglePrivacyDlpV2DataRiskLevel?
The data risk level of this resource.
getter/setter pair
dataSourceType ↔ GooglePrivacyDlpV2DataSourceType?
The resource type that was profiled.
getter/setter pair
dataStorageLocations ↔ List<String>?
For resources that have multiple storage locations, these are those regions.
getter/setter pair
domains ↔ List<GooglePrivacyDlpV2Domain>?
Domains associated with the profile.
getter/setter pair
fileClusterSummaries ↔ List<GooglePrivacyDlpV2FileClusterSummary>?
FileClusterSummary per each cluster.
getter/setter pair
fileStoreInfoTypeSummaries ↔ List<GooglePrivacyDlpV2FileStoreInfoTypeSummary>?
InfoTypes detected in this file store.
getter/setter pair
fileStoreIsEmpty ↔ bool?
The file store does not have any files.
getter/setter pair
fileStoreLocation ↔ String?
The location of the file store.
getter/setter pair
fileStorePath ↔ String?
The file store path.
getter/setter pair
fullResource ↔ String?
The resource name of the resource profiled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime ↔ String?
The time the file store was last modified.
getter/setter pair
locationType ↔ String?
The location type of the file store (region, dual-region, multi-region, etc).
getter/setter pair
name ↔ String?
The name of the profile.
getter/setter pair
profileLastGenerated ↔ String?
The last time the profile was generated.
getter/setter pair
profileStatus ↔ GooglePrivacyDlpV2ProfileStatus?
Success or error status from the most recent profile generation attempt.
getter/setter pair
projectDataProfile ↔ String?
The resource name of the project data profile for this file store.
getter/setter pair
projectId ↔ String?
The Google Cloud project ID that owns the resource.
getter/setter pair
relatedResources ↔ List<GooglePrivacyDlpV2RelatedResource>?
Resources related to this profile.
getter/setter pair
resourceAttributes ↔ Map<String, GooglePrivacyDlpV2Value>?
Attributes of the resource being profiled.
getter/setter pair
resourceLabels ↔ Map<String, String>?
The labels applied to the resource at the time the profile was generated.
getter/setter pair
resourceVisibility ↔ String?
How broadly a resource has been shared. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleFindingsTable ↔ GooglePrivacyDlpV2BigQueryTable?
The BigQuery table to which the sample findings are written.
getter/setter pair
sensitivityScore ↔ GooglePrivacyDlpV2SensitivityScore?
The sensitivity score of this resource.
getter/setter pair
state ↔ String?
State of a profile. Possible string values are:
getter/setter pair
tags ↔ List<GooglePrivacyDlpV2Tag>?
The tags attached to the resource, including any tags attached during profiling.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited