labelFieldsToMatch property
The field values of the Google Drive label to match.
Implementation
core.List<GooglePrivacyDlpV2LabelField>? labelFieldsToMatch;
The field values of the Google Drive label to match.
core.List<GooglePrivacyDlpV2LabelField>? labelFieldsToMatch;