GooglePrivacyDlpV2ImageFallbackLocation class

Configure image processing to fall back to any of the following processing options if image processing is unavailable in the original request location.

Properties

globalProcessing ↔ GooglePrivacyDlpV2JobNotificationEmails?
Processing occurs in the global region.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
multiRegionProcessing ↔ GooglePrivacyDlpV2JobNotificationEmails?
Processing occurs in a multi-region that contains the current region if available.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited