GooglePrivacyDlpV2ImageRedactionConfig class

Configuration for determining how redaction of images should occur.

Properties

hashCode → int
The hash code for this object.
no setterinherited
infoType ↔ GooglePrivacyDlpV2InfoType?
Only one per info_type should be provided per request.
getter/setter pair
redactAllText ↔ bool?
If true, all text found in the image, regardless whether it matches an info_type, is redacted.
getter/setter pair
redactionColor ↔ GooglePrivacyDlpV2Color?
The color to use when redacting content from an image.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited