GooglePrivacyDlpV2InspectJobConfig class

Controls what and how to inspect for findings.

Properties

actions ↔ List<GooglePrivacyDlpV2Action>?
Actions to execute at the completion of the job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inspectConfig ↔ GooglePrivacyDlpV2InspectConfig?
How and what to scan for.
getter/setter pair
inspectTemplateName ↔ String?
If provided, will be used as the default for all values in InspectConfig.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageConfig ↔ GooglePrivacyDlpV2StorageConfig?
The data to scan.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited