GooglePrivacyDlpV2InspectionRuleSet class

Rule set for modifying a set of infoTypes to alter behavior under certain circumstances, depending on the specific details of the rules within the set.

Properties

hashCode → int
The hash code for this object.
no setterinherited
infoTypes ↔ List<GooglePrivacyDlpV2InfoType>?
List of infoTypes this rule set is applied to.
getter/setter pair
rules ↔ List<GooglePrivacyDlpV2InspectionRule>?
Set of rules to be applied to infoTypes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited