key property
The metadata key.
The format depends on the source of the metadata. Example: -
MSIP_Label_122709e3-8f6b-4860-985f-7f722a94f61e_Enabled (a Microsoft
Purview Information Protection key example)
Implementation
core.String? key;
The metadata key.
The format depends on the source of the metadata. Example: -
MSIP_Label_122709e3-8f6b-4860-985f-7f722a94f61e_Enabled (a Microsoft
Purview Information Protection key example)
core.String? key;