GooglePrivacyDlpV2LabelFieldMetadata class

The field values of the Google Drive label

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
The identifier of the Label Field.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value GooglePrivacyDlpV2Value?
The value of the Label Field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited