GooglePrivacyDlpV2LoggingConfig class
A single logging configuration.
Constructors
- GooglePrivacyDlpV2LoggingConfig({GooglePrivacyDlpV2LogToBigQuery? logToBigQuery})
- GooglePrivacyDlpV2LoggingConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- logToBigQuery ↔ GooglePrivacyDlpV2LogToBigQuery?
-
Log the actions taken to a BigQuery table.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited