GooglePrivacyDlpV2MetadataKeyValueExpression class

Configuration for a custom infoType that detects key-value pairs in the metadata matching the specified regular expressions.

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyRegex ↔ String?
The regular expression for the key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueRegex ↔ String?
The regular expression for the value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited