GooglePrivacyDlpV2OrgConfig class

Project and scan location information.

Only set when the parent is an org.

Properties

hashCode → int
The hash code for this object.
no setterinherited
location ↔ GooglePrivacyDlpV2DiscoveryStartingLocation?
The data to scan: folder, org, or project
getter/setter pair
projectId ↔ String?
The project that will run the scan.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited