GooglePrivacyDlpV2OutputStorageConfig class

Cloud repository for storing output.

Properties

hashCode → int
The hash code for this object.
no setterinherited
outputSchema ↔ String?
Schema used for writing the findings for Inspect jobs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storagePath ↔ GooglePrivacyDlpV2CloudStoragePath?
Store findings in an existing Cloud Storage bucket.
getter/setter pair
table ↔ GooglePrivacyDlpV2BigQueryTable?
Store findings in an existing table or a new table in an existing dataset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited