returnVerdict property

  1. @Deprecated('Not supported. Member documentation may have more information.')
String? returnVerdict
getter/setter pair

If set, the verdict will be returned to the user.

Deprecated: Use action instead. Possible string values are:

  • "CONTENT_POLICY_VERDICT_UNSPECIFIED" : Not used.
  • "ALLOW" : The policy allows the provided content to be used.
  • "BLOCK" : The policy prevents the provided content from being used. This should result in a blocked file upload, exclusion from training dataset, or other similar block action. (specific action will depend on the caller).

Implementation

@core.Deprecated(
  'Not supported. Member documentation may have more information.',
)
core.String? returnVerdict;