GooglePrivacyDlpV2ProcessingLocation class

Configure processing location for discovery and inspection.

For example, image OCR is only provided in limited regions but configuring ProcessingLocation will redirect OCR to a location where OCR is provided.

Properties

documentFallbackLocation ↔ GooglePrivacyDlpV2DocumentFallbackLocation?
Document processing falls back using this configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageFallbackLocation ↔ GooglePrivacyDlpV2ImageFallbackLocation?
Image processing falls back using this configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited