GooglePrivacyDlpV2ProjectDataProfile class

An aggregated profile for this project, based on the resources profiled within it.

Constructors

GooglePrivacyDlpV2ProjectDataProfile({GooglePrivacyDlpV2DataRiskLevel? dataRiskLevel, String? fileStoreDataProfileCount, String? name, String? profileLastGenerated, GooglePrivacyDlpV2ProfileStatus? profileStatus, String? projectId, GooglePrivacyDlpV2SensitivityScore? sensitivityScore, String? tableDataProfileCount})
GooglePrivacyDlpV2ProjectDataProfile.fromJson(Map json_)

Properties

dataRiskLevel ↔ GooglePrivacyDlpV2DataRiskLevel?
The data risk level of this project.
getter/setter pair
fileStoreDataProfileCount ↔ String?
The number of file store data profiles generated for this project.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the profile.
getter/setter pair
profileLastGenerated ↔ String?
The last time the profile was generated.
getter/setter pair
profileStatus ↔ GooglePrivacyDlpV2ProfileStatus?
Success or error status of the last attempt to profile the project.
getter/setter pair
projectId ↔ String?
Project ID or account that was profiled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitivityScore ↔ GooglePrivacyDlpV2SensitivityScore?
The sensitivity score of this project.
getter/setter pair
tableDataProfileCount ↔ String?
The number of table data profiles generated for this project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited