GooglePrivacyDlpV2PubSubNotification class

Send a Pub/Sub message into the given Pub/Sub topic to connect other systems to data profile generation.

The message payload data will be the byte serialization of DataProfilePubSubMessage.

Properties

detailOfMessage ↔ String?
How much data to include in the Pub/Sub message.
getter/setter pair
event ↔ String?
The type of event that triggers a Pub/Sub.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pubsubCondition ↔ GooglePrivacyDlpV2DataProfilePubSubCondition?
Conditions (e.g., data risk or sensitivity level) for triggering a Pub/Sub.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic ↔ String?
Cloud Pub/Sub topic to send notifications to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited