GooglePrivacyDlpV2RedactImageRequest class

Request to search for potentially sensitive info in an image and redact it by covering it with a colored rectangle.

Constructors

GooglePrivacyDlpV2RedactImageRequest({GooglePrivacyDlpV2ByteContentItem? byteItem, String? deidentifyTemplate, List<GooglePrivacyDlpV2ImageRedactionConfig>? imageRedactionConfigs, bool? includeFindings, GooglePrivacyDlpV2InspectConfig? inspectConfig, String? inspectTemplate, String? locationId})
GooglePrivacyDlpV2RedactImageRequest.fromJson(Map json_)

Properties

byteItem ↔ GooglePrivacyDlpV2ByteContentItem?
The content must be PNG, JPEG, SVG or BMP.
getter/setter pair
deidentifyTemplate ↔ String?
The full resource name of the de-identification template to use.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageRedactionConfigs ↔ List<GooglePrivacyDlpV2ImageRedactionConfig>?
The configuration for specifying what content to redact from images.
getter/setter pair
includeFindings ↔ bool?
Whether the response should include findings along with the redacted image.
getter/setter pair
inspectConfig ↔ GooglePrivacyDlpV2InspectConfig?
Configuration for the inspector.
getter/setter pair
inspectTemplate ↔ String?
The full resource name of the inspection template to use.
getter/setter pair
locationId ↔ String?
This field has no effect.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited