deidentifyTemplate property

String? deidentifyTemplate
getter/setter pair

The full resource name of the de-identification template to use.

Settings in the main image_redaction_configs field override the corresponding settings in this de-identification template. The request fails if the type of the template's deidentify_config is not image_transformations.

Implementation

core.String? deidentifyTemplate;