GooglePrivacyDlpV2StatisticalTable class

An auxiliary table containing statistical information on the relative frequency of different quasi-identifiers values.

It has one or several quasi-identifiers columns, and one column that indicates the relative frequency of each quasi-identifier tuple. If a tuple is present in the data but not in the auxiliary table, the corresponding relative frequency is assumed to be zero (and thus, the tuple is highly reidentifiable).

Properties

hashCode → int
The hash code for this object.
no setterinherited
quasiIds ↔ List<GooglePrivacyDlpV2QuasiIdentifierField>?
Quasi-identifier columns.
getter/setter pair
relativeFrequency ↔ GooglePrivacyDlpV2FieldId?
The relative frequency column must contain a floating-point number between 0 and 1 (inclusive).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
table ↔ GooglePrivacyDlpV2BigQueryTable?
Auxiliary table location.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited