GooglePrivacyDlpV2StorageConfig class

Shared message indicating Cloud storage type.

Properties

bigQueryOptions ↔ GooglePrivacyDlpV2BigQueryOptions?
BigQuery options.
getter/setter pair
cloudStorageOptions ↔ GooglePrivacyDlpV2CloudStorageOptions?
Cloud Storage options.
getter/setter pair
datastoreOptions ↔ GooglePrivacyDlpV2DatastoreOptions?
Google Cloud Datastore options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hybridOptions ↔ GooglePrivacyDlpV2HybridOptions?
Hybrid inspection options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timespanConfig ↔ GooglePrivacyDlpV2TimespanConfig?
Configuration of the timespan of the items to include in scanning.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited