GooglePrivacyDlpV2Table class

Structured content to inspect.

Up to 50,000 Values per request allowed. See https://docs.cloud.google.com/sensitive-data-protection/docs/inspecting-structured-text#inspecting_a_table to learn more.

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers ↔ List<GooglePrivacyDlpV2FieldId>?
Headers of the table.
getter/setter pair
rows ↔ List<GooglePrivacyDlpV2Row>?
Rows of the table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited