GooglePrivacyDlpV2TableDataProfile class

The profile for a scanned table.

Constructors

GooglePrivacyDlpV2TableDataProfile({GooglePrivacyDlpV2DataProfileConfigSnapshot? configSnapshot, String? createTime, GooglePrivacyDlpV2DataRiskLevel? dataRiskLevel, GooglePrivacyDlpV2DataSourceType? dataSourceType, String? datasetId, String? datasetLocation, String? datasetProjectId, List<GooglePrivacyDlpV2Domain>? domains, String? encryptionStatus, String? expirationTime, String? failedColumnCount, String? fullResource, String? lastModifiedTime, String? name, List<GooglePrivacyDlpV2OtherInfoTypeSummary>? otherInfoTypes, List<GooglePrivacyDlpV2InfoTypeSummary>? predictedInfoTypes, String? profileLastGenerated, GooglePrivacyDlpV2ProfileStatus? profileStatus, String? projectDataProfile, List<GooglePrivacyDlpV2RelatedResource>? relatedResources, Map<String, String>? resourceLabels, String? resourceVisibility, String? rowCount, GooglePrivacyDlpV2BigQueryTable? sampleFindingsTable, String? scannedColumnCount, GooglePrivacyDlpV2SensitivityScore? sensitivityScore, String? state, String? tableId, String? tableSizeBytes, List<GooglePrivacyDlpV2Tag>? tags})
GooglePrivacyDlpV2TableDataProfile.fromJson(Map json_)

Properties

configSnapshot ↔ GooglePrivacyDlpV2DataProfileConfigSnapshot?
The snapshot of the configurations used to generate the profile.
getter/setter pair
createTime ↔ String?
The time at which the table was created.
getter/setter pair
dataRiskLevel ↔ GooglePrivacyDlpV2DataRiskLevel?
The data risk level of this table.
getter/setter pair
datasetId ↔ String?
If the resource is BigQuery, the dataset ID.
getter/setter pair
datasetLocation ↔ String?
If supported, the location where the dataset's data is stored.
getter/setter pair
datasetProjectId ↔ String?
The Google Cloud project ID that owns the resource.
getter/setter pair
dataSourceType ↔ GooglePrivacyDlpV2DataSourceType?
The resource type that was profiled.
getter/setter pair
domains ↔ List<GooglePrivacyDlpV2Domain>?
Domains associated with the profile.
getter/setter pair
encryptionStatus ↔ String?
How the table is encrypted. Possible string values are:
getter/setter pair
expirationTime ↔ String?
The time when this table expires.
getter/setter pair
failedColumnCount ↔ String?
The number of columns skipped in the table because of an error.
getter/setter pair
fullResource ↔ String?
The Cloud Asset Inventory resource that was profiled in order to generate this TableDataProfile.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedTime ↔ String?
The time when this table was last modified
getter/setter pair
name ↔ String?
The name of the profile.
getter/setter pair
otherInfoTypes ↔ List<GooglePrivacyDlpV2OtherInfoTypeSummary>?
Other infoTypes found in this table's data.
getter/setter pair
predictedInfoTypes ↔ List<GooglePrivacyDlpV2InfoTypeSummary>?
The infoTypes predicted from this table's data.
getter/setter pair
profileLastGenerated ↔ String?
The last time the profile was generated.
getter/setter pair
profileStatus ↔ GooglePrivacyDlpV2ProfileStatus?
Success or error status from the most recent profile generation attempt.
getter/setter pair
projectDataProfile ↔ String?
The resource name of the project data profile for this table.
getter/setter pair
relatedResources ↔ List<GooglePrivacyDlpV2RelatedResource>?
Resources related to this profile.
getter/setter pair
resourceLabels ↔ Map<String, String>?
The labels applied to the resource at the time the profile was generated.
getter/setter pair
resourceVisibility ↔ String?
How broadly a resource has been shared. Possible string values are:
getter/setter pair
rowCount ↔ String?
Number of rows in the table when the profile was generated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleFindingsTable ↔ GooglePrivacyDlpV2BigQueryTable?
The BigQuery table to which the sample findings are written.
getter/setter pair
scannedColumnCount ↔ String?
The number of columns profiled in the table.
getter/setter pair
sensitivityScore ↔ GooglePrivacyDlpV2SensitivityScore?
The sensitivity score of this table.
getter/setter pair
state ↔ String?
State of a profile.
getter/setter pair
tableId ↔ String?
The table ID.
getter/setter pair
tableSizeBytes ↔ String?
The size of the table when the profile was generated.
getter/setter pair
tags ↔ List<GooglePrivacyDlpV2Tag>?
The tags attached to the table, including any tags attached during profiling.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited