GooglePrivacyDlpV2TableOptions class

Instructions regarding the table content being inspected.

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifyingFields ↔ List<GooglePrivacyDlpV2FieldId>?
The columns that are the primary keys for table objects included in ContentItem.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited