GooglePrivacyDlpV2TransformationOverview class

Overview of the modifications that occurred.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transformationSummaries ↔ List<GooglePrivacyDlpV2TransformationSummary>?
Transformations applied to the dataset.
getter/setter pair
transformedBytes ↔ String?
Total size in bytes that were transformed in some way.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited