GooglePrivacyDlpV2UpdateContentPolicyRequest class

Request message for UpdateContentPolicy.

Properties

contentPolicy ↔ GooglePrivacyDlpV2ContentPolicy?
The content_policy with new values for the relevant fields.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask ↔ String?
Mask to control which fields get updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited