GooglePrivacyDlpV2Value class

Set of primitive values supported by the system.

Note that for the purposes of inspection or transformation, the number of bytes considered to comprise a 'Value' is based on its representation as a UTF-8 encoded string. For example, if 'integer_value' is set to 123456789, the number of bytes would be counted as 9, even though an int64 only holds up to 8 bytes of data.

Constructors

GooglePrivacyDlpV2Value({bool? booleanValue, GoogleTypeDate? dateValue, String? dayOfWeekValue, double? floatValue, String? integerValue, String? stringValue, GoogleTypeTimeOfDay? timeValue, String? timestampValue})
GooglePrivacyDlpV2Value.fromJson(Map json_)

Properties

booleanValue ↔ bool?
boolean
getter/setter pair
dateValue ↔ GoogleTypeDate?
date
getter/setter pair
dayOfWeekValue ↔ String?
day of week Possible string values are:
getter/setter pair
floatValue ↔ double?
float
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integerValue ↔ String?
integer
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValue ↔ String?
string
getter/setter pair
timestampValue ↔ String?
timestamp
getter/setter pair
timeValue ↔ GoogleTypeTimeOfDay?
time of day
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited