OrganizationsResource class

Constructors

OrganizationsResource(ApiRequester client)

Properties

deidentifyTemplates → OrganizationsDeidentifyTemplatesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
inspectTemplates → OrganizationsInspectTemplatesResource
no setter
locations → OrganizationsLocationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedInfoTypes → OrganizationsStoredInfoTypesResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited