ProjectsLocationsConnectionsResource class

Constructors

ProjectsLocationsConnectionsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(GooglePrivacyDlpV2CreateConnectionRequest request, String parent, {String? $fields}) → Future<GooglePrivacyDlpV2Connection>
Create a Connection to an external data source.
delete(String name, {String? $fields}) → Future<GoogleProtobufEmpty>
Delete a Connection.
get(String name, {String? $fields}) → Future<GooglePrivacyDlpV2Connection>
Get a Connection by name.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<GooglePrivacyDlpV2ListConnectionsResponse>
Lists Connections in a parent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GooglePrivacyDlpV2UpdateConnectionRequest request, String name, {String? $fields}) → Future<GooglePrivacyDlpV2Connection>
Update a Connection.
Searches for Connections in a parent.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited