create method
Future<GooglePrivacyDlpV2ContentPolicy>
create(
- GooglePrivacyDlpV2CreateContentPolicyRequest request,
- String parent, {
- String? $fields,
Create a ContentPolicy.
request - The metadata request object.
Request parameters:
parent - Required. Parent resource name. The format of this value varies
depending on the scope of the request (project or organization): +
Projects scope: projects/{project_id}/locations/{location_id} +
Organizations scope: organizations/{org_id}/locations/{location_id}
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GooglePrivacyDlpV2ContentPolicy.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GooglePrivacyDlpV2ContentPolicy> create(
GooglePrivacyDlpV2CreateContentPolicyRequest request,
core.String parent, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v2/' + core.Uri.encodeFull('$parent') + '/contentPolicies';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GooglePrivacyDlpV2ContentPolicy.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}