ProjectsResource class

Constructors

ProjectsResource(ApiRequester client)

Properties

content → ProjectsContentResource
no setter
deidentifyTemplates → ProjectsDeidentifyTemplatesResource
no setter
dlpJobs → ProjectsDlpJobsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
image → ProjectsImageResource
no setter
inspectTemplates → ProjectsInspectTemplatesResource
no setter
jobTriggers → ProjectsJobTriggersResource
no setter
locations → ProjectsLocationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storedInfoTypes → ProjectsStoredInfoTypesResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited