ProjectsStoredInfoTypesResource class

Constructors

ProjectsStoredInfoTypesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(GooglePrivacyDlpV2CreateStoredInfoTypeRequest request, String parent, {String? $fields}) → Future<GooglePrivacyDlpV2StoredInfoType>
Creates a pre-built stored infoType to be used for inspection.
delete(String name, {String? $fields}) → Future<GoogleProtobufEmpty>
Deletes a stored infoType.
get(String name, {String? $fields}) → Future<GooglePrivacyDlpV2StoredInfoType>
Gets a stored infoType.
list(String parent, {String? locationId, String? orderBy, int? pageSize, String? pageToken, String? $fields}) → Future<GooglePrivacyDlpV2ListStoredInfoTypesResponse>
Lists stored infoTypes.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GooglePrivacyDlpV2UpdateStoredInfoTypeRequest request, String name, {String? $fields}) → Future<GooglePrivacyDlpV2StoredInfoType>
Updates the stored infoType by creating a new version.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited