ChangesListResponse class

The response to a request to enumerate Changes to a ResourceRecordSets collection.

Constructors

ChangesListResponse({List<Change>? changes, String? kind, String? nextPageToken})
ChangesListResponse.fromJson(Map json_)

Properties

changes ↔ List<Change>?
The requested changes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Type of resource.
getter/setter pair
nextPageToken ↔ String?
This field indicates that more results are available beyond the last page displayed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited