list method
Enumerates Changes to a ResourceRecordSet collection.
Request parameters:
project - Identifies the project addressed by this request.
managedZone - Identifies the managed zone addressed by this request. Can
be the managed zone name or ID.
maxResults - Optional. Maximum number of results to be returned. If
unspecified, the server decides how many results to return.
pageToken - Optional. A tag returned by a previous list request that was
truncated. Use this parameter to continue a previous list request.
sortBy - Sorting criterion. The only supported value is change sequence.
Possible string values are:
- "changeSequence"
sortOrder - Sorting order direction: 'ascending' or 'descending'.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ChangesListResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ChangesListResponse> list(
core.String project,
core.String managedZone, {
core.int? maxResults,
core.String? pageToken,
core.String? sortBy,
core.String? sortOrder,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'maxResults': ?maxResults == null ? null : ['${maxResults}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'sortBy': ?sortBy == null ? null : [sortBy],
'sortOrder': ?sortOrder == null ? null : [sortOrder],
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'dns/v1/projects/' +
commons.escapeVariable('$project') +
'/managedZones/' +
commons.escapeVariable('$managedZone') +
'/changes';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ChangesListResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}