DnsKey class

A DNSSEC key pair.

Constructors

DnsKey({String? algorithm, String? creationTime, String? description, List<DnsKeyDigest>? digests, String? id, bool? isActive, int? keyLength, int? keyTag, String? kind, String? publicKey, String? type})
DnsKey.fromJson(Map json_)

Properties

algorithm ↔ String?
String mnemonic specifying the DNSSEC algorithm of this key.
getter/setter pair
creationTime ↔ String?
The time that this resource was created in the control plane.
getter/setter pair
description ↔ String?
A mutable string of at most 1024 characters associated with this resource for the user's convenience.
getter/setter pair
digests ↔ List<DnsKeyDigest>?
Cryptographic hashes of the DNSKEY resource record associated with this DnsKey.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique identifier for the resource; defined by the server (output only).
getter/setter pair
isActive ↔ bool?
Active keys are used to sign subsequent changes to the ManagedZone.
getter/setter pair
keyLength ↔ int?
Length of the key in bits.
getter/setter pair
keyTag ↔ int?
The key tag is a non-cryptographic hash of the a DNSKEY resource record associated with this DnsKey.
getter/setter pair
kind ↔ String?
getter/setter pair
publicKey ↔ String?
Base64 encoded public half of this key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
One of "KEY_SIGNING" or "ZONE_SIGNING".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited