ManagedZone class

A zone is a subtree of the DNS namespace under one administrative responsibility.

A ManagedZone is a resource that represents a DNS zone hosted by the Cloud DNS service.

Constructors

ManagedZone({ManagedZoneCloudLoggingConfig? cloudLoggingConfig, String? creationTime, String? description, String? dnsName, ManagedZoneDnsSecConfig? dnssecConfig, ManagedZoneForwardingConfig? forwardingConfig, String? id, String? kind, Map<String, String>? labels, String? name, String? nameServerSet, List<String>? nameServers, ManagedZonePeeringConfig? peeringConfig, ManagedZonePrivateVisibilityConfig? privateVisibilityConfig, ManagedZoneReverseLookupConfig? reverseLookupConfig, ManagedZoneServiceDirectoryConfig? serviceDirectoryConfig, String? visibility})
ManagedZone.fromJson(Map json_)

Properties

cloudLoggingConfig ↔ ManagedZoneCloudLoggingConfig?
getter/setter pair
creationTime ↔ String?
The time that this resource was created on the server.
getter/setter pair
description ↔ String?
A mutable string of at most 1024 characters associated with this resource for the user's convenience.
getter/setter pair
dnsName ↔ String?
The DNS name of this managed zone, for instance "example.com.".
getter/setter pair
dnssecConfig ↔ ManagedZoneDnsSecConfig?
DNSSEC configuration.
getter/setter pair
forwardingConfig ↔ ManagedZoneForwardingConfig?
The presence for this field indicates that outbound forwarding is enabled for this zone.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique identifier for the resource; defined by the server (output only)
getter/setter pair
kind ↔ String?
getter/setter pair
labels ↔ Map<String, String>?
User labels.
getter/setter pair
name ↔ String?
User assigned name for this resource.
getter/setter pair
nameServers ↔ List<String>?
Delegate your managed_zone to these virtual name servers; defined by the server (output only)
getter/setter pair
nameServerSet ↔ String?
Optionally specifies the NameServerSet for this ManagedZone.
getter/setter pair
peeringConfig ↔ ManagedZonePeeringConfig?
The presence of this field indicates that DNS Peering is enabled for this zone.
getter/setter pair
privateVisibilityConfig ↔ ManagedZonePrivateVisibilityConfig?
For privately visible zones, the set of Virtual Private Cloud resources that the zone is visible from.
getter/setter pair
reverseLookupConfig ↔ ManagedZoneReverseLookupConfig?
The presence of this field indicates that this is a managed reverse lookup zone and Cloud DNS resolves reverse lookup queries using automatically configured records for VPC resources.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceDirectoryConfig ↔ ManagedZoneServiceDirectoryConfig?
This field links to the associated service directory namespace.
getter/setter pair
visibility ↔ String?
The zone's visibility: public zones are exposed to the Internet, while private zones are visible only to Virtual Private Cloud resources. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited