ManagedZoneDnsSecConfig class

Constructors

ManagedZoneDnsSecConfig({List<DnsKeySpec>? defaultKeySpecs, String? kind, String? nonExistence, String? state})
ManagedZoneDnsSecConfig.fromJson(Map json_)

Properties

defaultKeySpecs ↔ List<DnsKeySpec>?
Specifies parameters for generating initial DnsKeys for this ManagedZone.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
getter/setter pair
nonExistence ↔ String?
Specifies the mechanism for authenticated denial-of-existence responses.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Specifies whether DNSSEC is enabled, and what mode it is in. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited