ManagedZoneForwardingConfigNameServerTarget class

Constructors

ManagedZoneForwardingConfigNameServerTarget({String? domainName, String? forwardingPath, String? ipv4Address, String? ipv6Address, String? kind})
ManagedZoneForwardingConfigNameServerTarget.fromJson(Map json_)

Properties

domainName ↔ String?
Fully qualified domain name for the forwarding target.
getter/setter pair
forwardingPath ↔ String?
Forwarding path for this NameServerTarget.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipv4Address ↔ String?
IPv4 address of a target name server.
getter/setter pair
ipv6Address ↔ String?
IPv6 address of a target name server.
getter/setter pair
kind ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited