ManagedZoneOperationsResource class

Constructors

ManagedZoneOperationsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String project, String managedZone, String operation, {String? clientOperationId, String? $fields}) → Future<Operation>
Fetches the representation of an existing Operation.
list(String project, String managedZone, {int? maxResults, String? pageToken, String? sortBy, String? $fields}) → Future<ManagedZoneOperationsListResponse>
Enumerates Operations for the given ManagedZone.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited