ManagedZonePeeringConfigTargetNetwork class

Properties

deactivateTime ↔ String?
The time at which the zone was deactivated, in RFC 3339 date-time format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
getter/setter pair
networkUrl ↔ String?
The fully qualified URL of the VPC network to forward queries to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited