ManagedZoneServiceDirectoryConfig class

Contains information about Service Directory-backed zones.

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
getter/setter pair
namespace ↔ ManagedZoneServiceDirectoryConfigNamespace?
Contains information about the namespace associated with the zone.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited