list method
Enumerates ManagedZones that have been created but not yet deleted.
Request parameters:
project - Identifies the project addressed by this request.
dnsName - Restricts the list to return only zones with this domain name.
maxResults - Optional. Maximum number of results to be returned. If
unspecified, the server decides how many results to return.
pageToken - Optional. A tag returned by a previous list request that was
truncated. Use this parameter to continue a previous list request.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ManagedZonesListResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ManagedZonesListResponse> list(
core.String project, {
core.String? dnsName,
core.int? maxResults,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'dnsName': ?dnsName == null ? null : [dnsName],
'maxResults': ?maxResults == null ? null : ['${maxResults}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'dns/v1/projects/' +
commons.escapeVariable('$project') +
'/managedZones';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ManagedZonesListResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}