Operation class

An operation represents a successful mutation performed on a Cloud DNS resource.

Operations provide: - An audit log of server resource mutations. - A way to recover/retry API calls in the case where the response is never received by the caller. Use the caller specified client_operation_id.

Constructors

Operation({OperationDnsKeyContext? dnsKeyContext, String? id, String? kind, String? startTime, String? status, String? type, String? user, OperationManagedZoneContext? zoneContext})
Operation.fromJson(Map json_)

Properties

dnsKeyContext ↔ OperationDnsKeyContext?
Only populated if the operation targeted a DnsKey (output only).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Unique identifier for the resource.
getter/setter pair
kind ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time that this operation was started by the server.
getter/setter pair
status ↔ String?
Status of the operation.
getter/setter pair
type ↔ String?
Type of the operation.
getter/setter pair
user ↔ String?
User who requested the operation, for example: user@example.com.
getter/setter pair
zoneContext ↔ OperationManagedZoneContext?
Only populated if the operation targeted a ManagedZone (output only).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited