Project class

A project resource.

The project is a top level container for resources including Cloud DNS ManagedZones. Projects can be created only in the APIs console.

Constructors

Project({String? id, String? kind, String? number, Quota? quota})
Project.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
User assigned unique identifier for the resource (output only).
getter/setter pair
kind ↔ String?
getter/setter pair
number ↔ String?
Unique numeric identifier for the resource; defined by the server (output only).
getter/setter pair
quota ↔ Quota?
Quotas assigned to this project (output only).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited