RRSetRoutingPolicyLoadBalancerTarget class

The configuration for an individual load balancer to health check.

Constructors

RRSetRoutingPolicyLoadBalancerTarget({String? ipAddress, String? ipProtocol, String? kind, String? loadBalancerType, String? networkUrl, String? port, String? project, String? region})
RRSetRoutingPolicyLoadBalancerTarget.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String?
The frontend IP address of the load balancer to health check.
getter/setter pair
ipProtocol ↔ String?
The protocol of the load balancer to health check. Possible string values are:
getter/setter pair
kind ↔ String?
getter/setter pair
loadBalancerType ↔ String?
The type of load balancer specified by this target.
getter/setter pair
networkUrl ↔ String?
The fully qualified URL of the network that the load balancer is attached to.
getter/setter pair
port ↔ String?
The configured port of the load balancer.
getter/setter pair
project ↔ String?
The project ID in which the load balancer is located.
getter/setter pair
region ↔ String?
The region in which the load balancer is located.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited