AutoText class

A ParagraphElement representing a spot in the text that's dynamically replaced with content that can change over time, like a page number.

Constructors

AutoText({List<String>? suggestedDeletionIds, List<String>? suggestedInsertionIds, Map<String, SuggestedTextStyle>? suggestedTextStyleChanges, TextStyle? textStyle, String? type})
AutoText.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedDeletionIds ↔ List<String>?
The suggested deletion IDs.
getter/setter pair
suggestedInsertionIds ↔ List<String>?
The suggested insertion IDs.
getter/setter pair
suggestedTextStyleChanges ↔ Map<String, SuggestedTextStyle>?
The suggested text style changes to this AutoText, keyed by suggestion ID.
getter/setter pair
textStyle ↔ TextStyle?
The text style of this AutoText.
getter/setter pair
type ↔ String?
The type of this auto text. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited