CreateFootnoteRequest class

Creates a Footnote segment and inserts a new FootnoteReference to it at the given location.

The new Footnote segment will contain a space followed by a newline character.

Constructors

CreateFootnoteRequest({EndOfSegmentLocation? endOfSegmentLocation, Location? location})
CreateFootnoteRequest.fromJson(Map json_)

Properties

endOfSegmentLocation ↔ EndOfSegmentLocation?
Inserts the footnote reference at the end of the document body.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ Location?
Inserts the footnote reference at a specific index in the document.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited