CropProperties class

The crop properties of an image.

The crop rectangle is represented using fractional offsets from the original content's 4 edges. - If the offset is in the interval (0, 1), the corresponding edge of crop rectangle is positioned inside of the image's original bounding rectangle. - If the offset is negative or greater than 1, the corresponding edge of crop rectangle is positioned outside of the image's original bounding rectangle. - If all offsets and rotation angles are 0, the image is not cropped.

Constructors

CropProperties({double? angle, double? offsetBottom, double? offsetLeft, double? offsetRight, double? offsetTop})
CropProperties.fromJson(Map json_)

Properties

angle ↔ double?
The clockwise rotation angle of the crop rectangle around its center, in radians.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offsetBottom ↔ double?
The offset specifies how far inwards the bottom edge of the crop rectangle is from the bottom edge of the original content as a fraction of the original content's height.
getter/setter pair
offsetLeft ↔ double?
The offset specifies how far inwards the left edge of the crop rectangle is from the left edge of the original content as a fraction of the original content's width.
getter/setter pair
offsetRight ↔ double?
The offset specifies how far inwards the right edge of the crop rectangle is from the right edge of the original content as a fraction of the original content's width.
getter/setter pair
offsetTop ↔ double?
The offset specifies how far inwards the top edge of the crop rectangle is from the top edge of the original content as a fraction of the original content's height.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited