CropPropertiesSuggestionState class

A mask that indicates which of the fields on the base CropProperties have been changed in this suggestion.

For any field set to true, there's a new suggested value.

Constructors

CropPropertiesSuggestionState({bool? angleSuggested, bool? offsetBottomSuggested, bool? offsetLeftSuggested, bool? offsetRightSuggested, bool? offsetTopSuggested})
CropPropertiesSuggestionState.fromJson(Map json_)

Properties

angleSuggested ↔ bool?
Indicates if there was a suggested change to angle.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
offsetBottomSuggested ↔ bool?
Indicates if there was a suggested change to offset_bottom.
getter/setter pair
offsetLeftSuggested ↔ bool?
Indicates if there was a suggested change to offset_left.
getter/setter pair
offsetRightSuggested ↔ bool?
Indicates if there was a suggested change to offset_right.
getter/setter pair
offsetTopSuggested ↔ bool?
Indicates if there was a suggested change to offset_top.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited