DateElementProperties class

Properties of a DateElement.

Constructors

DateElementProperties({String? dateFormat, String? displayText, String? locale, String? timeFormat, String? timeZoneId, String? timestamp})
DateElementProperties.fromJson(Map json_)

Properties

dateFormat String?
Determines how the date part of the DateElement will be displayed in the document.
getter/setter pair
displayText String?
Indicates how the DateElement is displayed in the document.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
locale String?
The language code of the DateElement.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeFormat String?
Determines how the time part of the DateElement will be displayed in the document.
getter/setter pair
timestamp String?
The point in time to represent, in seconds and nanoseconds since Unix epoch: January 1, 1970 at midnight UTC.
getter/setter pair
timeZoneId String?
The time zone of the DateElement, as defined by the Unicode Common Locale Data Repository (CLDR) project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited