DeleteNamedRangeRequest class

Deletes a NamedRange.

Constructors

DeleteNamedRangeRequest({String? name, String? namedRangeId, TabsCriteria? tabsCriteria})
DeleteNamedRangeRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the range(s) to delete.
getter/setter pair
namedRangeId ↔ String?
The ID of the named range to delete.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabsCriteria ↔ TabsCriteria?
The criteria used to specify which tab(s) the range deletion should occur in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited