DocumentStyle class

The style of the document.

Constructors

DocumentStyle({Background? background, String? defaultFooterId, String? defaultHeaderId, DocumentFormat? documentFormat, String? evenPageFooterId, String? evenPageHeaderId, String? firstPageFooterId, String? firstPageHeaderId, bool? flipPageOrientation, Dimension? marginBottom, Dimension? marginFooter, Dimension? marginHeader, Dimension? marginLeft, Dimension? marginRight, Dimension? marginTop, int? pageNumberStart, Size? pageSize, bool? useCustomHeaderFooterMargins, bool? useEvenPageHeaderFooter, bool? useFirstPageHeaderFooter})
DocumentStyle.fromJson(Map json_)

Properties

background ↔ Background?
The background of the document.
getter/setter pair
defaultFooterId ↔ String?
The ID of the default footer.
getter/setter pair
defaultHeaderId ↔ String?
The ID of the default header.
getter/setter pair
documentFormat ↔ DocumentFormat?
Specifies document-level format settings, such as the document mode (pages vs pageless).
getter/setter pair
evenPageFooterId ↔ String?
The ID of the footer used only for even pages.
getter/setter pair
evenPageHeaderId ↔ String?
The ID of the header used only for even pages.
getter/setter pair
firstPageFooterId ↔ String?
The ID of the footer used only for the first page.
getter/setter pair
firstPageHeaderId ↔ String?
The ID of the header used only for the first page.
getter/setter pair
flipPageOrientation ↔ bool?
Indicates whether to flip the dimensions of the page_size, which allows changing the page orientation between portrait and landscape.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
marginBottom ↔ Dimension?
The bottom page margin.
getter/setter pair
marginFooter ↔ Dimension?
The amount of space between the bottom of the page and the contents of the footer.
getter/setter pair
marginHeader ↔ Dimension?
The amount of space between the top of the page and the contents of the header.
getter/setter pair
marginLeft ↔ Dimension?
The left page margin.
getter/setter pair
marginRight ↔ Dimension?
The right page margin.
getter/setter pair
marginTop ↔ Dimension?
The top page margin.
getter/setter pair
pageNumberStart ↔ int?
The page number from which to start counting the number of pages.
getter/setter pair
pageSize ↔ Size?
The size of a page in the document.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useCustomHeaderFooterMargins ↔ bool?
Indicates whether DocumentStyle margin_header, SectionStyle margin_header and DocumentStyle margin_footer, SectionStyle margin_footer are respected.
getter/setter pair
useEvenPageHeaderFooter ↔ bool?
Indicates whether to use the even page header / footer IDs for the even pages.
getter/setter pair
useFirstPageHeaderFooter ↔ bool?
Indicates whether to use the first page header / footer IDs for the first page.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited