FootnoteReference class

A ParagraphElement representing a footnote reference.

A footnote reference is the inline content rendered with a number and is used to identify the footnote.

Constructors

FootnoteReference({String? footnoteId, String? footnoteNumber, List<String>? suggestedDeletionIds, List<String>? suggestedInsertionIds, Map<String, SuggestedTextStyle>? suggestedTextStyleChanges, TextStyle? textStyle})
FootnoteReference.fromJson(Map json_)

Properties

footnoteId ↔ String?
The ID of the footnote that contains the content of this footnote reference.
getter/setter pair
footnoteNumber ↔ String?
The rendered number of this footnote.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedDeletionIds ↔ List<String>?
The suggested deletion IDs.
getter/setter pair
suggestedInsertionIds ↔ List<String>?
The suggested insertion IDs.
getter/setter pair
suggestedTextStyleChanges ↔ Map<String, SuggestedTextStyle>?
The suggested text style changes to this FootnoteReference, keyed by suggestion ID.
getter/setter pair
textStyle ↔ TextStyle?
The text style of this FootnoteReference.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited