ImageProperties class

The properties of an image.

Constructors

ImageProperties({double? angle, double? brightness, String? contentUri, double? contrast, CropProperties? cropProperties, String? sourceUri, double? transparency})
ImageProperties.fromJson(Map json_)

Properties

angle ↔ double?
The clockwise rotation angle of the image, in radians.
getter/setter pair
brightness ↔ double?
The brightness effect of the image.
getter/setter pair
contentUri ↔ String?
A URI to the image with a default lifetime of 30 minutes.
getter/setter pair
contrast ↔ double?
The contrast effect of the image.
getter/setter pair
cropProperties ↔ CropProperties?
The crop properties of the image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceUri ↔ String?
The source URI is the URI used to insert the image.
getter/setter pair
transparency ↔ double?
The transparency effect of the image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited