location property

Location? location
getter/setter pair

Inserts the rich link at a specific index in the document.

The rich link must be inserted inside the bounds of an existing Paragraph. For instance, it cannot be inserted at a table's start index (i.e. between the table and its preceding paragraph). The rich link cannot be inserted inside an equation.

Implementation

Location? location;