InsertTableRequest class

Inserts a table at the specified location.

A newline character will be inserted before the inserted table.

Constructors

InsertTableRequest({int? columns, EndOfSegmentLocation? endOfSegmentLocation, Location? location, int? rows})
InsertTableRequest.fromJson(Map json_)

Properties

columns ↔ int?
The number of columns in the table.
getter/setter pair
endOfSegmentLocation ↔ EndOfSegmentLocation?
Inserts the table at the end of the given header, footer or document body.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ Location?
Inserts the table at a specific model index.
getter/setter pair
rows ↔ int?
The number of rows in the table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited