Link class

A reference to another portion of a document or an external URL resource.

Constructors

Link({BookmarkLink? bookmark, String? bookmarkId, HeadingLink? heading, String? headingId, String? tabId, String? url})
Link.fromJson(Map json_)

Properties

bookmark ↔ BookmarkLink?
A bookmark in this document.
getter/setter pair
bookmarkId ↔ String?
The ID of a bookmark in this document.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heading ↔ HeadingLink?
A heading in this document.
getter/setter pair
headingId ↔ String?
The ID of a heading in this document.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabId ↔ String?
The ID of a tab in this document.
getter/setter pair
url ↔ String?
An external URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited