List class

A List represents the list attributes for a group of paragraphs that all belong to the same list.

A paragraph that's part of a list has a reference to the list's ID in its bullet.

Constructors

List({ListProperties? listProperties, List<String>? suggestedDeletionIds, String? suggestedInsertionId, Map<String, SuggestedListProperties>? suggestedListPropertiesChanges})
List.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
listProperties ↔ ListProperties?
The properties of the list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedDeletionIds ↔ List<String>?
The suggested deletion IDs.
getter/setter pair
suggestedInsertionId ↔ String?
The suggested insertion ID.
getter/setter pair
suggestedListPropertiesChanges ↔ Map<String, SuggestedListProperties>?
The suggested changes to the list properties, keyed by suggestion ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited