NamedStyle class

A named style.

Paragraphs in the document can inherit their TextStyle and ParagraphStyle from this named style when they have the same named style type.

Constructors

NamedStyle({String? namedStyleType, ParagraphStyle? paragraphStyle, TextStyle? textStyle})
NamedStyle.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
namedStyleType ↔ String?
The type of this named style. Possible string values are:
getter/setter pair
paragraphStyle ↔ ParagraphStyle?
The paragraph style of this named style.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textStyle ↔ TextStyle?
The text style of this named style.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited