PersonProperties class

Properties specific to a linked Person.

Constructors

PersonProperties({String? email, String? name})
PersonProperties.fromJson(Map json_)

Properties

email ↔ String?
The email address linked to this Person.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the person if it's displayed in the link text instead of the person's email address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited