Range class

Specifies a contiguous range of text.

Constructors

Range({int? endIndex, String? segmentId, int? startIndex, String? tabId})
Range.fromJson(Map json_)

Properties

endIndex ↔ int?
The zero-based end index of this range, exclusive, in UTF-16 code units.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentId ↔ String?
The ID of the header, footer, or footnote that this range is contained in.
getter/setter pair
startIndex ↔ int?
The zero-based start index of this range, in UTF-16 code units.
getter/setter pair
tabId ↔ String?
The tab that contains this range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited