ReplaceImageRequest class

Replaces an existing image with a new image.

Replacing an image removes some image effects from the existing image in order to mirror the behavior of the Docs editor.

Constructors

ReplaceImageRequest({String? imageObjectId, String? imageReplaceMethod, String? tabId, String? uri})
ReplaceImageRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageObjectId ↔ String?
The ID of the existing image that will be replaced.
getter/setter pair
imageReplaceMethod ↔ String?
The replacement method. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabId ↔ String?
The tab that the image to be replaced is in.
getter/setter pair
uri ↔ String?
The URI of the new image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited