SectionStyle class

The styling that applies to a section.

Constructors

SectionStyle({List<SectionColumnProperties>? columnProperties, String? columnSeparatorStyle, String? contentDirection, String? defaultFooterId, String? defaultHeaderId, String? evenPageFooterId, String? evenPageHeaderId, String? firstPageFooterId, String? firstPageHeaderId, bool? flipPageOrientation, Dimension? marginBottom, Dimension? marginFooter, Dimension? marginHeader, Dimension? marginLeft, Dimension? marginRight, Dimension? marginTop, int? pageNumberStart, String? sectionType, bool? useFirstPageHeaderFooter})
SectionStyle.fromJson(Map json_)

Properties

columnProperties ↔ List<SectionColumnProperties>?
The section's columns properties.
getter/setter pair
columnSeparatorStyle ↔ String?
The style of column separators.
getter/setter pair
contentDirection ↔ String?
The content direction of this section.
getter/setter pair
defaultFooterId ↔ String?
The ID of the default footer.
getter/setter pair
defaultHeaderId ↔ String?
The ID of the default header.
getter/setter pair
evenPageFooterId ↔ String?
The ID of the footer used only for even pages.
getter/setter pair
evenPageHeaderId ↔ String?
The ID of the header used only for even pages.
getter/setter pair
firstPageFooterId ↔ String?
The ID of the footer used only for the first page of the section.
getter/setter pair
firstPageHeaderId ↔ String?
The ID of the header used only for the first page of the section.
getter/setter pair
flipPageOrientation ↔ bool?
Indicates whether to flip the dimensions of DocumentStyle's page_size for this section, which allows changing the page orientation between portrait and landscape.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
marginBottom ↔ Dimension?
The bottom page margin of the section.
getter/setter pair
marginFooter ↔ Dimension?
The footer margin of the section.
getter/setter pair
marginHeader ↔ Dimension?
The header margin of the section.
getter/setter pair
marginLeft ↔ Dimension?
The left page margin of the section.
getter/setter pair
marginRight ↔ Dimension?
The right page margin of the section.
getter/setter pair
marginTop ↔ Dimension?
The top page margin of the section.
getter/setter pair
pageNumberStart ↔ int?
The page number from which to start counting the number of pages for this section.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionType ↔ String?
The type of section.
getter/setter pair
useFirstPageHeaderFooter ↔ bool?
Indicates whether to use the first page header / footer IDs for the first page of the section.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited