SizeSuggestionState class

A mask that indicates which of the fields on the base Size have been changed in this suggestion.

For any field set to true, the Size has a new suggested value.

Constructors

SizeSuggestionState({bool? heightSuggested, bool? widthSuggested})
SizeSuggestionState.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
heightSuggested ↔ bool?
Indicates if there was a suggested change to height.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widthSuggested ↔ bool?
Indicates if there was a suggested change to width.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited