SubstringMatchCriteria class

A criteria that matches a specific string of text in the document.

Constructors

SubstringMatchCriteria({bool? matchCase, bool? searchByRegex, String? text})
SubstringMatchCriteria.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchCase ↔ bool?
Indicates whether the search should respect case: - True: the search is case sensitive.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchByRegex ↔ bool?
True if the find value should be treated as a regular expression.
getter/setter pair
text ↔ String?
The text to search for in the document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited