Tab class

A tab in a document.

Constructors

Tab({List<Tab>? childTabs, DocumentTab? documentTab, TabProperties? tabProperties})
Tab.fromJson(Map json_)

Properties

childTabs ↔ List<Tab>?
The child tabs nested within this tab.
getter/setter pair
documentTab ↔ DocumentTab?
A tab with document contents, like text and images.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabProperties ↔ TabProperties?
The properties of the tab, like ID and title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited