TabProperties class

Properties of a tab.

Constructors

TabProperties({String? iconEmoji, int? index, int? nestingLevel, String? parentTabId, String? tabId, String? title})
TabProperties.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
iconEmoji ↔ String?
The emoji icon displayed with the tab.
getter/setter pair
index ↔ int?
The zero-based index of the tab within the parent.
getter/setter pair
nestingLevel ↔ int?
The depth of the tab within the document.
getter/setter pair
parentTabId ↔ String?
The ID of the parent tab.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabId ↔ String?
The immutable ID of the tab.
getter/setter pair
title ↔ String?
The user-visible name of the tab.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited