TableCellLocation class

Location of a single cell within a table.

Constructors

TableCellLocation({int? columnIndex, int? rowIndex, Location? tableStartLocation})
TableCellLocation.fromJson(Map json_)

Properties

columnIndex ↔ int?
The zero-based column index.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rowIndex ↔ int?
The zero-based row index.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableStartLocation ↔ Location?
The location where the table starts in the document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited