TableOfContents class

A StructuralElement representing a table of contents.

Constructors

TableOfContents({List<StructuralElement>? content, List<String>? suggestedDeletionIds, List<String>? suggestedInsertionIds})
TableOfContents.fromJson(Map json_)

Properties

content ↔ List<StructuralElement>?
The content of the table of contents.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedDeletionIds ↔ List<String>?
The suggested deletion IDs.
getter/setter pair
suggestedInsertionIds ↔ List<String>?
The suggested insertion IDs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited