TableRow class

The contents and style of a row in a Table.

Constructors

TableRow({int? endIndex, int? startIndex, List<String>? suggestedDeletionIds, List<String>? suggestedInsertionIds, Map<String, SuggestedTableRowStyle>? suggestedTableRowStyleChanges, List<TableCell>? tableCells, TableRowStyle? tableRowStyle})
TableRow.fromJson(Map json_)

Properties

endIndex ↔ int?
The zero-based end index of this row, exclusive, in UTF-16 code units.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex ↔ int?
The zero-based start index of this row, in UTF-16 code units.
getter/setter pair
suggestedDeletionIds ↔ List<String>?
The suggested deletion IDs.
getter/setter pair
suggestedInsertionIds ↔ List<String>?
The suggested insertion IDs.
getter/setter pair
suggestedTableRowStyleChanges ↔ Map<String, SuggestedTableRowStyle>?
The suggested style changes to this row, keyed by suggestion ID.
getter/setter pair
tableCells ↔ List<TableCell>?
The contents and style of each cell in this row.
getter/setter pair
tableRowStyle ↔ TableRowStyle?
The style of the table row.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited