TextRun class

A ParagraphElement that represents a run of text that all has the same styling.

Constructors

TextRun({String? content, List<String>? suggestedDeletionIds, List<String>? suggestedInsertionIds, Map<String, SuggestedTextStyle>? suggestedTextStyleChanges, TextStyle? textStyle})
TextRun.fromJson(Map json_)

Properties

content ↔ String?
The text of this run.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedDeletionIds ↔ List<String>?
The suggested deletion IDs.
getter/setter pair
suggestedInsertionIds ↔ List<String>?
The suggested insertion IDs.
getter/setter pair
suggestedTextStyleChanges ↔ Map<String, SuggestedTextStyle>?
The suggested text style changes to this run, keyed by suggestion ID.
getter/setter pair
textStyle ↔ TextStyle?
The text style of this run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited