UpdateDocumentStyleRequest class

Updates the DocumentStyle.

Constructors

UpdateDocumentStyleRequest({DocumentStyle? documentStyle, String? fields, String? tabId})
UpdateDocumentStyleRequest.fromJson(Map json_)

Properties

documentStyle ↔ DocumentStyle?
The styles to set on the document.
getter/setter pair
fields ↔ String?
The fields that should be updated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tabId ↔ String?
The tab that contains the style to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited