UpdateTableCellStyleRequest class

Updates the style of a range of table cells.

Constructors

UpdateTableCellStyleRequest({String? fields, TableCellStyle? tableCellStyle, TableRange? tableRange, Location? tableStartLocation})
UpdateTableCellStyleRequest.fromJson(Map json_)

Properties

fields ↔ String?
The fields that should be updated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableCellStyle ↔ TableCellStyle?
The style to set on the table cells.
getter/setter pair
tableRange ↔ TableRange?
The table range representing the subset of the table to which the updates are applied.
getter/setter pair
tableStartLocation ↔ Location?
The location where the table starts in the document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited