DocumentApi class

Service to parse structured information from unstructured or semi-structured documents using state-of-the-art Google AI such as natural language, computer vision, translation, and AutoML.

Constructors

DocumentApi(Client client, {String rootUrl = 'https://documentai.googleapis.com/', String servicePath = ''})

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations → OperationsResource
no setter
projects → ProjectsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

cloudPlatformScope → const String
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.