blobAssetId property
Asset ID of the inline image.
If set, find the image content in the blob_assets field.
Optional.
Implementation
core.String? blobAssetId;
Asset ID of the inline image.
If set, find the image content in the blob_assets field.
Optional.
core.String? blobAssetId;