dataUri property
Data URI of the image.
It is composed of four parts: a prefix (data:), a MIME type indicating the type of data, an optional base64 token if non-textual, and the data itself: data:,
Optional.
Implementation
core.String? dataUri;
Data URI of the image.
It is composed of four parts: a prefix (data:), a MIME type indicating the type of data, an optional base64 token if non-textual, and the data itself: data:,
Optional.
core.String? dataUri;