rule property
The name of the rule resource that is used for validation.
Format: projects/{project}/locations/{location}/rules/{rule}
Optional.
Implementation
core.String? rule;
The name of the rule resource that is used for validation.
Format: projects/{project}/locations/{location}/rules/{rule}
Optional.
core.String? rule;