validationDetails property

String? validationDetails
getter/setter pair

The detailed information of the running the validation process using the entity from the document based on the validation rule.

Implementation

core.String? validationDetails;