baseSchemaVersion property
The base schema version name to use for the schema generation.
Format:
projects/{project}/locations/{location}/schemas/{schema}/schemaVersions/{schema_version}
Implementation
core.String? baseSchemaVersion;
The base schema version name to use for the schema generation.
Format:
projects/{project}/locations/{location}/schemas/{schema}/schemaVersions/{schema_version}
core.String? baseSchemaVersion;