GoogleCloudDocumentaiV1ListSchemaVersionsResponse class
Response message for ListSchemaVersions.
Constructors
-
GoogleCloudDocumentaiV1ListSchemaVersionsResponse({String? nextPageToken, List<
GoogleCloudDocumentaiV1SchemaVersion> ? schemaVersions}) - GoogleCloudDocumentaiV1ListSchemaVersionsResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
Points to the next SchemaVersion, otherwise empty.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schemaVersions
↔ List<
GoogleCloudDocumentaiV1SchemaVersion> ? -
The list of SchemaVersions.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited