GoogleCloudDocumentaiV1ListSchemasResponse class
Response message for ListSchemas.
Constructors
-
GoogleCloudDocumentaiV1ListSchemasResponse({String? nextPageToken, List<
GoogleCloudDocumentaiV1NextSchema> ? schemas}) - GoogleCloudDocumentaiV1ListSchemasResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
Points to the next Schema, otherwise empty.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schemas
↔ List<
GoogleCloudDocumentaiV1NextSchema> ? -
The list of Schemas.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited