GoogleCloudDocumentaiV1NextSchema class

NextSchema is a collection of SchemaVersions.

Constructors

GoogleCloudDocumentaiV1NextSchema({String? createTime, String? displayName, Map<String, String>? labels, String? name, String? updateTime})
GoogleCloudDocumentaiV1NextSchema.fromJson(Map json_)

Properties

createTime String?
The time when the Schema was created.
getter/setter pair
displayName String?
The user-defined name of the Schema.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
The GCP labels for the Schema.
getter/setter pair
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTime String?
The time when the Schema was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited