enableImageAnnotation property
Whether to include image annotations in layout parser response.
Optional.
Implementation
core.bool? enableImageAnnotation;
Whether to include image annotations in layout parser response.
Optional.
core.bool? enableImageAnnotation;