GoogleCloudDocumentaiV1ProcessOptionsLayoutConfigChunkingConfig class

Serving config for chunking.

Properties

chunkSize ↔ int?
The chunk sizes to use when splitting documents, in order of level.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeAncestorHeadings ↔ bool?
Whether or not to include ancestor headings when splitting.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited