previousFineTunedProcessorVersionName property
Resource name of a previously fine tuned version ID to copy the overwritten configs from.
The base_processor_version should be newer than the base processor version
used to fine tune this provided processor version. Format:
projects/{project}/locations/{location}/processors/{processor}/processorVersions/{processorVersion}.
Optional.
Implementation
core.String? previousFineTunedProcessorVersionName;