ProjectsLocationsProcessorsHumanReviewConfigResource class

Annotations
  • @Deprecated('Not supported. Member documentation may have more information.')

Constructors

ProjectsLocationsProcessorsHumanReviewConfigResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reviewDocument(GoogleCloudDocumentaiV1ReviewDocumentRequest request, String humanReviewConfig, {String? $fields}) → Future<GoogleLongrunningOperation>
Send a document for Human Review.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited