validateOnly property
If set, validates the request without actually updating the management settings.
Optional.
Implementation
core.bool? validateOnly;
If set, validates the request without actually updating the management settings.
Optional.
core.bool? validateOnly;