DomainForwarding class

Domain forwarding configuration.

Constructors

DomainForwarding({bool? pathForwarding, String? pemCertificate, String? redirectType, bool? sslEnabled, String? subdomain, String? targetUri})
DomainForwarding.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pathForwarding ↔ bool?
If true, forwards the path after the domain name to the same path at the new address.
getter/setter pair
pemCertificate ↔ String?
The PEM-encoded certificate chain.
getter/setter pair
redirectType ↔ String?
The redirect type. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sslEnabled ↔ bool?
If true, the forwarding works also over HTTPS.
getter/setter pair
subdomain ↔ String?
The subdomain of the registered domain that is being forwarded.
getter/setter pair
targetUri ↔ String?
The target of the domain forwarding, i.e. the path to redirect the subdomain to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited