EmailForwarding class

Email forwarding configuration.

Constructors

EmailForwarding({String? alias, String? targetEmailAddress})
EmailForwarding.fromJson(Map json_)

Properties

alias ↔ String?
An alias recipient email that forwards emails to the target_email_address.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetEmailAddress ↔ String?
Target email that receives emails sent to the alias.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited