ImportDomainRequest class

Deprecated: For more information, see Cloud Domains feature deprecation.

Request for the ImportDomain method.

Constructors

ImportDomainRequest({String? domainName, Map<String, String>? labels})
ImportDomainRequest.fromJson(Map json_)

Properties

domainName ↔ String?
The domain name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Set of labels associated with the Registration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited