ResourceRecordSet class

A unit of data that is returned by the DNS servers.

Constructors

ResourceRecordSet({String? name, RRSetRoutingPolicy? routingPolicy, List<String>? rrdata, List<String>? signatureRrdata, int? ttl, String? type})
ResourceRecordSet.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
For example, www.example.com.
getter/setter pair
routingPolicy ↔ RRSetRoutingPolicy?
Configures dynamic query responses based on either the geo location of the querying user or a weighted round robin based routing policy.
getter/setter pair
rrdata ↔ List<String>?
As defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1) -- see examples.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatureRrdata ↔ List<String>?
As defined in RFC 4034 (section 3.2).
getter/setter pair
ttl ↔ int?
Number of seconds that this ResourceRecordSet can be cached by resolvers.
getter/setter pair
type ↔ String?
The identifier of a supported record type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited