TransferDomainRequest class

Deprecated: For more information, see Cloud Domains feature deprecation.

Request for the TransferDomain method.

Constructors

TransferDomainRequest({AuthorizationCode? authorizationCode, List<String>? contactNotices, Registration? registration, bool? validateOnly, Money? yearlyPrice})
TransferDomainRequest.fromJson(Map json_)

Properties

authorizationCode ↔ AuthorizationCode?
The domain's transfer authorization code.
getter/setter pair
contactNotices ↔ List<String>?
The list of contact notices that you acknowledge.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
registration ↔ Registration?
The complete Registration resource to be created.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
Validate the request without actually transferring the domain.
getter/setter pair
yearlyPrice ↔ Money?
Acknowledgement of the price to transfer or renew the domain for one year.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited