TransferParameters class

Deprecated: For more information, see Cloud Domains feature deprecation.

Parameters required to transfer a domain from another registrar.

Constructors

TransferParameters({String? currentRegistrar, String? currentRegistrarUri, String? domainName, List<String>? nameServers, List<String>? supportedPrivacy, String? transferLockState, Money? yearlyPrice})
TransferParameters.fromJson(Map json_)

Properties

currentRegistrar ↔ String?
The registrar that currently manages the domain.
getter/setter pair
currentRegistrarUri ↔ String?
The URL of the registrar that currently manages the domain.
getter/setter pair
domainName ↔ String?
The domain name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nameServers ↔ List<String>?
The name servers that currently store the configuration of the domain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedPrivacy ↔ List<String>?
Contact privacy options that the domain supports.
getter/setter pair
transferLockState ↔ String?
Indicates whether the domain is protected by a transfer lock.
getter/setter pair
yearlyPrice ↔ Money?
Price to transfer or renew the domain for one year.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited