DataRange class

The date range to be reported on.

Constructors

DataRange({Date? customEndDate, Date? customStartDate, String? range})
DataRange.fromJson(Map json_)

Properties

customEndDate ↔ Date?
If CUSTOM_DATES is assigned to range, this field specifies the end date for the date range that is reported on.
getter/setter pair
customStartDate ↔ Date?
If CUSTOM_DATES is assigned to range, this field specifies the starting date for the date range that is reported on.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
range ↔ String?
The preset date range to be reported on.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited