Parameters class

Parameters of a generated report.

Constructors

Parameters({List<FilterPair>? filters, List<String>? groupBys, List<String>? metrics, Options? options, String? type})
Parameters.fromJson(Map json_)

Properties

filters ↔ List<FilterPair>?
Filters to limit the scope of reported data.
getter/setter pair
groupBys ↔ List<String>?
Dimensions by which to segment and group the data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ List<String>?
Metrics to define the data populating the report.
getter/setter pair
options ↔ Options?
Additional report parameter options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the report.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited