QueriesResource class

Constructors

QueriesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
reports → QueriesReportsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Query request, {String? $fields}) → Future<Query>
Creates a new query.
delete(String queryId, {String? $fields}) → Future<void>
Deletes an existing query as well as its generated reports.
get(String queryId, {String? $fields}) → Future<Query>
Retrieves a query.
list({String? orderBy, int? pageSize, String? pageToken, String? $fields}) → Future<ListQueriesResponse>
Lists queries created by the current user.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(RunQueryRequest request, String queryId, {bool? synchronous, String? $fields}) → Future<Report>
Runs an existing query to generate a report.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited