Query class

A single query used to generate a report.

Constructors

Query({QueryMetadata? metadata, Parameters? params, String? queryId, QuerySchedule? schedule})
Query.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ QueryMetadata?
The metadata of the query.
getter/setter pair
params ↔ Parameters?
The parameters of the report generated by the query.
getter/setter pair
queryId ↔ String?
The unique ID of the query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schedule ↔ QuerySchedule?
When and how often the query is scheduled to run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited