QueryMetadata class

The metadata of the query.

Constructors

QueryMetadata({DataRange? dataRange, String? format, bool? sendNotification, List<String>? shareEmailAddress, String? title})
QueryMetadata.fromJson(Map json_)

Properties

dataRange ↔ DataRange?
The date range the report generated by the query will report on.
getter/setter pair
format ↔ String?
The format of the report generated by the query. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendNotification ↔ bool?
Whether an email notification is sent to the query creator when a report generated by the query is ready.
getter/setter pair
shareEmailAddress ↔ List<String>?
List of additional email addresses with which to share the query.
getter/setter pair
title ↔ String?
The display name of the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited