QuerySchedule class

Settings on when and how frequently to run a query.

Constructors

QuerySchedule({Date? endDate, String? frequency, String? nextRunTimezoneCode, Date? startDate})
QuerySchedule.fromJson(Map json_)

Properties

endDate ↔ Date?
The date on which to end the scheduled runs.
getter/setter pair
frequency ↔ String?
How frequently to run the query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextRunTimezoneCode ↔ String?
The canonical code for the timezone the query schedule is based on.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ Date?
The date on which to begin the scheduled runs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited