Report class

A single report generated by its parent report.

Constructors

Report({ReportKey? key, ReportMetadata? metadata, Parameters? params})
Report.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ ReportKey?
The key information identifying the report.
getter/setter pair
metadata ↔ ReportMetadata?
The metadata of the report.
getter/setter pair
params ↔ Parameters?
The parameters of the report.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited