ReportMetadata class

The metadata of a report.

Constructors

ReportMetadata({String? googleCloudStoragePath, Date? reportDataEndDate, Date? reportDataStartDate, ReportStatus? status})
ReportMetadata.fromJson(Map json_)

Properties

googleCloudStoragePath ↔ String?
The location of the generated report file in Google Cloud Storage.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reportDataEndDate ↔ Date?
The end date of the report data date range.
getter/setter pair
reportDataStartDate ↔ Date?
The start date of the report data date range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ ReportStatus?
The status of the report.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited