RunQueryRequest class

Details specifying how to run a query.

Constructors

RunQueryRequest({DataRange? dataRange})
RunQueryRequest.fromJson(Map json_)

Properties

dataRange ↔ DataRange?
The date range used by the query to generate the report.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited