Availability class

A message containing availability data relevant to DoubleClick Search.

Constructors

Availability({String? advertiserId, String? agencyId, String? availabilityTimestamp, String? customerId, String? segmentationId, String? segmentationName, String? segmentationType})
Availability.fromJson(Map json_)

Properties

advertiserId ↔ String?
DS advertiser ID.
getter/setter pair
agencyId ↔ String?
DS agency ID.
getter/setter pair
availabilityTimestamp ↔ String?
The time by which all conversions have been uploaded, in epoch millis UTC.
getter/setter pair
customerId ↔ String?
Customer ID of a client account in the new Search Ads 360 experience.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentationId ↔ String?
The numeric segmentation identifier (for example, DoubleClick Search Floodlight activity ID).
getter/setter pair
segmentationName ↔ String?
The friendly segmentation identifier (for example, DoubleClick Search Floodlight activity name).
getter/setter pair
segmentationType ↔ String?
The segmentation type that this availability is for (its default value is FLOODLIGHT).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited