Conversion class

A conversion containing data relevant to DoubleClick Search.

Common DS3 API conversion fields: Id Range [1 - 2800]. Next Id to use: 33

Constructors

Conversion({String? adGroupId, String? adId, String? adUserDataConsent, String? advertiserId, String? agencyId, String? attributionModel, String? campaignId, String? channel, String? clickId, String? conversionId, String? conversionModifiedTimestamp, String? conversionTimestamp, String? countMillis, String? criterionId, String? currencyCode, List<CustomDimension>? customDimension, List<CustomMetric>? customMetric, String? customerId, String? deviceType, String? dsConversionId, String? engineAccountId, String? floodlightOrderId, String? inventoryAccountId, String? productCountry, String? productGroupId, String? productId, String? productLanguage, String? quantityMillis, String? revenueMicros, String? segmentationId, String? segmentationName, String? segmentationType, String? state, String? storeId, String? type})
Conversion.fromJson(Map json_)

Properties

adGroupId ↔ String?
DS ad group ID.
getter/setter pair
adId ↔ String?
DS ad ID.
getter/setter pair
adUserDataConsent ↔ String?
Represents consent for core platform services (CPS) preferences in settings.
getter/setter pair
advertiserId ↔ String?
DS advertiser ID.
getter/setter pair
agencyId ↔ String?
DS agency ID.
getter/setter pair
attributionModel ↔ String?
Available to advertisers only after contacting DoubleClick Search customer support.
getter/setter pair
campaignId ↔ String?
DS campaign ID.
getter/setter pair
channel ↔ String?
Sales channel for the product.
getter/setter pair
clickId ↔ String?
DS click ID for the conversion.
getter/setter pair
conversionId ↔ String?
For offline conversions, advertisers provide this ID.
getter/setter pair
conversionModifiedTimestamp ↔ String?
The time at which the conversion was last modified, in epoch millis UTC.
getter/setter pair
conversionTimestamp ↔ String?
The time at which the conversion took place, in epoch millis UTC.
getter/setter pair
countMillis ↔ String?
Available to advertisers only after contacting DoubleClick Search customer support.
getter/setter pair
criterionId ↔ String?
DS criterion (keyword) ID.
getter/setter pair
currencyCode ↔ String?
The currency code for the conversion's revenue.
getter/setter pair
customDimension ↔ List<CustomDimension>?
Custom dimensions for the conversion, which can be used to filter data in a report.
getter/setter pair
customerId ↔ String?
Customer ID of a client account in the new Search Ads 360 experience.
getter/setter pair
customMetric ↔ List<CustomMetric>?
Custom metrics for the conversion.
getter/setter pair
deviceType ↔ String?
The type of device on which the conversion occurred.
getter/setter pair
dsConversionId ↔ String?
ID that DoubleClick Search generates for each conversion.
getter/setter pair
engineAccountId ↔ String?
DS engine account ID.
getter/setter pair
floodlightOrderId ↔ String?
The Floodlight order ID provided by the advertiser for the conversion.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inventoryAccountId ↔ String?
ID that DS generates and uses to uniquely identify the inventory account that contains the product.
getter/setter pair
productCountry ↔ String?
The country registered for the Merchant Center feed that contains the product.
getter/setter pair
productGroupId ↔ String?
DS product group ID.
getter/setter pair
productId ↔ String?
The product ID (SKU).
getter/setter pair
productLanguage ↔ String?
The language registered for the Merchant Center feed that contains the product.
getter/setter pair
quantityMillis ↔ String?
The quantity of this conversion, in millis.
getter/setter pair
revenueMicros ↔ String?
The revenue amount of this TRANSACTION conversion, in micros (value multiplied by 1000000, no decimal).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentationId ↔ String?
The numeric segmentation identifier (for example, DoubleClick Search Floodlight activity ID).
getter/setter pair
segmentationName ↔ String?
The friendly segmentation identifier (for example, DoubleClick Search Floodlight activity name).
getter/setter pair
segmentationType ↔ String?
The segmentation type of this conversion (for example, FLOODLIGHT).
getter/setter pair
state ↔ String?
The state of the conversion, that is, either ACTIVE or REMOVED.
getter/setter pair
storeId ↔ String?
The ID of the local store for which the product was advertised.
getter/setter pair
type ↔ String?
The type of the conversion, that is, either ACTION or TRANSACTION.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited