Report class

A DoubleClick Search report.

This object contains the report request, some report metadata such as currency code, and the generated report rows or report files.

Constructors

Report({List<ReportFiles>? files, String? id, bool? isReportReady, String? kind, ReportRequest? request, int? rowCount, List<ReportRow>? rows, String? statisticsCurrencyCode, String? statisticsTimeZone})
Report.fromJson(Map json_)

Properties

files ↔ List<ReportFiles>?
Asynchronous report only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Asynchronous report only.
getter/setter pair
isReportReady ↔ bool?
Asynchronous report only.
getter/setter pair
kind ↔ String?
Identifies this as a Report resource.
getter/setter pair
request ↔ ReportRequest?
The request that created the report.
getter/setter pair
rowCount ↔ int?
The number of report rows generated by the report, not including headers.
getter/setter pair
rows ↔ List<ReportRow>?
Synchronous report only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statisticsCurrencyCode ↔ String?
The currency code of all monetary values produced in the report, including values that are set by users (e.g., keyword bid settings) and metrics (e.g., cost and revenue).
getter/setter pair
statisticsTimeZone ↔ String?
If all statistics of the report are sourced from the same time zone, this would be it.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited