ReportFiles class

Constructors

ReportFiles({String? byteCount, String? url})
ReportFiles.fromJson(Map json_)

Properties

byteCount ↔ String?
The size of this report file in bytes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
Use this url to download the report file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited