ReportRequest class

A request object used to create a DoubleClick Search report.

Constructors

ReportRequest({List<ReportApiColumnSpec>? columns, String? downloadFormat, List<ReportRequestFilters>? filters, bool? includeDeletedEntities, bool? includeRemovedEntities, int? maxRowsPerFile, List<ReportRequestOrderBy>? orderBy, ReportRequestReportScope? reportScope, String? reportType, int? rowCount, int? startRow, String? statisticsCurrency, ReportRequestTimeRange? timeRange, bool? verifySingleTimeZone})
ReportRequest.fromJson(Map json_)

Properties

columns ↔ List<ReportApiColumnSpec>?
The columns to include in the report.
getter/setter pair
downloadFormat ↔ String?
Format that the report should be returned in.
getter/setter pair
filters ↔ List<ReportRequestFilters>?
A list of filters to be applied to the report.\ The maximum number of filters per request is 300.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeDeletedEntities ↔ bool?
Determines if removed entities should be included in the report.
getter/setter pair
includeRemovedEntities ↔ bool?
Determines if removed entities should be included in the report.
getter/setter pair
maxRowsPerFile ↔ int?
Asynchronous report only.
getter/setter pair
orderBy ↔ List<ReportRequestOrderBy>?
Synchronous report only.
getter/setter pair
reportScope ↔ ReportRequestReportScope?
The reportScope is a set of IDs that are used to determine which subset of entities will be returned in the report.
getter/setter pair
reportType ↔ String?
Determines the type of rows that are returned in the report.
getter/setter pair
rowCount ↔ int?
Synchronous report only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startRow ↔ int?
Synchronous report only.
getter/setter pair
statisticsCurrency ↔ String?
Specifies the currency in which monetary will be returned.
getter/setter pair
timeRange ↔ ReportRequestTimeRange?
If metrics are requested in a report, this argument will be used to restrict the metrics to a specific time range.
getter/setter pair
verifySingleTimeZone ↔ bool?
If true, the report would only be created if all the requested stat data are sourced from a single timezone.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited