ReportRequestReportScope class

The reportScope is a set of IDs that are used to determine which subset of entities will be returned in the report.

The full lineage of IDs from the lowest scoped level desired up through agency is required.

Constructors

ReportRequestReportScope({String? adGroupId, String? adId, String? advertiserId, String? agencyId, String? campaignId, String? engineAccountId, String? keywordId})
ReportRequestReportScope.fromJson(Map json_)

Properties

adGroupId ↔ String?
DS ad group ID.
getter/setter pair
adId ↔ String?
DS ad ID.
getter/setter pair
advertiserId ↔ String?
DS advertiser ID.
getter/setter pair
agencyId ↔ String?
DS agency ID.
getter/setter pair
campaignId ↔ String?
DS campaign ID.
getter/setter pair
engineAccountId ↔ String?
DS engine account ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keywordId ↔ String?
DS keyword ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited