SavedColumn class

A saved column

Constructors

SavedColumn({String? kind, String? savedColumnName, String? type})
SavedColumn.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies this as a SavedColumn resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
savedColumnName ↔ String?
The name of the saved column.
getter/setter pair
type ↔ String?
The type of data this saved column will produce.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited