AboutFeatures class

Constructors

AboutFeatures({String? featureName, double? featureRate})
AboutFeatures.fromJson(Map json_)

Properties

featureName ↔ String?
The name of the feature.
getter/setter pair
featureRate ↔ double?
The request limit rate for this feature, in queries per second.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited