AppList class

A list of third-party applications which the user has installed or given access to Google Drive.

Constructors

AppList({List<String>? defaultAppIds, String? etag, List<App>? items, String? kind, String? selfLink})
AppList.fromJson(Map json_)

Properties

defaultAppIds ↔ List<String>?
List of app IDs that the user has specified to use by default.
getter/setter pair
etag ↔ String?
The ETag of the list.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<App>?
The list of apps.
getter/setter pair
kind ↔ String?
This is always drive#appList.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
A link back to this list.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited