ChildrenResource class

Constructors

ChildrenResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String folderId, String childId, {bool? enforceSingleParent, String? $fields}) → Future<void>
Removes a child from a folder.
get(String folderId, String childId, {String? $fields}) → Future<ChildReference>
Gets a specific child reference.
insert(ChildReference request, String folderId, {bool? enforceSingleParent, bool? supportsAllDrives, bool? supportsTeamDrives, String? $fields}) → Future<ChildReference>
Inserts a file into a folder.
list(String folderId, {int? maxResults, String? orderBy, String? pageToken, String? q, String? $fields}) → Future<ChildList>
Lists a folder's children.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited