CommentContext class

Context of a file which is being commented on.

Constructors

CommentContext({String? type, String? value})
CommentContext.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The MIME type of the context snippet.
getter/setter pair
value ↔ String?
Data representation of the segment of the file being commented on.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited