CommentReply class

A reply to a comment on a file in Google Drive.

Constructors

CommentReply({User? author, String? content, DateTime? createdDate, bool? deleted, String? htmlContent, String? kind, DateTime? modifiedDate, String? replyId, String? verb})
CommentReply.fromJson(Map json_)

Properties

author ↔ User?
The user who wrote this reply.
getter/setter pair
content ↔ String?
The plain text content used to create this reply.
getter/setter pair
createdDate ↔ DateTime?
The date when this reply was first created.
getter/setter pair
deleted ↔ bool?
Whether this reply has been deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
htmlContent ↔ String?
HTML formatted content for this reply.
getter/setter pair
kind ↔ String?
This is always drive#commentReply.
getter/setter pair
modifiedDate ↔ DateTime?
The date when this reply was last modified.
getter/setter pair
replyId ↔ String?
The ID of the reply.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
verb ↔ String?
The action this reply performed to the parent comment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited