ContentRestriction class

A restriction for accessing the content of the file.

Constructors

ContentRestriction({bool? ownerRestricted, bool? readOnly, String? reason, User? restrictingUser, DateTime? restrictionDate, bool? systemRestricted, String? type})
ContentRestriction.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ownerRestricted ↔ bool?
Whether the content restriction can only be modified or removed by a user who owns the file.
getter/setter pair
readOnly ↔ bool?
Whether the content of the file is read-only.
getter/setter pair
reason ↔ String?
Reason for why the content of the file is restricted.
getter/setter pair
restrictingUser ↔ User?
The user who set the content restriction.
getter/setter pair
restrictionDate ↔ DateTime?
The time at which the content restriction was set (formatted RFC 3339 timestamp).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemRestricted ↔ bool?
Whether the content restriction was applied by the system, for example due to an esignature.
getter/setter pair
type ↔ String?
The type of the content restriction.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited