DriveApi class

The Google Drive API allows clients to access resources from Google Drive.

Constructors

DriveApi(Client client, {String rootUrl = 'https://www.googleapis.com/', String servicePath = 'drive/v2/'})

Properties

about → AboutResource
no setter
apps → AppsResource
no setter
changes → ChangesResource
no setter
channels → ChannelsResource
no setter
children → ChildrenResource
no setter
comments → CommentsResource
no setter
drives → DrivesResource
no setter
files → FilesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
parents → ParentsResource
no setter
permissions → PermissionsResource
no setter
properties → PropertiesResource
no setter
replies → RepliesResource
no setter
revisions → RevisionsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamdrives → TeamdrivesResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

driveAppdataScope → const String
See, create, and delete its own configuration data in your Google Drive
driveAppsReadonlyScope → const String
View your Google Drive apps
driveFileScope → const String
See, edit, create, and delete only the specific Google Drive files you use with this app
driveMeetReadonlyScope → const String
See and download your Google Drive files that were created or edited by Google Meet.
driveMetadataReadonlyScope → const String
See information about your Google Drive files
driveMetadataScope → const String
View and manage metadata of files in your Google Drive
drivePhotosReadonlyScope → const String
View the photos, videos and albums in your Google Photos
driveReadonlyScope → const String
See and download all your Google Drive files
driveScope → const String
See, edit, create, and delete all of your Google Drive files
driveScriptsScope → const String
Modify your Google Apps Script scripts' behavior