DriveCapabilities class

Capabilities the current user has on this shared drive.

Output only.

Constructors

DriveCapabilities({bool? canAddChildren, bool? canChangeCopyRequiresWriterPermissionRestriction, bool? canChangeDomainUsersOnlyRestriction, bool? canChangeDriveBackground, bool? canChangeDriveMembersOnlyRestriction, bool? canChangeSharingFoldersRequiresOrganizerPermissionRestriction, bool? canComment, bool? canCopy, bool? canDeleteChildren, bool? canDeleteDrive, bool? canDownload, bool? canEdit, bool? canListChildren, bool? canManageMembers, bool? canReadRevisions, bool? canRename, bool? canRenameDrive, bool? canResetDriveRestrictions, bool? canShare, bool? canTrashChildren})
DriveCapabilities.fromJson(Map json_)

Properties

canAddChildren ↔ bool?
Whether the current user can add children to folders in this shared drive.
getter/setter pair
canChangeCopyRequiresWriterPermissionRestriction ↔ bool?
Whether the current user can change the copyRequiresWriterPermission restriction of this shared drive.
getter/setter pair
canChangeDomainUsersOnlyRestriction ↔ bool?
Whether the current user can change the domainUsersOnly restriction of this shared drive.
getter/setter pair
canChangeDriveBackground ↔ bool?
Whether the current user can change the background of this shared drive.
getter/setter pair
canChangeDriveMembersOnlyRestriction ↔ bool?
Whether the current user can change the driveMembersOnly restriction of this shared drive.
getter/setter pair
canChangeSharingFoldersRequiresOrganizerPermissionRestriction ↔ bool?
Whether the current user can change the sharingFoldersRequiresOrganizerPermission restriction of this shared drive.
getter/setter pair
canComment ↔ bool?
Whether the current user can comment on files in this shared drive.
getter/setter pair
canCopy ↔ bool?
Whether the current user can copy files in this shared drive.
getter/setter pair
canDeleteChildren ↔ bool?
Whether the current user can delete children from folders in this shared drive.
getter/setter pair
canDeleteDrive ↔ bool?
Whether the current user can delete this shared drive.
getter/setter pair
canDownload ↔ bool?
Whether the current user can download files in this shared drive.
getter/setter pair
canEdit ↔ bool?
Whether the current user can edit files in this shared drive
getter/setter pair
canListChildren ↔ bool?
Whether the current user can list the children of folders in this shared drive.
getter/setter pair
canManageMembers ↔ bool?
Whether the current user can add members to this shared drive or remove them or change their role.
getter/setter pair
canReadRevisions ↔ bool?
Whether the current user can read the revisions resource of files in this shared drive.
getter/setter pair
canRename ↔ bool?
Whether the current user can rename files or folders in this shared drive.
getter/setter pair
canRenameDrive ↔ bool?
Whether the current user can rename this shared drive.
getter/setter pair
canResetDriveRestrictions ↔ bool?
Whether the current user can reset the shared drive restrictions to defaults.
getter/setter pair
canShare ↔ bool?
Whether the current user can share files or folders in this shared drive.
getter/setter pair
canTrashChildren ↔ bool?
Whether the current user can trash children from folders in this shared drive.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited