DriveList class

A list of shared drives.

Constructors

DriveList({List<Drive>? items, String? kind, String? nextPageToken})
DriveList.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Drive>?
The list of shared drives.
getter/setter pair
kind ↔ String?
This is always drive#driveList
getter/setter pair
nextPageToken ↔ String?
The page token for the next page of shared drives.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited