DriveRestrictions class

A set of restrictions that apply to this shared drive or items inside this shared drive.

Constructors

DriveRestrictions({bool? adminManagedRestrictions, bool? copyRequiresWriterPermission, bool? domainUsersOnly, bool? driveMembersOnly, bool? sharingFoldersRequiresOrganizerPermission})
DriveRestrictions.fromJson(Map json_)

Properties

adminManagedRestrictions ↔ bool?
Whether administrative privileges on this shared drive are required to modify restrictions.
getter/setter pair
copyRequiresWriterPermission ↔ bool?
Whether the options to copy, print, or download files inside this shared drive, should be disabled for readers and commenters.
getter/setter pair
domainUsersOnly ↔ bool?
Whether access to this shared drive and items inside this shared drive is restricted to users of the domain to which this shared drive belongs.
getter/setter pair
driveMembersOnly ↔ bool?
Whether access to items inside this shared drive is restricted to its members.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharingFoldersRequiresOrganizerPermission ↔ bool?
If true, only users with the organizer role can share folders.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited