FileLabelInfo class

An overview of the labels on the file.

Output only.

Constructors

FileLabelInfo({List<Label>? labels})
FileLabelInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
labels ↔ List<Label>?
The set of labels on the file as requested by the label IDs in the includeLabels parameter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited