FileLinkShareMetadata class

Contains details about the link URLs that clients are using to refer to this item.

Constructors

FileLinkShareMetadata({bool? securityUpdateEligible, bool? securityUpdateEnabled})
FileLinkShareMetadata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityUpdateEligible ↔ bool?
Whether the file is eligible for security update.
getter/setter pair
securityUpdateEnabled ↔ bool?
Whether the security update is enabled for this file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited