FileThumbnail class

A thumbnail for the file.

This will only be used if a standard thumbnail cannot be generated.

Constructors

FileThumbnail({String? image, String? mimeType})
FileThumbnail.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
The URL-safe Base64 encoded bytes of the thumbnail image.
getter/setter pair
imageAsBytes ↔ List<int>
getter/setter pair
mimeType ↔ String?
The MIME type of the thumbnail.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited