GeneratedIds class

A list of generated IDs which can be provided in insert requests

Constructors

GeneratedIds({List<String>? ids, String? kind, String? space})
GeneratedIds.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ids ↔ List<String>?
The IDs generated for the requesting user in the specified space.
getter/setter pair
kind ↔ String?
This is always drive#generatedIds
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space ↔ String?
The type of file that can be created with these IDs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited