Label class

Representation of a label and label fields.

Constructors

Label({Map<String, LabelField>? fields, String? id, String? kind, String? revisionId})
Label.fromJson(Map json_)

Properties

fields ↔ Map<String, LabelField>?
A map of the fields on the label, keyed by the field's ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the label.
getter/setter pair
kind ↔ String?
This is always drive#label
getter/setter pair
revisionId ↔ String?
The revision ID of the label.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited