LabelField class

Representation of field, which is a typed key-value pair.

Constructors

LabelField({List<DateTime>? dateString, String? id, List<String>? integer, String? kind, List<String>? selection, List<String>? text, List<User>? user, String? valueType})
LabelField.fromJson(Map json_)

Properties

dateString ↔ List<DateTime>?
Only present if valueType is dateString.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The identifier of this label field.
getter/setter pair
integer ↔ List<String>?
Only present if valueType is integer.
getter/setter pair
kind ↔ String?
This is always drive#labelField.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selection ↔ List<String>?
Only present if valueType is selection
getter/setter pair
text ↔ List<String>?
Only present if valueType is text.
getter/setter pair
user ↔ List<User>?
Only present if valueType is user.
getter/setter pair
valueType ↔ String?
The field type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited