Permission class

A permission for a file.

A permission grants a user, group, domain, or the world access to a file or a folder hierarchy. Some resource methods (such as permissions.update) require a permissionId. Use the permissions.list method to retrieve the ID for a file, folder, or shared drive.

Constructors

Permission({List<String>? additionalRoles, String? authKey, bool? deleted, String? domain, String? emailAddress, String? etag, DateTime? expirationDate, String? id, bool? inheritedPermissionsDisabled, String? kind, String? name, bool? pendingOwner, List<PermissionPermissionDetails>? permissionDetails, String? photoLink, String? role, String? selfLink, List<PermissionTeamDrivePermissionDetails>? teamDrivePermissionDetails, String? type, String? value, String? view, bool? withLink})
Permission.fromJson(Map json_)

Properties

additionalRoles ↔ List<String>?
Additional roles for this user.
getter/setter pair
authKey ↔ String?
Deprecated.
getter/setter pair
deleted ↔ bool?
Whether the account associated with this permission has been deleted.
getter/setter pair
domain ↔ String?
The domain name of the entity this permission refers to.
getter/setter pair
emailAddress ↔ String?
The email address of the user or group this permission refers to.
getter/setter pair
etag ↔ String?
The ETag of the permission.
getter/setter pair
expirationDate ↔ DateTime?
The time at which this permission will expire (RFC 3339 date-time).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the user this permission refers to, and identical to the permissionId in the About and Files resources.
getter/setter pair
inheritedPermissionsDisabled ↔ bool?
When true, only organizers, owners, and users with permissions added directly on the item can access it.
getter/setter pair
kind ↔ String?
This is always drive#permission.
getter/setter pair
name ↔ String?
The name for this permission.
getter/setter pair
pendingOwner ↔ bool?
Whether the account associated with this permission is a pending owner.
getter/setter pair
permissionDetails ↔ List<PermissionPermissionDetails>?
Details of whether the permissions on this item are inherited or directly on this item.
getter/setter pair
A link to the profile photo, if available.
getter/setter pair
role ↔ String?
The primary role for this user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
A link back to this permission.
getter/setter pair
teamDrivePermissionDetails ↔ List<PermissionTeamDrivePermissionDetails>?
Deprecated: Use permissionDetails instead.
getter/setter pair
type ↔ String?
The account type.
getter/setter pair
value ↔ String?
The email address or domain name for the entity.
getter/setter pair
view ↔ String?
Indicates the view for this permission.
getter/setter pair
Whether the link is required for this permission.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited