Revision class

A revision of a file.

Some resource methods (such as revisions.update) require a revisionId. Use the revisions.list method to retrieve the ID for a revision.

Constructors

Revision({String? downloadUrl, String? etag, Map<String, String>? exportLinks, String? fileSize, String? id, String? kind, User? lastModifyingUser, String? lastModifyingUserName, String? md5Checksum, String? mimeType, DateTime? modifiedDate, String? originalFilename, bool? pinned, bool? publishAuto, bool? published, String? publishedLink, bool? publishedOutsideDomain, String? selfLink})
Revision.fromJson(Map json_)

Properties

downloadUrl ↔ String?
Short term download URL for the file.
getter/setter pair
etag ↔ String?
The ETag of the revision.
getter/setter pair
Links for exporting Docs Editors files to specific formats.
getter/setter pair
fileSize ↔ String?
The size of the revision in bytes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the revision.
getter/setter pair
kind ↔ String?
This is always drive#revision.
getter/setter pair
lastModifyingUser ↔ User?
The last user to modify this revision.
getter/setter pair
lastModifyingUserName ↔ String?
Name of the last user to modify this revision.
getter/setter pair
md5Checksum ↔ String?
An MD5 checksum for the content of this revision.
getter/setter pair
mimeType ↔ String?
The MIME type of the revision.
getter/setter pair
modifiedDate ↔ DateTime?
Last time this revision was modified (formatted RFC 3339 timestamp).
getter/setter pair
originalFilename ↔ String?
The original filename when this revision was created.
getter/setter pair
pinned ↔ bool?
Whether this revision is pinned to prevent automatic purging.
getter/setter pair
publishAuto ↔ bool?
Whether subsequent revisions will be automatically republished.
getter/setter pair
published ↔ bool?
Whether this revision is published.
getter/setter pair
A link to the published revision.
getter/setter pair
publishedOutsideDomain ↔ bool?
Whether this revision is published outside the domain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
A link back to this revision.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited