TeamDriveRestrictions class

A set of restrictions that apply to this Team Drive or items inside this Team Drive.

Constructors

TeamDriveRestrictions({bool? adminManagedRestrictions, bool? copyRequiresWriterPermission, bool? domainUsersOnly, bool? sharingFoldersRequiresOrganizerPermission, bool? teamMembersOnly})
TeamDriveRestrictions.fromJson(Map json_)

Properties

adminManagedRestrictions ↔ bool?
Whether administrative privileges on this Team Drive are required to modify restrictions.
getter/setter pair
copyRequiresWriterPermission ↔ bool?
Whether the options to copy, print, or download files inside this Team Drive, should be disabled for readers and commenters.
getter/setter pair
domainUsersOnly ↔ bool?
Whether access to this Team Drive and items inside this Team Drive is restricted to users of the domain to which this Team Drive belongs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharingFoldersRequiresOrganizerPermission ↔ bool?
If true, only users with the organizer role can share folders.
getter/setter pair
teamMembersOnly ↔ bool?
Whether access to items inside this Team Drive is restricted to members of this Team Drive.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited