User class

Information about a Drive user.

Constructors

User({String? displayName, String? emailAddress, bool? isAuthenticatedUser, String? kind, String? permissionId, UserPicture? picture})
User.fromJson(Map json_)

Properties

displayName ↔ String?
A plain text displayable name for this user.
getter/setter pair
emailAddress ↔ String?
The email address of the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAuthenticatedUser ↔ bool?
Whether this user is the same as the authenticated user for whom the request was made.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
permissionId ↔ String?
The user's ID as visible in Permission resources.
getter/setter pair
picture ↔ UserPicture?
The user's profile picture.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited