drive/v3 library

Google Drive API - v3

The Google Drive API allows clients to access resources from Google Drive.

For more information, see developers.google.com/workspace/drive/

Create an instance of DriveApi to access these resources:

Classes

About
Information about the user, the user's Drive, and system capabilities.
AboutDriveThemes
AboutResource
AboutStorageQuota
The user's storage quota limits and usage.
AboutTeamDriveThemes
AccessProposal
Manage outstanding access proposals on a file.
AccessProposalRoleAndView
A wrapper for the role and view of an access proposal.
AccessproposalsResource
AddReviewer
Representation of a reviewer addition.
App
The apps resource provides a list of apps that a user has installed, with information about each app's supported MIME types, file extensions, and other details.
AppIcons
AppList
A list of third-party applications which the user has installed or given access to Google Drive.
Approval
Metadata for an approval.
ApprovalList
The response of an approvals list request.
ApprovalsResource
AppsResource
ByteRange
Specifies a range of media.
CancelApprovalRequest
Request for cancelling an approval as an initiator.
Change
A change to a file or shared drive.
ChangeList
A list of changes for a user.
ChangesResource
ChannelsResource
ClientEncryptionDetails
Details about the client-side encryption applied to the file.
Comment
A comment on a file.
CommentApprovalRequest
Request for commenting on an approval.
CommentList
A list of comments on a file.
CommentQuotedFileContent
The file content to which the comment refers, typically within the anchor region.
CommentsResource
ContentRestriction
A restriction for accessing the content of the file.
DownloadOptions
Represents options for downloading media.
DownloadRestriction
A restriction for copy and download of the file.
DownloadRestrictionsMetadata
Download restrictions applied to the file.
Drive
Representation of a shared drive.
DriveApi
The Google Drive API allows clients to access resources from Google Drive.
DriveBackgroundImageFile
An image file and cropping parameters from which a background image for this shared drive is set.
DriveCapabilities
Capabilities the current user has on this shared drive.
DriveList
A list of shared drives.
DriveRestrictions
A set of restrictions that apply to this shared drive or items inside this shared drive.
DrivesResource
File
The metadata for a file.
FileCapabilities
Capabilities the current user has on this file.
FileContentHints
Additional information about the content of the file.
FileContentHintsThumbnail
A thumbnail for the file.
FileImageMediaMetadata
Additional metadata about image media, if available.
FileImageMediaMetadataLocation
Geographic location information stored in the image.
FileLabelInfo
Label information on the file.
FileLinkShareMetadata
Contains details about the link URLs that clients are using to refer to this item.
FileList
A list of files.
FileShortcutDetails
Information about a shortcut file.
FilesResource
FileVideoMediaMetadata
Additional metadata about video media.
GeneratedIds
A list of generated file IDs which can be provided in create requests.
Label
Representation of label and label fields.
LabelField
Representation of field, which is a typed key-value pair.
LabelFieldModification
A modification to a label's field.
LabelList
A list of labels applied to a file.
LabelModification
A modification to a label on a file.
ListAccessProposalsResponse
The response to an access proposal list request.
Media
Represents a media consisting of a stream of bytes, a content type and a length.
ModifyLabelsRequest
A request to modify the set of labels on a file.
ModifyLabelsResponse
Response to a ModifyLabels request.
Operation
This resource represents a long-running operation that is the result of a network API call.
OperationsResource
PartialDownloadOptions
Options for downloading a Media.
Permission
A permission for a file.
PermissionList
A list of permissions for a file.
PermissionPermissionDetails
PermissionsResource
PermissionTeamDrivePermissionDetails
ReassignApprovalRequest
Request for reassigning an approval.
ReplaceReviewer
Representation of a reviewer replacement.
RepliesResource
Reply
A reply to a comment on a file.
ReplyList
A list of replies to a comment on a file.
ResolveAccessProposalRequest
Request message for resolving an AccessProposal on a file.
ResumableUploadOptions
Specifies options for resumable uploads.
ReviewerResponse
A response on an approval made by a specific reviewer.
Revision
The metadata for a revision to a file.
RevisionList
A list of revisions of a file.
RevisionsResource
StartApprovalRequest
Allows creating an approval on a file.
StartPageToken
TeamDrive
Deprecated: use the drive collection instead.
TeamDriveBackgroundImageFile
The background image file for a Team Drive.
TeamDriveCapabilities
Capabilities the current user has on this Team Drive.
TeamDriveList
A list of Team Drives.
TeamDriveRestrictions
A set of restrictions that apply to this Team Drive or items inside this Team Drive.
TeamdrivesResource
UploadOptions
Represents options for uploading a Media.
User
Information about a Drive user.

Typedefs

ApproveApprovalRequest = $ApprovalRequest
Request for approving an approval as a reviewer.
Channel = $Channel01
A notification channel used to watch for resource changes.
DeclineApprovalRequest = $ApprovalRequest
Request for declining an approval as a reviewer.
DecryptionMetadata = $DecryptionMetadata
Representation of the CSE DecryptionMetadata.
GenerateCseTokenResponse = $GenerateCseTokenResponse
JWT and associated metadata used to generate CSE files.
Status = $Status00
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.