AccessProposal class

Manage outstanding access proposals on a file.

Constructors

AccessProposal({String? createTime, String? fileId, String? proposalId, String? recipientEmailAddress, String? requestMessage, String? requesterEmailAddress, List<AccessProposalRoleAndView>? rolesAndViews})
AccessProposal.fromJson(Map json_)

Properties

createTime ↔ String?
The creation time.
getter/setter pair
fileId ↔ String?
The file ID that the proposal for access is on.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
proposalId ↔ String?
The ID of the access proposal.
getter/setter pair
recipientEmailAddress ↔ String?
The email address of the user that will receive permissions, if accepted.
getter/setter pair
requesterEmailAddress ↔ String?
The email address of the requesting user.
getter/setter pair
requestMessage ↔ String?
The message that the requester added to the proposal.
getter/setter pair
rolesAndViews ↔ List<AccessProposalRoleAndView>?
A wrapper for the role and view of an access proposal.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited