AppIcons class

Constructors

AppIcons({String? category, String? iconUrl, int? size})
AppIcons.fromJson(Map json_)

Properties

category ↔ String?
Category of the icon.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconUrl ↔ String?
URL for the icon.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
Size of the icon.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited