Approval class

Metadata for an approval.

An approval is a review or approve process for a Drive item.

Constructors

Approval({String? approvalId, String? completeTime, String? createTime, String? dueTime, String? fileContentChangeBehavior, User? initiator, String? kind, String? modifyTime, List<ReviewerResponse>? reviewerResponses, String? status, String? targetFileId})
Approval.fromJson(Map json_)

Properties

approvalId ↔ String?
The approval ID.
getter/setter pair
completeTime ↔ String?
The time the approval was completed.
getter/setter pair
createTime ↔ String?
The time the approval was created.
getter/setter pair
dueTime ↔ String?
The time that the approval is due.
getter/setter pair
fileContentChangeBehavior ↔ String?
The behavior of the approval when the file content changes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initiator ↔ User?
The user that requested the approval.
getter/setter pair
kind ↔ String?
This is always drive#approval.
getter/setter pair
modifyTime ↔ String?
The most recent time the approval was modified.
getter/setter pair
reviewerResponses ↔ List<ReviewerResponse>?
The responses made on the approval by reviewers.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status of the approval at the time this resource was requested.
getter/setter pair
targetFileId ↔ String?
Target file id of the approval.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited