reassign method

Future<Approval> reassign(
  1. ReassignApprovalRequest request,
  2. String fileId,
  3. String approvalId, {
  4. String? $fields,
})

Reassigns the reviewers on an approval.

For more information, see Manage approvals. Adds or replaces reviewers in the ReviewerResponse of the approval. This can be called by any user with the writer permission on the file while the approval Status is IN_PROGRESS and the Response for the reviewer being reassigned is NO_RESPONSE. A user with the reader permission can only reassign an approval that's assigned to themselves. Removing a reviewer isn't allowed.

request - The metadata request object.

Request parameters:

fileId - Required. The ID of the file that the approval is on.

approvalId - Required. The ID of the approval to reassign.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Approval.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Approval> reassign(
  ReassignApprovalRequest request,
  core.String fileId,
  core.String approvalId, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'files/' +
      commons.escapeVariable('$fileId') +
      '/approvals/' +
      commons.escapeVariable('$approvalId') +
      ':reassign';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return Approval.fromJson(response_ as core.Map<core.String, core.dynamic>);
}