start method
Starts an approval on a file.
For more information, see Manage approvals.
request - The metadata request object.
Request parameters:
fileId - Required. The ID of the file that the approval is created on.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Approval.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Approval> start(
StartApprovalRequest request,
core.String fileId, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'files/' + commons.escapeVariable('$fileId') + '/approvals:start';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Approval.fromJson(response_ as core.Map<core.String, core.dynamic>);
}