message property

String? message
getter/setter pair

A message to accompany the cancellation of the approval.

This message is included in notifications for the action and in the approval activity log.

Optional.

Implementation

core.String? message;