Change class

A change to a file or shared drive.

Constructors

Change({String? changeType, Drive? drive, String? driveId, File? file, String? fileId, String? kind, bool? removed, TeamDrive? teamDrive, String? teamDriveId, DateTime? time, String? type})
Change.fromJson(Map json_)

Properties

changeType ↔ String?
The type of the change.
getter/setter pair
drive ↔ Drive?
The updated state of the shared drive.
getter/setter pair
driveId ↔ String?
The ID of the shared drive associated with this change.
getter/setter pair
file ↔ File?
The updated state of the file.
getter/setter pair
fileId ↔ String?
The ID of the file which has changed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
removed ↔ bool?
Whether the file or shared drive has been removed from this list of changes, for example by deletion or loss of access.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamDrive ↔ TeamDrive?
Deprecated: Use drive instead.
getter/setter pair
teamDriveId ↔ String?
Deprecated: Use driveId instead.
getter/setter pair
time ↔ DateTime?
The time of this change (RFC 3339 date-time).
getter/setter pair
type ↔ String?
Deprecated: Use changeType instead.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited