message property
A message to comment on the approval.
This message is included in notifications for the action and in the approval activity log.
Required.
Implementation
core.String? message;
A message to comment on the approval.
This message is included in notifications for the action and in the approval activity log.
Required.
core.String? message;