DownloadRestrictionsMetadata class

Download restrictions applied to the file.

Constructors

DownloadRestrictionsMetadata({DownloadRestriction? effectiveDownloadRestrictionWithContext, DownloadRestriction? itemDownloadRestriction})
DownloadRestrictionsMetadata.fromJson(Map json_)

Properties

effectiveDownloadRestrictionWithContext ↔ DownloadRestriction?
The effective download restriction applied to this file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemDownloadRestriction ↔ DownloadRestriction?
The download restriction of the file applied directly by the owner or organizer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited