clientEncryptionDetails property

ClientEncryptionDetails? clientEncryptionDetails
getter/setter pair

Client Side Encryption related details.

Contains details about the encryption state of the file and details regarding the encryption mechanism that clients need to use when decrypting the contents of this item. This will only be present on files and not on folders or shortcuts.

Implementation

ClientEncryptionDetails? clientEncryptionDetails;