trashed property

bool? trashed
getter/setter pair

Whether the file has been trashed, either explicitly or from a trashed parent folder.

Only the owner may trash a file, but other users can still access the file in the owner's trash until it's permanently deleted.

Implementation

core.bool? trashed;