canAccessViaGenAi property
Whether the current user can access this file via Gen AI features.
For more information, see Drive MCP file eligibility.
Implementation
core.bool? canAccessViaGenAi;
Whether the current user can access this file via Gen AI features.
For more information, see Drive MCP file eligibility.
core.bool? canAccessViaGenAi;