FileContentHints class

Additional information about the content of the file.

These fields are never populated in responses.

Constructors

FileContentHints({String? indexableText, FileContentHintsThumbnail? thumbnail})
FileContentHints.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
indexableText ↔ String?
Text to be indexed for the file to improve fullText queries.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail ↔ FileContentHintsThumbnail?
A thumbnail for the file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited