FileShortcutDetails class

Information about a shortcut file.

Constructors

FileShortcutDetails({String? targetId, String? targetMimeType, String? targetResourceKey})
FileShortcutDetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetId ↔ String?
The ID of the file that this shortcut points to.
getter/setter pair
targetMimeType ↔ String?
The MIME type of the file that this shortcut points to.
getter/setter pair
targetResourceKey ↔ String?
The resourceKey for the target file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited