LabelModification class

A modification to a label on a file.

A LabelModification can be used to apply a label to a file, update an existing label on a file, or remove a label from a file.

Constructors

LabelModification({List<LabelFieldModification>? fieldModifications, String? kind, String? labelId, bool? removeLabel})
LabelModification.fromJson(Map json_)

Properties

fieldModifications ↔ List<LabelFieldModification>?
The list of modifications to this label's fields.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
This is always "drive#labelModification".
getter/setter pair
labelId ↔ String?
The ID of the label to modify.
getter/setter pair
removeLabel ↔ bool?
If true, the label will be removed from the file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited