ModifyLabelsResponse class

Response to a ModifyLabels request.

This contains only those labels which were added or updated by the request.

Constructors

ModifyLabelsResponse({String? kind, List<Label>? modifiedLabels})
ModifyLabelsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
This is always "drive#modifyLabelsResponse".
getter/setter pair
modifiedLabels ↔ List<Label>?
The list of labels which were added or updated by the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited