emailAddress property
The email address of the user or group to which this permission refers.
Output only.
Implementation
core.String? emailAddress;
The email address of the user or group to which this permission refers.
Output only.
core.String? emailAddress;