id property
The ID of this permission.
This is a unique identifier for the grantee, and is published in the
User resource
as permissionId. IDs should be treated as opaque values.
Output only.
Implementation
core.String? id;
The ID of this permission.
This is a unique identifier for the grantee, and is published in the
User resource
as permissionId. IDs should be treated as opaque values.
Output only.
core.String? id;