ResolveAccessProposalRequest class

Request message for resolving an AccessProposal on a file.

Constructors

ResolveAccessProposalRequest({String? action, List<String>? role, bool? sendNotification, String? view})
ResolveAccessProposalRequest.fromJson(Map json_)

Properties

action ↔ String?
The action to take on the access proposal.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
role ↔ List<String>?
The roles that the approver has allowed, if any.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendNotification ↔ bool?
Whether to send an email to the requester when the access proposal is denied or accepted.
getter/setter pair
view ↔ String?
Indicates the view for this access proposal.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited