Revision class

The metadata for a revision to a file.

Some resource methods (such as revisions.update) require a revisionId. Use the revisions.list method to retrieve the ID for a revision.

Constructors

Revision({Map<String, String>? exportLinks, String? id, bool? keepForever, String? kind, User? lastModifyingUser, String? md5Checksum, String? mimeType, DateTime? modifiedTime, String? originalFilename, bool? publishAuto, bool? published, String? publishedLink, bool? publishedOutsideDomain, String? size})
Revision.fromJson(Map json_)

Properties

Links for exporting Docs Editors files to specific formats.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the revision.
getter/setter pair
keepForever ↔ bool?
Whether to keep this revision forever, even if it is no longer the head revision.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
lastModifyingUser ↔ User?
The last user to modify this revision.
getter/setter pair
md5Checksum ↔ String?
The MD5 checksum of the revision's content.
getter/setter pair
mimeType ↔ String?
The MIME type of the revision.
getter/setter pair
modifiedTime ↔ DateTime?
The last time the revision was modified (RFC 3339 date-time).
getter/setter pair
originalFilename ↔ String?
The original filename used to create this revision.
getter/setter pair
publishAuto ↔ bool?
Whether subsequent revisions will be automatically republished.
getter/setter pair
published ↔ bool?
Whether this revision is published.
getter/setter pair
A link to the published revision.
getter/setter pair
publishedOutsideDomain ↔ bool?
Whether this revision is published outside the domain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ String?
The size of the revision's content in bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited