StartApprovalRequest class

Allows creating an approval on a file.

Constructors

StartApprovalRequest({String? dueTime, String? fileContentChangeBehavior, bool? lockFile, String? message, List<String>? reviewerEmails})
StartApprovalRequest.fromJson(Map json_)

Properties

dueTime String?
The time that the approval is due.
getter/setter pair
fileContentChangeBehavior String?
The behavior of the approval when the file content changes.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lockFile bool?
Whether to lock the file when starting the approval.
getter/setter pair
message String?
A message to send to reviewers when notifying them of the approval request.
getter/setter pair
reviewerEmails List<String>?
The emails of the users who are set to review the approval.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited