TeamDrive class

Deprecated: use the drive collection instead.

Next ID: 33

Constructors

TeamDrive({TeamDriveBackgroundImageFile? backgroundImageFile, String? backgroundImageLink, TeamDriveCapabilities? capabilities, String? colorRgb, DateTime? createdTime, String? id, String? kind, String? name, String? orgUnitId, TeamDriveRestrictions? restrictions, String? themeId})
TeamDrive.fromJson(Map json_)

Properties

backgroundImageFile ↔ TeamDriveBackgroundImageFile?
The background image file for a Team Drive.
getter/setter pair
A short-lived link to this Team Drive's background image.
getter/setter pair
capabilities ↔ TeamDriveCapabilities?
Capabilities the current user has on this Team Drive.
getter/setter pair
colorRgb ↔ String?
The color of this Team Drive as an RGB hex string.
getter/setter pair
createdTime ↔ DateTime?
The time at which the Team Drive was created (RFC 3339 date-time).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of this Team Drive which is also the ID of the top level folder of this Team Drive.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
name ↔ String?
The name of this Team Drive.
getter/setter pair
orgUnitId ↔ String?
The organizational unit of this shared drive.
getter/setter pair
restrictions ↔ TeamDriveRestrictions?
A set of restrictions that apply to this Team Drive or items inside this Team Drive.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themeId ↔ String?
The ID of the theme from which the background image and color will be set.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited