TeamDriveBackgroundImageFile class

The background image file for a Team Drive.

Constructors

TeamDriveBackgroundImageFile({String? id, double? width, double? xCoordinate, double? yCoordinate})
TeamDriveBackgroundImageFile.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
The ID of an image file in Drive to use for the background image.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double?
The width of the cropped image in the closed range of 0 to 1.
getter/setter pair
xCoordinate double?
The X coordinate of the upper left corner of the cropping area in the background image.
getter/setter pair
yCoordinate double?
The Y coordinate of the upper left corner of the cropping area in the background image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited