Action class

Information about the action.

Constructors

Action({Actor? actor, ActionDetail? detail, Target? target, TimeRange? timeRange, String? timestamp})
Action.fromJson(Map json_)

Properties

actor ↔ Actor?
The actor responsible for this action (or empty if all actors are responsible).
getter/setter pair
detail ↔ ActionDetail?
The type and detailed information about the action.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ Target?
The target this action affects (or empty if affecting all targets).
getter/setter pair
timeRange ↔ TimeRange?
The action occurred over this time range.
getter/setter pair
timestamp ↔ String?
The action occurred at this specific time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited