Actor class

The actor of a Drive activity.

Constructors

Actor({Administrator? administrator, AnonymousUser? anonymous, Impersonation? impersonation, SystemEvent? system, User? user})
Actor.fromJson(Map json_)

Properties

administrator ↔ Edit?
An administrator.
getter/setter pair
anonymous ↔ Edit?
An anonymous user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
impersonation ↔ Impersonation?
An account acting on behalf of another.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
system ↔ SystemEvent?
A non-user actor (i.e. system triggered).
getter/setter pair
user ↔ User?
An end user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited