Comment class

A change about comments on an object.

Constructors

Comment({Assignment? assignment, List<User>? mentionedUsers, Post? post, Suggestion? suggestion})
Comment.fromJson(Map json_)

Properties

assignment ↔ Assignment?
A change on an assignment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mentionedUsers ↔ List<User>?
Users who are mentioned in this comment.
getter/setter pair
post ↔ Post?
A change on a regular posted comment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestion ↔ Suggestion?
A change on a suggestion.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited