FieldValueChange class

Change to a Field value.

Constructors

FieldValueChange({String? displayName, String? fieldId, FieldValue? newValue, FieldValue? oldValue})
FieldValueChange.fromJson(Map json_)

Properties

displayName ↔ String?
The human-readable display name for this field.
getter/setter pair
fieldId ↔ String?
The ID of this field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newValue ↔ FieldValue?
The value that is now set on the field.
getter/setter pair
oldValue ↔ FieldValue?
The value that was previously set on the field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited