FileComment class

A comment on a file.

Constructors

FileComment({String? legacyCommentId, String? legacyDiscussionId, String? linkToDiscussion, DriveItem? parent})
FileComment.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
legacyCommentId ↔ String?
The comment in the discussion thread.
getter/setter pair
legacyDiscussionId ↔ String?
The discussion thread to which the comment was added.
getter/setter pair
linkToDiscussion ↔ String?
The link to the discussion thread containing this comment, for example, https://docs.google.com/DOCUMENT_ID/edit?disco=THREAD_ID.
getter/setter pair
parent ↔ DriveItem?
The Drive item containing this comment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited