KnownUser class

A known user.

Constructors

KnownUser({bool? isCurrentUser, String? personName})
KnownUser.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCurrentUser ↔ bool?
True if this is the user making the request.
getter/setter pair
personName ↔ String?
The identifier for this user that can be used with the People API to get more information.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited