QueryDriveActivityRequest class

The request message for querying Drive activity.

Constructors

QueryDriveActivityRequest({String? ancestorName, ConsolidationStrategy? consolidationStrategy, String? filter, String? itemName, int? pageSize, String? pageToken})
QueryDriveActivityRequest.fromJson(Map json_)

Properties

ancestorName ↔ String?
Return activities for this Drive folder, plus all children and descendants.
getter/setter pair
consolidationStrategy ↔ ConsolidationStrategy?
Details on how to consolidate related actions that make up the activity.
getter/setter pair
filter ↔ String?
The filtering for items returned from this query request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemName ↔ String?
Return activities for this Drive item.
getter/setter pair
pageSize ↔ int?
The minimum number of activities desired in the response; the server attempts to return at least this quantity.
getter/setter pair
pageToken ↔ String?
The token identifies which page of results to return.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited