RestrictionChange class

Information about restriction policy changes to a feature.

Constructors

RestrictionChange({String? feature, String? newRestriction})
RestrictionChange.fromJson(Map json_)

Properties

feature ↔ String?
The feature which had a change in restriction policy. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newRestriction ↔ String?
The restriction in place after the change. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited