Selection class

Wrapper for Selection Field value as combined value/display_name pair for selected choice.

Constructors

Selection({String? displayName, String? value})
Selection.fromJson(Map json_)

Properties

displayName ↔ String?
Selection value as human-readable display string.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
Selection value as Field Choice ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited