TargetReference class

A lightweight reference to the target of activity.

Properties

drive ↔ DriveReference?
The target is a shared drive.
getter/setter pair
driveItem ↔ DriveItemReference?
The target is a Drive item.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
teamDrive ↔ TeamDriveReference?
This field is deprecated; please use the drive field instead.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited