TeamDriveReference class

This item is deprecated; please see DriveReference instead.

Constructors

TeamDriveReference({String? name, String? title})
TeamDriveReference.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
This field is deprecated; please see DriveReference.name instead.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
This field is deprecated; please see DriveReference.title instead.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited