TimeRange class

Information about time ranges.

Constructors

TimeRange({String? endTime, String? startTime})
TimeRange.fromJson(Map json_)

Properties

endTime ↔ String?
The end of the time range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The start of the time range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited