User class

Information about an end user.

Constructors

User({DeletedUser? deletedUser, KnownUser? knownUser, UnknownUser? unknownUser})
User.fromJson(Map json_)

Properties

deletedUser ↔ Edit?
A user whose account has since been deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
knownUser ↔ KnownUser?
A known user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownUser ↔ Edit?
A user about whom nothing is currently known.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited