GoogleAppsDriveLabelsV2DeltaUpdateLabelRequest class

The set of requests for updating aspects of a label.

If any request isn't valid, no requests will be applied.

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The BCP-47 language code to use for evaluating localized field labels when include_label_in_response is true.
getter/setter pair
requests ↔ List<GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestRequest>?
A list of updates to apply to the label.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useAdminAccess ↔ bool?
Set to true in order to use the user's admin credentials.
getter/setter pair
view ↔ String?
When specified, only certain fields belonging to the indicated view will be returned. Possible string values are:
getter/setter pair
writeControl ↔ GoogleAppsDriveLabelsV2WriteControl?
Provides control over how write requests are executed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited