GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDeleteSelectionChoiceRequest class

Request to delete a choice.

Properties

fieldId ↔ String?
The selection field from which a choice will be deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Choice to delete.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited