GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestRequest class

A single kind of update to apply to a label.

Properties

createField ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestCreateFieldRequest?
Creates a field.
getter/setter pair
createSelectionChoice ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestCreateSelectionChoiceRequest?
Create a choice within a selection field.
getter/setter pair
deleteField ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDeleteFieldRequest?
Deletes a field from the label.
getter/setter pair
deleteSelectionChoice ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDeleteSelectionChoiceRequest?
Delete a choice within a selection field.
getter/setter pair
disableField ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDisableFieldRequest?
Disables the field.
getter/setter pair
disableSelectionChoice ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestDisableSelectionChoiceRequest?
Disable a choice within a selection field.
getter/setter pair
enableField ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestEnableFieldRequest?
Enables the field.
getter/setter pair
enableSelectionChoice ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestEnableSelectionChoiceRequest?
Enable a choice within a selection field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateField ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateFieldPropertiesRequest?
Updates basic properties of a field.
getter/setter pair
updateFieldType ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateFieldTypeRequest?
Update field type and/or type options.
getter/setter pair
updateLabel ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateLabelPropertiesRequest?
Updates the label properties.
getter/setter pair
updateSelectionChoiceProperties ↔ GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateSelectionChoicePropertiesRequest?
Update a choice property within a selection field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited