GoogleAppsDriveLabelsV2DeltaUpdateLabelRequestUpdateFieldTypeRequest class

Request to change the type of a field.

Properties

dateOptions ↔ GoogleAppsDriveLabelsV2FieldDateOptions?
Update field to Date.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The field to update.
getter/setter pair
integerOptions ↔ GoogleAppsDriveLabelsV2FieldIntegerOptions?
Update field to Integer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectionOptions ↔ GoogleAppsDriveLabelsV2FieldSelectionOptions?
Update field to Selection.
getter/setter pair
textOptions ↔ GoogleAppsDriveLabelsV2FieldTextOptions?
Update field to Text.
getter/setter pair
updateMask ↔ String?
The fields that should be updated.
getter/setter pair
userOptions ↔ GoogleAppsDriveLabelsV2FieldUserOptions?
Update field to User.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited