GoogleAppsDriveLabelsV2EnableLabelRequest class

Request to enable a label.

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The BCP-47 language code to use for evaluating localized field labels.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useAdminAccess ↔ bool?
Set to true in order to use the user's admin credentials.
getter/setter pair
writeControl ↔ GoogleAppsDriveLabelsV2WriteControl?
Provides control over how write requests are executed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited