GoogleAppsDriveLabelsV2Field class

Defines a field that has a display name, data type, and other configuration options.

This field defines the kind of metadata that may be set on a Drive item.

Properties

appliedCapabilities ↔ GoogleAppsDriveLabelsV2FieldAppliedCapabilities?
The capabilities this user has on this field and its value when the label is applied on Drive items.
getter/setter pair
createTime ↔ String?
The time this field was created.
getter/setter pair
creator ↔ GoogleAppsDriveLabelsV2UserInfo?
The user who created this field.
getter/setter pair
dateOptions ↔ GoogleAppsDriveLabelsV2FieldDateOptions?
Date field options.
getter/setter pair
disabler ↔ GoogleAppsDriveLabelsV2UserInfo?
The user who disabled this field.
getter/setter pair
disableTime ↔ String?
The time this field was disabled.
getter/setter pair
displayHints ↔ GoogleAppsDriveLabelsV2FieldDisplayHints?
UI display hints for rendering a field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The key of a field, unique within a label or library.
getter/setter pair
integerOptions ↔ GoogleAppsDriveLabelsV2FieldIntegerOptions?
Integer field options.
getter/setter pair
lifecycle ↔ GoogleAppsDriveLabelsV2Lifecycle?
The lifecycle of this field.
getter/setter pair
lockStatus ↔ GoogleAppsDriveLabelsV2LockStatus?
The LockStatus of this field.
getter/setter pair
properties ↔ GoogleAppsDriveLabelsV2FieldProperties?
The basic properties of the field.
getter/setter pair
publisher ↔ GoogleAppsDriveLabelsV2UserInfo?
The user who published this field.
getter/setter pair
queryKey ↔ String?
The key to use when constructing Drive search queries to find files based on values defined for this field on files.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaCapabilities ↔ GoogleAppsDriveLabelsV2FieldSchemaCapabilities?
The capabilities this user has when editing this field.
getter/setter pair
selectionOptions ↔ GoogleAppsDriveLabelsV2FieldSelectionOptions?
Selection field options.
getter/setter pair
textOptions ↔ GoogleAppsDriveLabelsV2FieldTextOptions?
Text field options.
getter/setter pair
updater ↔ GoogleAppsDriveLabelsV2UserInfo?
The user who modified this field.
getter/setter pair
updateTime ↔ String?
The time this field was updated.
getter/setter pair
userOptions ↔ GoogleAppsDriveLabelsV2FieldUserOptions?
User field options.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited