GoogleAppsDriveLabelsV2FieldDateOptions class

Options for the date field type.

Properties

dateFormat ↔ String?
ICU date format.
getter/setter pair
dateFormatType ↔ String?
Localized date formatting option.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxValue ↔ GoogleTypeDate?
Maximum valid value (year, month, day).
getter/setter pair
minValue ↔ GoogleTypeDate?
Minimum valid value (year, month, day).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited