GoogleAppsDriveLabelsV2FieldDisplayHints class

UI display hints for rendering a field.

Constructors

GoogleAppsDriveLabelsV2FieldDisplayHints({bool? disabled, bool? hiddenInSearch, bool? required, bool? shownInApply})
GoogleAppsDriveLabelsV2FieldDisplayHints.fromJson(Map json_)

Properties

disabled ↔ bool?
Whether the field should be shown in the UI as disabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hiddenInSearch ↔ bool?
This field should be hidden in the search menu when searching for Drive items.
getter/setter pair
required ↔ bool?
Whether the field should be shown as required in the UI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shownInApply ↔ bool?
This field should be shown in the apply menu when applying values to a Drive item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited