GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceProperties class

Basic properties of the choice.

Properties

badgeConfig ↔ GoogleAppsDriveLabelsV2BadgeConfig?
The badge configuration for this choice.
getter/setter pair
description ↔ String?
The description of this label.
getter/setter pair
displayName ↔ String?
The display text to show in the UI identifying this field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
insertBeforeChoice ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited