GoogleAppsDriveLabelsV2FieldSelectionOptionsChoiceSchemaCapabilities class

The capabilities related to this choice when editing the choice.

Properties

canDelete ↔ bool?
Whether the user can delete this choice.
getter/setter pair
canDisable ↔ bool?
Whether the user can disable this choice.
getter/setter pair
canEnable ↔ bool?
Whether the user can enable this choice.
getter/setter pair
canUpdate ↔ bool?
Whether the user can update this choice.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited