GoogleAppsDriveLabelsV2FieldTextOptions class

Options for the Text field type.

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxLength ↔ int?
The maximum valid length of values for the text field.
getter/setter pair
minLength ↔ int?
The minimum valid length of values for the text field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited