GoogleAppsDriveLabelsV2LabelAppliedLabelPolicy class

Behavior of this label when it's applied to Drive items.

Properties

copyMode ↔ String?
Indicates how the applied label and field values should be copied when a Drive item is copied. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited