GoogleAppsDriveLabelsV2LabelEnabledAppSettings class

Describes the Google Workspace apps in which the label can be used.

Properties

enabledApps ↔ List<GoogleAppsDriveLabelsV2LabelEnabledAppSettingsEnabledApp>?
The list of apps where the label can be used.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited