GoogleAppsDriveLabelsV2LabelLimits class

Label constraints governing the structure of a label; such as, the maximum number of fields allowed and maximum length of the label title.

Constructors

GoogleAppsDriveLabelsV2LabelLimits({GoogleAppsDriveLabelsV2FieldLimits? fieldLimits, int? maxDeletedFields, int? maxDescriptionLength, int? maxDraftRevisions, int? maxFields, int? maxTitleLength, String? name})
GoogleAppsDriveLabelsV2LabelLimits.fromJson(Map json_)

Properties

fieldLimits ↔ GoogleAppsDriveLabelsV2FieldLimits?
The limits for fields.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxDeletedFields ↔ int?
The maximum number of published fields that can be deleted.
getter/setter pair
maxDescriptionLength ↔ int?
The maximum number of characters allowed for the description.
getter/setter pair
maxDraftRevisions ↔ int?
The maximum number of draft revisions that will be kept before deleting old drafts.
getter/setter pair
maxFields ↔ int?
The maximum number of fields allowed within the label.
getter/setter pair
maxTitleLength ↔ int?
The maximum number of characters allowed for the title.
getter/setter pair
name ↔ String?
Resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited