GoogleAppsDriveLabelsV2LabelLock class

A lock that can be applied to a label, field, or choice.

Properties

capabilities ↔ GoogleAppsDriveLabelsV2LabelLockCapabilities?
The user's capabilities on this label lock.
getter/setter pair
choiceId ↔ String?
The ID of the selection field choice that should be locked.
getter/setter pair
createTime ↔ String?
The time this label lock was created.
getter/setter pair
creator ↔ GoogleAppsDriveLabelsV2UserInfo?
The user whose credentials were used to create the label lock.
getter/setter pair
deleteTime ↔ String?
A timestamp indicating when this label lock was scheduled for deletion.
getter/setter pair
fieldId ↔ String?
The ID of the field that should be locked.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of this label lock.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
This label lock's state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited