GoogleAppsDriveLabelsV2LabelPermission class

The permission that applies to a principal (user, group, audience) on a label.

Properties

audience ↔ String?
Audience to grant a role to.
getter/setter pair
email ↔ String?
Specifies the email address for a user or group principal.
getter/setter pair
group ↔ String?
Group resource name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of this permission.
getter/setter pair
person ↔ String?
Person resource name.
getter/setter pair
role ↔ String?
The role the principal should have. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited