GoogleAppsDriveLabelsV2ListLabelLocksResponse class

The response to a ListLabelLocksRequest.

Properties

hashCode → int
The hash code for this object.
no setterinherited
labelLocks ↔ List<GoogleAppsDriveLabelsV2LabelLock>?
Label locks.
getter/setter pair
nextPageToken ↔ String?
The token of the next page in the response.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited