GoogleAppsDriveLabelsV2SelectionLimits class

Limits for selection field type.

Constructors

GoogleAppsDriveLabelsV2SelectionLimits({GoogleAppsDriveLabelsV2ListLimits? listLimits, int? maxChoices, int? maxDeletedChoices, int? maxDisplayNameLength, int? maxIdLength})
GoogleAppsDriveLabelsV2SelectionLimits.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
listLimits ↔ GoogleAppsDriveLabelsV2ListLimits?
Limits for list-variant of a field type.
getter/setter pair
maxChoices ↔ int?
Maximum number of choices.
getter/setter pair
maxDeletedChoices ↔ int?
Maximum number of deleted choices.
getter/setter pair
maxDisplayNameLength ↔ int?
Maximum length for display name.
getter/setter pair
maxIdLength ↔ int?
Maximum ID length for a selection option.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited