GoogleAppsDriveLabelsV2UpdateLabelCopyModeRequest class

Request to update the CopyMode of the given label.

Changes to this policy aren't revisioned, don't require publishing, and take effect immediately. \

Properties

copyMode ↔ String?
Indicates how the applied label and field values should be copied when a Drive item is copied.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The BCP-47 language code to use for evaluating localized field labels.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useAdminAccess ↔ bool?
Set to true in order to use the user's admin credentials.
getter/setter pair
view ↔ String?
When specified, only certain fields belonging to the indicated view will be returned. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited