FilteringAttribute class

A representation of the FilteringAttribute resource.

Filtering attributes are per event type.

Constructors

FilteringAttribute({String? attribute, String? description, bool? pathPatternSupported, bool? required})
FilteringAttribute.fromJson(Map json_)

Properties

attribute ↔ String?
Attribute used for filtering the event type.
getter/setter pair
description ↔ String?
Description of the purpose of the attribute.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pathPatternSupported ↔ bool?
If true, the attribute accepts matching expressions in the Eventarc PathPattern format.
getter/setter pair
required ↔ bool?
If true, the triggers for this provider should always specify a filter on these attributes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited