GoogleChannelConfig class

Can be used to customize security settings for Eventarc first-party triggers in a specific region.

Once the GoogleChannelConfig resource is configured, first-party event data is protected using the specified customer-managed encryption key instead of a Google-managed encryption key.

Constructors

GoogleChannelConfig({String? cryptoKeyName, Map<String, String>? labels, String? name, String? updateTime})
GoogleChannelConfig.fromJson(Map json_)

Properties

cryptoKeyName ↔ String?
Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt their event data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels.
getter/setter pair
name ↔ String?
The resource name of the config.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The last-modified time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited