ListMessageBusesResponse class

The response message for the ListMessageBuses method.

Constructors

ListMessageBusesResponse({List<MessageBus>? messageBuses, String? nextPageToken, List<String>? unreachable})
ListMessageBusesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
messageBuses ↔ List<MessageBus>?
The requested message buses, up to the number specified in page_size.
getter/setter pair
nextPageToken ↔ String?
A page token that can be sent to ListMessageBuses to request the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unreachable resources, if any.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited