LoggingConfig class

The configuration for Platform Telemetry logging for Eventarc Advanced resources.

Constructors

LoggingConfig({String? logSeverity})
LoggingConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logSeverity ↔ String?
The minimum severity of logs that will be sent to Stackdriver/Platform Telemetry.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited