MessageBus class

MessageBus for the messages flowing through the system.

The admin has visibility and control over the messages being published and consumed and can restrict publishers and subscribers to only a subset of data available in the system by defining authorization policies.

Constructors

MessageBus({Map<String, String>? annotations, String? createTime, String? cryptoKeyName, String? displayName, String? etag, Map<String, String>? labels, LoggingConfig? loggingConfig, String? name, String? uid, String? updateTime})
MessageBus.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Resource annotations.
getter/setter pair
createTime ↔ String?
The creation time.
getter/setter pair
cryptoKeyName ↔ String?
Resource name of a KMS crypto key (managed by the user) used to encrypt/decrypt their event data.
getter/setter pair
displayName ↔ String?
Resource display name.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and might be sent only on update and delete requests to ensure that the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels.
getter/setter pair
loggingConfig ↔ LoggingConfig?
Config to control Platform logging for the Message Bus.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String?
Server assigned unique identifier for the channel.
getter/setter pair
updateTime ↔ String?
The last-modified time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited