Trigger class

A representation of the trigger resource.

Constructors

Trigger({String? channel, Map<String, StateCondition>? conditions, String? createTime, Destination? destination, String? etag, String? eventDataContentType, List<EventFilter>? eventFilters, Map<String, String>? labels, String? name, RetryPolicy? retryPolicy, bool? satisfiesPzs, String? serviceAccount, Transport? transport, String? uid, String? updateTime})
Trigger.fromJson(Map json_)

Properties

channel ↔ String?
The name of the channel associated with the trigger in projects/{project}/locations/{location}/channels/{channel} format.
getter/setter pair
conditions ↔ Map<String, StateCondition>?
The reason(s) why a trigger is in FAILED state.
getter/setter pair
createTime ↔ String?
The creation time.
getter/setter pair
destination ↔ Destination?
Destination specifies where the events should be sent to.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and might be sent only on create requests to ensure that the client has an up-to-date value before proceeding.
getter/setter pair
eventDataContentType ↔ String?
EventDataContentType specifies the type of payload in MIME format that is expected from the CloudEvent data field.
getter/setter pair
eventFilters ↔ List<EventFilter>?
Unordered list.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
User labels attached to the triggers that can be used to group resources.
getter/setter pair
name ↔ String?
The resource name of the trigger.
getter/setter pair
retryPolicy ↔ RetryPolicy?
The retry policy to use in the Trigger.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Whether or not this Trigger satisfies the requirements of physical zone separation
getter/setter pair
serviceAccount ↔ String?
The IAM service account email associated with the trigger.
getter/setter pair
transport ↔ Transport?
To deliver messages, Eventarc might use other Google Cloud products as a transport intermediary.
getter/setter pair
uid ↔ String?
Server-assigned unique identifier for the trigger.
getter/setter pair
updateTime ↔ String?
The last-modified time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited