ApnsConfig class

Constructors

ApnsConfig({ApnsFcmOptions? fcmOptions, Map<String, String>? headers, String? liveActivityToken, Map<String, Object?>? payload})
ApnsConfig.fromJson(Map json_)

Properties

fcmOptions ↔ ApnsFcmOptions?
Options for features provided by the FCM SDK for iOS.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
HTTP request headers defined in Apple Push Notification Service.
getter/setter pair
liveActivityToken ↔ String?
Apple Live Activity token to send updates to.
getter/setter pair
payload ↔ Map<String, Object?>?
APNs payload as a JSON object, including both aps dictionary and custom payload.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited