Message class

Message to send by Firebase Cloud Messaging Service.

Constructors

Message({AndroidConfig? android, ApnsConfig? apns, String? condition, Map<String, String>? data, FcmOptions? fcmOptions, String? name, Notification? notification, String? token, String? topic, WebpushConfig? webpush})
Message.fromJson(Map json_)

Properties

android ↔ AndroidConfig?
Input only.
getter/setter pair
apns ↔ ApnsConfig?
Input only.
getter/setter pair
condition ↔ String?
Condition to send a message to, e.g. "'foo' in topics && 'bar' in topics".
getter/setter pair
data ↔ Map<String, String>?
Input only.
getter/setter pair
fcmOptions ↔ AndroidFcmOptions?
Input only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The identifier of the message sent, in the format of projects / * /messages/{message_id}.
getter/setter pair
notification ↔ Notification?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token ↔ String?
Registration token to send a message to.
getter/setter pair
topic ↔ String?
Topic name to send a message to, e.g. "weather".
getter/setter pair
webpush ↔ WebpushConfig?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited