Notification class

Basic notification template to use across all platforms.

Constructors

Notification({String? body, String? image, String? title})
Notification.fromJson(Map json_)

Properties

body ↔ String?
The notification's body text.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
Contains the URL of an image that is going to be downloaded on the device and displayed in a notification.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The notification's title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited