SendMessageRequest class

Request to send a message to specified target.

Constructors

SendMessageRequest({Message? message, bool? validateOnly})
SendMessageRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ Message?
Message to send.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
Flag for testing the request without actually delivering the message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited