WebpushConfig class

Webpush protocol options.

Constructors

WebpushConfig({Map<String, String>? data, WebpushFcmOptions? fcmOptions, Map<String, String>? headers, Map<String, Object?>? notification})
WebpushConfig.fromJson(Map json_)

Properties

data ↔ Map<String, String>?
Arbitrary key/value payload.
getter/setter pair
fcmOptions ↔ WebpushFcmOptions?
Options for features provided by the FCM SDK for Web.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
HTTP headers defined in webpush protocol.
getter/setter pair
notification ↔ Map<String, Object?>?
Web Notification options as a JSON object.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited