FileShareConfig class

File share configuration for the instance.

Constructors

FileShareConfig({String? capacityGb, String? name, List<NfsExportOptions>? nfsExportOptions, String? sourceBackup, String? sourceBackupdrBackup})
FileShareConfig.fromJson(Map json_)

Properties

capacityGb ↔ String?
File share capacity in gigabytes (GB).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the file share.
getter/setter pair
nfsExportOptions ↔ List<NfsExportOptions>?
Nfs Export Options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceBackup ↔ String?
The resource name of the backup, in the format projects/{project_number}/locations/{location_id}/backups/{backup_id}, that this file share has been restored from.
getter/setter pair
sourceBackupdrBackup ↔ String?
The resource name of the BackupDR backup, in the format projects/{project_id}/locations/{location_id}/backupVaults/{backupvault_id}/dataSources/{datasource_id}/backups/{backup_id},
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited