Instance class

A Filestore instance.

Constructors

Instance({String? capacityStepSizeGb, String? createTime, bool? customPerformanceSupported, bool? deletionProtectionEnabled, String? deletionProtectionReason, String? description, DirectoryServicesConfig? directoryServices, String? etag, List<FileShareConfig>? fileShares, String? kmsKeyName, Map<String, String>? labels, String? maxCapacityGb, String? minCapacityGb, String? name, List<NetworkConfig>? networks, PerformanceConfig? performanceConfig, PerformanceLimits? performanceLimits, String? protocol, Replication? replication, bool? satisfiesPzi, bool? satisfiesPzs, String? state, String? statusMessage, List<String>? suspensionReasons, Map<String, String>? tags, String? tier})
Instance.fromJson(Map json_)

Properties

capacityStepSizeGb ↔ String?
The incremental increase or decrease in capacity, designated in some number of GB.
getter/setter pair
createTime ↔ String?
The time when the instance was created.
getter/setter pair
customPerformanceSupported ↔ bool?
Indicates whether this instance supports configuring its performance.
getter/setter pair
deletionProtectionEnabled ↔ bool?
Indicates whether the instance is protected against deletion.
getter/setter pair
deletionProtectionReason ↔ String?
The reason for enabling deletion protection.
getter/setter pair
description ↔ String?
The description of the instance (2048 characters or less).
getter/setter pair
directoryServices ↔ DirectoryServicesConfig?
Directory Services configuration for Kerberos-based authentication.
getter/setter pair
etag ↔ String?
Server-specified ETag for the instance resource to prevent simultaneous updates from overwriting each other.
getter/setter pair
fileShares ↔ List<FileShareConfig>?
File system shares on the instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
KMS key name used for data encryption.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
maxCapacityGb ↔ String?
The maximum capacity of the instance in GB.
getter/setter pair
minCapacityGb ↔ String?
The minimum capacity of the instance in GB.
getter/setter pair
name ↔ String?
The resource name of the instance, in the format projects/{project}/locations/{location}/instances/{instance}.
getter/setter pair
networks ↔ List<NetworkConfig>?
VPC networks to which the instance is connected.
getter/setter pair
performanceConfig ↔ PerformanceConfig?
Used to configure performance.
getter/setter pair
performanceLimits ↔ PerformanceLimits?
Used for getting performance limits.
getter/setter pair
protocol ↔ String?
The protocol indicates the access protocol for all shares in the instance.
getter/setter pair
replication ↔ Replication?
Replication configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
state ↔ String?
The instance state.
getter/setter pair
statusMessage ↔ String?
Additional information about the instance state, if available.
getter/setter pair
suspensionReasons ↔ List<String>?
Field indicates all the reasons the instance is in "SUSPENDED" state.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
tier ↔ String?
The service tier of the instance. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited