ListLocationsResponse class

The response message for Locations.ListLocations.

Constructors

ListLocationsResponse({List<Location>? locations, String? nextPageToken})
ListLocationsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
locations ↔ List<Location>?
A list of locations that matches the specified filter in the request.
getter/setter pair
nextPageToken ↔ String?
The standard List next-page token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited