PromoteReplicaRequest class

PromoteReplicaRequest promotes a Filestore standby instance (replica).

Constructors

PromoteReplicaRequest({String? peerInstance})
PromoteReplicaRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
peerInstance ↔ String?
The resource name of the peer instance to promote, in the format projects/{project_id}/locations/{location_id}/instances/{instance_id}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited