ReplicaConfig class

Replica configuration for the instance.

Constructors

ReplicaConfig({String? lastActiveSyncTime, String? peerInstance, String? state, List<String>? stateReasons, String? stateUpdateTime})
ReplicaConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastActiveSyncTime ↔ String?
The timestamp of the latest replication snapshot taken on the active instance and is already replicated safely.
getter/setter pair
peerInstance ↔ String?
The name of the source instance for the replica, in the format projects/{project}/locations/{location}/instances/{instance}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The replica state.
getter/setter pair
stateReasons ↔ List<String>?
Additional information about the replication state, if available.
getter/setter pair
stateUpdateTime ↔ String?
The time when the replica state was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited