Replication class

The configuration used to replicate an instance.

Optional.

Constructors

Replication({List<ReplicaConfig>? replicas, String? role})
Replication.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
replicas ↔ List<ReplicaConfig>?
Replication configuration for the replica instance associated with this instance.
getter/setter pair
role ↔ String?
The replication role.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited