RestoreInstanceRequest class

RestoreInstanceRequest restores an existing instance's file share from a backup.

Constructors

RestoreInstanceRequest({String? fileShare, String? sourceBackup})
RestoreInstanceRequest.fromJson(Map json_)

Properties

fileShare ↔ String?
Name of the file share in the Filestore instance that the backup is being restored to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceBackup ↔ String?
The resource name of the backup, in the format projects/{project_number}/locations/{location_id}/backups/{backup_id}.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited