GoogleFirebaseAppcheckV1ExchangeCustomTokenRequest class

Request message for the ExchangeCustomToken method.

Properties

customToken ↔ String?
A custom token signed using your project's Admin SDK service account credentials.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jti ↔ String?
When limited_use is set to true, this field specifies the desired jti claim (Section 4.1.7 of RFC 7519) in the returned App Check token.
getter/setter pair
limitedUse ↔ bool?
Specifies whether this attestation is for use in a limited use (true) or session based (false) context.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited