GoogleFirebaseAppcheckV1PlayIntegrityConfigDeviceIntegrity class

A settings object specifying device integrity requirements for Android devices running your app.

These settings correspond to requirements on the [device integrity field](https://developer.android.com/google/play/integrity/verdicts#device-integrity-field) obtained from the Play Integrity API. See the default responses table for a quick summary. Warning: There are also conditional as well as optional responses that you can receive, but requires additional explicit opt-in from you. The App Check API is not responsible for any such opt-ins. The default values for these settings work for most apps, and are recommended.

Properties

hashCode → int
The hash code for this object.
no setterinherited
minDeviceRecognitionLevel ↔ String?
Specifies the minimum device integrity level in order for the device to be considered valid.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited