service property

GoogleFirebaseAppcheckV1Service? service
getter/setter pair

The Service to update.

The Service's name field is used to identify the Service to be updated, in the format: projects/{project_number}/services/{service_id} Note that the service_id element must be a supported service ID. Consult the Service.name field for a list of supported service IDs.

Required.

Implementation

GoogleFirebaseAppcheckV1Service? service;