delete method

Future<GoogleProtobufEmpty> delete(
  1. String name, {
  2. String? etag,
  3. String? $fields,
})

Deletes the specified DebugToken.

A deleted debug token cannot be used to exchange for an App Check token. Use this method when you suspect the secret token has been compromised or when you no longer need the debug token.

Request parameters:

name - Required. The relative resource name of the DebugToken to delete, in the format: projects/{project_number}/apps/{app_id}/debugTokens/{debug_token_id} Value must have pattern ^projects/\[^/\]+/apps/\[^/\]+/debugTokens/\[^/\]+$.

etag - Optional. The checksum to be validated against the current DebugToken, to ensure the client has an up-to-date value before proceeding. This checksum is computed by the server based on the values of fields in the DebugToken object, and can be obtained from the DebugToken object received from the last CreateDebugToken, GetDebugToken, ListDebugTokens, or UpdateDebugToken call. This etag is strongly validated as defined by RFC 7232.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleProtobufEmpty.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleProtobufEmpty> delete(
  core.String name, {
  core.String? etag,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'etag': ?etag == null ? null : [etag],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'DELETE',
    queryParams: queryParams_,
  );
  return GoogleProtobufEmpty.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}