patch method

Future<GoogleFirebaseAppcheckV1Service> patch(
  1. GoogleFirebaseAppcheckV1Service request,
  2. String name, {
  3. String? updateMask,
  4. String? $fields,
})

Updates the specified Service configuration.

request - The metadata request object.

Request parameters:

name - Required. The relative resource name of the service configuration object, in the format: projects/{project_number}/services/{service_id} Note that the service_id element must be a supported service ID. Currently, the following service IDs are supported. Firebase and Google Cloud services: * identitytoolkit.googleapis.com (Firebase Authentication) * firebasedataconnect.googleapis.com (Firebase SQL Connect) * firestore.googleapis.com (Cloud Firestore) * firebasedatabase.googleapis.com (Firebase Realtime Database) * firebasestorage.googleapis.com (Cloud Storage for Firebase) * firebaseml.googleapis.com (Firebase AI Logic) Google Maps Platform services: * maps-backend.googleapis.com (Maps JavaScript API) * places.googleapis.com (Places API (New)) Other supported Google services: * oauth2.googleapis.com (Google Identity for iOS) Note: While all the supported service_ids may appear to be subdomains of googleapis.com, the service_id has no semantic meaning beyond identifying the service to App Check. It is not intended to represent the actual domain to which your apps send traffic, nor is it necessarily the API that should be enabled to use the service. For information on using these Google services, consult their documentation. Value must have pattern ^projects/\[^/\]+/services/\[^/\]+$.

updateMask - Required. A comma-separated list of names of fields in the Service to update. Example: enforcement_mode.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleFirebaseAppcheckV1Service.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleFirebaseAppcheckV1Service> patch(
  GoogleFirebaseAppcheckV1Service request,
  core.String name, {
  core.String? updateMask,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'updateMask': ?updateMask == null ? null : [updateMask],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'PATCH',
    body: body_,
    queryParams: queryParams_,
  );
  return GoogleFirebaseAppcheckV1Service.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}