testState property

String? testState
getter/setter pair

The overall state of tests run on this release

Output only. Possible string values are:

  • "TEST_STATE_UNSPECIFIED" : No test state specified
  • "NO_TESTS_REQUESTED" : No tests have been requested for this release
  • "IN_PROGRESS" : One or more device executions are in progress
  • "PASSED" : All device executions passed during the most recent test
  • "FAILED" : Some device executions failed during the most recent test
  • "INCONCLUSIVE" : Some device executions were inconclusive, but none failed, during the most recent test

Implementation

core.String? testState;