ArchiveSource class

The URI of an storage archive or a signed URL to use as the build source.

Constructors

ArchiveSource({SourceUserMetadata? author, String? description, String? externalSignedUri, String? rootDirectory, String? userStorageUri})
ArchiveSource.fromJson(Map json_)

Properties

author SourceUserMetadata?
Deprecated: Not used.
getter/setter pair
description String?
An optional message that describes the uploaded version of the source code.
getter/setter pair
externalSignedUri String?
Signed URL to an archive in a storage bucket.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rootDirectory String?
The directory relative to the root of the archive to use as the root for the deployed web app.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userStorageUri String?
URI to an archive in Cloud Storage.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited