Backend class

A backend is the primary resource of App Hosting.

Constructors

Backend({Map<String, String>? annotations, String? appId, Codebase? codebase, String? createTime, String? deleteTime, String? displayName, String? environment, String? etag, Map<String, String>? labels, List<ManagedResource>? managedResources, String? mode, String? name, bool? reconciling, bool? requestLogsDisabled, String? serviceAccount, String? servingLocality, String? uid, String? updateTime, String? uri})
Backend.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Unstructured key value map that may be set by external tools to store and arbitrary metadata.
getter/setter pair
appId ↔ String?
The ID of a Web App associated with the backend.
getter/setter pair
codebase ↔ Codebase?
If specified, the connection to an external source repository to watch for event-driven updates to the backend.
getter/setter pair
createTime ↔ String?
Time at which the backend was created.
getter/setter pair
deleteTime ↔ String?
Time at which the backend was deleted.
getter/setter pair
displayName ↔ String?
Human-readable name.
getter/setter pair
environment ↔ String?
The environment name of the backend, used to load environment variables from environment specific configuration.
getter/setter pair
etag ↔ String?
Server-computed checksum based on other values; may be sent on update or delete to ensure operation is done on expected resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Unstructured key value map that can be used to organize and categorize objects.
getter/setter pair
managedResources ↔ List<ManagedResource>?
A list of the resources managed by this backend.
getter/setter pair
mode ↔ String?
Deprecated: Use environment instead.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
reconciling ↔ bool?
A field that, if true, indicates that the system is working to make adjustments to the backend during a LRO.
getter/setter pair
requestLogsDisabled ↔ bool?
A field that, if true, indicates that incoming request logs are disabled for this backend.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
The name of the service account used for Cloud Build and Cloud Run.
getter/setter pair
servingLocality ↔ String?
Specifies how App Hosting will serve the content for this backend.
getter/setter pair
uid ↔ String?
System-assigned, unique identifier.
getter/setter pair
updateTime ↔ String?
Time at which the backend was last updated.
getter/setter pair
uri ↔ String?
The primary URI to communicate with the backend.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited