Build class

A single build for a backend, at a specific point codebase reference tag and point in time.

Encapsulates several resources, including an Artifact Registry container image, a Cloud Build invocation that built the image, and the Cloud Run revision that uses that image.

Constructors

Build({Map<String, String>? annotations, String? buildLogsUri, Config? config, String? createTime, String? deleteTime, String? displayName, String? environment, List<Error>? errors, String? etag, String? image, Map<String, String>? labels, String? name, bool? reconciling, BuildSource? source, String? state, String? uid, String? updateTime})
Build.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Unstructured key value map that may be set by external tools to store and arbitrary metadata.
getter/setter pair
buildLogsUri ↔ String?
The location of the Cloud Build logs for the build process.
getter/setter pair
config ↔ Config?
Additional configuration of the service.
getter/setter pair
createTime ↔ String?
Time at which the build was created.
getter/setter pair
deleteTime ↔ String?
Time at which the build was deleted.
getter/setter pair
displayName ↔ String?
Human-readable name.
getter/setter pair
environment ↔ String?
The environment name of the backend when this build was created.
getter/setter pair
errors ↔ List<Error>?
A list of all errors that occurred during an App Hosting build.
getter/setter pair
etag ↔ String?
Server-computed checksum based on other values; may be sent on update or delete to ensure operation is done on expected resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
The Artifact Registry container image URI, used by the Cloud Run [revision](https://cloud.google.com/run/docs/reference/rest/v2/projects.locations.services.revisions) for this build.
getter/setter pair
labels ↔ Map<String, String>?
Unstructured key value map that can be used to organize and categorize objects.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
reconciling ↔ bool?
A field that, if true, indicates that the build has an ongoing LRO.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ BuildSource?
The source for the build.
getter/setter pair
state ↔ String?
The state of the build.
getter/setter pair
uid ↔ String?
System-assigned, unique identifier.
getter/setter pair
updateTime ↔ String?
Time at which the build was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited