CodebaseSource class

A codebase source, representing the state of the codebase that the build will be created at.

Constructors

CodebaseSource({UserMetadata? author, String? branch, String? commit, String? commitMessage, String? commitTime, String? displayName, String? hash, String? repository, String? uri})
CodebaseSource.fromJson(Map json_)

Properties

author UserMetadata?
The author contained in the metadata of a version control change.
getter/setter pair
branch String?
The branch in the codebase to build from, using the latest commit.
getter/setter pair
commit String?
The commit in the codebase to build from.
getter/setter pair
commitMessage String?
The message of a codebase change.
getter/setter pair
commitTime String?
The time the change was made.
getter/setter pair
displayName String?
The human-friendly name to use for this Codebase when displaying a build.
getter/setter pair
hash String?
The full SHA-1 hash of a Git commit, if available.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
repository String?
The resource name for the Developer Connect [gitRepositoryLink](https://cloud.google.com/developer-connect/docs/api/reference/rest/v1/projects.locations.connections.gitRepositoryLinks) used for this build, in the format: projects/{project}/locations/{location}/connections/{connection}/gitRepositoryLinks/{repositoryLink}
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
A URI linking to the codebase on an hosting provider's website.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited