CustomDomainStatus class

The status of a custom domain's linkage to a backend.

Constructors

CustomDomainStatus({String? certState, String? hostState, List<Status>? issues, String? ownershipState, List<DnsUpdates>? requiredDnsUpdates})
CustomDomainStatus.fromJson(Map json_)

Properties

certState ↔ String?
Tracks SSL certificate status for the domain.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostState ↔ String?
Tracks whether a custom domain is detected as appropriately directing traffic to App Hosting.
getter/setter pair
issues ↔ List<Status>?
A list of issues with domain configuration.
getter/setter pair
ownershipState ↔ String?
Tracks whether the backend is permitted to serve content on the domain, based off the domain's DNS records.
getter/setter pair
requiredDnsUpdates ↔ List<DnsUpdates>?
Lists the records that must added or removed to a custom domain's DNS in order to finish setup and start serving content.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited