DnsRecordSet class

A set of DNS records relevant to the setup and maintenance of a custom domain in App Hosting.

Constructors

DnsRecordSet({Status? checkError, String? domainName, List<DnsRecord>? records})
DnsRecordSet.fromJson(Map json_)

Properties

checkError ↔ Status?
An error App Hosting services encountered when querying your domain's DNS records.
getter/setter pair
domainName ↔ String?
The domain name the record set pertains to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
records ↔ List<DnsRecord>?
Records on the domain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited