EnvironmentVariable class

Environment variables for this build.

Constructors

EnvironmentVariable({List<String>? availability, String? secret, String? value, String? variable})
EnvironmentVariable.fromJson(Map json_)

Properties

availability ↔ List<String>?
Where this variable should be made available.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret ↔ String?
A fully qualified secret version.
getter/setter pair
value ↔ String?
A plaintext value.
getter/setter pair
variable ↔ String?
The name of the environment variable.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited