Error class

The container for the rpc status and source for any errors found during the build process.

Constructors

Error({String? cloudResource, Status? error, String? errorSource})
Error.fromJson(Map json_)

Properties

cloudResource ↔ String?
Resource link
getter/setter pair
error ↔ Status?
A status and (human readable) error message for the build, if in a FAILED state.
getter/setter pair
errorSource ↔ String?
The source of the error for the build, if in a FAILED state.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited