ManagedResource class

An external resource managed by App Hosting on the project.

Constructors

ManagedResource({RunService? runService})
ManagedResource.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runService ↔ RunService?
A Cloud Run [service](https://cloud.google.com/run/docs/reference/rest/v2/projects.locations.services#resource:-service), managed by App Hosting.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited