ignoredPaths property

List<Path>? ignoredPaths
getter/setter pair

A list of file paths patterns to exclude from triggering a rollout.

Patterns in this list take precedence over required_paths. Note: All paths must be in the ignored_paths in order for the rollout to be skipped. Limited to 100 paths. Example: ignored_paths: { pattern: "foo/bar/excluded / * ” type: GLOB }

Optional.

Implementation

core.List<Path>? ignoredPaths;