requiredPaths property
A list of file paths patterns that trigger a build and rollout if at least one of the changed files in the commit are present in this list.
This field is optional; the rollout policy will default to triggering on
all paths if both ignored_paths and required_paths are not populated.
Limited to 100 paths. Example: required_paths: { pattern: "foo/bar / * ", type: "GLOB" }
Optional.
Implementation
core.List<Path>? requiredPaths;