RunConfig class

Constructors

RunConfig({int? concurrency, double? cpu, int? maxInstances, int? memoryMib, int? minInstances})
RunConfig.fromJson(Map json_)

Properties

concurrency ↔ int?
Maximum number of requests that each Cloud Run instance can receive.
getter/setter pair
cpu ↔ double?
Number of CPUs used for each serving instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxInstances ↔ int?
Number of Cloud Run instances to maintain at maximum for each revision.
getter/setter pair
memoryMib ↔ int?
Amount of memory allocated for each serving instance in MiB.
getter/setter pair
minInstances ↔ int?
Number of Cloud Run instances to maintain at minimum for each Cloud Run Service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited