ServingBehavior class

Indicates whether App Hosting will serve content on the domain.

Constructors

ServingBehavior({Redirect? redirect})
ServingBehavior.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
redirect ↔ Redirect?
Redirect behavior for a domain, if provided.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited