SourceUserMetadata class

Deprecated: Not used.

Metadata for the user who started the build.

Constructors

SourceUserMetadata({String? displayName, String? email, String? imageUri})
SourceUserMetadata.fromJson(Map json_)

Properties

displayName ↔ String?
Deprecated: Not used.
getter/setter pair
email ↔ String?
Deprecated: Not used.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageUri ↔ String?
Deprecated: Not used.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited