TrafficSplit class

The traffic allocation for the backend.

Constructors

TrafficSplit({String? build, int? percent})
TrafficSplit.fromJson(Map json_)

Properties

build ↔ String?
The build that traffic is being routed to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
percent ↔ int?
The percentage of traffic to send to the build.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited