firebasedataconnect/v1 library

Firebase SQL Connect API - v1

Firebase SQL Connect is a relational database service for mobile and web apps that lets you build and scale using a fully-managed PostgreSQL database powered by Cloud SQL. The REST API lets developers manage the connections to their database, change the schema of their database, and query the database.

For more information, see firebase.google.com/docs/data-connect

Create an instance of FirebaseDataConnectApi to access these resources:

Classes

ClientCache
Client caching settings of a connector.
CloudSqlInstance
Settings for CloudSQL instance configuration.
CodeChunk
A chunk of code.
Connector
Connector consists of a set of operations, i.e. queries and mutations.
DataConnectProperties
SQL Connect specific properties for a path under response.data.
Datasource
A data source that backs Firebase SQL Connect services.
ExecuteMutationResponse
The ExecuteMutation response from Firebase SQL Connect.
ExecuteQueryResponse
The ExecuteQuery response from Firebase SQL Connect.
File
Individual files.
FirebaseDataConnectApi
Firebase SQL Connect is a relational database service for mobile and web apps that lets you build and scale using a fully-managed PostgreSQL database powered by Cloud SQL.
GenerateQueryRequest
Request message for GenerateQuery.
GenerateQueryResponse
Output for streaming generate query requests
GenerateSchemaRequest
Request message for GenerateSchema.
GenerateSchemaResponse
Output for streaming generate schema requests
GenerationStatus
Represents the progress of the server side generation request.
GraphqlError
GraphqlError conforms to the GraphQL error spec.
GraphqlErrorExtensions
GraphqlErrorExtensions contains additional information of GraphqlError.
GraphqlRequest
The GraphQL request to Firebase SQL Connect.
GraphqlRequestExtensions
GraphqlRequestExtensions contains additional information of GraphqlRequest.
GraphqlResponse
The GraphQL response from Firebase SQL Connect.
GraphqlResponseExtensions
GraphqlResponseExtensions contains additional information of GraphqlResponse or ExecuteQueryResponse.
HttpGraphql
Settings for HTTP GraphQL server webhook.
ImpersonateRequest
The Impersonate request to Firebase SQL Connect.
Impersonation
Impersonation configures the Firebase Auth context to impersonate.
ListConnectorsResponse
Message for response to listing Connectors.
ListLocationsResponse
The response message for Locations.ListLocations.
ListOperationsResponse
The response message for Operations.ListOperations.
ListSchemasResponse
Message for response to listing Schemas.
ListServicesResponse
Message for response to listing Services.
Operation
This resource represents a long-running operation that is the result of a network API call.
Part
Represents a chunk of content.
PostgreSql
Settings for PostgreSQL data source.
ProjectsLocationsOperationsResource
ProjectsLocationsResource
ProjectsLocationsServicesConnectorsResource
ProjectsLocationsServicesResource
ProjectsLocationsServicesSchemasResource
ProjectsResource
Schema
The application schema of a Firebase SQL Connect service.
Service
A Firebase SQL Connect service.
Used to represent a set of source files.
SourceLocation
SourceLocation references a location in a GraphQL source.
TextChunk
A chunk of conversational text.
Workaround
Workaround provides suggestions to address errors and warnings.

Typedefs

CancelOperationRequest = $Empty
The request message for Operations.CancelOperation.
Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
ExecuteMutationRequest = $Request11
The ExecuteMutation request to Firebase SQL Connect.
ExecuteQueryRequest = $Request11
The ExecuteQuery request to Firebase SQL Connect.
Location = $Location00
A resource that represents a Google Cloud location.
Status = $Status00
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.