ClientCache class

Client caching settings of a connector.

Constructors

ClientCache({bool? entityIdIncluded, bool? strictValidationEnabled})
ClientCache.fromJson(Map json_)

Properties

entityIdIncluded ↔ bool?
A field that, if true, means that responses served by this connector will include entityIds in GraphQL response extensions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strictValidationEnabled ↔ bool?
A field that, if true, enables stricter validation on the connector source code to make sure the operation response shapes are suitable for client-side caching.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited