strictValidationEnabled property

bool? strictValidationEnabled
getter/setter pair

A field that, if true, enables stricter validation on the connector source code to make sure the operation response shapes are suitable for client-side caching.

This can include additional errors and warnings. For example, using the same alias for different fields is disallowed, as it may cause conflicts or confusion with normalized caching. (This field is off by default for compatibility, but enabling it is highly recommended to catch common caching pitfalls.)

Optional.

Implementation

core.bool? strictValidationEnabled;