CloudSqlInstance class
Settings for CloudSQL instance configuration.
Constructors
- CloudSqlInstance({String? edition, String? instance})
- CloudSqlInstance.fromJson(Map json_)
Properties
- edition ↔ String?
-
The Cloud SQL instance edition.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance ↔ String?
-
Name of the CloudSQL instance, in the format:
projects/{project}/locations/{location}/instances/{instance}getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited