languageCode property
Specifies the language if we expand support beyond GraphQL (e.g., SQL or JSON) The standard is BCP-47 language code.
Optional.
Implementation
core.String? languageCode;
Specifies the language if we expand support beyond GraphQL (e.g., SQL or JSON) The standard is BCP-47 language code.
Optional.
core.String? languageCode;