entityIds property

List<String>? entityIds
getter/setter pair

A list of Entity IDs.

Set if the path points to an array of entities. An ID is present for each element of the array at the corresponding index.

Implementation

core.List<core.String>? entityIds;