ExecuteQueryResponse class

The ExecuteQuery response from Firebase SQL Connect.

Properties

data ↔ Map<String, Object?>?
The result of executing the requested operation.
getter/setter pair
errors ↔ List<GraphqlError>?
Errors of this response.
getter/setter pair
extensions ↔ GraphqlResponseExtensions?
Additional response information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited