GenerateQueryRequest class
Request message for GenerateQuery.
Constructors
-
GenerateQueryRequest({String? prompt, List<
Schema> ? schemas}) - GenerateQueryRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- prompt ↔ String?
-
The natural language description of the desired query.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schemas
↔ List<
Schema> ? -
The user's locally defined FDC Schema(s).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited