prompt property
The natural language description of the desired query.
Example: "Find all users who signed up in the last 7 days."
Required.
Implementation
core.String? prompt;
The natural language description of the desired query.
Example: "Find all users who signed up in the last 7 days."
Required.
core.String? prompt;