prompt property
The natural language description of the data model to generate.
Example: "A blog system with Users, Posts, and Comments. Users can have multiple posts."
Required.
Implementation
core.String? prompt;
The natural language description of the data model to generate.
Example: "A blog system with Users, Posts, and Comments. Users can have multiple posts."
Required.
core.String? prompt;