GenerateSchemaResponse class

Output for streaming generate schema requests

Properties

hashCode int
The hash code for this object.
no setterinherited
part Part?
The content from the current conversational turn.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status GenerationStatus?
Essential for providing responsive UI feedback (e.g., a spinner or "Analyzing schema..." step).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited