GenerationStatus class

Represents the progress of the server side generation request.

Constructors

GenerationStatus({String? message, String? state})
GenerationStatus.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
A message providing more details about the state.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of generation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited