HttpGraphql class

Settings for HTTP GraphQL server webhook.

Constructors

HttpGraphql({String? timeout, String? uri})
HttpGraphql.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeout ↔ String?
Timeout duration for the HTTP request.
getter/setter pair
uri ↔ String?
The endpoint of the HTTP GraphQL server.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited