PostgreSql class

Settings for PostgreSQL data source.

Constructors

PostgreSql({CloudSqlInstance? cloudSql, String? database, bool? ephemeral, String? schema, String? schemaMigration, String? schemaValidation, bool? unlinked})
PostgreSql.fromJson(Map json_)

Properties

cloudSql CloudSqlInstance?
Cloud SQL configurations.
getter/setter pair
database String?
Name of the PostgreSQL database.
getter/setter pair
ephemeral bool?
Ephemeral is true if this SQL Connect service is served from temporary in-memory emulation of Postgres.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schema String?
User-configured PostgreSQL schema.
getter/setter pair
schemaMigration String?
Configure how to perform automatic PostgreSQL schema migration before deploying the FDC schema.
getter/setter pair
schemaValidation String?
Configure how much PostgreSQL schema validation to perform against the live database before deploying the FDC schema.
getter/setter pair
unlinked bool?
No Postgres data source is linked.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited