schemaMigration property

String? schemaMigration
getter/setter pair

Configure how to perform automatic PostgreSQL schema migration before deploying the FDC schema.

This is an additive-only operation.

Optional. Possible string values are:

  • "SQL_SCHEMA_MIGRATION_UNSPECIFIED" : Unspecified SQL schema migration.
  • "MIGRATE_COMPATIBLE" : Waits for the Cloud SQL instance to be provisioned and automatically creates necessary SQL resources (tables, columns, etc.) to match the desired FDC schema. This operation is strictly additive and executes as a Long-Running Operation during provisioning. Rejects migrations on a non-empty existing SQL schema.

Implementation

core.String? schemaMigration;