Schema class

The application schema of a Firebase SQL Connect service.

Constructors

Schema({Map<String, String>? annotations, String? createTime, List<Datasource>? datasources, String? displayName, String? etag, Map<String, String>? labels, String? name, bool? reconciling, Source? source, String? uid, String? updateTime})
Schema.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Stores small amounts of arbitrary data.
getter/setter pair
createTime ↔ String?
Create time stamp.
getter/setter pair
datasources ↔ List<Datasource>?
The data sources linked in the schema.
getter/setter pair
displayName ↔ String?
Mutable human-readable name.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels as key value pairs.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
reconciling ↔ bool?
A field that if true, indicates that the system is working to compile and deploy the schema.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Source?
The source files that comprise the application schema.
getter/setter pair
uid ↔ String?
System-assigned, unique identifier.
getter/setter pair
updateTime ↔ String?
Update time stamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited