Service class

A Firebase SQL Connect service.

Constructors

Service({Map<String, String>? annotations, List<Connector>? connectors, String? createTime, String? displayName, String? etag, Map<String, String>? labels, String? name, bool? reconciling, List<Schema>? schemas, Source? source, String? uid, String? updateTime})
Service.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Stores small amounts of arbitrary data.
getter/setter pair
connectors ↔ List<Connector>?
The list of connectors in this service.
getter/setter pair
createTime ↔ String?
Create time stamp.
getter/setter pair
displayName ↔ String?
Mutable human-readable name.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels as key value pairs.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
reconciling ↔ bool?
A field that if true, indicates that the system is working update the service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemas ↔ List<Schema>?
The list of schemas in this service.
getter/setter pair
source ↔ Source?
Input only.
getter/setter pair
uid ↔ String?
System-assigned, unique identifier.
getter/setter pair
updateTime ↔ String?
Update time stamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited