Workaround class

Workaround provides suggestions to address errors and warnings.

Constructors

Workaround({String? description, String? reason, String? replace})
Workaround.fromJson(Map json_)

Properties

description ↔ String?
Description of this workaround.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reason ↔ String?
Why would this workaround address the error and warning.
getter/setter pair
replace ↔ String?
A suggested code snippet to fix the error and warning.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited