V1Resource class

Constructors

V1Resource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLinkStats(String dynamicLink, {String? durationDays, String? sdkVersion, String? $fields}) → Future<DynamicLinkStats>
Fetches analytics stats of a short Dynamic Link for a given duration.
installAttribution(GetIosPostInstallAttributionRequest request, {String? $fields}) → Future<GetIosPostInstallAttributionResponse>
Get iOS strong/weak-match info for post-install attribution.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reopenAttribution(GetIosReopenAttributionRequest request, {String? $fields}) → Future<GetIosReopenAttributionResponse>
Get iOS reopen attribution for app universal link open deeplinking.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited