Arg class

Arg matchers for the mock function.

Constructors

Arg({Empty? anyValue, Object? exactValue})
Arg.fromJson(Map json_)

Properties

anyValue ↔ Empty?
Argument matches any value provided.
getter/setter pair
exactValue ↔ Object?
Argument exactly matches value provided.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited