GetReleaseExecutableResponse class

The response for FirebaseRulesService.GetReleaseExecutable

Constructors

GetReleaseExecutableResponse({String? executable, String? executableVersion, String? language, String? rulesetName, String? syncTime, String? updateTime})
GetReleaseExecutableResponse.fromJson(Map json_)

Properties

executable ↔ String?
Executable view of the Ruleset referenced by the Release.
getter/setter pair
executableAsBytes ↔ List<int>
getter/setter pair
executableVersion ↔ String?
The Rules runtime version of the executable. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
language ↔ String?
Language used to generate the executable bytes. Possible string values are:
getter/setter pair
rulesetName ↔ String?
Ruleset name associated with the Release executable.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncTime ↔ String?
Optional, indicates the freshness of the result.
getter/setter pair
updateTime ↔ String?
Timestamp for the most recent Release.update_time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited