SourcePosition class

Position in the Source content including its line, column number, and an index of the File in the Source message.

Used for debug purposes.

Constructors

SourcePosition({int? column, int? currentOffset, int? endOffset, String? fileName, int? line})
SourcePosition.fromJson(Map json_)

Properties

column ↔ int?
First column on the source line associated with the source fragment.
getter/setter pair
currentOffset ↔ int?
Start position relative to the beginning of the file.
getter/setter pair
endOffset ↔ int?
End position relative to the beginning of the file.
getter/setter pair
fileName ↔ String?
Name of the File.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
line ↔ int?
Line number of the source fragment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited