TestRulesetResponse class

The response for FirebaseRulesService.TestRuleset.

Constructors

TestRulesetResponse({List<Issue>? issues, List<TestResult>? testResults})
TestRulesetResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
issues ↔ List<Issue>?
Syntactic and semantic Source issues of varying severity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testResults ↔ List<TestResult>?
The set of test results given the test cases in the TestSuite.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited