TestSuite class

TestSuite is a collection of TestCase instances that validate the logical correctness of a Ruleset.

The TestSuite may be referenced in-line within a TestRuleset invocation or as part of a Release object as a pre-release check.

Constructors

TestSuite({List<TestCase>? testCases})
TestSuite.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testCases ↔ List<TestCase>?
Collection of test cases associated with the TestSuite.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited