UpdateReleaseRequest class

The request for FirebaseRulesService.UpdateRelease.

Constructors

UpdateReleaseRequest({Release? release, String? updateMask})
UpdateReleaseRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
release ↔ Release?
Release to update.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask ↔ String?
Specifies which fields to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited