AggregationResult class

The result of a single bucket from a Firestore aggregation query.

The keys of aggregate_fields are the same for all results in an aggregation query, unlike document queries which can have different fields present for each result.

Constructors

AggregationResult({Map<String, Value>? aggregateFields})
AggregationResult.fromJson(Map json_)

Properties

aggregateFields ↔ Map<String, Value>?
The result of the aggregation functions, ex: COUNT(*) AS total_docs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited