BatchWriteResponse class

The response from Firestore.BatchWrite.

Constructors

BatchWriteResponse({List<Status>? status, List<WriteResult>? writeResults})
BatchWriteResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ List<Status>?
The status of applying the writes.
getter/setter pair
writeResults ↔ List<WriteResult>?
The result of applying the writes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited