CommitRequest class

The request for Firestore.Commit.

Constructors

CommitRequest({String? transaction, List<Write>? writes})
CommitRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction ↔ String?
If set, applies all writes in this transaction, and commits it.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair
writes ↔ List<Write>?
The writes to apply.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited