Cursor class

A position in a query result set.

Constructors

Cursor({bool? before, List<Value>? values})
Cursor.fromJson(Map json_)

Properties

before ↔ bool?
If the position is just before or just after the given values, relative to the sort order defined by the query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<Value>?
The values that represent a position, in the order they appear in the order by clause of a query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited