ExplainStats class

Pipeline explain stats.

Depending on the explain options in the original request, this can contain the optimized plan and / or execution stats.

Constructors

ExplainStats({Map<String, Object?>? data})
ExplainStats.fromJson(Map json_)

Properties

data ↔ Map<String, Object?>?
The format depends on the output_format options in the request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited