Function_ class

Represents an unevaluated scalar expression.

For example, the expression like(user_name, "%alice%") is represented as:

"%alice%" } ```

Constructors

Function_({List<Value>? args, String? name, Map<String, Value>? options})
Function_.fromJson(Map json_)

Properties

args ↔ List<Value>?
Ordered list of arguments the given function expects.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the function to evaluate.
getter/setter pair
options ↔ Map<String, Value>?
Optional named arguments that certain functions may support.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited