collectionGroupScope property
If set, the change stream is scoped to a collection group.
Implementation
GoogleFirestoreAdminV1CollectionGroupScope? collectionGroupScope;
If set, the change stream is scoped to a collection group.
GoogleFirestoreAdminV1CollectionGroupScope? collectionGroupScope;