databaseScope property
If set, the change stream is scoped to the entire database.
Implementation
GoogleFirestoreAdminV1DatabaseScope? databaseScope;
If set, the change stream is scoped to the entire database.
GoogleFirestoreAdminV1DatabaseScope? databaseScope;