GoogleFirestoreAdminV1CustomerManagedEncryptionOptions class

The configuration options for using CMEK (Customer Managed Encryption Key) encryption.

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
Only keys in the same location as the database are allowed to be used for encryption.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited