GoogleFirestoreAdminV1Database class

A Cloud Firestore Database.

Constructors

GoogleFirestoreAdminV1Database({String? appEngineIntegrationMode, GoogleFirestoreAdminV1CmekConfig? cmekConfig, String? concurrencyMode, String? createTime, String? databaseEdition, String? deleteProtectionState, String? deleteTime, String? earliestVersionTime, String? etag, String? firestoreDataAccessMode, bool? freeTier, String? keyPrefix, String? locationId, String? mongodbCompatibleDataAccessMode, String? name, String? pointInTimeRecoveryEnablement, String? previousId, String? realtimeUpdatesMode, GoogleFirestoreAdminV1SourceInfo? sourceInfo, Map<String, String>? tags, String? type, String? uid, String? updateTime, String? versionRetentionPeriod})
GoogleFirestoreAdminV1Database.fromJson(Map json_)

Properties

appEngineIntegrationMode ↔ String?
The App Engine integration mode to use for this database. Possible string values are:
getter/setter pair
cmekConfig ↔ GoogleFirestoreAdminV1CmekConfig?
Presence indicates CMEK is enabled for this database.
getter/setter pair
concurrencyMode ↔ String?
The default concurrency control mode to use for this database.
getter/setter pair
createTime ↔ String?
The timestamp at which this database was created.
getter/setter pair
databaseEdition ↔ String?
The edition of the database.
getter/setter pair
deleteProtectionState ↔ String?
State of delete protection for the database. Possible string values are:
getter/setter pair
deleteTime ↔ String?
The timestamp at which this database was deleted.
getter/setter pair
earliestVersionTime ↔ String?
The earliest timestamp at which older versions of the data can be read from the database.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
firestoreDataAccessMode ↔ String?
The Firestore API data access mode to use for this database.
getter/setter pair
freeTier ↔ bool?
Background: Free tier is the ability of a Firestore database to use a small amount of resources every day without being charged.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyPrefix ↔ String?
The key_prefix for this database.
getter/setter pair
locationId ↔ String?
The location of the database.
getter/setter pair
mongodbCompatibleDataAccessMode ↔ String?
The MongoDB compatible API data access mode to use for this database.
getter/setter pair
name ↔ String?
The resource name of the Database.
getter/setter pair
pointInTimeRecoveryEnablement ↔ String?
Whether to enable the PITR feature on this database. Possible string values are:
getter/setter pair
previousId ↔ String?
The database resource's prior database ID.
getter/setter pair
realtimeUpdatesMode ↔ String?
The default Realtime Updates mode to use for this database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceInfo ↔ GoogleFirestoreAdminV1SourceInfo?
Information about the provenance of this database.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
type ↔ String?
The type of the database.
getter/setter pair
uid ↔ String?
The system-generated UUID4 for this Database.
getter/setter pair
updateTime ↔ String?
The timestamp at which this database was most recently updated.
getter/setter pair
versionRetentionPeriod ↔ String?
The period during which past versions of data are retained in the database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited