GoogleFirestoreAdminV1DatabaseScope typedef

GoogleFirestoreAdminV1DatabaseScope = $Empty

The change stream is scoped to the entire database.

All events in the database are visible to the Change Stream. One Database scope Change Stream is allowed per database.

Implementation

typedef GoogleFirestoreAdminV1DatabaseScope = $Empty;