GoogleFirestoreAdminV1EncryptionConfig class

Encryption configuration for a new database being created from another source.

The source could be a Backup or a PitrSnapshot.

Properties

customerManagedEncryption ↔ GoogleFirestoreAdminV1CustomerManagedEncryptionOptions?
Use Customer Managed Encryption Keys (CMEK) for encryption.
getter/setter pair
googleDefaultEncryption ↔ GoogleFirestoreAdminV1DailyRecurrence?
Use Google default encryption.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useSourceEncryption ↔ GoogleFirestoreAdminV1DailyRecurrence?
The database will use the same encryption configuration as the source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited