fields property

List<GoogleFirestoreAdminV1IndexField>? fields
getter/setter pair

The fields supported by this index.

At most 100 fields may be specified. In Standard edition databases only: - At least 2 fields must be specified. - The last field entry is always for the field path __name__. If, on creation, __name__ was not specified as the last field, it will be added automatically with the same direction as that of the last field defined. If the final field in the index is not directional, the __name__ will be ordered ASCENDING (unless explicitly specified).

Implementation

core.List<GoogleFirestoreAdminV1IndexField>? fields;