GoogleFirestoreAdminV1SearchGeoSpec class
The specification for how to build a geo search index for a field.
Constructors
- GoogleFirestoreAdminV1SearchGeoSpec({bool? geoJsonIndexingDisabled})
- GoogleFirestoreAdminV1SearchGeoSpec.fromJson(Map json_)
Properties
- geoJsonIndexingDisabled ↔ bool?
-
Disables geoJSON indexing for the field.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited