GoogleFirestoreAdminV1SearchIndexOptions class

Options for search indexes at the definition level.

Constructors

GoogleFirestoreAdminV1SearchIndexOptions({String? textLanguage, String? textLanguageOverrideFieldPath})
GoogleFirestoreAdminV1SearchIndexOptions.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textLanguage String?
The language to use for text search indexes.
getter/setter pair
textLanguageOverrideFieldPath String?
The field in the document that specifies which language to use for that specific document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited