textLanguageOverrideFieldPath property

String? textLanguageOverrideFieldPath
getter/setter pair

The field in the document that specifies which language to use for that specific document.

For indexes with MONGODB_COMPATIBLE_API ApiScope: if unspecified, the language is taken from the "language" field if it exists or from text_language if it does not.

Optional.

Implementation

core.String? textLanguageOverrideFieldPath;