GoogleFirestoreAdminV1SearchTextIndexSpec class
Specification of how the field should be indexed for search text indexes.
Constructors
- GoogleFirestoreAdminV1SearchTextIndexSpec({String? indexType, String? matchType})
- GoogleFirestoreAdminV1SearchTextIndexSpec.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexType ↔ String?
-
How to index the text field value.
getter/setter pair
- matchType ↔ String?
-
How to match the text field value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited