GoogleFirestoreAdminV1SourceInfo class

Information about the provenance of this database.

Properties

backup ↔ GoogleFirestoreAdminV1BackupSource?
If set, this database was restored from the specified backup (or a snapshot thereof).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
operation ↔ String?
The associated long-running operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited