Order class

An order on a field.

Constructors

Order({String? direction, FieldReference? field})
Order.fromJson(Map json_)

Properties

direction ↔ String?
The direction to order by.
getter/setter pair
field ↔ FieldReference?
The field to order by.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited