PartitionQueryResponse class

The response for Firestore.PartitionQuery.

Constructors

PartitionQueryResponse({String? nextPageToken, List<Cursor>? partitions})
PartitionQueryResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A page token that may be used to request an additional set of results, up to the number specified by partition_count in the PartitionQuery request.
getter/setter pair
partitions ↔ List<Cursor>?
Partition results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited