ProjectsDatabasesCollectionGroupsFieldsResource class

Constructors

ProjectsDatabasesCollectionGroupsFieldsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) → Future<GoogleFirestoreAdminV1Field>
Gets the metadata and configuration for a Field.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<GoogleFirestoreAdminV1ListFieldsResponse>
Lists the field configuration and metadata for this database.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleFirestoreAdminV1Field request, String name, {String? updateMask, String? $fields}) → Future<GoogleLongrunningOperation>
Updates a field configuration.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited