concurrencyMode property

String? concurrencyMode
getter/setter pair

The concurrency control mode to use for this transaction.

A database is able to use different concurrency modes for different transactions simultaneously. 3rd party auth requests are only allowed to create optimistic read-write transactions and must specify that here even if the database-level setting is already configured to optimistic.

Optional. Possible string values are:

  • "CONCURRENCY_MODE_UNSPECIFIED" : Start the transaction with the database-level default concurrency mode.
  • "OPTIMISTIC" : Use optimistic concurrency control for the new transaction.
  • "PESSIMISTIC" : Use pessimistic concurrency control for the new transaction.

Implementation

core.String? concurrencyMode;