RunAggregationQueryRequest class

The request for Firestore.RunAggregationQuery.

Constructors

RunAggregationQueryRequest({ExplainOptions? explainOptions, TransactionOptions? newTransaction, String? readTime, StructuredAggregationQuery? structuredAggregationQuery, String? transaction})
RunAggregationQueryRequest.fromJson(Map json_)

Properties

explainOptions ↔ ExplainOptions?
Explain options for the query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newTransaction ↔ TransactionOptions?
Starts a new transaction as part of the query, defaulting to read-only.
getter/setter pair
readTime ↔ String?
Executes the query at the given timestamp.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredAggregationQuery ↔ StructuredAggregationQuery?
An aggregation query.
getter/setter pair
transaction ↔ String?
Run the aggregation within an already active transaction.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited