RunQueryRequest class

The request for Firestore.RunQuery.

Constructors

RunQueryRequest({ExplainOptions? explainOptions, TransactionOptions? newTransaction, String? readTime, StructuredQuery? structuredQuery, String? transaction})
RunQueryRequest.fromJson(Map json_)

Properties

explainOptions ↔ ExplainOptions?
Explain options for the query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newTransaction ↔ TransactionOptions?
Starts a new transaction and reads the documents.
getter/setter pair
readTime ↔ String?
Reads documents as they were at the given time.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structuredQuery ↔ StructuredQuery?
A structured query.
getter/setter pair
transaction ↔ String?
Run the query within an already active transaction.
getter/setter pair
transactionAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited