StructuredQuery class

A Firestore query.

The query stages are executed in the following order: 1. from 2. where 3. select 4. order_by + start_at + end_at 5. offset 6. limit 7. find_nearest

Constructors

StructuredQuery({Cursor? endAt, FindNearest? findNearest, List<CollectionSelector>? from, int? limit, int? offset, List<Order>? orderBy, Projection? select, Cursor? startAt, Filter? where})
StructuredQuery.fromJson(Map json_)

Properties

endAt ↔ Cursor?
A potential prefix of a position in the result set to end the query at.
getter/setter pair
findNearest ↔ FindNearest?
A potential nearest neighbors search.
getter/setter pair
from ↔ List<CollectionSelector>?
The collections to query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int?
The maximum number of results to return.
getter/setter pair
offset ↔ int?
The number of documents to skip before returning the first result.
getter/setter pair
orderBy ↔ List<Order>?
The order to apply to the query results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
select ↔ Projection?
Optional sub-set of the fields to return.
getter/setter pair
startAt ↔ Cursor?
A potential prefix of a position in the result set to start the query at.
getter/setter pair
where ↔ Filter?
The filter to apply.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited