bytesValue property

String? bytesValue
getter/setter pair

A bytes value.

In Standard edition databases: * The value must not exceed 1 MiB - 89 bytes. * Only the first 1,500 bytes are considered by queries. In Enterprise edition databases, there is no limit on the size of the value. However, it is still subject to document and index entry size limits.

Implementation

core.String? bytesValue;