WriteResponse class

The response for Firestore.Write.

Constructors

WriteResponse({String? commitTime, String? streamId, String? streamToken, List<WriteResult>? writeResults})
WriteResponse.fromJson(Map json_)

Properties

commitTime ↔ String?
The time at which the commit occurred.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streamId ↔ String?
The ID of the stream.
getter/setter pair
streamToken ↔ String?
A token that represents the position of this response in the stream.
getter/setter pair
streamTokenAsBytes ↔ List<int>
getter/setter pair
writeResults ↔ List<WriteResult>?
The result of applying the writes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited