AggregateBucket class

Constructors

AggregateBucket({int? activity, List<Dataset>? dataset, String? endTimeMillis, Session? session, String? startTimeMillis, String? type})
AggregateBucket.fromJson(Map json_)

Properties

activity ↔ int?
Available for Bucket.Type.ACTIVITY_TYPE, Bucket.Type.ACTIVITY_SEGMENT
getter/setter pair
dataset ↔ List<Dataset>?
There will be one dataset per AggregateBy in the request.
getter/setter pair
endTimeMillis ↔ String?
The end time for the aggregated data, in milliseconds since epoch, inclusive.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session ↔ Session?
Available for Bucket.Type.SESSION
getter/setter pair
startTimeMillis ↔ String?
The start time for the aggregated data, in milliseconds since epoch, inclusive.
getter/setter pair
type ↔ String?
The type of a bucket signifies how the data aggregation is performed in the bucket. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited