AggregateRequest class

Next id: 10

Constructors

AggregateRequest({List<AggregateBy>? aggregateBy, BucketByActivity? bucketByActivitySegment, BucketByActivity? bucketByActivityType, BucketBySession? bucketBySession, BucketByTime? bucketByTime, String? endTimeMillis, List<String>? filteredDataQualityStandard, String? startTimeMillis})
AggregateRequest.fromJson(Map json_)

Properties

aggregateBy ↔ List<AggregateBy>?
The specification of data to be aggregated.
getter/setter pair
bucketByActivitySegment ↔ BucketByActivity?
Specifies that data be aggregated each activity segment recorded for a user.
getter/setter pair
bucketByActivityType ↔ BucketByActivity?
Specifies that data be aggregated by the type of activity being performed when the data was recorded.
getter/setter pair
bucketBySession ↔ BucketBySession?
Specifies that data be aggregated by user sessions.
getter/setter pair
bucketByTime ↔ BucketByTime?
Specifies that data be aggregated by a single time interval.
getter/setter pair
endTimeMillis ↔ String?
The end of a window of time.
getter/setter pair
filteredDataQualityStandard ↔ List<String>?
DO NOT POPULATE THIS FIELD.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimeMillis ↔ String?
The start of a window of time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited