Application class

Constructors

Application({String? detailsUrl, String? name, String? packageName, String? version})
Application.fromJson(Map json_)

Properties

detailsUrl ↔ String?
An optional URI that can be used to link back to the application.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of this application.
getter/setter pair
packageName ↔ String?
Package name for this application.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
Version of the application.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited