DataType class

Constructors

DataType({List<DataTypeField>? field, String? name})
DataType.fromJson(Map json_)

Properties

field ↔ List<DataTypeField>?
A field represents one dimension of a data type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Each data type has a unique, namespaced, name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited