ListDataPointChangesResponse class

Constructors

ListDataPointChangesResponse({String? dataSourceId, List<DataPoint>? deletedDataPoint, List<DataPoint>? insertedDataPoint, String? nextPageToken})
ListDataPointChangesResponse.fromJson(Map json_)

Properties

dataSourceId ↔ String?
The data stream ID of the data source with data point changes.
getter/setter pair
deletedDataPoint ↔ List<DataPoint>?
Deleted data points for the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
insertedDataPoint ↔ List<DataPoint>?
Inserted data points for the user.
getter/setter pair
nextPageToken ↔ String?
The continuation token, which is used to page through large result sets.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited