ListSessionsResponse class

Constructors

ListSessionsResponse({List<Session>? deletedSession, bool? hasMoreData, String? nextPageToken, List<Session>? session})
ListSessionsResponse.fromJson(Map json_)

Properties

deletedSession ↔ List<Session>?
If includeDeleted is set to true in the request, and startTime and endTime are omitted, this will include sessions which were deleted since the last sync.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasMoreData ↔ bool?
Flag to indicate server has more data to transfer.
getter/setter pair
nextPageToken ↔ String?
The sync token which is used to sync further changes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
session ↔ List<Session>?
Sessions starting before endTime of the request and ending after startTime of the request up to (endTime of the request + 1 day).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited