Session class

Sessions contain metadata, such as a user-friendly name and time interval information.

Constructors

Session({String? activeTimeMillis, int? activityType, Application? application, String? description, String? endTimeMillis, String? id, String? modifiedTimeMillis, String? name, String? startTimeMillis})
Session.fromJson(Map json_)

Properties

activeTimeMillis ↔ String?
Session active time.
getter/setter pair
activityType ↔ int?
The type of activity this session represents.
getter/setter pair
application ↔ Application?
The application that created the session.
getter/setter pair
description ↔ String?
A description for this session.
getter/setter pair
endTimeMillis ↔ String?
An end time, in milliseconds since epoch, inclusive.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
A client-generated identifier that is unique across all sessions owned by this particular user.
getter/setter pair
modifiedTimeMillis ↔ String?
A timestamp that indicates when the session was last modified.
getter/setter pair
name ↔ String?
A human readable name of the session.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTimeMillis ↔ String?
A start time, in milliseconds since epoch, inclusive.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited