BatchUpdateFormResponse class

Response to a BatchUpdateFormRequest.

Constructors

BatchUpdateFormResponse({Form? form, List<Response>? replies, WriteControl? writeControl})
BatchUpdateFormResponse.fromJson(Map json_)

Properties

form ↔ Form?
Based on the bool request field include_form_in_response, a form with all applied mutations/updates is returned or not.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
replies ↔ List<Response>?
The reply of the updates.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeControl ↔ WriteControl?
The updated write control after applying the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited