CloudPubsubTopic class

A Pub/Sub topic.

Constructors

CloudPubsubTopic({String? topicName})
CloudPubsubTopic.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topicName ↔ String?
A fully qualified Pub/Sub topic name to publish the events to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited