CreateItemRequest class

Create an item in a form.

Constructors

CreateItemRequest({Item? item, Location? location})
CreateItemRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
item ↔ Item?
The item to create.
getter/setter pair
location ↔ Location?
Where to place the new item.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited