FileUploadQuestion class

A file upload question.

The API currently does not support creating file upload questions.

Constructors

FileUploadQuestion({String? folderId, String? maxFileSize, int? maxFiles, List<String>? types})
FileUploadQuestion.fromJson(Map json_)

Properties

folderId ↔ String?
The ID of the Drive folder where uploaded files are stored.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxFiles ↔ int?
Maximum number of files that can be uploaded for this question in a single response.
getter/setter pair
maxFileSize ↔ String?
Maximum number of bytes allowed for any single file uploaded to this question.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types ↔ List<String>?
File types accepted by this question.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited