FormsApi class

Reads and writes Google Forms and responses.

Constructors

FormsApi(Client client, {String rootUrl = 'https://forms.googleapis.com/', String servicePath = ''})

Properties

forms → FormsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

driveFileScope → const String
See, edit, create, and delete only the specific Google Drive files you use with this app
driveReadonlyScope → const String
See and download all your Google Drive files
driveScope → const String
See, edit, create, and delete all of your Google Drive files
formsBodyReadonlyScope → const String
See all your Google Forms forms
formsBodyScope → const String
See, edit, create, and delete all your Google Forms forms
formsResponsesReadonlyScope → const String
See all responses to your Google Forms forms