FormsResource class

Constructors

FormsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
responses → FormsResponsesResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
watches → FormsWatchesResource
no setter

Methods

batchUpdate(BatchUpdateFormRequest request, String formId, {String? $fields}) → Future<BatchUpdateFormResponse>
Change the form with a batch of updates.
create(Form request, {bool? unpublished, String? $fields}) → Future<Form>
Create a new form using the title given in the provided form message in the request.
get(String formId, {String? $fields}) → Future<Form>
Get a form.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setPublishSettings(SetPublishSettingsRequest request, String formId, {String? $fields}) → Future<SetPublishSettingsResponse>
Updates the publish settings of a form.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited