FormsWatchesResource class

Constructors

FormsWatchesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(CreateWatchRequest request, String formId, {String? $fields}) → Future<Watch>
Create a new watch.
delete(String formId, String watchId, {String? $fields}) → Future<Empty>
Delete a watch.
list(String formId, {String? $fields}) → Future<ListWatchesResponse>
Return a list of the watches owned by the invoking project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
renew(RenewWatchRequest request, String formId, String watchId, {String? $fields}) → Future<Watch>
Renew an existing watch for seven days.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited