Grid class

A grid of choices (radio or check boxes) with each row constituting a separate question.

Each row has the same choices, which are shown as the columns.

Constructors

Grid({ChoiceQuestion? columns, bool? shuffleQuestions})
Grid.fromJson(Map json_)

Properties

columns ↔ ChoiceQuestion?
The choices shared by each question in the grid.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuffleQuestions ↔ bool?
If true, the questions are randomly ordered.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited