QuizSettings class

Settings related to quiz forms and grading.

These must be updated with the UpdateSettingsRequest.

Constructors

QuizSettings({bool? isQuiz})
QuizSettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isQuiz ↔ bool?
Whether this form is a quiz or not.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited