VideoLink class

Link to a video.

Constructors

VideoLink({String? displayText, String? youtubeUri})
VideoLink.fromJson(Map json_)

Properties

displayText ↔ String?
The display text for the link.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
youtubeUri ↔ String?
The URI of a YouTube video.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited