ftp/v1 library

Cloud FTP API - v1

A managed, cloud-native solution to move data in and out of Google Cloud by using SSH File Transfer Protocol (SFTP).

For more information, see docs.cloud.google.com/cloud-ftp

Create an instance of CloudFTPApi to access these resources:

Classes

AllowedConsumer
A consumer project or network that is permitted to connect to the server via PSC.
CloudFTPApi
A managed, cloud-native solution to move data in and out of Google Cloud by using SSH File Transfer Protocol (SFTP).
DeniedConsumer
A consumer project or network that is denied to connect to the server via PSC.
ExternalServerConfig
Configuration for external server.
InternalServerConfig
Configuration for private server accessible via PSC.
ListLocationsResponse
The response message for Locations.ListLocations.
ListOperationsResponse
The response message for Operations.ListOperations.
ListServersResponse
Message for response to listing Servers
ListUsersResponse
Message for response to listing Users
Operation
This resource represents a long-running operation that is the result of a network API call.
ProjectsLocationsOperationsResource
ProjectsLocationsResource
ProjectsLocationsServersResource
ProjectsLocationsServersUsersResource
ProjectsResource
PscEndpoint
Details of PSC endpoint created by customer.
Server
Message describing Server object
ServerCredential
Represents credentials of an FTP Server.
StorageDirectoryMapping
Mapping of backing Cloud Storage path to the directory where the user lands in the SFTP server.
User
Message describing User object
UserCredential
Message describing UserCredential object

Typedefs

CancelOperationRequest = $Empty
The request message for Operations.CancelOperation.
Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Location = $Location00
A resource that represents a Google Cloud location.
StartServerRequest = $Empty
Request message for starting a Server.
Status = $Status00
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
StopServerRequest = $Empty
Request message for stopping a Server.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.