AllowedConsumer class
A consumer project or network that is permitted to connect to the server via PSC.
Constructors
- AllowedConsumer({String? connectionLimit, String? project})
- AllowedConsumer.fromJson(Map json_)
Properties
- connectionLimit ↔ String?
-
The connection limit for the consumer.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- project ↔ String?
-
The project ID or number of the consumer project.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited