CloudFTPApi class
A managed, cloud-native solution to move data in and out of Google Cloud by using SSH File Transfer Protocol (SFTP).
Constructors
- CloudFTPApi(Client client, {String rootUrl = 'https://ftp.googleapis.com/', String servicePath = ''})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projects → ProjectsResource
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- cloudPlatformScope → const String
- See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.