DeniedConsumer class
A consumer project or network that is denied to connect to the server via PSC.
Constructors
- DeniedConsumer({String? project})
- DeniedConsumer.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited