ExternalServerConfig class

Configuration for external server.

Constructors

ExternalServerConfig({List<String>? allowedCidrBlocks, String? ipAddress})
ExternalServerConfig.fromJson(Map json_)

Properties

allowedCidrBlocks ↔ List<String>?
List of CIDR blocks that are allowed to access the Server.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String?
IP address of the LB via which clients will connect.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited