allowedCidrBlocks property

List<String>? allowedCidrBlocks
getter/setter pair

List of CIDR blocks that are allowed to access the Server.

A CIDR range consists of an IP Address and a prefix length to construct the subnet mask. By default, the prefix length is 32 (i.e. matches a single IP address). For now, only IPV4 addresses are supported. Examples: "203.0.113.0/24" - matches with the IP addresses in the range 203.0.113.0

  • 203.0.113.255. "0.0.0.0/0" - matches against any IP address. This field must contain at least one entry if the access type is EXTERNAL. The number of allowed CIDR blocks cannot exceed 500. Example: 192.168.0.0/16

Optional.

Implementation

core.List<core.String>? allowedCidrBlocks;