InternalServerConfig class

Configuration for private server accessible via PSC.

Constructors

InternalServerConfig({List<AllowedConsumer>? consumerAcceptList, List<DeniedConsumer>? consumerRejectList, List<PscEndpoint>? pscEndpoints, String? serviceAttachment})
InternalServerConfig.fromJson(Map json_)

Properties

consumerAcceptList ↔ List<AllowedConsumer>?
A list of projects that are permitted to connect.
getter/setter pair
consumerRejectList ↔ List<DeniedConsumer>?
A list of projects that are denied connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pscEndpoints ↔ List<PscEndpoint>?
Details of endpoints created by the customer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAttachment ↔ String?
The resource name of the service attachment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited