ProjectsLocationsServersResource class

Constructors

ProjectsLocationsServersResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
users ProjectsLocationsServersUsersResource
no setter

Methods

create(Server request, String parent, {String? requestId, String? serverId, String? $fields}) Future<Operation>
Creates a new Server in a given project and location.
delete(String name, {String? $fields}) Future<Operation>
Deletes a single Server.
get(String name, {String? view, String? $fields}) Future<Server>
Gets details of a single Server.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? view, String? $fields}) Future<ListServersResponse>
Lists Servers in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Server request, String name, {String? requestId, String? updateMask, String? $fields}) Future<Operation>
Updates the parameters of a single Server.
start(StartServerRequest request, String name, {String? $fields}) Future<Operation>
Starts a stopping/stopped Server.
stop(StopServerRequest request, String name, {String? $fields}) Future<Operation>
Stops an active Server.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited