get method
Gets details of a single Server.
Request parameters:
name - Required. Name of the resource
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/servers/\[^/\]+$.
view - Optional. The view of the Server resource to return.
Possible string values are:
- "SERVER_VIEW_UNSPECIFIED" : Default value. Equivalent to SERVER_VIEW_BASIC.
- "SERVER_VIEW_BASIC" : Basic view. Excludes heavy configurations (internal_config, external_config, google_managed_server_credential).
- "SERVER_VIEW_FULL" : Full view. Includes all fields.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Server.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Server> get(
core.String name, {
core.String? view,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'view': ?view == null ? null : [view],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return Server.fromJson(response_ as core.Map<core.String, core.dynamic>);
}