ProjectsLocationsServersUsersResource class

Constructors

ProjectsLocationsServersUsersResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(User request, String parent, {String? requestId, String? userId, String? $fields}) Future<Operation>
Creates a new User in a given project and location and Server.
delete(String name, {bool? force, String? $fields}) Future<Operation>
Deletes a single User.
get(String name, {String? view, String? $fields}) Future<User>
Gets details of a single User.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? view, String? $fields}) Future<ListUsersResponse>
Lists Users in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(User request, String name, {String? updateMask, String? $fields}) Future<Operation>
Updates the parameters of a single User.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited