get method
Gets details of a single User.
Request parameters:
name - Required. Name of the resource
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/servers/\[^/\]+/users/\[^/\]+$.
view - Optional. The view of the User resource to return.
Possible string values are:
- "USER_VIEW_UNSPECIFIED" : Default value. Equivalent to USER_VIEW_BASIC.
- "USER_VIEW_BASIC" : Basic view. Excludes heavy configurations (user_credentials, storage_directory_mappings).
- "USER_VIEW_FULL" : Full view. Includes all fields.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a User.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<User> get(
core.String name, {
core.String? view,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'view': ?view == null ? null : [view],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return User.fromJson(response_ as core.Map<core.String, core.dynamic>);
}