endpoint property
This is a Resource name for Private Service Connect endpoint.
Format:
projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}
Output only.
Implementation
core.String? endpoint;
This is a Resource name for Private Service Connect endpoint.
Format:
projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}
Output only.
core.String? endpoint;