Server class

Message describing Server object

Constructors

Server({String? accessType, String? createTime, String? displayName, ExternalServerConfig? externalConfig, ServerCredential? googleManagedServerCredential, InternalServerConfig? internalConfig, Map<String, String>? labels, String? name, String? serviceAgent, String? state, String? updateTime})
Server.fromJson(Map json_)

Properties

accessType ↔ String?
The access type of the Server.
getter/setter pair
createTime ↔ String?
Create time stamp
getter/setter pair
displayName ↔ String?
Display name of the Server
getter/setter pair
externalConfig ↔ ExternalServerConfig?
Configuration for external access.
getter/setter pair
googleManagedServerCredential ↔ ServerCredential?
Credentials of the FTP Server.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalConfig ↔ InternalServerConfig?
Configuration for internal access.
getter/setter pair
labels ↔ Map<String, String>?
Labels as key value pairs
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAgent ↔ String?
Service agent used to access the customer bucket.
getter/setter pair
state ↔ String?
The state of the server.
getter/setter pair
updateTime ↔ String?
Update time stamp
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited