ServerCredential class

Represents credentials of an FTP Server.

Constructors

ServerCredential({String? asymmetricAlgorithm, String? fingerprint})
ServerCredential.fromJson(Map json_)

Properties

asymmetricAlgorithm String?
Asymmetric algorithm used by the public key.
getter/setter pair
fingerprint String?
The fingerprint is a hash of the public key, and is displayed when clients access the server for the first time to verify the server's identity.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited