StorageDirectoryMapping class

Mapping of backing Cloud Storage path to the directory where the user lands in the SFTP server.

If directory is not specified, it'll default to '/'. Eg 1 - (bucket_name: bucket, bucket_prefix: path1/path2, directory: /abc/def/username) The user will land at /abcd/def/username, and the view there will match that of /bucket/path1/path2. The user will not be aware of Cloud Storage prefix '/bucket/path1' and there will be no such directory in the view. Eg 2 - (bucket_name: bucket, bucket_prefix: path1/path2, directory: '') The user will land at '/', and the view there will match that of /bucket/path1/path2. The user will not be aware of Cloud Storage prefix '/bucket/path1/path2' and there will be no such directory in the view.

Constructors

StorageDirectoryMapping({String? bucket, String? bucketPrefix, String? directory, String? permission})
StorageDirectoryMapping.fromJson(Map json_)

Properties

bucket String?
Name of the bucket.
getter/setter pair
bucketPrefix String?
Prefix inside the bucket.
getter/setter pair
directory String?
Directory where the user lands in the SFTP server.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
permission String?
Permission to the bucket.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited