customerServiceAccount property
Service account in customer project attached to this SFTP User.
Required.
Implementation
core.String? customerServiceAccount;
Service account in customer project attached to this SFTP User.
Required.
core.String? customerServiceAccount;