storageDirectoryMappings property
Mapping of Cloud Storage buckets to directories where the user will land in the SFTP server.
Required.
Implementation
core.List<StorageDirectoryMapping>? storageDirectoryMappings;
Mapping of Cloud Storage buckets to directories where the user will land in the SFTP server.
Required.
core.List<StorageDirectoryMapping>? storageDirectoryMappings;