UserCredential class

Message describing UserCredential object

Constructors

UserCredential({String? credentialName, String? credentialType, String? sshPublicKeyBody})
UserCredential.fromJson(Map json_)

Properties

credentialName String?
Name of the user credential.
getter/setter pair
credentialType String?
Type of credential.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sshPublicKeyBody String?
SSH public key body in OpenSSH format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited