Application class

The Application resource.

Constructors

Application({int? achievementCount, List<ImageAsset>? assets, String? author, ApplicationCategory? category, String? description, List<String>? enabledFeatures, String? id, List<Instance>? instances, String? kind, String? lastUpdatedTimestamp, int? leaderboardCount, String? name, String? themeColor})
Application.fromJson(Map json_)

Properties

achievementCount ↔ int?
The number of achievements visible to the currently authenticated player.
getter/setter pair
assets ↔ List<ImageAsset>?
The assets of the application.
getter/setter pair
author ↔ String?
The author of the application.
getter/setter pair
category ↔ ApplicationCategory?
The category of the application.
getter/setter pair
description ↔ String?
The description of the application.
getter/setter pair
enabledFeatures ↔ List<String>?
A list of features that have been enabled for the application.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the application.
getter/setter pair
instances ↔ List<Instance>?
The instances of the application.
getter/setter pair
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
lastUpdatedTimestamp ↔ String?
The last updated timestamp of the application.
getter/setter pair
leaderboardCount ↔ int?
The number of leaderboards visible to the currently authenticated player.
getter/setter pair
name ↔ String?
The name of the application.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
themeColor ↔ String?
A hint to the client UI for what color to use as an app-themed color.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited