ApplicationPlayerId class

Primary scoped player identifier for an application.

Constructors

ApplicationPlayerId({String? applicationId, String? playerId})
ApplicationPlayerId.fromJson(Map json_)

Properties

applicationId ↔ String?
The application that this player identifier is for.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
playerId ↔ String?
The player identifier for the application.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited