droidGuardBlob property
The DroidGuard blob generated by the client.
This is used to detect abuse signals from the devices
Optional.
Implementation
core.String? droidGuardBlob;
The DroidGuard blob generated by the client.
This is used to detect abuse signals from the devices
Optional.
core.String? droidGuardBlob;