requestTime property
The time from the client when this specific batch of events was submitted.
Required.
Implementation
core.String? requestTime;
The time from the client when this specific batch of events was submitted.
Required.
core.String? requestTime;