salt property
The salt used to generate content binding for the DroidGuard blob.
This is used to prevent replay attacks.
Optional.
Implementation
core.String? salt;
The salt used to generate content binding for the DroidGuard blob.
This is used to prevent replay attacks.
Optional.
core.String? salt;