BatchRecordEventsResponse class

A successful response indicates that the batch of events has been processed.

Properties

failedRequests Map<String, Status>?
Map of failed events, keyed by their zero-based index in BatchRecordEventsRequest.events.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited