EventPeriodRange class

An event period time range.

Constructors

EventPeriodRange({String? kind, String? periodEndMillis, String? periodStartMillis})
EventPeriodRange.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
periodEndMillis ↔ String?
The time when this update period ends, in millis, since 1970 UTC (Unix Epoch).
getter/setter pair
periodStartMillis ↔ String?
The time when this update period begins, in millis, since 1970 UTC (Unix Epoch).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited