EventPeriodUpdate class

An event period update resource.

Constructors

EventPeriodUpdate({String? kind, EventPeriodRange? timePeriod, List<EventUpdateRequest>? updates})
EventPeriodUpdate.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timePeriod ↔ EventPeriodRange?
The time period being covered by this update.
getter/setter pair
updates ↔ List<EventUpdateRequest>?
The updates being made for this time period.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited