EventRecordFailure class

An event update failure resource.

Constructors

EventRecordFailure({String? eventId, String? failureCause, String? kind})
EventRecordFailure.fromJson(Map json_)

Properties

eventId ↔ String?
The ID of the event that was not updated.
getter/setter pair
failureCause ↔ String?
The cause for the update failure. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited