EventRecordRequest class

An event period update resource.

Constructors

EventRecordRequest({String? currentTimeMillis, String? kind, String? requestId, List<EventPeriodUpdate>? timePeriods})
EventRecordRequest.fromJson(Map json_)

Properties

currentTimeMillis ↔ String?
The current time when this update was sent, in milliseconds, since 1970 UTC (Unix Epoch).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
requestId ↔ String?
The request ID used to identify this attempt to record events.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timePeriods ↔ List<EventPeriodUpdate>?
A list of the time period updates being made in this request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited