EventUpdateRequest class

An event period update resource.

Constructors

EventUpdateRequest({String? definitionId, String? kind, String? updateCount})
EventUpdateRequest.fromJson(Map json_)

Properties

definitionId ↔ String?
The ID of the event being modified in this update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateCount ↔ String?
The number of times this event occurred in this time period.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited