GameStatsResource class
Constructors
- GameStatsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchRecordEvents(
BatchRecordEventsRequest request, String playerId, {String? $fields}) → Future< BatchRecordEventsResponse> - Records a batch of player game events for a specific player.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited