batchRecordEvents method
Future<BatchRecordEventsResponse>
batchRecordEvents(
- BatchRecordEventsRequest request,
- String playerId, {
- String? $fields,
Records a batch of player game events for a specific player.
This method allows sending multiple events in a single request.
request - The metadata request object.
Request parameters:
playerId - Required. The player ID of the player that performed the
events.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a BatchRecordEventsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<BatchRecordEventsResponse> batchRecordEvents(
BatchRecordEventsRequest request,
core.String playerId, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'games/v1/players/' +
commons.escapeVariable('$playerId') +
'/gameStats:batchRecordEvents';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return BatchRecordEventsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}