InstanceAndroidDetails class

The Android instance details resource.

Constructors

InstanceAndroidDetails({bool? enablePiracyCheck, String? kind, String? packageName, bool? preferred})
InstanceAndroidDetails.fromJson(Map json_)

Properties

enablePiracyCheck ↔ bool?
Flag indicating whether the anti-piracy check is enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
packageName ↔ String?
Android package name which maps to Google Play URL.
getter/setter pair
preferred ↔ bool?
Indicates that this instance is the default for new installations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited