InstanceWebDetails class

The Web details resource.

Constructors

InstanceWebDetails({String? kind, String? launchUrl, bool? preferred})
InstanceWebDetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
launchUrl ↔ String?
Launch URL for the game.
getter/setter pair
preferred ↔ bool?
Indicates that this instance is the default for new installations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited