Player class

A Player resource.

Constructors

Player({String? avatarImageUrl, String? bannerUrlLandscape, String? bannerUrlPortrait, String? displayName, PlayerExperienceInfo? experienceInfo, String? friendStatus, String? gamePlayerId, String? kind, PlayerName? name, String? originalPlayerId, String? playerId, ProfileSettings? profileSettings, String? title})
Player.fromJson(Map json_)

Properties

avatarImageUrl ↔ String?
The base URL for the image that represents the player.
getter/setter pair
bannerUrlLandscape ↔ String?
The url to the landscape mode player banner image.
getter/setter pair
bannerUrlPortrait ↔ String?
The url to the portrait mode player banner image.
getter/setter pair
displayName ↔ String?
The name to display for the player.
getter/setter pair
experienceInfo ↔ PlayerExperienceInfo?
An object to represent Play Game experience information for the player.
getter/setter pair
friendStatus ↔ String?
The friend status of the given player, relative to the requester.
getter/setter pair
gamePlayerId ↔ String?
Per-application unique player identifier.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
name ↔ PlayerName?
A representation of the individual components of the name.
getter/setter pair
originalPlayerId ↔ String?
The player ID that was used for this player the first time they signed into the game in question.
getter/setter pair
playerId ↔ String?
The ID of the player.
getter/setter pair
profileSettings ↔ ProfileSettings?
The player's profile settings.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The player's title rewarded for their game activities.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited