PlayerEvent class

An event status resource.

Constructors

PlayerEvent({String? definitionId, String? formattedNumEvents, String? kind, String? numEvents, String? playerId})
PlayerEvent.fromJson(Map json_)

Properties

definitionId ↔ String?
The ID of the event definition.
getter/setter pair
formattedNumEvents ↔ String?
The current number of times this event has occurred, as a string.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
numEvents ↔ String?
The current number of times this event has occurred.
getter/setter pair
playerId ↔ String?
The ID of the player.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited