PlayerGameEvent class

A representation of a single player game event triggered by a player's event in a game.

This might be completing a level, unlocking an item, or finishing a match.

Constructors

PlayerGameEvent({String? eventId, String? eventName, Map<String, PropertyValue>? eventProperties, String? eventTime})
PlayerGameEvent.fromJson(Map json_)

Properties

eventId String?
A unique client-generated UUID for this specific event instance.
getter/setter pair
eventName String?
Client-defined name of the event (e.g., "run_completed", "level_up").
getter/setter pair
eventProperties Map<String, PropertyValue>?
Key-value properties providing details about the event.
getter/setter pair
eventTime String?
The time from the client when this specific event was performed.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited