PlayerName class

A representation of the individual components of the name.

Constructors

PlayerName({String? familyName, String? givenName})
PlayerName.fromJson(Map json_)

Properties

familyName ↔ String?
The family name of this player.
getter/setter pair
givenName ↔ String?
The given name of this player.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited