PlayerScoreResponse class

A list of leaderboard entry resources.

Constructors

PlayerScoreResponse({List<String>? beatenScoreTimeSpans, String? formattedScore, String? kind, String? leaderboardId, String? scoreTag, List<PlayerScore>? unbeatenScores})
PlayerScoreResponse.fromJson(Map json_)

Properties

beatenScoreTimeSpans ↔ List<String>?
The time spans where the submitted score is better than the existing score for that time span.
getter/setter pair
formattedScore ↔ String?
The formatted value of the submitted score.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Uniquely identifies the type of this resource.
getter/setter pair
leaderboardId ↔ String?
The leaderboard ID that this score was submitted to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scoreTag ↔ String?
Additional information about this score.
getter/setter pair
unbeatenScores ↔ List<PlayerScore>?
The scores in time spans that have not been beaten.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited