PropertyValue class
Wrapper for the value.
Constructors
- PropertyValue({bool? boolValue, double? doubleValue, String? durationValue, String? intValue, String? stringValue, String? timestampValue})
- PropertyValue.fromJson(Map json_)
Properties
- boolValue ↔ bool?
-
A boolean value.
getter/setter pair
- doubleValue ↔ double?
-
A double value.
getter/setter pair
- durationValue ↔ String?
-
A duration value.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- intValue ↔ String?
-
An integer value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue ↔ String?
-
A string value.
getter/setter pair
- timestampValue ↔ String?
-
A timestamp value.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited