namespaceCount property
The total number of user managed namespaces contained in the Backup.
Output only.
Implementation
core.int? namespaceCount;
The total number of user managed namespaces contained in the Backup.
Output only.
core.int? namespaceCount;