BackupConfig class

BackupConfig defines the configuration of Backups created via this BackupPlan.

Constructors

BackupConfig({bool? allNamespaces, EncryptionKey? encryptionKey, bool? includeSecrets, bool? includeVolumeData, bool? permissiveMode, NamespacedNames? selectedApplications, ResourceLabels? selectedNamespaceLabels, Namespaces? selectedNamespaces})
BackupConfig.fromJson(Map json_)

Properties

allNamespaces ↔ bool?
If True, include all namespaced resources
getter/setter pair
encryptionKey ↔ EncryptionKey?
This defines a customer managed encryption key that will be used to encrypt the "config" portion (the Kubernetes resources) of Backups created via this plan.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeSecrets ↔ bool?
This flag specifies whether Kubernetes Secret resources should be included when they fall into the scope of Backups.
getter/setter pair
includeVolumeData ↔ bool?
This flag specifies whether volume data should be backed up when PVCs are included in the scope of a Backup.
getter/setter pair
permissiveMode ↔ bool?
If false, Backups will fail when Backup for GKE detects Kubernetes configuration that is non-standard or requires additional setup to restore.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedApplications ↔ NamespacedNames?
If set, include just the resources referenced by the listed ProtectedApplications.
getter/setter pair
selectedNamespaceLabels ↔ ResourceLabels?
If set, the list of labels whose constituent namespaces were included in the Backup.
getter/setter pair
selectedNamespaces ↔ Namespaces?
If set, include just the resources in the listed namespaces.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited