RestoreConfig class

Configuration of a restore.

Constructors

RestoreConfig({bool? allNamespaces, String? clusterResourceConflictPolicy, ClusterResourceRestoreScope? clusterResourceRestoreScope, Namespaces? excludedNamespaces, String? namespacedResourceRestoreMode, bool? noNamespaces, RestoreOrder? restoreOrder, NamespacedNames? selectedApplications, Namespaces? selectedNamespaces, List<SubstitutionRule>? substitutionRules, List<TransformationRule>? transformationRules, String? volumeDataRestorePolicy, List<VolumeDataRestorePolicyBinding>? volumeDataRestorePolicyBindings})
RestoreConfig.fromJson(Map json_)

Properties

allNamespaces ↔ bool?
Restore all namespaced resources in the Backup if set to "True".
getter/setter pair
clusterResourceConflictPolicy ↔ String?
Defines the behavior for handling the situation where cluster-scoped resources being restored already exist in the target cluster.
getter/setter pair
clusterResourceRestoreScope ↔ ClusterResourceRestoreScope?
Identifies the cluster-scoped resources to restore from the Backup.
getter/setter pair
excludedNamespaces ↔ Namespaces?
A list of selected namespaces excluded from restoration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
namespacedResourceRestoreMode ↔ String?
Defines the behavior for handling the situation where sets of namespaced resources being restored already exist in the target cluster.
getter/setter pair
noNamespaces ↔ bool?
Do not restore any namespaced resources if set to "True".
getter/setter pair
restoreOrder ↔ RestoreOrder?
RestoreOrder contains custom ordering to use on a Restore.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedApplications ↔ NamespacedNames?
A list of selected ProtectedApplications to restore.
getter/setter pair
selectedNamespaces ↔ Namespaces?
A list of selected Namespaces to restore from the Backup.
getter/setter pair
substitutionRules ↔ List<SubstitutionRule>?
A list of transformation rules to be applied against Kubernetes resources as they are selected for restoration from a Backup.
getter/setter pair
transformationRules ↔ List<TransformationRule>?
A list of transformation rules to be applied against Kubernetes resources as they are selected for restoration from a Backup.
getter/setter pair
volumeDataRestorePolicy ↔ String?
Specifies the mechanism to be used to restore volume data.
getter/setter pair
volumeDataRestorePolicyBindings ↔ List<VolumeDataRestorePolicyBinding>?
A table that binds volumes by their scope to a restore policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited