rolloutCreationScope property

RolloutCreationScope? rolloutCreationScope
getter/setter pair

Specifies the scope of automation for the creation of rollouts.

Represents the types of rollouts (version upgrades) the sequence should initiate automatically. If this field is unset, it defaults to all types. If this field is set but the internal upgrade_types list is empty, most automatic rollouts are disabled for this sequence. Exceptions are rollouts enforcing our security policies (e.g. such as end-of-support and outdated control plane patch enforcements). These policy enforcements cannot be disabled.

Optional.

Implementation

RolloutCreationScope? rolloutCreationScope;