compliancePostureConfig property

  1. @Deprecated('Not supported. Member documentation may have more information.')
CompliancePostureConfig? compliancePostureConfig
getter/setter pair

Deprecated: Compliance Posture is no longer supported.

For more details, see https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation. Enable/Disable Compliance Posture features for the cluster. Note that on UpdateFleet, only full replacement of this field is allowed. Users are not allowed for partial updates through field mask.

Optional.

Implementation

@core.Deprecated(
  'Not supported. Member documentation may have more information.',
)
CompliancePostureConfig? compliancePostureConfig;