EdgeCluster class

EdgeCluster contains information specific to Google Edge Clusters.

Constructors

EdgeCluster({String? resourceLink})
EdgeCluster.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
Self-link of the Google Cloud resource for the Edge Cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited