Feature class

Feature represents the settings and status of any Fleet Feature.

Constructors

Feature({String? createTime, String? deleteTime, CommonFleetDefaultMemberConfigSpec? fleetDefaultMemberConfig, Map<String, String>? labels, Map<String, MembershipFeatureSpec>? membershipSpecs, Map<String, MembershipFeatureState>? membershipStates, String? name, FeatureResourceState? resourceState, Map<String, ScopeFeatureSpec>? scopeSpecs, Map<String, ScopeFeatureState>? scopeStates, CommonFeatureSpec? spec, CommonFeatureState? state, List<String>? unreachable, String? updateTime})
Feature.fromJson(Map json_)

Properties

createTime ↔ String?
When the Feature resource was created.
getter/setter pair
deleteTime ↔ String?
When the Feature resource was deleted.
getter/setter pair
fleetDefaultMemberConfig ↔ CommonFleetDefaultMemberConfigSpec?
Feature configuration applicable to all memberships of the fleet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels for this Feature.
getter/setter pair
membershipSpecs ↔ Map<String, MembershipFeatureSpec>?
Membership-specific configuration for this Feature.
getter/setter pair
membershipStates ↔ Map<String, MembershipFeatureState>?
Membership-specific Feature status.
getter/setter pair
name ↔ String?
The full, unique name of this Feature resource in the format projects / * /locations / * /features / * .
getter/setter pair
resourceState ↔ FeatureResourceState?
State of the Feature resource itself.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeSpecs ↔ Map<String, ScopeFeatureSpec>?
Scope-specific configuration for this Feature.
getter/setter pair
scopeStates ↔ Map<String, ScopeFeatureState>?
Scope-specific Feature status.
getter/setter pair
spec ↔ CommonFeatureSpec?
Fleet-wide Feature configuration.
getter/setter pair
state ↔ CommonFeatureState?
The Fleet-wide Feature state.
getter/setter pair
unreachable ↔ List<String>?
List of locations that could not be reached while fetching this feature.
getter/setter pair
updateTime ↔ String?
When the Feature resource was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited