FleetObservabilityFeatureState class

FleetObservability: Hub-wide Feature for FleetObservability feature.

state.

Properties

hashCode → int
The hash code for this object.
no setterinherited
logging ↔ FleetObservabilityFleetObservabilityLoggingState?
The feature state of default logging.
getter/setter pair
monitoring ↔ FleetObservabilityFleetObservabilityMonitoringState?
The feature state of fleet monitoring.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited