FleetObservabilityLoggingConfig class

LoggingConfig defines the configuration for different types of logs.

Properties

defaultConfig ↔ FleetObservabilityRoutingConfig?
Specified if applying the default routing config to logs not specified in other configs.
getter/setter pair
fleetScopeLogsConfig ↔ FleetObservabilityRoutingConfig?
Specified if applying the routing config to all logs for all fleet scopes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited