ListScopeNamespacesResponse class

List of fleet namespaces.

Constructors

ListScopeNamespacesResponse({String? nextPageToken, List<Namespace>? scopeNamespaces})
ListScopeNamespacesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to request the next page of resources from the ListNamespaces method.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeNamespaces ↔ List<Namespace>?
The list of fleet namespaces
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited