MembershipFeatureSpec class

MembershipFeatureSpec contains configuration information for a single Membership.

Properties

configmanagement ↔ ConfigManagementMembershipSpec?
Config Management-specific spec.
getter/setter pair
fleetobservability ↔ AppDevExperienceFeatureSpec?
Fleet observability membership spec
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identityservice ↔ IdentityServiceMembershipSpec?
Identity Service-specific spec.
getter/setter pair
mesh ↔ ServiceMeshMembershipSpec?
Anthos Service Mesh-specific spec
getter/setter pair
origin ↔ Origin?
Whether this per-Membership spec was inherited from a fleet-level default.
getter/setter pair
policycontroller ↔ PolicyControllerMembershipSpec?
Policy Controller spec.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited