MembershipFeatureState class

MembershipFeatureState contains Feature status information for a single Membership.

Properties

appdevexperience ↔ AppDevExperienceFeatureState?
Appdevexperience specific state.
getter/setter pair
clusterupgrade ↔ ClusterUpgradeMembershipState?
ClusterUpgrade state.
getter/setter pair
configmanagement ↔ ConfigManagementMembershipState?
Config Management-specific state.
getter/setter pair
fleetobservability ↔ AppDevExperienceFeatureSpec?
Fleet observability membership state.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identityservice ↔ IdentityServiceMembershipState?
Identity Service-specific state.
getter/setter pair
policycontroller ↔ PolicyControllerMembershipState?
Policycontroller-specific state.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servicemesh ↔ ServiceMeshMembershipState?
Service Mesh-specific state.
getter/setter pair
state ↔ FeatureState?
The high-level state of this Feature for a single membership.
getter/setter pair
workloadidentity ↔ WorkloadIdentityMembershipState?
Workload Identity membership specific state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited