state property

String? state
getter/setter pair

State of the Rollout Sequence.

Output only. Possible string values are:

  • "STATE_CODE_UNSPECIFIED" : The default value. This value is used if the state is omitted.
  • "ACTIVE" : The Rollout Sequence is active.
  • "WARNING" : The Rollout Sequence has warnings. It is still functioning but performance may be degraded.
  • "ERROR" : The Rollout Sequence has errors and is not functioning.
  • "INITIALIZING" : The Rollout Sequence is being initialized.

Implementation

core.String? state;