stateChangeTime property

String? stateChangeTime
getter/setter pair

The timestamp at which the operational state was last changed.

Used to track how long it has been in the current state.

Output only.

Implementation

core.String? stateChangeTime;