PerStageSoakDurationOverrides class
Configuration for per-stage soak duration overrides.
Constructors
-
PerStageSoakDurationOverrides({Map<
String, String> ? stageOverrides}) - PerStageSoakDurationOverrides.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stageOverrides
↔ Map<
String, String> ? -
A mapping of stage numbers to their respective desired soak durations.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited