Rollout class

Rollout contains the Rollout metadata and configuration.

Next ID: 31

Constructors

Rollout({String? completeTime, String? createTime, String? deleteTime, String? displayName, String? etag, bool? ignoreClusterDisruptionBudgets, bool? ignoreMaintenancePolicies, String? intent, Map<String, String>? labels, Map<String, RolloutMembershipState>? membershipStates, String? name, String? rolloutSequence, Map<String, String>? stageSoakDurationOverrides, List<RolloutStage>? stages, String? state, String? stateReason, String? stateReasonType, String? trigger, String? uid, String? updateTime, VersionUpgrade? versionUpgrade})
Rollout.fromJson(Map json_)

Properties

completeTime String?
The timestamp at which the Rollout was completed.
getter/setter pair
createTime String?
The timestamp at which the Rollout was created.
getter/setter pair
deleteTime String?
The timestamp at the Rollout was deleted.
getter/setter pair
displayName String?
Human readable display name of the Rollout.
getter/setter pair
etag String?
etag of the Rollout Ex.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ignoreClusterDisruptionBudgets bool?
If set to true, the rollout will ignore the disruption budgets of the clusters.
getter/setter pair
ignoreMaintenancePolicies bool?
If set to true, the rollout will ignore any maintenance policies (Maintenance Windows and Maintenance Exclusions) set on the clusters.
getter/setter pair
intent String?
The intent of the rollout.
getter/setter pair
labels Map<String, String>?
Labels for this Rollout.
getter/setter pair
membershipStates Map<String, RolloutMembershipState>?
States of upgrading control plane or node pool targets of a single cluster (GKE Hub membership) that's part of this Rollout.
getter/setter pair
name String?
Identifier.
getter/setter pair
rolloutSequence String?
The full, unique resource name of the rollout sequence that initiatied this Rollout.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stages List<RolloutStage>?
The stages of the Rollout.
getter/setter pair
stageSoakDurationOverrides Map<String, String>?
Overrides the soak durations for specific stages of the rollout.
getter/setter pair
state String?
State specifies various states of the Rollout.
getter/setter pair
stateReason String?
A human-readable description explaining the reason for the current state.
getter/setter pair
stateReasonType String?
StateReasonType specifies the reason type of the Rollout state.
getter/setter pair
trigger String?
The trigger of the rollout.
getter/setter pair
uid String?
Google-generated UUID for this resource.
getter/setter pair
updateTime String?
The timestamp at which the Rollout was last updated.
getter/setter pair
versionUpgrade VersionUpgrade?
Config for version upgrade of clusters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited