intent property

String? intent
getter/setter pair

The intent of the rollout.

Output only. Possible string values are:

  • "ROLLOUT_INTENT_UNSPECIFIED" : The default value.
  • "REGULAR_UPGRADE" : A standard rollout for the whole sequence.
  • "CONTROL_PLANE_PATCH_ENFORCEMENT" : A mandatory upgrade for clusters that haven't been patched within the allowed window.
  • "END_OF_SUPPORT_ENFORCEMENT" : A mandatory upgrade for clusters that have reached its end of support.
  • "PARTIAL_PATCH" : A patch upgrade for a subset of clusters on a given minor version.

Implementation

core.String? intent;