name property
Identifier.
The full, unique resource name of this Rollout in the format of
projects/{project}/locations/global/rollouts/{rollout}.
Implementation
core.String? name;
Identifier.
The full, unique resource name of this Rollout in the format of
projects/{project}/locations/global/rollouts/{rollout}.
core.String? name;