stateReason property
A human-readable description explaining the reason for the current state.
Output only.
Implementation
core.String? stateReason;
A human-readable description explaining the reason for the current state.
Output only.
core.String? stateReason;