stateReasonType property

String? stateReasonType
getter/setter pair

StateReasonType specifies the reason type of the Rollout state.

Output only. Possible string values are:

  • "STATE_REASON_TYPE_UNSPECIFIED" : Unspecified state reason.
  • "PAUSED_BY_USER" : Paused by the user.
  • "PAUSED_BY_SYSTEM_CONFIG" : Paused by system config (ex. GKE freeze).
  • "PAUSED_WAITING_FOR_NEXT_STAGE" : Paused waiting for the next stage to start.
  • "CANCELLED_BY_USER" : Cancelled by the user.
  • "CANCELLED_PAUSED_TOO_LONG" : Cancelled by the system because it was paused too long.
  • "CANCELLED_SUPERSEDED" : Cancelled by the system because the version is too old.
  • "CANCELLED_INCOMPATIBLE_ROLLOUT_SEQUENCE" : Cancelled by the system because the rollout sequence is incompatible, for example it has different number of stages, fleet projects or label selectors than the rollout.
  • "CANCELLED_SUPERSEDED_BY_USER_ROLLOUT" : Cancelled because of a new user-triggered rollout.

Implementation

core.String? stateReasonType;