RolloutMembershipState class
Metadata about single cluster (GKE Hub membership) that's part of this Rollout.
Constructors
-
RolloutMembershipState({String? lastUpdateTime, int? stageAssignment, List<
RolloutTarget> ? targets}) - RolloutMembershipState.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastUpdateTime ↔ String?
-
The time this status and any related Rollout-specific details for the
membership were updated.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stageAssignment ↔ int?
-
The stage assignment of this cluster in this rollout.
getter/setter pair
-
targets
↔ List<
RolloutTarget> ? -
The targets of the rollout - clusters or node pools that are being
upgraded.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited