autoUpgradeConfig property
Configuration for automatic upgrades.
If this message is unset, the system applies default behavior.
Optional.
Implementation
AutoUpgradeConfig? autoUpgradeConfig;
Configuration for automatic upgrades.
If this message is unset, the system applies default behavior.
Optional.
AutoUpgradeConfig? autoUpgradeConfig;