ignoredClustersSelector property
Selector for clusters to exclude from the Rollout Sequence.
Optional.
Implementation
ClusterSelector? ignoredClustersSelector;
Selector for clusters to exclude from the Rollout Sequence.
Optional.
ClusterSelector? ignoredClustersSelector;