targetControlPlaneVersion property
The target control plane version of the Rollout Sequence.
Output only.
Implementation
core.String? targetControlPlaneVersion;
The target control plane version of the Rollout Sequence.
Output only.
core.String? targetControlPlaneVersion;