Scope class

Scope represents a Scope in a Fleet.

Constructors

Scope({String? createTime, String? deleteTime, Map<String, String>? labels, String? name, Map<String, String>? namespaceLabels, ScopeLifecycleState? state, String? uid, String? updateTime})
Scope.fromJson(Map json_)

Properties

createTime ↔ String?
When the scope was created.
getter/setter pair
deleteTime ↔ String?
When the scope was deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels for this Scope.
getter/setter pair
name ↔ String?
The resource name for the scope projects/{project}/locations/{location}/scopes/{scope}
getter/setter pair
namespaceLabels ↔ Map<String, String>?
Scope-level cluster namespace labels.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ ScopeLifecycleState?
State of the scope resource.
getter/setter pair
uid ↔ String?
Google-generated UUID for this resource.
getter/setter pair
updateTime ↔ String?
When the scope was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited