ServiceMeshFeatureState class

Service Mesh: State for the whole Hub, as analyzed by the Service Mesh Hub Controller.

Properties

conditions ↔ List<ServiceMeshFeatureCondition>?
List of conditions reported for this feature.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited