Stage class

Rollout stage.

Constructors

Stage({ClusterSelector? clusterSelector, List<String>? fleetProjects, String? soakDuration})
Stage.fromJson(Map json_)

Properties

clusterSelector ClusterSelector?
Filter members of fleets (above) to a subset of clusters.
getter/setter pair
fleetProjects List<String>?
List of Fleet projects to select the clusters from.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
soakDuration String?
Soak time after upgrading all the clusters in the stage.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited