patchOnly property

bool? patchOnly
getter/setter pair

If set to true, the rollout will only upgrade clusters that match the minor version of the version field, but are on an earlier patch version.

Optional.

Implementation

core.bool? patchOnly;