version property
GKE version to upgrade to.
A valid GKE version available on the release channel used by the sequence.
Patch versions from less conservative channels are allowed if their minor
version is already available in the sequence's channel. This is similar to
single-cluster upgrade rules, see
https://cloud.google.com/kubernetes-engine/docs/how-to/upgrading-a-cluster#supported-versions
Example: With the following versions available on the RAPID and REGULAR
channels: * REGULAR: 1.35.3-gke.123000 * RAPID: 1.36.4-gke.321000,
1.35.6-gke.045000 Valid versions are 1.35.3-gke.123, 1.35.6-gke.045000
Aliases like latest are supported. For more information on valid upgrade
versions and specifying cluster versions, see:
https://cloud.google.com/kubernetes-engine/versioning#specifying_cluster_version
Required.
Implementation
core.String? version;