VersionUpgrade class

Config for version upgrade of clusters.

Constructors

VersionUpgrade({String? desiredVersion, String? type})
VersionUpgrade.fromJson(Map json_)

Properties

desiredVersion ↔ String?
Desired version of the component.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of version upgrade specifies which component should be upgraded.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited