WorkloadIdentityFeatureState class

WorkloadIdentity: Global feature state.

Constructors

WorkloadIdentityFeatureState({Map<String, WorkloadIdentityNamespaceStateDetail>? namespaceStateDetails, Map<String, String>? namespaceStates, String? scopeTenancyWorkloadIdentityPool, String? workloadIdentityPool, Map<String, WorkloadIdentityWorkloadIdentityPoolStateDetail>? workloadIdentityPoolStateDetails})
WorkloadIdentityFeatureState.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
namespaceStateDetails ↔ Map<String, WorkloadIdentityNamespaceStateDetail>?
The state of the IAM namespaces for the fleet.
getter/setter pair
namespaceStates ↔ Map<String, String>?
Deprecated, this field will be erased after code is changed to use the new field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopeTenancyWorkloadIdentityPool ↔ String?
The full name of the scope-tenancy pool for the fleet.
getter/setter pair
workloadIdentityPool ↔ String?
The full name of the svc.id.goog pool for the fleet.
getter/setter pair
workloadIdentityPoolStateDetails ↔ Map<String, WorkloadIdentityWorkloadIdentityPoolStateDetail>?
The state of the Workload Identity Pools for the fleet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited