ClusterUpgradeState class

Per-membership state for this feature.

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignored ↔ ClusterUpgradeIgnoredMembership?
Whether this membership is ignored by the feature.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
upgrades ↔ List<ClusterUpgradeMembershipGKEUpgradeState>?
Actual upgrade state against desired.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited