ConfigManagementConfigSync class

Configuration for Config Sync

Constructors

ConfigManagementConfigSync({List<ConfigManagementDeploymentOverride>? deploymentOverrides, bool? enabled, ConfigManagementGitConfig? git, String? metricsGcpServiceAccountEmail, ConfigManagementOciConfig? oci, bool? preventDrift, String? sourceFormat, bool? stopSyncing})
ConfigManagementConfigSync.fromJson(Map json_)

Properties

deploymentOverrides ↔ List<ConfigManagementDeploymentOverride>?
Configuration for deployment overrides.
getter/setter pair
enabled ↔ bool?
Enables the installation of Config Sync.
getter/setter pair
git ↔ ConfigManagementGitConfig?
Git repo configuration for the cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metricsGcpServiceAccountEmail ↔ String?
The Email of the Google Cloud Service Account (GSA) used for exporting Config Sync metrics to Cloud Monitoring and Cloud Monarch when Workload Identity is enabled.
getter/setter pair
oci ↔ ConfigManagementOciConfig?
OCI repo configuration for the cluster.
getter/setter pair
preventDrift ↔ bool?
Set to true to enable the Config Sync admission webhook to prevent drifts.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceFormat ↔ String?
Specifies whether the Config Sync repo is in hierarchical or unstructured mode.
getter/setter pair
stopSyncing ↔ bool?
Set to true to stop syncing configs for a single cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited