ConfigManagementConfigSyncDeploymentState class

The state of ConfigSync's deployment on a cluster.

Constructors

ConfigManagementConfigSyncDeploymentState({String? admissionWebhook, String? gitSync, String? importer, String? monitor, String? otelCollector, String? reconcilerManager, String? resourceGroupControllerManager, String? rootReconciler, String? syncer})
ConfigManagementConfigSyncDeploymentState.fromJson(Map json_)

Properties

admissionWebhook ↔ String?
Deployment state of admission-webhook. Possible string values are:
getter/setter pair
gitSync ↔ String?
Deployment state of the git-sync pod. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importer ↔ String?
Deployment state of the importer pod. Possible string values are:
getter/setter pair
monitor ↔ String?
Deployment state of the monitor pod. Possible string values are:
getter/setter pair
otelCollector ↔ String?
Deployment state of otel-collector Possible string values are:
getter/setter pair
reconcilerManager ↔ String?
Deployment state of reconciler-manager pod. Possible string values are:
getter/setter pair
resourceGroupControllerManager ↔ String?
Deployment state of resource-group-controller-manager Possible string values are:
getter/setter pair
rootReconciler ↔ String?
Deployment state of root-reconciler. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncer ↔ String?
Deployment state of the syncer pod. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited