ConfigManagementConfigSyncState class

State information for ConfigSync.

Constructors

ConfigManagementConfigSyncState({String? clusterLevelStopSyncingState, int? crCount, ConfigManagementConfigSyncDeploymentState? deploymentState, List<ConfigManagementConfigSyncError>? errors, String? reposyncCrd, String? rootsyncCrd, String? state, ConfigManagementSyncState? syncState, ConfigManagementConfigSyncVersion? version})
ConfigManagementConfigSyncState.fromJson(Map json_)

Properties

clusterLevelStopSyncingState ↔ String?
Whether syncing resources to the cluster is stopped at the cluster level.
getter/setter pair
crCount ↔ int?
The number of RootSync and RepoSync CRs in the cluster.
getter/setter pair
deploymentState ↔ ConfigManagementConfigSyncDeploymentState?
Information about the deployment of ConfigSync, including the version.
getter/setter pair
errors ↔ List<ConfigManagementConfigSyncError>?
Errors pertaining to the installation of Config Sync.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reposyncCrd ↔ String?
The state of the Reposync CRD
getter/setter pair
rootsyncCrd ↔ String?
The state of the RootSync CRD
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of CS This field summarizes the other fields in this message.
getter/setter pair
syncState ↔ ConfigManagementSyncState?
The state of ConfigSync's process to sync configs to a cluster.
getter/setter pair
version ↔ ConfigManagementConfigSyncVersion?
The version of ConfigSync deployed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited