ConfigManagementConfigSyncVersion class

Specific versioning information pertaining to ConfigSync's Pods.

Constructors

ConfigManagementConfigSyncVersion({String? admissionWebhook, String? gitSync, String? importer, String? monitor, String? otelCollector, String? reconcilerManager, String? resourceGroupControllerManager, String? rootReconciler, String? syncer})
ConfigManagementConfigSyncVersion.fromJson(Map json_)

Properties

admissionWebhook ↔ String?
Version of the deployed admission-webhook pod.
getter/setter pair
gitSync ↔ String?
Version of the deployed git-sync pod.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importer ↔ String?
Version of the deployed importer pod.
getter/setter pair
monitor ↔ String?
Version of the deployed monitor pod.
getter/setter pair
otelCollector ↔ String?
Version of the deployed otel-collector pod
getter/setter pair
reconcilerManager ↔ String?
Version of the deployed reconciler-manager pod.
getter/setter pair
resourceGroupControllerManager ↔ String?
Version of the deployed resource-group-controller-manager pod
getter/setter pair
rootReconciler ↔ String?
Version of the deployed reconciler container in root-reconciler pod.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncer ↔ String?
Version of the deployed syncer pod.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited