ConfigManagementDeploymentOverride class

Configuration for a deployment override.

Properties

containers ↔ List<ConfigManagementContainerOverride>?
The containers of the deployment resource to be overridden.
getter/setter pair
deploymentName ↔ String?
The name of the deployment resource to be overridden.
getter/setter pair
deploymentNamespace ↔ String?
The namespace of the deployment resource to be overridden.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited