ConfigManagementErrorResource class

Model for a config file in the git repo with an associated Sync error.

Constructors

ConfigManagementErrorResource({ConfigManagementGroupVersionKind? resourceGvk, String? resourceName, String? resourceNamespace, String? sourcePath})
ConfigManagementErrorResource.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourceGvk ↔ ConfigManagementGroupVersionKind?
Group/version/kind of the resource that is causing an error
getter/setter pair
resourceName ↔ String?
Metadata name of the resource that is causing an error
getter/setter pair
resourceNamespace ↔ String?
Namespace of the resource that is causing an error
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourcePath ↔ String?
Path in the git repo of the erroneous config
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited