ConfigManagementGatekeeperDeploymentState class

State of Policy Controller installation.

Constructors

ConfigManagementGatekeeperDeploymentState({String? gatekeeperAudit, String? gatekeeperControllerManagerState, String? gatekeeperMutation})
ConfigManagementGatekeeperDeploymentState.fromJson(Map json_)

Properties

gatekeeperAudit ↔ String?
Status of gatekeeper-audit deployment. Possible string values are:
getter/setter pair
gatekeeperControllerManagerState ↔ String?
Status of gatekeeper-controller-manager pod. Possible string values are:
getter/setter pair
gatekeeperMutation ↔ String?
Status of the pod serving the mutation webhook. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited