ConfigManagementHierarchyControllerState class

State for Hierarchy Controller.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ ConfigManagementHierarchyControllerDeploymentState?
The deployment state for Hierarchy Controller.
getter/setter pair
version ↔ ConfigManagementHierarchyControllerVersion?
The version for Hierarchy Controller.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited