ConfigManagementPolicyController class

Configuration for Policy Controller

Constructors

ConfigManagementPolicyController({String? auditIntervalSeconds, bool? enabled, List<String>? exemptableNamespaces, bool? logDeniesEnabled, ConfigManagementPolicyControllerMonitoring? monitoring, bool? mutationEnabled, bool? referentialRulesEnabled, bool? templateLibraryInstalled, String? updateTime})
ConfigManagementPolicyController.fromJson(Map json_)

Properties

auditIntervalSeconds ↔ String?
Sets the interval for Policy Controller Audit Scans (in seconds).
getter/setter pair
enabled ↔ bool?
Enables the installation of Policy Controller.
getter/setter pair
exemptableNamespaces ↔ List<String>?
The set of namespaces that are excluded from Policy Controller checks.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
logDeniesEnabled ↔ bool?
Logs all denies and dry run failures.
getter/setter pair
monitoring ↔ ConfigManagementPolicyControllerMonitoring?
Monitoring specifies the configuration of monitoring.
getter/setter pair
mutationEnabled ↔ bool?
Enable or disable mutation in policy controller.
getter/setter pair
referentialRulesEnabled ↔ bool?
Enables the ability to use Constraint Templates that reference to objects other than the object currently being evaluated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateLibraryInstalled ↔ bool?
Installs the default template library along with Policy Controller.
getter/setter pair
updateTime ↔ String?
Last time this membership spec was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited