ConfigManagementPolicyControllerState class

State for PolicyControllerState.

Properties

deploymentState ↔ ConfigManagementGatekeeperDeploymentState?
The state about the policy controller installation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
migration ↔ ConfigManagementPolicyControllerMigration?
Record state of ACM -> PoCo Hub migration for this feature.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ ConfigManagementPolicyControllerVersion?
The version of Gatekeeper Policy Controller deployed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited