ConfigManagementSpec class

Anthos Config Management: Configuration for a single cluster.

Intended to parallel the ConfigManagement CR.

Properties

binauthz ↔ ConfigManagementBinauthzConfig?
Deprecated: Binauthz configuration will be ignored and should not be set.
getter/setter pair
cluster ↔ String?
User-specified cluster name used by the Config Sync cluster-name-selector annotation or ClusterSelector object, for applying configs to only a subset of clusters.
getter/setter pair
configSync ↔ ConfigManagementConfigSync?
Config Sync configuration for the cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hierarchyController ↔ ConfigManagementHierarchyControllerConfig?
Hierarchy Controller configuration for the cluster.
getter/setter pair
management ↔ String?
Deprecated: Automatic Feature management is in Preview and is unavailable in version 1.21.0 and later, after which Config Sync only supports manual upgrades.
getter/setter pair
policyController ↔ ConfigManagementPolicyController?
Policy Controller configuration for the cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
Version of Config Sync to install.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited