management property
- @Deprecated('Not supported. Member documentation may have more information.')
getter/setter pair
Deprecated: Automatic Feature management is in Preview and is unavailable in version 1.21.0 and later, after which Config Sync only supports manual upgrades.
If set to manual upgrades, clear this field instead, which is behaviorally equivalent but helps prevent compatibility issues with newer fields.
Optional. Possible string values are:
- "MANAGEMENT_UNSPECIFIED" : Unspecified
- "MANAGEMENT_AUTOMATIC" : Google will manage the Feature for the cluster.
- "MANAGEMENT_MANUAL" : User will manually manage the Feature for the cluster.
Implementation
@core.Deprecated(
'Not supported. Member documentation may have more information.',
)
core.String? management;