ConfigManagementSyncError class

An ACM created error representing a problem syncing configurations.

Properties

code ↔ String?
An ACM defined error code
getter/setter pair
errorMessage ↔ String?
A description of the error
getter/setter pair
errorResources ↔ List<ConfigManagementErrorResource>?
A list of config(s) associated with the error, if any
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited