ConfigManagementSyncState class

State indicating an ACM's progress syncing configurations to a cluster.

Constructors

ConfigManagementSyncState({String? code, List<ConfigManagementSyncError>? errors, String? importToken, String? lastSync, String? lastSyncTime, String? sourceToken, String? syncToken})
ConfigManagementSyncState.fromJson(Map json_)

Properties

code ↔ String?
Sync status code. Possible string values are:
getter/setter pair
errors ↔ List<ConfigManagementSyncError>?
A list of errors resulting from problematic configs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importToken ↔ String?
Token indicating the state of the importer.
getter/setter pair
lastSync ↔ String?
Deprecated: use last_sync_time instead.
getter/setter pair
lastSyncTime ↔ String?
Timestamp type of when ACM last successfully synced the repo.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceToken ↔ String?
Token indicating the state of the repo.
getter/setter pair
syncToken ↔ String?
Token indicating the state of the syncer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited