FeatureState class

FeatureState contains high-level state information and per-feature state information for this MembershipFeature.

Constructors

FeatureState({AppDevExperienceState? appdevexperience, ClusterUpgradeState? clusterupgrade, ConfigManagementState? configmanagement, IdentityServiceState? identityservice, MeteringState? metering, PolicyControllerState? policycontroller, RBACRoleBindingActuationState? rbacrolebindingactuation, ServiceMeshState? servicemesh, State? state, WorkloadIdentityState? workloadidentity})
FeatureState.fromJson(Map json_)

Properties

appdevexperience ↔ AppDevExperienceState?
Appdevexperience specific state.
getter/setter pair
clusterupgrade ↔ ClusterUpgradeState?
Cluster upgrade state.
getter/setter pair
configmanagement ↔ ConfigManagementState?
Config Management state
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identityservice ↔ IdentityServiceState?
Identity service state
getter/setter pair
metering ↔ MeteringState?
Metering state
getter/setter pair
policycontroller ↔ PolicyControllerState?
Policy Controller state
getter/setter pair
rbacrolebindingactuation ↔ RBACRoleBindingActuationState?
RBAC Role Binding Actuation state
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
servicemesh ↔ ServiceMeshState?
Service mesh state
getter/setter pair
state ↔ State?
The high-level state of this MembershipFeature.
getter/setter pair
workloadidentity ↔ WorkloadIdentityState?
Workload Identity state
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited