IdentityServiceAuthMethod class

Configuration of an auth method for a member/cluster.

Only one authentication method (e.g., OIDC and LDAP) can be set per AuthMethod.

Properties

azureadConfig ↔ IdentityServiceAzureADConfig?
AzureAD specific Configuration.
getter/setter pair
googleConfig ↔ IdentityServiceGoogleConfig?
GoogleConfig specific configuration
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ldapConfig ↔ IdentityServiceLdapConfig?
LDAP specific configuration.
getter/setter pair
name ↔ String?
Identifier for auth config.
getter/setter pair
oidcConfig ↔ IdentityServiceOidcConfig?
OIDC specific configuration.
getter/setter pair
proxy ↔ String?
Proxy server address to use for auth method.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
samlConfig ↔ IdentityServiceSamlConfig?
SAML specific configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited