IdentityServiceIdentityServiceOptions class

Holds non-protocol-related configuration options.

Properties

diagnosticInterface ↔ IdentityServiceDiagnosticInterface?
Configuration options for the AIS diagnostic interface.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionDuration ↔ String?
Determines the lifespan of STS tokens issued by Anthos Identity Service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited