IdentityServiceLdapConfig class

Configuration for the LDAP Auth flow.

Properties

group ↔ IdentityServiceGroupConfig?
Contains the properties for locating and authenticating groups in the directory.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
server ↔ IdentityServiceServerConfig?
Server settings for the external LDAP server.
getter/setter pair
serviceAccount ↔ IdentityServiceServiceAccountConfig?
Contains the credentials of the service account which is authorized to perform the LDAP search in the directory.
getter/setter pair
user ↔ IdentityServiceUserConfig?
Defines where users exist in the LDAP directory.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited