IdentityServiceState class

IdentityService: State for a single membership, analyzed and reported by feature controller.

Constructors

IdentityServiceState({String? failureReason, String? installedVersion, IdentityServiceSpec? memberConfig, String? state})
IdentityServiceState.fromJson(Map json_)

Properties

failureReason ↔ String?
The reason of the failure.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installedVersion ↔ String?
Installed AIS version.
getter/setter pair
memberConfig ↔ IdentityServiceSpec?
Last reconciled membership configuration
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Deployment state on this member Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited