MembershipFeature class

MembershipFeature represents the settings and status of a Fleet Feature enabled on a single Fleet Membership.

Constructors

MembershipFeature({String? createTime, String? deleteTime, Map<String, String>? labels, LifecycleState? lifecycleState, String? name, FeatureSpec? spec, FeatureState? state, String? updateTime})
MembershipFeature.fromJson(Map json_)

Properties

createTime ↔ String?
When the MembershipFeature resource was created.
getter/setter pair
deleteTime ↔ String?
When the MembershipFeature resource was deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Google Cloud labels for this MembershipFeature.
getter/setter pair
lifecycleState ↔ LifecycleState?
Lifecycle information of the resource itself.
getter/setter pair
name ↔ String?
The resource name of the membershipFeature, in the format: projects/{project}/locations/{location}/memberships/{membership}/features/{feature}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ FeatureSpec?
Spec of this membershipFeature.
getter/setter pair
state ↔ FeatureState?
State of the this membershipFeature.
getter/setter pair
updateTime ↔ String?
When the MembershipFeature resource was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited