PolicyControllerPolicyContentSpec class

PolicyContentSpec defines the user's desired content configuration on the cluster.

Properties

bundles ↔ Map<String, PolicyControllerBundleInstallSpec>?
map of bundle name to BundleInstallSpec.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateLibrary ↔ PolicyControllerTemplateLibraryConfig?
Configures the installation of the Template Library.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited