PolicyControllerPolicyContentState class

The state of the policy controller policy content

Properties

bundleStates ↔ Map<String, PolicyControllerOnClusterState>?
The state of the any bundles included in the chosen version of the manifest
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
referentialSyncConfigState ↔ PolicyControllerOnClusterState?
The state of the referential data sync configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateLibraryState ↔ PolicyControllerOnClusterState?
The state of the template library
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited