PolicyControllerPolicyControllerDeploymentConfig class

Deployment-specific configuration.

Properties

containerResources ↔ PolicyControllerResourceRequirements?
Container resource requirements.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
podAffinity ↔ String?
Pod affinity configuration. Possible string values are:
getter/setter pair
podAntiAffinity ↔ bool?
Pod anti-affinity enablement.
getter/setter pair
podTolerations ↔ List<PolicyControllerToleration>?
Pod tolerations of node taints.
getter/setter pair
replicaCount ↔ String?
Pod replica count.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited