PolicyControllerResourceRequirements class

ResourceRequirements describes the compute resource requirements.

Properties

hashCode → int
The hash code for this object.
no setterinherited
limits ↔ PolicyControllerResourceList?
Limits describes the maximum amount of compute resources allowed for use by the running container.
getter/setter pair
requests ↔ PolicyControllerResourceList?
Requests describes the amount of compute resources reserved for the container by the kube-scheduler.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited