PolicyControllerSpec class

Policy Controller: Configuration for a single cluster.

Intended to parallel the PolicyController CR.

Constructors

PolicyControllerSpec({PolicyControllerHubConfig? policyControllerHubConfig, String? version})
PolicyControllerSpec.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
policyControllerHubConfig ↔ PolicyControllerHubConfig?
Policy Controller configuration for the cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
Version of Policy Controller installed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited