State class

High-level state of a MembershipFeature.

Constructors

State({String? code, String? description, String? updateTime})
State.fromJson(Map json_)

Properties

code ↔ String?
The high-level, machine-readable status of this MembershipFeature. Possible string values are:
getter/setter pair
description ↔ String?
A human-readable description of the current status.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The time this status and any related Feature-specific details were updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited