WorkloadIdentityState class

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.

Constructors

WorkloadIdentityState({String? description, Map<String, WorkloadIdentityIdentityProviderStateDetail>? identityProviderStateDetails})
WorkloadIdentityState.fromJson(Map json_)

Properties

description ↔ String?
Deprecated, this field will be erased after code is changed to use the new field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identityProviderStateDetails ↔ Map<String, WorkloadIdentityIdentityProviderStateDetail>?
The state of the Identity Providers corresponding to the membership.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited