BareMetalNetworkConfig class

Specifies the cluster network configuration.

Constructors

BareMetalNetworkConfig({bool? advancedNetworking, BareMetalIslandModeCidrConfig? islandModeCidr, BareMetalMultipleNetworkInterfacesConfig? multipleNetworkInterfacesConfig, BareMetalSrIovConfig? srIovConfig})
BareMetalNetworkConfig.fromJson(Map json_)

Properties

advancedNetworking ↔ bool?
Enables the use of advanced Anthos networking features, such as Bundled Load Balancing with BGP or the egress NAT gateway.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
islandModeCidr ↔ BareMetalIslandModeCidrConfig?
Configuration for island mode CIDR.
getter/setter pair
multipleNetworkInterfacesConfig ↔ BareMetalAdminMultipleNetworkInterfacesConfig?
Configuration for multiple network interfaces.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srIovConfig ↔ BareMetalSrIovConfig?
Configuration for SR-IOV.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited