BareMetalNodePool class

Resource that represents a bare metal node pool.

Constructors

BareMetalNodePool({Map<String, String>? annotations, String? createTime, String? deleteTime, String? displayName, String? etag, String? name, BareMetalNodePoolConfig? nodePoolConfig, bool? reconciling, String? state, ResourceStatus? status, String? uid, String? updateTime, BareMetalNodePoolUpgradePolicy? upgradePolicy})
BareMetalNodePool.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Annotations on the bare metal node pool.
getter/setter pair
createTime ↔ String?
The time at which this bare metal node pool was created.
getter/setter pair
deleteTime ↔ String?
The time at which this bare metal node pool was deleted.
getter/setter pair
displayName ↔ String?
The display name for the bare metal node pool.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The bare metal node pool resource name.
getter/setter pair
nodePoolConfig ↔ BareMetalNodePoolConfig?
Node pool configuration.
getter/setter pair
reconciling ↔ bool?
If set, there are currently changes in flight to the bare metal node pool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of the bare metal node pool.
getter/setter pair
status ↔ ResourceStatus?
ResourceStatus representing the detailed node pool status.
getter/setter pair
uid ↔ String?
The unique identifier of the bare metal node pool.
getter/setter pair
updateTime ↔ String?
The time at which this bare metal node pool was last updated.
getter/setter pair
upgradePolicy ↔ BareMetalNodePoolUpgradePolicy?
The worker node pool upgrade policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited