BareMetalStorageConfig class

BareMetalStorageConfig specifies the cluster storage configuration.

Constructors

BareMetalStorageConfig({BareMetalLvpConfig? lvpNodeMountsConfig, BareMetalLvpShareConfig? lvpShareConfig})
BareMetalStorageConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lvpNodeMountsConfig ↔ BareMetalLvpConfig?
Specifies the config for local PersistentVolumes backed by mounted node disks.
getter/setter pair
lvpShareConfig ↔ BareMetalLvpShareConfig?
Specifies the config for local PersistentVolumes backed by subdirectories in a shared filesystem.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited