BareMetalWorkloadNodeConfig class

Specifies the workload node configurations.

Constructors

BareMetalWorkloadNodeConfig({String? containerRuntime, String? maxPodsPerNode})
BareMetalWorkloadNodeConfig.fromJson(Map json_)

Properties

containerRuntime ↔ String?
Specifies which container runtime will be used. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxPodsPerNode ↔ String?
The maximum number of pods a node can run.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited