ClusterUser class

ClusterUser configures user principals for an RBAC policy.

Constructors

ClusterUser({String? username})
ClusterUser.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String?
The name of the user, e.g. my-gcp-id@gmail.com.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited