ValidationCheck class

ValidationCheck represents the result of preflight check.

Constructors

ValidationCheck({String? option, String? scenario, ValidationCheckStatus? status})
ValidationCheck.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
option ↔ String?
Options used for the validation check Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scenario ↔ String?
The scenario when the preflight checks were run.
getter/setter pair
status ↔ ValidationCheckStatus?
The detailed validation check status.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited