Version class

Version describes the number of nodes at a given version under a resource.

Constructors

Version({String? count, String? version})
Version.fromJson(Map json_)

Properties

count ↔ String?
Number of machines under the above version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
Resource version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited