VmwareAdminControlPlaneNodeConfig class

VmwareAdminControlPlaneNodeConfig contains control plane node configuration for VMware admin cluster.

Properties

cpus ↔ String?
The number of vCPUs for the control-plane node of the admin cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memory ↔ String?
The number of mebibytes of memory for the control-plane node of the admin cluster.
getter/setter pair
replicas ↔ String?
The number of control plane nodes for this VMware admin cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited