VmwareAdminLoadBalancerConfig class

VmwareAdminLoadBalancerConfig contains load balancer configuration for VMware admin cluster.

Properties

f5Config ↔ VmwareAdminF5BigIpConfig?
Configuration for F5 Big IP typed load balancers.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manualLbConfig ↔ VmwareAdminManualLbConfig?
Manually configured load balancers.
getter/setter pair
metalLbConfig ↔ VmwareAdminMetalLbConfig?
MetalLB load balancers.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seesawConfig ↔ VmwareAdminSeesawConfig?
Configuration for Seesaw typed load balancers.
getter/setter pair
vipConfig ↔ VmwareAdminVipConfig?
The VIPs used by the load balancer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited