VmwareNodeConfig class

Parameters that describe the configuration of all nodes within a given node pool.

Constructors

VmwareNodeConfig({String? bootDiskSizeGb, String? cpus, bool? enableLoadBalancer, String? image, String? imageType, Map<String, String>? labels, String? memoryMb, String? replicas, List<NodeTaint>? taints, VmwareVsphereConfig? vsphereConfig})
VmwareNodeConfig.fromJson(Map json_)

Properties

bootDiskSizeGb ↔ String?
VMware disk size to be used during creation.
getter/setter pair
cpus ↔ String?
The number of CPUs for each node in the node pool.
getter/setter pair
enableLoadBalancer ↔ bool?
Allow node pool traffic to be load balanced.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ String?
The OS image name in vCenter, only valid when using Windows.
getter/setter pair
imageType ↔ String?
The OS image to be used for each node in a node pool.
getter/setter pair
labels ↔ Map<String, String>?
The map of Kubernetes labels (key/value pairs) to be applied to each node.
getter/setter pair
memoryMb ↔ String?
The megabytes of memory for each node in the node pool.
getter/setter pair
replicas ↔ String?
The number of nodes in the node pool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taints ↔ List<NodeTaint>?
The initial taints assigned to nodes of this node pool.
getter/setter pair
vsphereConfig ↔ VmwareVsphereConfig?
Specifies the vSphere config for node pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited