VmwareNodePool class

Resource VmwareNodePool represents a VMware node pool.

Constructors

VmwareNodePool({Map<String, String>? annotations, VmwareNodeConfig? config, String? createTime, String? deleteTime, String? displayName, String? etag, String? name, VmwareNodePoolAutoscalingConfig? nodePoolAutoscaling, String? onPremVersion, bool? reconciling, String? state, ResourceStatus? status, String? uid, String? updateTime})
VmwareNodePool.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Annotations on the node pool.
getter/setter pair
config ↔ VmwareNodeConfig?
The node configuration of the node pool.
getter/setter pair
createTime ↔ String?
The time at which this node pool was created.
getter/setter pair
deleteTime ↔ String?
The time at which this node pool was deleted.
getter/setter pair
displayName ↔ String?
The display name for the node pool.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of this node pool.
getter/setter pair
nodePoolAutoscaling ↔ VmwareNodePoolAutoscalingConfig?
Node pool autoscaling config for the node pool.
getter/setter pair
onPremVersion ↔ String?
Anthos version for the node pool.
getter/setter pair
reconciling ↔ bool?
If set, there are currently changes in flight to the node pool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of the node pool.
getter/setter pair
status ↔ ResourceStatus?
ResourceStatus representing the detailed VMware node pool state.
getter/setter pair
uid ↔ String?
The unique identifier of the node pool.
getter/setter pair
updateTime ↔ String?
The time at which this node pool was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited