VmwareVCenterConfig class

Represents configuration for the VMware VCenter for the user cluster.

Constructors

VmwareVCenterConfig({String? address, String? caCertData, String? cluster, String? datacenter, String? datastore, String? folder, String? resourcePool, String? storagePolicyName})
VmwareVCenterConfig.fromJson(Map json_)

Properties

address ↔ String?
The vCenter IP address.
getter/setter pair
caCertData ↔ String?
Contains the vCenter CA certificate public key for SSL verification.
getter/setter pair
cluster ↔ String?
The name of the vCenter cluster for the user cluster.
getter/setter pair
datacenter ↔ String?
The name of the vCenter datacenter for the user cluster.
getter/setter pair
datastore ↔ String?
The name of the vCenter datastore for the user cluster.
getter/setter pair
folder ↔ String?
The name of the vCenter folder for the user cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resourcePool ↔ String?
The name of the vCenter resource pool for the user cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storagePolicyName ↔ String?
The name of the vCenter storage policy for the user cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited