VmwareVsphereConfig class

VmwareVsphereConfig represents configuration for the VMware VCenter for node pool.

Constructors

VmwareVsphereConfig({String? datastore, List<String>? hostGroups, List<VmwareVsphereTag>? tags})
VmwareVsphereConfig.fromJson(Map json_)

Properties

datastore ↔ String?
The name of the vCenter datastore.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostGroups ↔ List<String>?
Vsphere host groups to apply to all VMs in the node pool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<VmwareVsphereTag>?
Tags to apply to VMs.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited