addClassificationLabels property
A list of Classification Label values to add.
If a Classification Label with the same label ID is already applied to the message, fields with existing field IDs will be updated and fields with new field IDs will be added. There's a limit of 20 Classification Label values per request. If the message is already classified and the final total number of Classification Label values exceeds the maximum allowed number of Classification Label values per message, the modification fails.
Implementation
core.List<ClassificationLabelValue>? addClassificationLabels;