ImapSettings class

IMAP settings for an account.

Constructors

ImapSettings({bool? autoExpunge, bool? enabled, String? expungeBehavior, int? maxFolderSize})
ImapSettings.fromJson(Map json_)

Properties

autoExpunge ↔ bool?
If this value is true, Gmail will immediately expunge a message when it is marked as deleted in IMAP.
getter/setter pair
enabled ↔ bool?
Whether IMAP is enabled for the account.
getter/setter pair
expungeBehavior ↔ String?
The action that will be executed on a message when it is marked as deleted and expunged from the last visible IMAP folder. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxFolderSize ↔ int?
An optional limit on the number of messages that an IMAP folder may contain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited