Label class

Labels are used to categorize messages and threads within the user's mailbox.

The maximum number of labels supported for a user's mailbox is 10,000.

Constructors

Label({LabelColor? color, String? id, String? labelListVisibility, String? messageListVisibility, int? messagesTotal, int? messagesUnread, String? name, int? threadsTotal, int? threadsUnread, String? type})
Label.fromJson(Map json_)

Properties

color ↔ LabelColor?
The color to assign to the label.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The immutable ID of the label.
getter/setter pair
labelListVisibility ↔ String?
The visibility of the label in the label list in the Gmail web interface. Possible string values are:
getter/setter pair
messageListVisibility ↔ String?
The visibility of messages with this label in the message list in the Gmail web interface. Possible string values are:
getter/setter pair
messagesTotal ↔ int?
The total number of messages with the label.
getter/setter pair
messagesUnread ↔ int?
The number of unread messages with the label.
getter/setter pair
name ↔ String?
The display name of the label.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadsTotal ↔ int?
The total number of threads with the label.
getter/setter pair
threadsUnread ↔ int?
The number of unread threads with the label.
getter/setter pair
type ↔ String?
The owner type for the label.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited