ListCseIdentitiesResponse class

Constructors

ListCseIdentitiesResponse({List<CseIdentity>? cseIdentities, String? nextPageToken})
ListCseIdentitiesResponse.fromJson(Map json_)

Properties

cseIdentities ↔ List<CseIdentity>?
One page of the list of CSE identities configured for the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Pagination token to be passed to a subsequent ListCseIdentities call in order to retrieve the next page of identities.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited