ListCseKeyPairsResponse class

Constructors

ListCseKeyPairsResponse({List<CseKeyPair>? cseKeyPairs, String? nextPageToken})
ListCseKeyPairsResponse.fromJson(Map json_)

Properties

cseKeyPairs ↔ List<CseKeyPair>?
One page of the list of CSE key pairs installed for the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Pagination token to be passed to a subsequent ListCseKeyPairs call in order to retrieve the next page of key pairs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited