ListHistoryResponse class

Constructors

ListHistoryResponse({List<History>? history, String? historyId, String? nextPageToken})
ListHistoryResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
history ↔ List<History>?
List of history records.
getter/setter pair
historyId ↔ String?
The ID of the mailbox's current history record.
getter/setter pair
nextPageToken ↔ String?
Page token to retrieve the next page of results in the list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited