ListMessagesResponse class

Constructors

ListMessagesResponse({List<Message>? messages, String? nextPageToken, int? resultSizeEstimate})
ListMessagesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
messages ↔ List<Message>?
List of messages.
getter/setter pair
nextPageToken ↔ String?
Token to retrieve the next page of results in the list.
getter/setter pair
resultSizeEstimate ↔ int?
Estimated total number of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited