MessagePart class

A single MIME message part.

Constructors

MessagePart({MessagePartBody? body, String? filename, List<MessagePartHeader>? headers, String? mimeType, String? partId, List<MessagePart>? parts})
MessagePart.fromJson(Map json_)

Properties

body ↔ MessagePartBody?
The message part body for this part, which may be empty for container MIME message parts.
getter/setter pair
filename ↔ String?
The filename of the attachment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ List<MessagePartHeader>?
List of headers on this message part.
getter/setter pair
mimeType ↔ String?
The MIME type of the message part.
getter/setter pair
partId ↔ String?
The immutable ID of the message part.
getter/setter pair
parts ↔ List<MessagePart>?
The child MIME message parts of this part.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited