MessagePartBody class

The body of a single MIME message part.

Constructors

MessagePartBody({String? attachmentId, String? data, int? size})
MessagePartBody.fromJson(Map json_)

Properties

attachmentId ↔ String?
When present, contains the ID of an external attachment that can be retrieved in a separate messages.attachments.get request.
getter/setter pair
data ↔ String?
The body data of a MIME message part as a base64url encoded string.
getter/setter pair
dataAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ int?
Number of bytes for the message part data (encoding notwithstanding).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited