ModifyMessageRequest class

Constructors

ModifyMessageRequest({List<ClassificationLabelValue>? addClassificationLabels, List<String>? addLabelIds, List<String>? removeClassificationLabelIds, List<String>? removeLabelIds})
ModifyMessageRequest.fromJson(Map json_)

Properties

addClassificationLabels ↔ List<ClassificationLabelValue>?
A list of classification label values to add.
getter/setter pair
addLabelIds ↔ List<String>?
A list of IDs of labels to add to this message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
removeClassificationLabelIds ↔ List<String>?
A list of Classification Label values to remove from this message.
getter/setter pair
removeLabelIds ↔ List<String>?
A list IDs of labels to remove from this message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited