ModifyThreadRequest class

Constructors

ModifyThreadRequest({List<String>? addLabelIds, List<String>? removeLabelIds})
ModifyThreadRequest.fromJson(Map json_)

Properties

addLabelIds ↔ List<String>?
A list of IDs of labels to add to this thread.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
removeLabelIds ↔ List<String>?
A list of IDs of labels to remove from this thread.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited