delete method
Removes the specified delegate (which can be of any verification status), and revokes any verification that may have been required for using it.
For more information, see Manage delegates. A delegate user must be referred to by their primary email address, and not an email alias. This method is only available to service account clients that have been delegated domain-wide authority.
Request parameters:
userId - User's email address. The special value "me" can be used to
indicate the authenticated user.
delegateEmail - The email address of the user to be removed as a
delegate.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<void> delete(
core.String userId,
core.String delegateEmail, {
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'gmail/v1/users/' +
commons.escapeVariable('$userId') +
'/settings/delegates/' +
commons.escapeVariable('$delegateEmail');
await _requester.request(
url_,
'DELETE',
queryParams: queryParams_,
downloadOptions: null,
);
}