delete method

Future<void> delete(
  1. String userId,
  2. String forwardingEmail, {
  3. String? $fields,
})

Deletes the specified forwarding address and revokes any verification that may have been required.

For more information, see Manage email forwarding. This method is only available to service account clients that have been delegated domain-wide authority.

Request parameters:

userId - User's email address. The special value "me" can be used to indicate the authenticated user.

forwardingEmail - The forwarding address to be deleted.

$fields - Selector specifying which fields to include in a partial response.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<void> delete(
  core.String userId,
  core.String forwardingEmail, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'gmail/v1/users/' +
      commons.escapeVariable('$userId') +
      '/settings/forwardingAddresses/' +
      commons.escapeVariable('$forwardingEmail');

  await _requester.request(
    url_,
    'DELETE',
    queryParams: queryParams_,
    downloadOptions: null,
  );
}