delete method
Immediately and permanently deletes the specified thread.
Any messages that belong to the thread are also deleted. This operation
cannot be undone. Prefer threads.trash instead. For more information,
see
Manage threads.
Request parameters:
userId - The user's email address. The special value me can be used to
indicate the authenticated user.
id - ID of the Thread to delete.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<void> delete(
core.String userId,
core.String id, {
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'gmail/v1/users/' +
commons.escapeVariable('$userId') +
'/threads/' +
commons.escapeVariable('$id');
await _requester.request(
url_,
'DELETE',
queryParams: queryParams_,
downloadOptions: null,
);
}