gmailpostmastertools/v2 library

Gmail Postmaster Tools API - v2

The Postmaster Tools API is a RESTful API that provides programmatic access to email traffic metrics (like spam reports, delivery errors etc) otherwise available through the Gmail Postmaster Tools UI currently.

For more information, see developers.google.com/workspace/gmail/postmaster

Create an instance of PostmasterToolsApi to access these resources:

Classes

BaseMetric
Specifies the base metric to query, which can be a predefined standard metric or a user-defined custom metric (if supported in the future).
BatchQueryDomainStatsRequest
Request message for BatchQueryDomainStats.
BatchQueryDomainStatsResponse
Response message for BatchQueryDomainStats.
BatchQueryDomainStatsResult
Represents the result of a single QueryDomainStatsRequest within a batch.
ComplianceRowData
Data for a single row of the compliance status table.
ComplianceStatus
The status of a sender compliance requirement.
CreateDomainRequest
Developer Preview: Request message for CreateDomain.
CreateUserRequest
Developer Preview: Request message for CreateUser.
DateList
A set of specific dates.
DateRange
A single date range defined by a start and end date.
DateRanges
A set of date ranges.
DeliverabilityStatusVerdict
Developer Preview: Verdict of domain deliverability status.
Domain
Information about a domain registered by the user.
DomainComplianceData
Compliance data for a given domain.
DomainComplianceStatus
Compliance status for a domain.
DomainsDomainStatsResource
DomainsResource
DomainStat
Email statistics for a domain for a specified time period or date.
DomainStatsResource
DomainsUsersResource
DomainVerificationToken
Developer Preview: The DNS token a user can use to verify ownership of a domain.
HonorUnsubscribeVerdict
Compliance verdict for whether a sender meets the unsubscribe honoring compliance requirement.
ListDomainsResponse
Response message for ListDomains.
ListUsersResponse
Developer Preview: Response message for ListUsers.
MetricDefinition
Defines a specific metric to query, including a user-defined name, the base metric type, and optional filters.
OneClickUnsubscribeVerdict
Compliance verdict for whether a sender meets the one-click unsubscribe compliance requirement.
PostmasterToolsApi
The Postmaster Tools API is a RESTful API that provides programmatic access to email traffic metrics (like spam reports, delivery errors etc) otherwise available through the Gmail Postmaster Tools UI currently.
QueryDomainStatsRequest
Request message for QueryDomainStats.
QueryDomainStatsResponse
Response message for QueryDomainStats.
StatisticValue
The actual value of a statistic.
TimeQuery
The date ranges or specific dates for which you want to retrieve data.
User
Developer Preview: Information about a user's access to a domain.
VerifyDomainRequest
Developer Preview: Request message for VerifyDomain.

Typedefs

Date = $Date
Represents a whole or partial calendar date, such as a birthday.
Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Status = $Status00
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
StringList = $StringList
Represents a list of strings.
VerifyDomainResponse = $Empty
Developer Preview: Response message for VerifyDomain.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.