results property

List<BatchQueryDomainStatsResult>? results
getter/setter pair

A list of responses, one for each query in the BatchQueryDomainStatsRequest.

The order of responses will correspond to the order of requests.

Implementation

core.List<BatchQueryDomainStatsResult>? results;