CreateUserRequest class

Developer Preview: Request message for CreateUser.

Constructors

CreateUserRequest({String? permission, String? userId})
CreateUserRequest.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
permission String?
Specifies the permission level to give the user for the specified domain.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
The user to create.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited