DateRange class

A single date range defined by a start and end date.

Constructors

DateRange({Date? end, Date? start})
DateRange.fromJson(Map json_)

Properties

end Date?
The inclusive end date of the date range.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start Date?
The inclusive start date of the date range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited