DateRanges class

A set of date ranges.

Constructors

DateRanges({List<DateRange>? dateRanges})
DateRanges.fromJson(Map json_)

Properties

dateRanges List<DateRange>?
The list of date ranges for which to retrieve data.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited