Domain class

Information about a domain registered by the user.

Constructors

Domain({String? createTime, String? lastVerifyTime, String? name, String? permission, String? verificationState})
Domain.fromJson(Map json_)

Properties

createTime String?
The timestamp at which the domain was added to the user's account.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastVerifyTime String?
The timestamp at which the domain was last verified by the user.
getter/setter pair
name String?
Identifier.
getter/setter pair
permission String?
User's permission of this domain.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verificationState String?
Information about a user's verification history and properties for the domain.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited