createTime property
The timestamp at which the domain was added to the user's account.
Output only. Immutable.
Implementation
core.String? createTime;
The timestamp at which the domain was added to the user's account.
Output only. Immutable.
core.String? createTime;