rowData property

List<ComplianceRowData>? rowData
getter/setter pair

Data for each of the rows of the table.

Each message contains all the data that backs a single row.

Implementation

core.List<ComplianceRowData>? rowData;