subdomainComplianceData property
Compliance data calculated specifically for the subdomain in name.
This field is only populated if the domain in name is a subdomain that
differs from its registrable domain (e.g., sub.example.com), and if
compliance data is available for that specific subdomain.
Implementation
DomainComplianceData? subdomainComplianceData;