DomainStat class
Email statistics for a domain for a specified time period or date.
Constructors
- DomainStat({Date? date, String? metric, String? name, StatisticValue? value})
- DomainStat.fromJson(Map json_)
Properties
- date ↔ Date?
-
The specific date for these stats, if granularity is DAILY.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- metric ↔ String?
-
The user-defined name from MetricDefinition.name in the request, used to
correlate this result with the requested metric.
getter/setter pair
- name ↔ String?
-
The resource name of the DomainStat resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ StatisticValue?
-
The value of the corresponding metric.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited