date property
The specific date for these stats, if granularity is DAILY.
This field is populated if the QueryDomainStatsRequest specified a DAILY aggregation granularity.
Optional.
Implementation
Date? date;
The specific date for these stats, if granularity is DAILY.
This field is populated if the QueryDomainStatsRequest specified a DAILY aggregation granularity.
Optional.
Date? date;