metric property
The user-defined name from MetricDefinition.name in the request, used to correlate this result with the requested metric.
Implementation
core.String? metric;
The user-defined name from MetricDefinition.name in the request, used to correlate this result with the requested metric.
core.String? metric;