DomainVerificationToken class
Developer Preview: The DNS token a user can use to verify ownership of a domain.
Constructors
- DomainVerificationToken({String? name, String? token, String? verificationMethod})
- DomainVerificationToken.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token ↔ String?
-
The verification token.
getter/setter pair
- verificationMethod ↔ String?
-
The verification method used.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited