DomainsDomainStatsResource class

Constructors

DomainsDomainStatsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
query(QueryDomainStatsRequest request, String parent, {String? $fields}) Future<QueryDomainStatsResponse>
Retrieves a list of domain statistics for a given domain and time period.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited