list method

Future<ListDomainsResponse> list({
  1. int? pageSize,
  2. String? pageToken,
  3. String? $fields,
})

Retrieves a list of all domains registered by you, along with their corresponding metadata.

The order of domains in the response is unspecified and non-deterministic. Newly registered domains will not necessarily be added to the end of this list.

Request parameters:

pageSize - Optional. Requested page size. Server may return fewer domains than requested. If unspecified, the default value for this field is 10. The maximum value for this field is 200.

pageToken - Optional. The next_page_token value returned from a previous List request, if any.

$fields - Selector specifying which fields to include in a partial response.

Completes with a ListDomainsResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<ListDomainsResponse> list({
  core.int? pageSize,
  core.String? pageToken,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'pageSize': ?pageSize == null ? null : ['${pageSize}'],
    'pageToken': ?pageToken == null ? null : [pageToken],
    'fields': ?$fields == null ? null : [$fields],
  };

  const url_ = 'v2/domains';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return ListDomainsResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}