DomainsUsersResource class

Constructors

DomainsUsersResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(CreateUserRequest request, String parent, {String? $fields}) Future<User>
Developer Preview: Creates a user, who has access to a domain.
delete(String name, {String? $fields}) Future<Empty>
Developer Preview: Deletes a user from a domain.
get(String name, {String? $fields}) Future<User>
Developer Preview: Retrieves detailed information about a user that has access to a domain.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<ListUsersResponse>
Developer Preview: Lists the users that have access to a domain.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(User request, String name, {String? updateMask, String? $fields}) Future<User>
Developer Preview: Updates a user for a domain.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited