list method
Developer Preview: Lists the users that have access to a domain.
Request parameters:
parent - Required. The parent resource name for which to list users.
Format: domains/{domain}
Value must have pattern ^domains/\[^/\]+$.
pageSize - Optional. Requested page size. Server may return fewer users
than requested. If unspecified, the default value for this field is 10.
The maximum value for this field is 200.
pageToken - Optional. The next_page_token value returned from a previous
List request, if any.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListUsersResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListUsersResponse> list(
core.String parent, {
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v2/' + core.Uri.encodeFull('$parent') + '/users';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListUsersResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}