HonorUnsubscribeVerdict class
Compliance verdict for whether a sender meets the unsubscribe honoring compliance requirement.
Constructors
- HonorUnsubscribeVerdict({String? reason, ComplianceStatus? status})
- HonorUnsubscribeVerdict.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reason ↔ String?
-
The specific reason for the compliance verdict.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ ComplianceStatus?
-
The compliance status.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited