MetricDefinition class

Defines a specific metric to query, including a user-defined name, the base metric type, and optional filters.

Constructors

MetricDefinition({BaseMetric? baseMetric, String? filter, String? name})
MetricDefinition.fromJson(Map json_)

Properties

baseMetric ↔ BaseMetric?
The underlying metric to query.
getter/setter pair
filter ↔ String?
Optional filters to apply to the metric.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The user-defined name for this metric.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited