name property
The user-defined name for this metric.
This name will be used as the key for this metric's value in the response.
Required.
Implementation
core.String? name;
The user-defined name for this metric.
This name will be used as the key for this metric's value in the response.
Required.
core.String? name;