PostmasterToolsApi class

The Postmaster Tools API is a RESTful API that provides programmatic access to email traffic metrics (like spam reports, delivery errors etc) otherwise available through the Gmail Postmaster Tools UI currently.

Constructors

PostmasterToolsApi(Client client, {String rootUrl = 'https://gmailpostmastertools.googleapis.com/', String servicePath = ''})

Properties

domains DomainsResource
no setter
domainStats DomainStatsResource
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

postmasterDomainScope → const String
View and manage the domains you have registered with Postmaster Tools
postmasterScope → const String
Get email traffic metrics, manage domains, and manage domain users for the domains you have registered with Postmaster Tools
postmasterTrafficReadonlyScope → const String
Get email traffic metrics for the domains you have registered with Postmaster Tools
postmasterUserScope → const String
View and manage users for the domains you have registered with Postmaster Tools