postmasterScope constant

String const postmasterScope

Get email traffic metrics, manage domains, and manage domain users for the domains you have registered with Postmaster Tools

Implementation

static const postmasterScope = 'https://www.googleapis.com/auth/postmaster';