aggregationGranularity property

String? aggregationGranularity
getter/setter pair

The granularity at which to aggregate the statistics.

If unspecified, defaults to DAILY.

Optional. Possible string values are:

  • "AGGREGATION_GRANULARITY_UNSPECIFIED" : Unspecified granularity. Defaults to DAILY.
  • "DAILY" : Statistics are aggregated on a daily basis. Each DomainStats entry in the response will correspond to a single day.
  • "OVERALL" : Statistics are aggregated over the entire requested time period. Each DomainStats entry in the response will represent the total for the period.

Implementation

core.String? aggregationGranularity;