metricDefinitions property
The specific metrics to query.
You can define a custom name for each metric, which will be used in the response.
Required.
Implementation
core.List<MetricDefinition>? metricDefinitions;
The specific metrics to query.
You can define a custom name for each metric, which will be used in the response.
Required.
core.List<MetricDefinition>? metricDefinitions;