parent property
The parent resource name where the stats are queried.
Format: domains/{domain}
Required.
Implementation
core.String? parent;
The parent resource name where the stats are queried.
Format: domains/{domain}
Required.
core.String? parent;