domainStats property
The list of domain statistics.
Each DomainStat object contains the value for a metric requested in the QueryDomainStatsRequest.
Implementation
core.List<DomainStat>? domainStats;
The list of domain statistics.
Each DomainStat object contains the value for a metric requested in the QueryDomainStatsRequest.
core.List<DomainStat>? domainStats;