TimeQuery class
The date ranges or specific dates for which you want to retrieve data.
Constructors
- TimeQuery({DateList? dateList, DateRanges? dateRanges})
- TimeQuery.fromJson(Map json_)
Properties
- dateList ↔ DateList?
-
A list of specific dates.
getter/setter pair
- dateRanges ↔ DateRanges?
-
A list of date ranges.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited