User class

Developer Preview: Information about a user's access to a domain.

Constructors

User({String? accessGranter, String? createTime, String? name, String? permission, String? user})
User.fromJson(Map json_)

Properties

accessGranter String?
The user that added the current user.
getter/setter pair
createTime String?
The time the user was granted access.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
permission String?
The permission level that the user has for the specified domain. Possible string values are:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
user String?
The user's email address.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited