ActivityLevel class

Internal type to capture activity level during a certain time interval.

Constructors

ActivityLevel({String? activityLevelType, ObservationTimeInterval? interval})
ActivityLevel.fromJson(Map json_)

Properties

activityLevelType String?
Activity level type in the given time interval.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval ObservationTimeInterval?
Observed interval.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited