ActivityLevelRollupByActivityLevelType class
Represents the total duration in a specific activity level type.
Constructors
- ActivityLevelRollupByActivityLevelType({String? activityLevelType, String? totalDuration})
- ActivityLevelRollupByActivityLevelType.fromJson(Map json_)
Properties
- activityLevelType ↔ String?
-
Activity level type.
Possible string values are:
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalDuration ↔ String?
-
Total duration in the activity level type.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited