ActivityLevelRollupValue class

Represents the result of the rollup of the activity level data type.

Constructors

ActivityLevelRollupValue({List<ActivityLevelRollupByActivityLevelType>? activityLevelRollupsByActivityLevelType})
ActivityLevelRollupValue.fromJson(Map json_)

Properties

activityLevelRollupsByActivityLevelType List<ActivityLevelRollupByActivityLevelType>?
List of total durations in each activity level type.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited