civilStartTime property
Observed interval start time in civil time in the timezone the subject is in at the start of the observed interval
Output only.
Implementation
CivilDateTime? civilStartTime;
Observed interval start time in civil time in the timezone the subject is in at the start of the observed interval
Output only.
CivilDateTime? civilStartTime;