positive property

bool? positive
getter/setter pair

Flag indicating whether the window was positive for AFib or not.

A true value indicates that AFib was detected in this window. A false value means AFib was not detected, but does not guarantee the absence of AFib.

Optional.

Implementation

core.bool? positive;