Application class
Optional metadata for the application that provided this data.
Constructors
- Application({String? googleWebClientId, String? packageName, String? webClientId})
- Application.fromJson(Map json_)
Properties
- googleWebClientId ↔ String?
-
The Google OAuth 2.0 client ID of the web application or service that
recorded the data.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- packageName ↔ String?
-
A unique identifier for the mobile application that was the source of the
data.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webClientId ↔ String?
-
The client ID of the application that recorded the data.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited