packageName property

String? packageName
getter/setter pair

A unique identifier for the mobile application that was the source of the data.

This is typically the application's package name on Android (e.g., com.google.fitbit) or the bundle ID on iOS. This field is informational and helps trace data origin. This field is system-populated when the data is uploaded from the Fitbit mobile application, Health Connect or Health Kit.

Output only.

Implementation

core.String? packageName;