BodyFat class
Body fat measurement.
Constructors
- BodyFat({double? percentage, ObservationSampleTime? sampleTime})
- BodyFat.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- percentage ↔ double?
-
Body fat percentage, in range [0, 100].
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleTime ↔ ObservationSampleTime?
-
The time at which body fat was measured.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited