CivilTimeInterval class

Counterpart of google.type.Interval, but using CivilDateTime.

Properties

end CivilDateTime?
The exclusive end of the range.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start CivilDateTime?
The inclusive start of the range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited