CoreBodyTemperature class

Core body temperature measurement, distinct from peripheral body temperature, reflects the temperature of the body's internal organs.

Constructors

CoreBodyTemperature({String? id, String? measurementLocation, ObservationSampleTime? sampleTime, double? temperatureCelsius})
CoreBodyTemperature.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
The unique identifier of the core body temperature measurement.
getter/setter pair
measurementLocation String?
The location of the core body temperature measurement.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleTime ObservationSampleTime?
The time at which core body temperature was measured.
getter/setter pair
temperatureCelsius double?
The core body temperature in Celsius.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited