CreateSubscriberPayload class

Payload for creating a subscriber.

Constructors

CreateSubscriberPayload({EndpointAuthorization? endpointAuthorization, String? endpointUri, List<SubscriberConfig>? subscriberConfigs})
CreateSubscriberPayload.fromJson(Map json_)

Properties

endpointAuthorization ↔ EndpointAuthorization?
Authorization mechanism for the subscriber endpoint.
getter/setter pair
endpointUri ↔ String?
The full HTTPS URI where update notifications will be sent.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriberConfigs ↔ List<SubscriberConfig>?
Configuration for the subscriber.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited