CreateSubscriptionPayload class
Payload for creating a subscription.
Constructors
-
CreateSubscriptionPayload({List<
String> ? dataTypes, String? user}) - CreateSubscriptionPayload.fromJson(Map json_)
Properties
-
dataTypes
↔ List<
String> ? -
Data types subscribed to.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user ↔ String?
-
The resource name of the user for whom this subscription is active.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited