DailyRollUpDataPointsRequest class

Request to roll up data points by civil time intervals.

Constructors

DailyRollUpDataPointsRequest({String? dataSourceFamily, int? pageSize, String? pageToken, CivilTimeInterval? range, int? windowSizeDays})
DailyRollUpDataPointsRequest.fromJson(Map json_)

Properties

dataSourceFamily String?
The data source family name to roll up.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pageSize int?
The maximum number of data points to return.
getter/setter pair
pageToken String?
The next_page_token from a previous request, if any.
getter/setter pair
range CivilTimeInterval?
Closed-open range of data points that will be rolled up.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
windowSizeDays int?
Aggregation window size, in number of days.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited