range property

CivilTimeInterval? range
getter/setter pair

Closed-open range of data points that will be rolled up.

The start time must be aligned with the aggregation window. The maximum range for calories-in-heart-rate-zone, heart-rate, active-minutes and total-calories is 14 days. The maximum range for all other data types is 90 days.

Required.

Implementation

CivilTimeInterval? range;