DailyRollupDataPoint class

Value of a daily rollup for a single civil time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.

Constructors

DailyRollupDataPoint({ActiveEnergyBurnedRollupValue? activeEnergyBurned, ActiveMinutesRollupValue? activeMinutes, ActiveZoneMinutesRollupValue? activeZoneMinutes, ActivityLevelRollupValue? activityLevel, AltitudeRollupValue? altitude, BloodGlucoseRollupValue? bloodGlucose, BodyFatRollupValue? bodyFat, CaloriesInHeartRateZoneRollupValue? caloriesInHeartRateZone, CivilDateTime? civilEndTime, CivilDateTime? civilStartTime, CoreBodyTemperatureRollupValue? coreBodyTemperature, DistanceRollupValue? distance, FloorsRollupValue? floors, HeartRateRollupValue? heartRate, HeartRateVariabilityPersonalRangeRollupValue? heartRateVariabilityPersonalRange, HydrationLogRollupValue? hydrationLog, NutritionLogRollupValue? nutritionLog, RestingHeartRatePersonalRangeRollupValue? restingHeartRatePersonalRange, RunVO2MaxRollupValue? runVo2Max, SedentaryPeriodRollupValue? sedentaryPeriod, StepsRollupValue? steps, SwimLengthsDataRollupValue? swimLengthsData, TimeInHeartRateZoneRollupValue? timeInHeartRateZone, TotalCaloriesRollupValue? totalCalories, WeightRollupValue? weight})
DailyRollupDataPoint.fromJson(Map json_)

Properties

activeEnergyBurned ↔ ActiveEnergyBurnedRollupValue?
Returned by default when rolling up data points from the active-energy-burned data type.
getter/setter pair
activeMinutes ↔ ActiveMinutesRollupValue?
Returned by default when rolling up data points from the active-minutes data type, or when requested explicitly using the active-minutes rollup type identifier.
getter/setter pair
activeZoneMinutes ↔ ActiveZoneMinutesRollupValue?
Returned by default when rolling up data points from the active-zone-minutes data type, or when requested explicitly using the active-zone-minutes rollup type identifier.
getter/setter pair
activityLevel ↔ ActivityLevelRollupValue?
Returned by default when rolling up data points from the activity-level data type, or when requested explicitly using the activity-level rollup type identifier.
getter/setter pair
altitude ↔ AltitudeRollupValue?
Returned by default when rolling up data points from the altitude data type, or when requested explicitly using the altitude rollup type identifier.
getter/setter pair
bloodGlucose ↔ BloodGlucoseRollupValue?
Returned by default when rolling up data points from the blood-glucose data type.
getter/setter pair
bodyFat ↔ BodyFatRollupValue?
Returned by default when rolling up data points from the body-fat data type, or when requested explicitly using the body-fat rollup type identifier.
getter/setter pair
caloriesInHeartRateZone ↔ CaloriesInHeartRateZoneRollupValue?
Returned by default when rolling up data points from the calories-in-heart-rate-zone data type, or when requested explicitly using the calories-in-heart-rate-zone rollup type identifier.
getter/setter pair
civilEndTime ↔ CivilDateTime?
End time of the window this value aggregates over
getter/setter pair
civilStartTime ↔ CivilDateTime?
Start time of the window this value aggregates over
getter/setter pair
coreBodyTemperature ↔ CoreBodyTemperatureRollupValue?
Returned by default when rolling up data points from the core-body-temperature data type, or when requested explicitly using the core-body-temperature rollup type identifier.
getter/setter pair
distance ↔ DistanceRollupValue?
Returned by default when rolling up data points from the distance data type, or when requested explicitly using the distance rollup type identifier.
getter/setter pair
floors ↔ FloorsRollupValue?
Returned by default when rolling up data points from the floors data type, or when requested explicitly using the floors rollup type identifier.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heartRate ↔ HeartRateRollupValue?
Returned by default when rolling up data points from the heart-rate data type, or when requested explicitly using the heart-rate rollup type identifier.
getter/setter pair
heartRateVariabilityPersonalRange ↔ HeartRateVariabilityPersonalRangeRollupValue?
Returned by default when rolling up data points from the daily-heart-rate-variability data type, or when requested explicitly using the heart-rate-variability-personal-range rollup type identifier.
getter/setter pair
hydrationLog ↔ HydrationLogRollupValue?
Returned by default when rolling up data points from the hydration-log data type, or when requested explicitly using the hydration-log rollup type identifier.
getter/setter pair
nutritionLog ↔ NutritionLogRollupValue?
Returned by default when rolling up data points from the nutrition-log data type, or when requested explicitly using the nutrition-log rollup type identifier.
getter/setter pair
restingHeartRatePersonalRange ↔ RestingHeartRatePersonalRangeRollupValue?
Returned by default when rolling up data points from the daily-resting-heart-rate data type, or when requested explicitly using the resting-heart-rate-personal-range rollup type identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runVo2Max ↔ RunVO2MaxRollupValue?
Returned by default when rolling up data points from the run-vo2-max data type, or when requested explicitly using the run-vo2-max rollup type identifier.
getter/setter pair
sedentaryPeriod ↔ SedentaryPeriodRollupValue?
Returned by default when rolling up data points from the sedentary-period data type, or when requested explicitly using the sedentary-period rollup type identifier.
getter/setter pair
steps ↔ StepsRollupValue?
Returned by default when rolling up data points from the steps data type, or when requested explicitly using the steps rollup type identifier.
getter/setter pair
swimLengthsData ↔ SwimLengthsDataRollupValue?
Returned by default when rolling up data points from the swim-lengths-data data type, or when requested explicitly using the swim-lengths-data rollup type identifier.
getter/setter pair
timeInHeartRateZone ↔ TimeInHeartRateZoneRollupValue?
Returned by default when rolling up data points from the time-in-heart-rate-zone data type, or when requested explicitly using the time-in-heart-rate-zone rollup type identifier.
getter/setter pair
totalCalories ↔ TotalCaloriesRollupValue?
Returned by default when rolling up data points from the total-calories data type, or when requested explicitly using the total-calories rollup type identifier.
getter/setter pair
weight ↔ WeightRollupValue?
Returned by default when rolling up data points from the weight data type, or when requested explicitly using the weight rollup type identifier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited