hydrationLog property

HydrationLogRollupValue? hydrationLog
getter/setter pair

Returned by default when rolling up data points from the hydration-log data type, or when requested explicitly using the hydration-log rollup type identifier.

Implementation

HydrationLogRollupValue? hydrationLog;