steps property

StepsRollupValue? steps
getter/setter pair

Returned by default when rolling up data points from the steps data type, or when requested explicitly using the steps rollup type identifier.

Implementation

StepsRollupValue? steps;