weight property
Returned by default when rolling up data points from the weight data
type, or when requested explicitly using the weight rollup type
identifier.
Implementation
WeightRollupValue? weight;
Returned by default when rolling up data points from the weight data
type, or when requested explicitly using the weight rollup type
identifier.
WeightRollupValue? weight;