electrocardiogram property
Data for points in the electrocardiogram session data type collection.
Optional.
Implementation
Electrocardiogram? electrocardiogram;
Data for points in the electrocardiogram session data type collection.
Optional.
Electrocardiogram? electrocardiogram;