DataSource class

Data Source definition to track the origin of data.

Each health data point, regardless of the complexity or data model (whether a simple step count or a detailed sleep session) must retain information about its source of origin (e.g. the device or app that collected it).

Constructors

DataSource({Application? application, Device? device, String? platform, String? recordingMethod})
DataSource.fromJson(Map json_)

Properties

application Application?
Captures metadata for the application that provided this data.
getter/setter pair
device Device?
Captures metadata for raw data points originating from devices.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
platform String?
Captures the platform that uploaded the data.
getter/setter pair
recordingMethod String?
Captures how the data was recorded.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited