device property
Captures metadata for raw data points originating from devices.
We expect this data source to be used for data points written on device sync.
Optional.
Implementation
Device? device;
Captures metadata for raw data points originating from devices.
We expect this data source to be used for data points written on device sync.
Optional.
Device? device;