Device class
Captures metadata about the device that recorded the measurement.
Constructors
Properties
- displayName ↔ String?
-
An optional name for the device.
getter/setter pair
- formFactor ↔ String?
-
Captures the form factor of the device.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- manufacturer ↔ String?
-
An optional manufacturer of the device.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited