DistanceRollupValue class

Result of the rollup of the user's distance.

Constructors

DistanceRollupValue({String? millimetersSum})
DistanceRollupValue.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
millimetersSum String?
Sum of the distance in millimeters.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited