EndpointAuthorization class

Authorization mechanism for a subscriber endpoint.

For all requests sent by the Webhooks service, the JSON payload is cryptographically signed. The signature is delivered in the GOOGLE-HEALTH-API-SIGNATURE HTTP header. This is an ECDSA (NIST P256) signature of the JSON payload. Clients must verify this signature using Google Health API's public key to confirm the payload was sent by the Health API.

Constructors

EndpointAuthorization({String? secret, bool? secretSet})
EndpointAuthorization.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secret String?
Input only.
getter/setter pair
secretSet bool?
Whether the secret is set.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited