Exercise class

An exercise that stores information about a physical activity.

Constructors

Exercise({String? activeDuration, String? createTime, String? displayName, List<ExerciseEvent>? exerciseEvents, ExerciseMetadata? exerciseMetadata, String? exerciseType, SessionTimeInterval? interval, MetricsSummary? metricsSummary, String? notes, List<SplitSummary>? splitSummaries, List<SplitSummary>? splits, String? updateTime})
Exercise.fromJson(Map json_)

Properties

activeDuration ↔ String?
Duration excluding pauses.
getter/setter pair
createTime ↔ String?
Represents the timestamp of the creation of the exercise.
getter/setter pair
displayName ↔ String?
The localized, human-readable name of the exercise.
getter/setter pair
exerciseEvents ↔ List<ExerciseEvent>?
Exercise events that happen during an exercise, such as pause & restarts.
getter/setter pair
exerciseMetadata ↔ ExerciseMetadata?
Additional exercise metadata.
getter/setter pair
exerciseType ↔ String?
The type of activity performed during an exercise.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interval ↔ SessionTimeInterval?
Observed exercise interval
getter/setter pair
metricsSummary ↔ MetricsSummary?
Summary metrics for this exercise ( )
getter/setter pair
notes ↔ String?
Standard free-form notes captured at manual logging.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splits ↔ List<SplitSummary>?
The default split is 1 km or 1 mile.
getter/setter pair
splitSummaries ↔ List<SplitSummary>?
Laps or splits recorded within an exercise.
getter/setter pair
updateTime ↔ String?
This is the timestamp of the last update to the exercise.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited