displayName property

String? displayName
getter/setter pair

The localized, human-readable name of the exercise.

For all exercise types other than OTHER, the system ignores client input and overrides this field with a generated name based on exercise_type (e.g., "Walking" for WALKING). If exercise_type is OTHER, this field can contain the user's custom, free-form display name.

Required.

Implementation

core.String? displayName;