splits property

List<SplitSummary>? splits
getter/setter pair

The default split is 1 km or 1 mile.

  • if the movement distance is less than the default, then there are no splits - if the movement distance is greater than or equal to the default, then we have splits

Optional.

Implementation

core.List<SplitSummary>? splits;