ExerciseEvent class

Represents instantaneous events that happen during an exercise, such as start, stop, pause, split.

Constructors

ExerciseEvent({String? eventTime, String? eventUtcOffset, String? exerciseEventType})
ExerciseEvent.fromJson(Map json_)

Properties

eventTime ↔ String?
Exercise event time
getter/setter pair
eventUtcOffset ↔ String?
Exercise event time offset from UTC
getter/setter pair
exerciseEventType ↔ String?
The type of the event, such as start, stop, pause, resume.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited