FoodMeasurementUnit class
Represents a food measurement unit.
Constructors
- FoodMeasurementUnit({String? displayName, String? pluralDisplayName})
- FoodMeasurementUnit.fromJson(Map json_)
Properties
- displayName ↔ String?
-
The display name of the food measurement unit (e.g., "gram", "piece").
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pluralDisplayName ↔ String?
-
The plural display name of the food measurement unit (e.g., "grams",
"pieces").
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited