HeartRate class

A heart rate measurement.

Constructors

HeartRate({String? beatsPerMinute, HeartRateMetadata? metadata, ObservationSampleTime? sampleTime})
HeartRate.fromJson(Map json_)

Properties

beatsPerMinute String?
The heart rate value in beats per minute.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata HeartRateMetadata?
Metadata about the heart rate sample.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleTime ObservationSampleTime?
Observation time
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited