HeartRateMetadata class

Heart rate metadata.

Constructors

HeartRateMetadata({String? motionContext, String? sensorLocation})
HeartRateMetadata.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
motionContext String?
Indicates the user’s level of activity when the heart rate sample was measured
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensorLocation String?
Indicates the location of the sensor that measured the heart rate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited