HeartRateVariabilityPersonalRangeRollupValue class
Represents the result of the rollup of the user's daily heart rate variability personal range.
Constructors
- HeartRateVariabilityPersonalRangeRollupValue({double? averageHeartRateVariabilityMillisecondsMax, double? averageHeartRateVariabilityMillisecondsMin})
- HeartRateVariabilityPersonalRangeRollupValue.fromJson(Map json_)
Properties
- averageHeartRateVariabilityMillisecondsMax ↔ double?
-
The upper bound of the user's average heart rate variability personal
range.
getter/setter pair
- averageHeartRateVariabilityMillisecondsMin ↔ double?
-
The lower bound of the user's average heart rate variability personal
range.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited