Height class
Body height measurement.
Constructors
- Height({String? heightMillimeters, ObservationSampleTime? sampleTime})
- Height.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heightMillimeters ↔ String?
-
Height of the user in millimeters.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleTime ↔ ObservationSampleTime?
-
The time at which the height was recorded.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited