Identity class

Represents details about the Google user's identity.

Constructors

Identity({String? healthUserId, String? legacyUserId, String? name})
Identity.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthUserId ↔ String?
The Google User Identifier in the Google Health APIs.
getter/setter pair
legacyUserId ↔ String?
The legacy Fitbit User identifier.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited