IrregularRhythmNotification class

Represents an Irregular Rhythm Notification alert, indicating a potential sign of atrial fibrillation (AFib).

This data type is based on SaMD feature and any changes to it may require additional review.

Properties

alertWindows List<AlertWindow>?
The overlapping analysis windows that were used to evaluate rhythm for potential AFib, containing specific information about the user's heart rhythm.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval SessionTimeInterval?
Observed interval.
getter/setter pair
medicalDeviceInfo MedicalDeviceInfo?
The meta information for the compatible device used to conduct the measurement.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited