alertWindows property
The overlapping analysis windows that were used to evaluate rhythm for potential AFib, containing specific information about the user's heart rhythm.
Optional.
Implementation
core.List<AlertWindow>? alertWindows;
The overlapping analysis windows that were used to evaluate rhythm for potential AFib, containing specific information about the user's heart rhythm.
Optional.
core.List<AlertWindow>? alertWindows;