ListDataPointsResponse class

Response containing raw data points matching the query

Constructors

ListDataPointsResponse({List<DataPoint>? dataPoints, String? nextPageToken})
ListDataPointsResponse.fromJson(Map json_)

Properties

dataPoints List<DataPoint>?
Data points matching the query
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nextPageToken String?
Next page token, empty if the response is complete
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited