ObservationSampleTime class

Represents a sample time of an observed data point.

Constructors

ObservationSampleTime({CivilDateTime? civilTime, String? physicalTime, String? utcOffset})
ObservationSampleTime.fromJson(Map json_)

Properties

civilTime ↔ CivilDateTime?
The civil time in the timezone the subject is in at the time of the observation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
physicalTime ↔ String?
The time of the observation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
utcOffset ↔ String?
The offset of the user's local time during the observation relative to the Coordinated Universal Time (UTC).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited