civilTime property
The civil time in the timezone the subject is in at the time of the observation.
Output only.
Implementation
CivilDateTime? civilTime;
The civil time in the timezone the subject is in at the time of the observation.
Output only.
CivilDateTime? civilTime;