utcOffset property
The offset of the user's local time during the observation relative to the Coordinated Universal Time (UTC).
Required.
Implementation
core.String? utcOffset;
The offset of the user's local time during the observation relative to the Coordinated Universal Time (UTC).
Required.
core.String? utcOffset;