ObservationTimeInterval class

Represents a time interval of an observed data point.

Constructors

ObservationTimeInterval({CivilDateTime? civilEndTime, CivilDateTime? civilStartTime, String? endTime, String? endUtcOffset, String? startTime, String? startUtcOffset})
ObservationTimeInterval.fromJson(Map json_)

Properties

civilEndTime ↔ CivilDateTime?
Observed interval end time in civil time in the timezone the subject is in at the end of the observed interval
getter/setter pair
civilStartTime ↔ CivilDateTime?
Observed interval start time in civil time in the timezone the subject is in at the start of the observed interval
getter/setter pair
endTime ↔ String?
Observed interval end time.
getter/setter pair
endUtcOffset ↔ String?
The offset of the user's local time at the end of the observation relative to the Coordinated Universal Time (UTC).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Observed interval start time.
getter/setter pair
startUtcOffset ↔ String?
The offset of the user's local time at the start of the observation relative to the Coordinated Universal Time (UTC).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited