OvulationTest class

Ovulation test record.

Constructors

OvulationTest({String? result, ObservationSampleTime? sampleTime})
OvulationTest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
result ↔ String?
The result of the ovulation test.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleTime ↔ ObservationSampleTime?
The time at which ovulation test was measured.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited