PairedDevice class

User's Paired 1P Device The PairedDevice details include information about the device type, battery status, battery level, last sync time, device version, mac address, and features.

Constructors

PairedDevice({int? batteryLevel, String? batteryStatus, String? deviceType, String? deviceVersion, List<String>? features, String? lastSyncTime, String? macAddress, String? name})
PairedDevice.fromJson(Map json_)

Properties

batteryLevel int?
The battery level of the device.
getter/setter pair
batteryStatus String?
The battery status of the device.
getter/setter pair
deviceType String?
The device type.
getter/setter pair
deviceVersion String?
The product name of the device
getter/setter pair
features List<String>?
Lists of unique features supported by the device.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lastSyncTime String?
The time of last sync with the Fitbit mobile application.
getter/setter pair
macAddress String?
Mac ID number of the device.
getter/setter pair
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited