ProjectsSubscribersResource class

Constructors

ProjectsSubscribersResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptions ProjectsSubscribersSubscriptionsResource
no setter

Methods

create(CreateSubscriberPayload request, String parent, {String? subscriberId, String? $fields}) Future<Operation>
Registers a new subscriber endpoint to receive notifications.
delete(String name, {bool? force, String? $fields}) Future<Operation>
Deletes a subscriber registration.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<ListSubscribersResponse>
Lists all subscribers registered within the owned Google Cloud Project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Subscriber request, String name, {String? updateMask, String? $fields}) Future<Operation>
Updates the configuration of an existing subscriber, such as the endpoint URI or the data types it's interested in.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited