ProjectsSubscribersSubscriptionsResource class

Constructors

ProjectsSubscribersSubscriptionsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(CreateSubscriptionPayload request, String parent, {String? subscriptionId, String? $fields}) Future<Subscription>
Creates a subscription for a specific user to a specific subscriber.
delete(String name, {String? $fields}) Future<Empty>
Deletes a specific user subscription, stopping notifications for this user to this subscriber.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) Future<ListSubscriptionsResponse>
Lists all active subscriptions for a given subscriber.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Subscription request, String name, {String? updateMask, String? $fields}) Future<Subscription>
Updates the data types for an existing user subscription.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited