activityLevel property

ActivityLevelRollupValue? activityLevel
getter/setter pair

Returned by default when rolling up data points from the activity-level data type, or when requested explicitly using the activity-level rollup type identifier.

Implementation

ActivityLevelRollupValue? activityLevel;