coreBodyTemperature property
Returned by default when rolling up data points from the
core-body-temperature data type, or when requested explicitly using the
core-body-temperature rollup type identifier.
Implementation
CoreBodyTemperatureRollupValue? coreBodyTemperature;