runVo2Max property

RunVO2MaxRollupValue? runVo2Max
getter/setter pair

Returned by default when rolling up data points from the run-vo2-max data type, or when requested explicitly using the run-vo2-max rollup type identifier.

Implementation

RunVO2MaxRollupValue? runVo2Max;