sedentaryPeriod property
Returned by default when rolling up data points from the
sedentary-period data type, or when requested explicitly using the
sedentary-period rollup type identifier.
Implementation
SedentaryPeriodRollupValue? sedentaryPeriod;