timeInHeartRateZone property

TimeInHeartRateZoneRollupValue? timeInHeartRateZone
getter/setter pair

Returned by default when rolling up data points from the time-in-heart-rate-zone data type, or when requested explicitly using the time-in-heart-rate-zone rollup type identifier.

Implementation

TimeInHeartRateZoneRollupValue? timeInHeartRateZone;