weight property

WeightRollupValue? weight
getter/setter pair

Returned by default when rolling up data points from the weight data type, or when requested explicitly using the weight rollup type identifier.

Implementation

WeightRollupValue? weight;