civilStartTime property

CivilDateTime? civilStartTime
getter/setter pair

Session start time in civil time in the timezone the subject is in at the start of the session.

Output only.

Implementation

CivilDateTime? civilStartTime;