startUtcOffset property
The offset of the user's local time at the start of the session relative to the Coordinated Universal Time (UTC).
Required.
Implementation
core.String? startUtcOffset;
The offset of the user's local time at the start of the session relative to the Coordinated Universal Time (UTC).
Required.
core.String? startUtcOffset;