Sleep class

A sleep session possibly including stages.

Constructors

Sleep({String? createTime, SessionTimeInterval? interval, SleepMetadata? metadata, List<OutOfBedSegment>? outOfBedSegments, List<SleepStage>? shortAwakenings, List<SleepStage>? stages, SleepSummary? summary, String? type, String? updateTime})
Sleep.fromJson(Map json_)

Properties

createTime String?
Creation time of this sleep observation.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval SessionTimeInterval?
Observed sleep interval.
getter/setter pair
metadata SleepMetadata?
Sleep metadata: processed, main_sleep, manually_edited, and stages_status.
getter/setter pair
outOfBedSegments List<OutOfBedSegment>?
“Out of bed” segments that can overlap with sleep stages.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortAwakenings List<SleepStage>?
List of short awake segments (under a set threshold) that are part of the sleep session.
getter/setter pair
stages List<SleepStage>?
List of non-overlapping contiguous sleep stage segments that cover the sleep period.
getter/setter pair
summary SleepSummary?
Sleep summary: metrics and stages summary.
getter/setter pair
type String?
SleepType: classic or stages.
getter/setter pair
updateTime String?
Last update time of this sleep observation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited