mainSleep property

bool? mainSleep
getter/setter pair

main_sleep: the longest sleep session with stages within one day.

If no sleep session has stages, then the longest sleep is the main_sleep. If there are multiple days of sleep in the response, there is one main_sleep per day.

Output only.

Implementation

core.bool? mainSleep;