manuallyEdited property
Some sleeps autodetected by algorithms can be manually edited by users.
Output only.
Implementation
core.bool? manuallyEdited;
Some sleeps autodetected by algorithms can be manually edited by users.
Output only.
core.bool? manuallyEdited;