Subscriber class

-- Resource Messages -- A subscriber receives notifications from Google Health API.

Constructors

Subscriber({String? createTime, EndpointAuthorization? endpointAuthorization, String? endpointUri, String? name, String? state, List<SubscriberConfig>? subscriberConfigs, String? updateTime})
Subscriber.fromJson(Map json_)

Properties

createTime String?
The time at which the subscriber was created.
getter/setter pair
endpointAuthorization EndpointAuthorization?
Authorization mechanism for a subscriber endpoint.
getter/setter pair
endpointUri String?
The full HTTPS URI where update notifications will be sent.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The state of the subscriber.
getter/setter pair
subscriberConfigs List<SubscriberConfig>?
Configuration for the subscriber.
getter/setter pair
updateTime String?
The time at which the subscriber was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited