SubscriberConfig class

Configuration for a subscriber.

A notification is sent to a subscription ONLY if the subscriber has a config for the data type.

Constructors

SubscriberConfig({List<String>? dataTypes, String? subscriptionCreatePolicy})
SubscriberConfig.fromJson(Map json_)

Properties

dataTypes ↔ List<String>?
See Google Health API data types for the list of supported data types.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionCreatePolicy ↔ String?
Policy for subscription creation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited