dataTypes property
See Google Health API data types for the list of supported data types.
Values should be in kebab-case.
Required.
Implementation
core.List<core.String>? dataTypes;
See Google Health API data types for the list of supported data types.
Values should be in kebab-case.
Required.
core.List<core.String>? dataTypes;