subscriptionCreatePolicy property

String? subscriptionCreatePolicy
getter/setter pair

Policy for subscription creation.

Required. Possible string values are:

  • "SUBSCRIPTION_CREATE_POLICY_UNSPECIFIED" : Represents an unspecified policy.
  • "AUTOMATIC" : When using AUTOMATIC, individual subscriptions are not created or stored. Instead, eligibility for notifications is computed dynamically. When a data update occurs for a given data type, notifications are sent to all subscribers with an AUTOMATIC policy for that data type, provided the user has granted the necessary consents. This means you do not need to call CreateSubscription for each user; notifications are managed automatically based on user consents. As Subscription resources are not stored, they cannot be retrieved or managed through GetSubscription, ListSubscriptions, UpdateSubscription, or DeleteSubscription.
  • "MANUAL" : Requires subscriptions to be created manually for new users. The developer needs to call CreateSubscription for new users.

Implementation

core.String? subscriptionCreatePolicy;