TimeInHeartRateZoneValue class

Represents the total time spent in a specific heart rate zone.

Constructors

TimeInHeartRateZoneValue({String? duration, String? heartRateZone})
TimeInHeartRateZoneValue.fromJson(Map json_)

Properties

duration ↔ String?
The total time spent in the specified heart rate zone.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
heartRateZone ↔ String?
The heart rate zone. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited