UsersDataTypesDataPointsResource class

Constructors

UsersDataTypesDataPointsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchDelete(BatchDeleteDataPointsRequest request, String parent, {String? $fields}) Future<Operation>
Delete a batch of identifyable data points.
create(DataPoint request, String parent, {String? $fields}) Future<Operation>
Creates a single identifiable data point.
dailyRollUp(DailyRollUpDataPointsRequest request, String parent, {String? $fields}) Future<DailyRollUpDataPointsResponse>
Roll up data points over civil time intervals for supported data types.
exportExerciseTcx(String name, {bool? partialData, String? $fields, DownloadOptions downloadOptions = commons.DownloadOptions.metadata}) Future<Object>
Exports exercise data in TCX format.
get(String name, {String? $fields}) Future<DataPoint>
Get a single identifyable data point.
list(String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) Future<ListDataPointsResponse>
Query user health and fitness data points.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(DataPoint request, String name, {String? $fields}) Future<Operation>
Updates a single identifiable data point.
reconcile(String parent, {String? dataSourceFamily, String? filter, int? pageSize, String? pageToken, String? $fields}) Future<ReconcileDataPointsResponse>
Reconcile data points from multiple data sources into a single data stream.
rollUp(RollUpDataPointsRequest request, String parent, {String? $fields}) Future<RollUpDataPointsResponse>
Roll up data points over physical time intervals for supported data types.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited