get method
Get a single identifyable data point.
Request parameters:
name - Required. The name of the data point to retrieve. Format:
users/{user}/dataTypes/{data_type}/dataPoints/{data_point} See
DataPoint.name for examples and possible values.
Value must have pattern
^users/\[^/\]+/dataTypes/\[^/\]+/dataPoints/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a DataPoint.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<DataPoint> get(core.String name, {core.String? $fields}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v4/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return DataPoint.fromJson(response_ as core.Map<core.String, core.dynamic>);
}