list method
Returns the user's list of paired 1P trackers and smartwatches.
Request parameters:
parent - Required. The parent, which owns this collection of devices.
Format: users/{user}
Value must have pattern ^users/\[^/\]+$.
pageSize - Optional. The maximum number of devices to return. The
service may return fewer than this value. If unspecified, at most 5
devices will be returned. The maximum value is 100. values above 100 will
be coerced to 100.
pageToken - Optional. A page token, received from a previous
ListPairedDevices call. Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListPairedDevices must
match the call that provided the page token.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListPairedDevicesResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListPairedDevicesResponse> list(
core.String parent, {
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v4/' + core.Uri.encodeFull('$parent') + '/pairedDevices';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListPairedDevicesResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}