updateProfile method

Future<Profile> updateProfile(
  1. Profile request,
  2. String name, {
  3. String? updateMask,
  4. String? $fields,
})

Updates the user's profile details.

request - The metadata request object.

Request parameters:

name - Identifier. The resource name of this Profile resource. Format: users/{user}/profile Example: users/1234567890/profile or users/me/profile The {user} ID is a system-generated Google Health API user ID, a string of 1-63 characters consisting of lowercase and uppercase letters, numbers, and hyphens. The literal me can also be used to refer to the authenticated user. Value must have pattern ^users/\[^/\]+/profile$.

updateMask - Optional. The list of fields to be updated.

$fields - Selector specifying which fields to include in a partial response.

Completes with a Profile.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<Profile> updateProfile(
  Profile request,
  core.String name, {
  core.String? updateMask,
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'updateMask': ?updateMask == null ? null : [updateMask],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v4/' + core.Uri.encodeFull('$name');

  final response_ = await _requester.request(
    url_,
    'PATCH',
    body: body_,
    queryParams: queryParams_,
  );
  return Profile.fromJson(response_ as core.Map<core.String, core.dynamic>);
}