VolumeQuantity class

Represents the volume quantity.

Constructors

VolumeQuantity({double? milliliters, String? userProvidedUnit})
VolumeQuantity.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
milliliters double?
Value representing the volume in milliliters.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userProvidedUnit String?
Value representing the user provided unit, used only for user-facing input and display purposes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited