userProvidedUnit property

String? userProvidedUnit
getter/setter pair

Value representing the user provided unit, used only for user-facing input and display purposes.

In the API format, all volume quantities are converted to milliliters.

Optional. Possible string values are:

  • "VOLUME_UNIT_UNSPECIFIED" : Unspecified volume unit.
  • "CUP_IMPERIAL" : Cup (imperial)
  • "CUP_US" : Cup (US)
  • "FLUID_OUNCE_IMPERIAL" : Fluid ounce (imperial)
  • "FLUID_OUNCE_US" : Fluid ounce (US)
  • "LITER" : Liter
  • "MILLILITER" : Milliliter
  • "PINT_IMPERIAL" : Pint (imperial)
  • "PINT_US" : Pint (US)

Implementation

core.String? userProvidedUnit;