Component class
Component of a provider device.
Constructors
Properties
-
childComponents
↔ List<
Component> ? -
Child components.
getter/setter pair
-
deviceTypes
↔ List<
String> ? -
List of Device types associated with this component.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
ID of the component from the device provider.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
traitData
↔ List<
TraitData> ? -
List of trait data associated with the component.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited