ComponentTraitUpdates class

Contains the set of updates for a component.

Constructors

ComponentTraitUpdates({String? componentId, List<TraitData>? traitData})
ComponentTraitUpdates.fromJson(Map json_)

Properties

componentId ↔ String?
ID of the component from the device provider.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traitData ↔ List<TraitData>?
The updated trait data for the component.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited