DeviceInfo class

Device information.

Constructors

DeviceInfo({String? hwVersion, String? manufacturer, String? model, String? swVersion})
DeviceInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hwVersion ↔ String?
Device hardware version.
getter/setter pair
manufacturer ↔ String?
Device manufacturer.
getter/setter pair
model ↔ String?
Device model.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swVersion ↔ String?
Device software version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited