DeviceMetadata class

Metadata for traits of a single device.

Constructors

DeviceMetadata({Map<String, String>? traitCommitTimestamps})
DeviceMetadata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traitCommitTimestamps ↔ Map<String, String>?
Map from the Trait ID (e.g., "action.devices.traits.OnOff") to its last Spanner commit timestamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited