DeviceNames class

Identifiers used to describe the device.

Constructors

DeviceNames({List<String>? defaultNames, String? name, List<String>? nicknames})
DeviceNames.fromJson(Map json_)

Properties

defaultNames ↔ List<String>?
List of names provided by the manufacturer rather than the user, such as serial numbers, SKUs, etc.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Primary name of the device, generally provided by the user.
getter/setter pair
nicknames ↔ List<String>?
Additional names provided by the user for the device.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited