EventData class

Contains the details for a single event.

Constructors

EventData({Map<String, Object?>? event, String? eventId, String? eventTime})
EventData.fromJson(Map json_)

Properties

event Map<String, Object?>?
The actual event payload.
getter/setter pair
eventId String?
The unique event ID from the device provider.
getter/setter pair
eventTime String?
The timestamp of the event.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited