HomeTraitUpdates class

Contains the set of updates for a device.

Constructors

HomeTraitUpdates({List<ComponentTraitUpdates>? components, String? deviceId})
HomeTraitUpdates.fromJson(Map json_)

Properties

components ↔ List<ComponentTraitUpdates>?
Trait updates for each component.
getter/setter pair
deviceId ↔ String?
Unique identifier for the device.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited