deviceView property
Specifies the type of device data to be returned in the response.
This allows callers to request traditional Smart Home traits, Unified Device Data Model (UDDM) traits, or both. If unspecified, defaults to SMART_HOME_TRAIT_ONLY.
Optional. Possible string values are:
- "DEVICE_VIEW_UNSPECIFIED" : Default value. Equivalent to SMART_HOME_TRAIT_ONLY.
- "SMART_HOME_TRAIT_ONLY" : Return only standard Smart Home traits in the
devicesmap. - "HOME_TRAIT_ONLY" : Return only Unified Device Data Model (UDDM) traits
in the
home_trait_payloadmap. - "HOME_TRAIT_AND_SMART_HOME_TRAIT" : Return both standard Smart Home traits and UDDM traits.
Implementation
core.String? deviceView;