includeDeviceMetadata property
If true, the response will include device metadata in the device_metadata field.
Optional.
Implementation
core.bool? includeDeviceMetadata;
If true, the response will include device metadata in the device_metadata field.
Optional.
core.bool? includeDeviceMetadata;