QueryResponsePayload class

Payload containing device states information.

Constructors

QueryResponsePayload({Map<String, DeviceMetadata>? deviceMetadata, Map<String, Map<String, Object?>>? devices, Map<String, HomeTraitPayload>? homeTraitPayload})
QueryResponsePayload.fromJson(Map json_)

Properties

deviceMetadata Map<String, DeviceMetadata>?
Map from the Trait ID (e.g., "action.devices.traits.OnOff") to its last Spanner commit timestamp.
getter/setter pair
devices Map<String, Map<String, Object?>>?
States of the devices.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
homeTraitPayload Map<String, HomeTraitPayload>?
Map of device IDs to their Unified Device Data Model (UDDM) trait payloads.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited