commitTime property
Other metadata for the trait.
The time the client update was committed in the server.
Implementation
core.String? commitTime;
Other metadata for the trait.
The time the client update was committed in the server.
core.String? commitTime;