providerVersionTime property

String? providerVersionTime
getter/setter pair

Optional in write requests (e.g. ReportStateAndNotification).

If set, represents the provider version timestamp of the existing trait in the database. The server will perform optimistic locking validation if this field is present and the experiment is enabled. It will not be persisted to the database.

Implementation

core.String? providerVersionTime;