ComputeInstance class

Details about a Compute Engine instance.

Constructors

ComputeInstance({String? instance})
ComputeInstance.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instance ↔ String?
Name of the VM instance, in the format projects/{project}/zones/{zone}/instances/{instance}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited