ComputeInstanceSlurmNodeSet class

When set in a SlurmNodeSet, indicates that the nodeset should be backed by Compute Engine VM instances.

Constructors

ComputeInstanceSlurmNodeSet({BootDisk? bootDisk, Map<String, String>? labels, String? startupScript})
ComputeInstanceSlurmNodeSet.fromJson(Map json_)

Properties

bootDisk ↔ BootDisk?
Boot disk for the compute instance
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels that should be applied to each VM instance in the nodeset.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startupScript ↔ String?
Startup script to be run on each VM instance in the nodeset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited