NetworkReference class

A reference to a VPC network in Google Compute Engine.

Constructors

NetworkReference({String? network, String? subnetwork})
NetworkReference.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
network ↔ String?
Name of the network, in the format projects/{project}/global/networks/{network}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetwork ↔ String?
Name of the particular subnetwork being used by the cluster, in the format projects/{project}/regions/{region}/subnetworks/{subnetwork}.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited