NetworkResourceConfig class

Describes how a network resource should be initialized.

Each network resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.

Properties

existingNetwork ↔ ExistingNetworkConfig?
If set, indicates that an existing network should be imported.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newNetwork ↔ NewNetworkConfig?
If set, indicates that a new network should be created.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited