NewBucketConfig class

When set in a StorageResourceConfig, indicates that a new Google Cloud Storage bucket should be created.

Constructors

NewBucketConfig({GcsAutoclassConfig? autoclass, String? bucket, GcsHierarchicalNamespaceConfig? hierarchicalNamespace, String? storageClass})
NewBucketConfig.fromJson(Map json_)

Properties

autoclass ↔ GcsAutoclassConfig?
If set, indicates that the bucket should use Autoclass.
getter/setter pair
bucket ↔ String?
Name of the Cloud Storage bucket to create.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hierarchicalNamespace ↔ GcsHierarchicalNamespaceConfig?
If set, indicates that the bucket should use hierarchical namespaces.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageClass ↔ String?
If set, uses the provided storage class as the bucket's default storage class.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited