computeId property
The ID of the compute resource on which this nodeset runs.
Must match a key in the cluster's compute_resources.
Required.
Implementation
core.String? computeId;
The ID of the compute resource on which this nodeset runs.
Must match a key in the cluster's compute_resources.
Required.
core.String? computeId;