id property
The ID for the nodeset, which allows it to be referenced by cluster partitions.
The nodeset ID must start with a lowercase letter (a-z), use only
lowercase letters or numbers, and contain up to 15 characters. For
example, specify nodeset001.
Required.
Implementation
core.String? id;