id property
ID of the storage resource to mount, which must match a key in the cluster's storage_resources.
Required.
Implementation
core.String? id;
ID of the storage resource to mount, which must match a key in the cluster's storage_resources.
Required.
core.String? id;