StorageResource class

A resource representing a form of persistent storage that is accessible to compute resources in the cluster.

Properties

bucket ↔ BucketReference?
Reference to a Google Cloud Storage bucket.
getter/setter pair
config ↔ StorageResourceConfig?
Configuration for this storage resource, which describes how it should be created or imported.
getter/setter pair
filestore ↔ FilestoreReference?
Reference to a Filestore instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lustre ↔ LustreReference?
Reference to a Managed Lustre instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited