filestore property
A reference to a Filestore instance.
Populated if and only if the storage resource was configured to use Filestore.
Output only.
Implementation
FilestoreReference? filestore;
A reference to a Filestore instance.
Populated if and only if the storage resource was configured to use Filestore.
Output only.
FilestoreReference? filestore;