lustre property
A reference to a Managed Lustre instance.
Populated if and only if the storage resource was configured to use Managed Lustre.
Output only.
Implementation
LustreReference? lustre;
A reference to a Managed Lustre instance.
Populated if and only if the storage resource was configured to use Managed Lustre.
Output only.
LustreReference? lustre;