StorageResourceConfig class

Describes how a storage resource should be initialized.

Each storage resource can either be imported from an existing Google Cloud resource or initialized when the cluster is created.

Constructors

StorageResourceConfig({ExistingBucketConfig? existingBucket, ExistingFilestoreConfig? existingFilestore, ExistingLustreConfig? existingLustre, NewBucketConfig? newBucket, NewFilestoreConfig? newFilestore, NewLustreConfig? newLustre})
StorageResourceConfig.fromJson(Map json_)

Properties

existingBucket ↔ ExistingBucketConfig?
If set, indicates that an existing Cloud Storage bucket should be imported.
getter/setter pair
existingFilestore ↔ ExistingFilestoreConfig?
If set, indicates that an existing Filestore instance should be imported.
getter/setter pair
existingLustre ↔ ExistingLustreConfig?
If set, indicates that an existing Managed Lustre instance should be imported.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newBucket ↔ NewBucketConfig?
If set, indicates that a new Cloud Storage bucket should be created.
getter/setter pair
newFilestore ↔ NewFilestoreConfig?
If set, indicates that a new Filestore instance should be created.
getter/setter pair
newLustre ↔ NewLustreConfig?
If set, indicates that a new Managed Lustre instance should be created.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited