CreateRoleRequest class

The request to create a new role.

Constructors

CreateRoleRequest({Role? role, String? roleId})
CreateRoleRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
role ↔ Role?
The Role resource to create.
getter/setter pair
roleId ↔ String?
The role ID to use for this role.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited