CreateServiceAccountKeyRequest class

The service account key create request.

Constructors

CreateServiceAccountKeyRequest({String? keyAlgorithm, String? privateKeyType})
CreateServiceAccountKeyRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyAlgorithm ↔ String?
Which type of key and algorithm to use for the key.
getter/setter pair
privateKeyType ↔ String?
The output format of the private key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited