useDefaultSharedCa property

bool? useDefaultSharedCa
getter/setter pair

If set to true, the trust domain will utilize the GCP-provisioned default CA.

A default CA in the same region as the workload will be selected to issue the certificate. Enabling this will clear any existing ca_pools configuration to provision the certificates. NOTE: This field is mutually exclusive with ca_pools. If this flag is enabled, certificates will be automatically provisioned from the default shared CAs. This flag should not be set if you want to use your own CA pools to provision the certificates.

Optional.

Implementation

core.bool? useDefaultSharedCa;