IntermediateCA class

Intermediate CA certificates used for building the trust chain to trust anchor

Constructors

IntermediateCA({String? pemCertificate})
IntermediateCA.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pemCertificate ↔ String?
PEM certificate of the PKI used for validation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited