KeyData class

Represents a public key data along with its format.

Constructors

KeyData({String? format, String? key, String? keySpec, String? notAfterTime, String? notBeforeTime})
KeyData.fromJson(Map json_)

Properties

format ↔ String?
The format of the key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The key data.
getter/setter pair
keySpec ↔ String?
The specifications for the key.
getter/setter pair
notAfterTime ↔ String?
Latest timestamp when this key is valid.
getter/setter pair
notBeforeTime ↔ String?
Earliest timestamp when this key is valid.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited