QueryGrantableRolesRequest class

The grantable role query request.

Constructors

QueryGrantableRolesRequest({String? fullResourceName, int? pageSize, String? pageToken, String? view})
QueryGrantableRolesRequest.fromJson(Map json_)

Properties

fullResourceName ↔ String?
The full resource name to query from the list of grantable roles.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int?
Optional limit on the number of roles to include in the response.
getter/setter pair
pageToken ↔ String?
Optional pagination token returned in an earlier QueryGrantableRolesResponse.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
view ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited