QueryTestablePermissionsRequest class

A request to get permissions which can be tested on a resource.

Constructors

QueryTestablePermissionsRequest({String? fullResourceName, int? pageSize, String? pageToken})
QueryTestablePermissionsRequest.fromJson(Map json_)

Properties

fullResourceName ↔ String?
The full resource name to query from the list of testable permissions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int?
Optional limit on the number of permissions to include in the response.
getter/setter pair
pageToken ↔ String?
Optional pagination token returned in an earlier QueryTestablePermissionsRequest.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited