Role class

A role in the Identity and Access Management API.

Constructors

Role({bool? deleted, String? description, String? etag, List<String>? includedPermissions, String? name, String? stage, String? title})
Role.fromJson(Map json_)

Properties

deleted ↔ bool?
The current deleted state of the role.
getter/setter pair
description ↔ String?
A human-readable description for the role.
getter/setter pair
etag ↔ String?
Used to perform a consistent read-modify-write.
getter/setter pair
etagAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includedPermissions ↔ List<String>?
The names of the permissions this role grants when bound in an IAM policy.
getter/setter pair
name ↔ String?
The name of the role.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stage ↔ String?
The current launch stage of the role.
getter/setter pair
title ↔ String?
A human-readable title for the role.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited