SignBlobRequest class

Migrate to Service Account Credentials API.

The service account sign blob request.

Deprecated.

Constructors

SignBlobRequest({String? bytesToSign})
SignBlobRequest.fromJson(Map json_)

Properties

bytesToSign ↔ String?
Migrate to Service Account Credentials API.
getter/setter pair
bytesToSignAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited