UploadServiceAccountKeyRequest class

The service account key upload request.

Properties

hashCode → int
The hash code for this object.
no setterinherited
publicKeyData ↔ String?
The public key to associate with the service account.
getter/setter pair
publicKeyDataAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited