extraAttributesOauth2Client property

GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client? extraAttributesOauth2Client
getter/setter pair

Defines the configuration for the OAuth 2.0 client that is used to get the additional user attributes in a separate backchannel call to the identity provider.

This should be used when users can't get the required claims in authentication credentials. Currently, the OAuth 2.0 protocol is the only supported authorization method for this backchannel call.

Optional.

Implementation

GoogleIamAdminV1WorkforcePoolProviderExtraAttributesOAuth2Client?
extraAttributesOauth2Client;