WorkforcePoolProviderScimTenant class

Gemini Enterprise only.

Represents a SCIM tenant. Used for provisioning and managing identity data (such as Users and Groups) in cross-domain environments.

Constructors

WorkforcePoolProviderScimTenant({String? baseUri, Map<String, String>? claimMapping, String? description, String? displayName, String? name, String? purgeTime, String? serviceAgent, String? state})
WorkforcePoolProviderScimTenant.fromJson(Map json_)

Properties

baseUri ↔ String?
Gemini Enterprise only.
getter/setter pair
claimMapping ↔ Map<String, String>?
Gemini Enterprise only.
getter/setter pair
description ↔ String?
Gemini Enterprise only.
getter/setter pair
displayName ↔ String?
Gemini Enterprise only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
purgeTime ↔ String?
Gemini Enterprise only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAgent ↔ String?
Service Agent created by SCIM Tenant API.
getter/setter pair
state ↔ String?
Gemini Enterprise only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited