WorkloadIdentityPool class

Represents a collection of workload identities.

You can define IAM policies to grant these identities access to Google Cloud resources.

Constructors

WorkloadIdentityPool({String? description, bool? disabled, String? displayName, String? expireTime, InlineCertificateIssuanceConfig? inlineCertificateIssuanceConfig, InlineTrustConfig? inlineTrustConfig, String? mode, String? name, String? state})
WorkloadIdentityPool.fromJson(Map json_)

Properties

description ↔ String?
A description of the pool.
getter/setter pair
disabled ↔ bool?
Whether the pool is disabled.
getter/setter pair
displayName ↔ String?
A display name for the pool.
getter/setter pair
expireTime ↔ String?
Time after which the workload identity pool will be permanently purged and cannot be recovered.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inlineCertificateIssuanceConfig ↔ InlineCertificateIssuanceConfig?
Defines the Certificate Authority (CA) pool resources and configurations required for issuance and rotation of mTLS workload certificates.
getter/setter pair
inlineTrustConfig ↔ InlineTrustConfig?
Represents config to add additional trusted trust domains.
getter/setter pair
mode ↔ String?
The mode the pool is operating in.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited