mode property

String? mode
getter/setter pair

The mode the pool is operating in.

Immutable. Possible string values are:

  • "MODE_UNSPECIFIED" : State unspecified. New pools should not use this mode. Pools with an unspecified mode will operate as if they are in federation-only mode.
  • "FEDERATION_ONLY" : Federation-only mode. FEDERATION_ONLY mode pools can only be used for federating external workload identities into Google Cloud. Unless otherwise noted, no structure or format constraints are applied to workload identities in a FEDERATION_ONLY mode pool, and you cannot create any resources within the pool besides providers.
  • "TRUST_DOMAIN" : Trust-domain mode. TRUST_DOMAIN mode pools can be used to assign identities to Google Cloud workloads. Identities within a TRUST_DOMAIN mode pool share the same root of trust. WorkloadIdentityPoolProviders cannot be created within trust-domain pools.
  • "SYSTEM_TRUST_DOMAIN" : SYSTEM_TRUST_DOMAIN mode pools are managed by Google Cloud services. Neither WorkloadIdentityPoolNamespaces nor WorkloadIdentityPoolProviders can be created within SYSTEM_TRUST_DOMAIN mode pools. All identities within a SYSTEM_TRUST_DOMAIN mode pool are in one of the following formats: * spiffe:///ns//sa/ * spiffe:///resources//

Implementation

core.String? mode;