WorkloadIdentityPoolManagedIdentity class

Represents a managed identity for a workload identity pool namespace.

Constructors

WorkloadIdentityPoolManagedIdentity({String? description, bool? disabled, String? expireTime, String? name, String? state})
WorkloadIdentityPoolManagedIdentity.fromJson(Map json_)

Properties

description ↔ String?
A description of the managed identity.
getter/setter pair
disabled ↔ bool?
Whether the managed identity is disabled.
getter/setter pair
expireTime ↔ String?
Time after which the managed identity will be permanently purged and cannot be recovered.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the managed identity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited