WorkloadIdentityPoolProviderKey class

Represents a public key configuration for your workload identity pool provider.

The key can be configured in your identity provider to encrypt the SAML assertions. Google holds the corresponding private key which it uses to decrypt encrypted tokens.

Constructors

WorkloadIdentityPoolProviderKey({String? expireTime, KeyData? keyData, String? name, String? state, String? use})
WorkloadIdentityPoolProviderKey.fromJson(Map json_)

Properties

expireTime ↔ String?
Time after which the key will be permanently purged and cannot be recovered.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyData ↔ KeyData?
Public half of the asymmetric key.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the key.
getter/setter pair
use ↔ String?
The purpose of the key.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited