GenerateAccessTokenRequest class

Constructors

GenerateAccessTokenRequest({List<String>? delegates, String? lifetime, List<String>? scope})
GenerateAccessTokenRequest.fromJson(Map json_)

Properties

delegates ↔ List<String>?
The sequence of service accounts in a delegation chain.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lifetime ↔ String?
The desired lifetime duration of the access token in seconds.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ List<String>?
Code to identify the scopes to be included in the OAuth 2.0 access token.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited