GenerateIdTokenRequest class

Constructors

GenerateIdTokenRequest({String? audience, List<String>? delegates, bool? includeEmail, bool? organizationNumberIncluded})
GenerateIdTokenRequest.fromJson(Map json_)

Properties

audience ↔ String?
The audience for the token, such as the API or account that this token grants access to.
getter/setter pair
delegates ↔ List<String>?
The sequence of service accounts in a delegation chain.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeEmail ↔ bool?
Include the service account email in the token.
getter/setter pair
organizationNumberIncluded ↔ bool?
Include the organization number of the service account in the token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited