SignJwtResponse class

Constructors

SignJwtResponse({String? keyId, String? signedJwt})
SignJwtResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyId ↔ String?
The ID of the key used to sign the JWT.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signedJwt ↔ String?
The signed JWT.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited