ApplicationSettings class

Wrapper over application specific settings for IAP.

Constructors

ApplicationSettings({AccessDeniedPageSettings? accessDeniedPageSettings, AttributePropagationSettings? attributePropagationSettings, String? cookieDomain, CsmSettings? csmSettings})
ApplicationSettings.fromJson(Map json_)

Properties

accessDeniedPageSettings ↔ AccessDeniedPageSettings?
Customization for Access Denied page.
getter/setter pair
attributePropagationSettings ↔ AttributePropagationSettings?
Settings to configure attribute propagation.
getter/setter pair
cookieDomain ↔ String?
The Domain value to set for cookies generated by IAP.
getter/setter pair
csmSettings ↔ CsmSettings?
Settings to configure IAP's behavior for a service mesh.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited