IdentityAwareProxyClient class

Contains the data that describes an Identity Aware Proxy owned client.

Constructors

IdentityAwareProxyClient({String? displayName, String? name, String? secret})
IdentityAwareProxyClient.fromJson(Map json_)

Properties

displayName ↔ String?
Human-friendly name given to the OAuth client.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Unique identifier of the OAuth client.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret ↔ String?
Client secret of the OAuth client.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited