NextStateOfTags class

Used for calculating the next state of tags on the resource being passed for the CheckCustomConstraints RPC call.

The detail evaluation of each field is described in go/op-create-update-time-tags and go/tags-in-orgpolicy-requests.

Constructors

NextStateOfTags({TagsFullState? tagsFullState, TagsFullStateForChildResource? tagsFullStateForChildResource, TagsPartialState? tagsPartialState})
NextStateOfTags.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagsFullState ↔ TagsFullState?
getter/setter pair
tagsFullStateForChildResource ↔ TagsFullStateForChildResource?
getter/setter pair
tagsPartialState ↔ TagsPartialState?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited