OAuthSettings class

Configuration for OAuth login&consent flow behavior as well as for OAuth Credentials.

Constructors

OAuthSettings({String? clientId, String? clientSecret, String? clientSecretSha256, String? loginHint, List<String>? programmaticClients})
OAuthSettings.fromJson(Map json_)

Properties

clientId String?
OAuth 2.0 client ID used in the OAuth flow.
getter/setter pair
clientSecret String?
Input only.
getter/setter pair
clientSecretSha256 String?
OAuth secret SHA256 paired with client ID.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loginHint String?
Domain hint to send as hd=? parameter in OAuth request flow.
getter/setter pair
programmaticClients List<String>?
List of client ids allowed to use IAP programmatically.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited