WorkforceIdentitySettings class

WorkforceIdentitySettings allows customers to configure workforce pools and OAuth 2.0 settings to gate their applications using a third-party IdP with access control.

Constructors

WorkforceIdentitySettings({OAuth2? oauth2, List<String>? workforcePools})
WorkforceIdentitySettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
oauth2 ↔ OAuth2?
OAuth 2.0 settings for IAP to perform OIDC flow with workforce identity federation services.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workforcePools ↔ List<String>?
The workforce pool resources.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited