GoogleCloudIdentitytoolkitV1SendVerificationCodeRequest class

Request message for SendVerificationCode.

'captcha_response' is required when reCAPTCHA enterprise is enabled, or otherwise at least one of (ios_receipt and ios_secret), recaptcha_token, or play_integrity_token must be specified to verify the verification code is being sent on behalf of a real app and not an emulator.

Constructors

GoogleCloudIdentitytoolkitV1SendVerificationCodeRequest({GoogleCloudIdentitytoolkitV1AutoRetrievalInfo? autoRetrievalInfo, String? captchaResponse, String? clientType, String? iosReceipt, String? iosSecret, String? phoneNumber, String? playIntegrityToken, String? recaptchaToken, String? recaptchaVersion, String? safetyNetToken, String? tenantId})
GoogleCloudIdentitytoolkitV1SendVerificationCodeRequest.fromJson(Map json_)

Properties

autoRetrievalInfo ↔ GoogleCloudIdentitytoolkitV1AutoRetrievalInfo?
Android only.
getter/setter pair
captchaResponse ↔ String?
The reCAPTCHA Enterprise token provided by the reCAPTCHA client-side integration.
getter/setter pair
clientType ↔ String?
The client type, web, android or ios.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iosReceipt ↔ String?
Receipt of successful iOS app token validation.
getter/setter pair
iosSecret ↔ String?
Secret delivered to iOS app as a push notification.
getter/setter pair
phoneNumber ↔ String?
The phone number to send the verification code to in E.164 format.
getter/setter pair
playIntegrityToken ↔ String?
Android only.
getter/setter pair
recaptchaToken ↔ String?
Recaptcha token for app verification.
getter/setter pair
recaptchaVersion ↔ String?
The reCAPTCHA version of the reCAPTCHA token in the captcha_response.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safetyNetToken ↔ String?
Android only.
getter/setter pair
tenantId ↔ String?
Tenant ID of the Identity Platform tenant the user is signing in to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited