GoogleCloudIdentitytoolkitV1SignInWithCustomTokenRequest class

Request message for SignInWithCustomToken.

Constructors

GoogleCloudIdentitytoolkitV1SignInWithCustomTokenRequest({String? delegatedProjectNumber, String? instanceId, bool? returnSecureToken, String? tenantId, String? token})
GoogleCloudIdentitytoolkitV1SignInWithCustomTokenRequest.fromJson(Map json_)

Properties

delegatedProjectNumber ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceId ↔ String?
getter/setter pair
returnSecureToken ↔ bool?
Should always be true.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenantId ↔ String?
The ID of the Identity Platform tenant the user is signing in to.
getter/setter pair
token ↔ String?
The custom Auth token asserted by the developer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited