GoogleCloudIdentitytoolkitV1SignInWithPasswordRequest class

Request message for SignInWithPassword.

Constructors

GoogleCloudIdentitytoolkitV1SignInWithPasswordRequest({String? captchaChallenge, String? captchaResponse, String? clientType, String? delegatedProjectNumber, String? email, String? idToken, String? instanceId, String? password, String? pendingIdToken, String? recaptchaVersion, bool? returnSecureToken, String? tenantId})
GoogleCloudIdentitytoolkitV1SignInWithPasswordRequest.fromJson(Map json_)

Properties

captchaChallenge ↔ String?
getter/setter pair
captchaResponse ↔ String?
The reCAPTCHA token provided by the reCAPTCHA client-side integration.
getter/setter pair
clientType ↔ String?
The client type, web, android or ios.
getter/setter pair
delegatedProjectNumber ↔ String?
getter/setter pair
email ↔ String?
The email the user is signing in with.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idToken ↔ String?
getter/setter pair
instanceId ↔ String?
getter/setter pair
password ↔ String?
The password the user provides to sign in to the account.
getter/setter pair
pendingIdToken ↔ String?
getter/setter pair
recaptchaVersion ↔ String?
The reCAPTCHA version of the reCAPTCHA token in the captcha_response. Possible string values are:
getter/setter pair
returnSecureToken ↔ bool?
Should always be true.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenantId ↔ String?
The ID of the Identity Platform tenant the user is signing in to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited