GoogleCloudIdentitytoolkitAdminV2RecaptchaKey class

The reCAPTCHA key config.

reCAPTCHA Enterprise offers different keys for different client platforms.

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The reCAPTCHA Enterprise key resource name, e.g. "projects/{project}/keys/{key}"
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The client's platform type. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited