ProjectsResource class

Constructors

ProjectsResource(ApiRequester client)

Properties

defaultSupportedIdpConfigs → ProjectsDefaultSupportedIdpConfigsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
identityPlatform → ProjectsIdentityPlatformResource
no setter
inboundSamlConfigs → ProjectsInboundSamlConfigsResource
no setter
oauthIdpConfigs → ProjectsOauthIdpConfigsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenants → ProjectsTenantsResource
no setter

Methods

getConfig(String name, {String? $fields}) → Future<GoogleCloudIdentitytoolkitAdminV2Config>
Retrieve an Identity Toolkit project configuration.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateConfig(GoogleCloudIdentitytoolkitAdminV2Config request, String name, {String? updateMask, String? $fields}) → Future<GoogleCloudIdentitytoolkitAdminV2Config>
Update an Identity Toolkit project configuration.

Operators

operator ==(Object other) → bool
The equality operator.
inherited