EmailLinkSigninResponse class

Response of email signIn.

Constructors

EmailLinkSigninResponse({String? email, String? expiresIn, String? idToken, bool? isNewUser, String? kind, String? localId, String? refreshToken})
EmailLinkSigninResponse.fromJson(Map json_)

Properties

email ↔ String?
The user's email.
getter/setter pair
expiresIn ↔ String?
Expiration time of STS id token in seconds.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idToken ↔ String?
The STS id token to login the newly signed in user.
getter/setter pair
isNewUser ↔ bool?
Whether the user is new.
getter/setter pair
kind ↔ String?
The fixed string "identitytoolkit#EmailLinkSigninResponse".
getter/setter pair
localId ↔ String?
The RP local ID of the user.
getter/setter pair
refreshToken ↔ String?
The refresh token for the signed in user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited