EmailTemplate class

Template for an email template.

Constructors

EmailTemplate({String? body, String? format, String? from, String? fromDisplayName, String? replyTo, String? subject})
EmailTemplate.fromJson(Map json_)

Properties

body ↔ String?
Email body.
getter/setter pair
format ↔ String?
Email body format.
getter/setter pair
from ↔ String?
From address of the email.
getter/setter pair
fromDisplayName ↔ String?
From display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
replyTo ↔ String?
Reply-to address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String?
Subject of the email.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited