GetOobConfirmationCodeResponse class

Response of getting a code for user confirmation (reset password, change email etc.).

Properties

email ↔ String?
The email address that the email is sent to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The fixed string "identitytoolkit#GetOobConfirmationCodeResponse".
getter/setter pair
oobCode ↔ String?
The code to be send to the user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited