GetRecaptchaParamResponse class

Response of getting recaptcha param.

Constructors

GetRecaptchaParamResponse({String? kind, String? recaptchaSiteKey, String? recaptchaStoken})
GetRecaptchaParamResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The fixed string "identitytoolkit#GetRecaptchaParamResponse".
getter/setter pair
recaptchaSiteKey ↔ String?
Site key registered at recaptcha.
getter/setter pair
recaptchaStoken ↔ String?
The stoken field for the recaptcha widget, used to request captcha challenge.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited