IdentitytoolkitRelyingpartyEmailLinkSigninRequest class

Request to sign in with email.

Properties

email ↔ String?
The email address of the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idToken ↔ String?
Token for linking flow.
getter/setter pair
oobCode ↔ String?
The confirmation code.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited