IdentitytoolkitRelyingpartyGetProjectConfigResponse class

Response of getting the project configuration.

Constructors

IdentitytoolkitRelyingpartyGetProjectConfigResponse({bool? allowPasswordUser, String? apiKey, List<String>? authorizedDomains, EmailTemplate? changeEmailTemplate, String? dynamicLinksDomain, bool? enableAnonymousUser, List<IdpConfig>? idpConfig, EmailTemplate? legacyResetPasswordTemplate, String? projectId, EmailTemplate? resetPasswordTemplate, bool? useEmailSending, EmailTemplate? verifyEmailTemplate})
IdentitytoolkitRelyingpartyGetProjectConfigResponse.fromJson(Map json_)

Properties

allowPasswordUser ↔ bool?
Whether to allow password user sign in or sign up.
getter/setter pair
apiKey ↔ String?
Browser API key, needed when making http request to Apiary.
getter/setter pair
authorizedDomains ↔ List<String>?
Authorized domains.
getter/setter pair
changeEmailTemplate ↔ EmailTemplate?
Change email template.
getter/setter pair
dynamicLinksDomain ↔ String?
getter/setter pair
enableAnonymousUser ↔ bool?
Whether anonymous user is enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idpConfig ↔ List<IdpConfig>?
OAuth2 provider configuration.
getter/setter pair
legacyResetPasswordTemplate ↔ EmailTemplate?
Legacy reset password email template.
getter/setter pair
projectId ↔ String?
Project ID of the relying party.
getter/setter pair
resetPasswordTemplate ↔ EmailTemplate?
Reset password email template.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useEmailSending ↔ bool?
Whether to use email sending provided by Firebear.
getter/setter pair
verifyEmailTemplate ↔ EmailTemplate?
Verify email template.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited