IdentitytoolkitRelyingpartySendVerificationCodeRequest class

Request for Identitytoolkit-SendVerificationCode

Properties

hashCode → int
The hash code for this object.
no setterinherited
iosReceipt ↔ String?
Receipt of successful app token validation with APNS.
getter/setter pair
iosSecret ↔ String?
Secret delivered to iOS app via APNS.
getter/setter pair
phoneNumber ↔ String?
The phone number to send the verification code to in E.164 format.
getter/setter pair
recaptchaToken ↔ String?
Recaptcha solution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited