SetAccountInfoResponse class

Respone of setting the account information.

Constructors

SetAccountInfoResponse({String? displayName, String? email, bool? emailVerified, String? expiresIn, String? idToken, String? kind, String? localId, String? newEmail, String? passwordHash, String? photoUrl, List<SetAccountInfoResponseProviderUserInfo>? providerUserInfo, String? refreshToken})
SetAccountInfoResponse.fromJson(Map json_)

Properties

displayName ↔ String?
The name of the user.
getter/setter pair
email ↔ String?
The email of the user.
getter/setter pair
emailVerified ↔ bool?
If email has been verified.
getter/setter pair
expiresIn ↔ String?
If idToken is STS id token, then this field will be expiration time of STS id token in seconds.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idToken ↔ String?
The Gitkit id token to login the newly sign up user.
getter/setter pair
kind ↔ String?
The fixed string "identitytoolkit#SetAccountInfoResponse".
getter/setter pair
localId ↔ String?
The local ID of the user.
getter/setter pair
newEmail ↔ String?
The new email the user attempts to change to.
getter/setter pair
passwordHash ↔ String?
The user's hashed password.
getter/setter pair
passwordHashAsBytes ↔ List<int>
getter/setter pair
photoUrl ↔ String?
The photo url of the user.
getter/setter pair
providerUserInfo ↔ List<SetAccountInfoResponseProviderUserInfo>?
The user's profiles at the associated IdPs.
getter/setter pair
refreshToken ↔ String?
If idToken is STS id token, then this field will be refresh token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited