UserInfo class

Template for an individual account info.

Constructors

UserInfo({String? createdAt, String? customAttributes, bool? customAuth, bool? disabled, String? displayName, String? email, bool? emailVerified, String? lastLoginAt, String? localId, String? passwordHash, double? passwordUpdatedAt, String? phoneNumber, String? photoUrl, List<UserInfoProviderUserInfo>? providerUserInfo, String? rawPassword, String? salt, String? screenName, String? validSince, int? version})
UserInfo.fromJson(Map json_)

Properties

createdAt ↔ String?
User creation timestamp.
getter/setter pair
customAttributes ↔ String?
The custom attributes to be set in the user's id token.
getter/setter pair
customAuth ↔ bool?
Whether the user is authenticated by the developer.
getter/setter pair
disabled ↔ bool?
Whether the user is disabled.
getter/setter pair
displayName ↔ String?
The name of the user.
getter/setter pair
email ↔ String?
The email of the user.
getter/setter pair
emailVerified ↔ bool?
Whether the email has been verified.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastLoginAt ↔ String?
last login timestamp.
getter/setter pair
localId ↔ String?
The local ID of the user.
getter/setter pair
passwordHash ↔ String?
The user's hashed password.
getter/setter pair
passwordHashAsBytes ↔ List<int>
getter/setter pair
passwordUpdatedAt ↔ double?
The timestamp when the password was last updated.
getter/setter pair
phoneNumber ↔ String?
User's phone number.
getter/setter pair
photoUrl ↔ String?
The URL of the user profile photo.
getter/setter pair
providerUserInfo ↔ List<UserInfoProviderUserInfo>?
The IDP of the user.
getter/setter pair
rawPassword ↔ String?
The user's plain text password.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
salt ↔ String?
The user's password salt.
getter/setter pair
saltAsBytes ↔ List<int>
getter/setter pair
screenName ↔ String?
User's screen name at Twitter or login name at Github.
getter/setter pair
validSince ↔ String?
Timestamp in seconds for valid login token.
getter/setter pair
version ↔ int?
Version of the user's password.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited