UserInfoProviderUserInfo class

Constructors

UserInfoProviderUserInfo({String? displayName, String? email, String? federatedId, String? phoneNumber, String? photoUrl, String? providerId, String? rawId, String? screenName})
UserInfoProviderUserInfo.fromJson(Map json_)

Properties

displayName ↔ String?
The user's display name at the IDP.
getter/setter pair
email ↔ String?
User's email at IDP.
getter/setter pair
federatedId ↔ String?
User's identifier at IDP.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
phoneNumber ↔ String?
User's phone number.
getter/setter pair
photoUrl ↔ String?
The user's photo url at the IDP.
getter/setter pair
providerId ↔ String?
The IdP ID.
getter/setter pair
rawId ↔ String?
User's raw identifier directly returned from IDP.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenName ↔ String?
User's screen name at Twitter or login name at Github.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited