VerifyCustomTokenResponse class

Response from verifying a custom token

Constructors

VerifyCustomTokenResponse({String? expiresIn, String? idToken, bool? isNewUser, String? kind, String? refreshToken})
VerifyCustomTokenResponse.fromJson(Map json_)

Properties

expiresIn ↔ String?
If idToken is STS id token, then this field will be expiration time of STS id token in seconds.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idToken ↔ String?
The GITKit token for authenticated user.
getter/setter pair
isNewUser ↔ bool?
True if it's a new user sign-in, false if it's a returning user.
getter/setter pair
kind ↔ String?
The fixed string "identitytoolkit#VerifyCustomTokenResponse".
getter/setter pair
refreshToken ↔ String?
If idToken is STS id token, then this field will be refresh token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited