VerifyPasswordResponse class

Request of verifying the password.

Constructors

VerifyPasswordResponse({String? displayName, String? email, String? expiresIn, String? idToken, String? kind, String? localId, String? oauthAccessToken, String? oauthAuthorizationCode, int? oauthExpireIn, String? photoUrl, String? refreshToken, bool? registered})
VerifyPasswordResponse.fromJson(Map json_)

Properties

displayName ↔ String?
The name of the user.
getter/setter pair
email ↔ String?
The email returned by the IdP.
getter/setter pair
expiresIn ↔ String?
If idToken is STS id token, then this field will be expiration time of STS id token in seconds.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idToken ↔ String?
The GITKit token for authenticated user.
getter/setter pair
kind ↔ String?
The fixed string "identitytoolkit#VerifyPasswordResponse".
getter/setter pair
localId ↔ String?
The RP local ID if it's already been mapped to the IdP account identified by the federated ID.
getter/setter pair
oauthAccessToken ↔ String?
The OAuth2 access token.
getter/setter pair
oauthAuthorizationCode ↔ String?
The OAuth2 authorization code.
getter/setter pair
oauthExpireIn ↔ int?
The lifetime in seconds of the OAuth2 access token.
getter/setter pair
photoUrl ↔ String?
The URI of the user's photo at IdP
getter/setter pair
refreshToken ↔ String?
If idToken is STS id token, then this field will be refresh token.
getter/setter pair
registered ↔ bool?
Whether the email is registered.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited