UrlNotificationsResource class

Constructors

UrlNotificationsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMetadata({String? url, String? $fields}) → Future<UrlNotificationMetadata>
Gets metadata about a Web Document.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
publish(UrlNotification request, {String? $fields}) → Future<PublishUrlNotificationResponse>
Notifies that a URL has been updated or deleted.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited