GoogleCloudIntegrationsV1alphaAuthConfig class

The AuthConfig resource use to hold channels and connection config data.

Constructors

GoogleCloudIntegrationsV1alphaAuthConfig({String? certificateId, String? createTime, String? creatorEmail, String? credentialType, GoogleCloudIntegrationsV1alphaCredential? decryptedCredential, String? description, String? displayName, String? encryptedCredential, List<String>? expiryNotificationDuration, String? lastModifierEmail, String? name, String? overrideValidTime, String? reason, String? state, String? updateTime, String? validTime, String? visibility})
GoogleCloudIntegrationsV1alphaAuthConfig.fromJson(Map json_)

Properties

certificateId ↔ String?
Certificate id for client certificate
getter/setter pair
createTime ↔ String?
The timestamp when the auth config is created.
getter/setter pair
creatorEmail ↔ String?
The creator's email address.
getter/setter pair
credentialType ↔ String?
Credential type of the encrypted credential.
getter/setter pair
decryptedCredential ↔ GoogleCloudIntegrationsV1alphaCredential?
Raw auth credentials.
getter/setter pair
description ↔ String?
A description of the auth config.
getter/setter pair
displayName ↔ String?
The name of the auth config.
getter/setter pair
encryptedCredential ↔ String?
Auth credential encrypted by Cloud KMS.
getter/setter pair
encryptedCredentialAsBytes ↔ List<int>
getter/setter pair
expiryNotificationDuration ↔ List<String>?
User can define the time to receive notification after which the auth config becomes invalid.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastModifierEmail ↔ String?
The last modifier's email address.
getter/setter pair
name ↔ String?
Resource name of the auth config.
getter/setter pair
overrideValidTime ↔ String?
User provided expiry time to override.
getter/setter pair
reason ↔ String?
The reason / details of the current status.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The status of the auth config.
getter/setter pair
updateTime ↔ String?
The timestamp when the auth config is modified.
getter/setter pair
validTime ↔ String?
The time until the auth config is valid.
getter/setter pair
visibility ↔ String?
The visibility of the auth config.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited