GoogleCloudIntegrationsV1alphaClientConfig class

The configuration information for the Client

Constructors

GoogleCloudIntegrationsV1alphaClientConfig({String? billingType, String? clientState, GoogleCloudIntegrationsV1alphaCloudKmsConfig? cloudKmsConfig, String? createTime, GoogleCloudIntegrationsV1alphaCustomerConfig? customerConfig, String? description, bool? enableHttpCall, bool? enableInternalIp, bool? enableManagedAiFeatures, bool? enableVariableMasking, String? id, bool? isGmek, String? p4ServiceAccount, String? projectId, String? region, String? runAsServiceAccount})
GoogleCloudIntegrationsV1alphaClientConfig.fromJson(Map json_)

Properties

billingType ↔ String?
Indicates the billing type of the client Possible string values are:
getter/setter pair
clientState ↔ String?
Indicates the activity state the client Possible string values are:
getter/setter pair
cloudKmsConfig ↔ GoogleCloudIntegrationsV1alphaCloudKmsConfig?
getter/setter pair
createTime ↔ String?
The timestamp when the client was first created.
getter/setter pair
customerConfig ↔ GoogleCloudIntegrationsV1alphaCustomerConfig?
Customer configuration information for the given client.
getter/setter pair
description ↔ String?
Description of what the client is used for
getter/setter pair
enableHttpCall ↔ bool?
Optional.
getter/setter pair
enableInternalIp ↔ bool?
Indicates the client enables internal IP feature, this is applicable for internal clients only.
getter/setter pair
enableManagedAiFeatures ↔ bool?
Optional.
getter/setter pair
enableVariableMasking ↔ bool?
Optional.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Globally unique ID (project_id + region)
getter/setter pair
isGmek ↔ bool?
Indicates the client is provisioned with CMEK or GMEK.
getter/setter pair
p4ServiceAccount ↔ String?
The service agent associated with this client
getter/setter pair
projectId ↔ String?
The GCP project id of the client associated with
getter/setter pair
region ↔ String?
The region the client is linked to.
getter/setter pair
runAsServiceAccount ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited