GoogleCloudIntegrationsV1alphaCreateCloudFunctionRequest class

Request for Creating Cloud Function rpc call.

Properties

functionName ↔ String?
The function name of CF to be created
getter/setter pair
functionRegion ↔ String?
The function region of CF to be created
getter/setter pair
gcfApiVersion ↔ String?
The api version of CF to be created
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
projectId ↔ String?
Indicates the id of the GCP project that the function will be created in.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited