GoogleCloudIntegrationsV1alphaExecuteIntegrationsRequest class

The request for executing an integration.

Properties

doNotPropagateError ↔ bool?
Flag to determine how to should propagate errors.
getter/setter pair
executionId ↔ String?
The id of the ON_HOLD execution to be resumed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputParameters ↔ Map<String, GoogleCloudIntegrationsV1alphaValueType>?
Input parameters used by integration execution.
getter/setter pair
parameterEntries ↔ List<EnterpriseCrmFrontendsEventbusProtoParameterEntry>?
Parameters are a part of Event and can be used to communicate between different tasks that are part of the same integration execution.
getter/setter pair
parameters ↔ EnterpriseCrmFrontendsEventbusProtoEventParameters?
Passed in as parameters to each integration execution.
getter/setter pair
requestId ↔ String?
This is used to de-dup incoming request: if the duplicate request was detected, the response from the previous execution is returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
triggerId ↔ String?
Matched against all {@link TriggerConfig}s across all integrations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited