GoogleCloudIntegrationsV1alphaIntegrationVersion class

The integration version definition.

Constructors

GoogleCloudIntegrationsV1alphaIntegrationVersion({String? cloudKmsKey, GoogleCloudIntegrationsV1alphaCloudLoggingDetails? cloudLoggingDetails, String? createTime, String? createdFromTemplate, String? databasePersistencePolicy, String? description, bool? enableVariableMasking, List<GoogleCloudIntegrationsV1alphaErrorCatcherConfig>? errorCatcherConfigs, List<GoogleCloudIntegrationsV1alphaIntegrationConfigParameter>? integrationConfigParameters, List<GoogleCloudIntegrationsV1alphaIntegrationParameter>? integrationParameters, EnterpriseCrmFrontendsEventbusProtoWorkflowParameters? integrationParametersInternal, String? lastModifierEmail, String? lockHolder, String? name, String? origin, String? parentTemplateId, String? runAsServiceAccount, String? snapshotNumber, String? state, String? status, List<GoogleCloudIntegrationsV1alphaTaskConfig>? taskConfigs, List<EnterpriseCrmFrontendsEventbusProtoTaskConfig>? taskConfigsInternal, EnterpriseCrmEventbusProtoTeardown? teardown, List<GoogleCloudIntegrationsV1alphaTriggerConfig>? triggerConfigs, List<EnterpriseCrmFrontendsEventbusProtoTriggerConfig>? triggerConfigsInternal, String? updateTime, String? userLabel})
GoogleCloudIntegrationsV1alphaIntegrationVersion.fromJson(Map json_)

Properties

cloudKmsKey ↔ String?
Cloud KMS resource name for the CMEK encryption key.
getter/setter pair
cloudLoggingDetails ↔ GoogleCloudIntegrationsV1alphaCloudLoggingDetails?
Cloud Logging details for the integration version
getter/setter pair
createdFromTemplate ↔ String?
The resource name of the template from which the integration is created.
getter/setter pair
createTime ↔ String?
Auto-generated.
getter/setter pair
databasePersistencePolicy ↔ String?
Flag to disable database persistence for execution data, including event execution info, execution export info, execution metadata index and execution param index.
getter/setter pair
description ↔ String?
The integration description.
getter/setter pair
enableVariableMasking ↔ bool?
True if variable masking feature should be turned on for this version
getter/setter pair
errorCatcherConfigs ↔ List<GoogleCloudIntegrationsV1alphaErrorCatcherConfig>?
Error Catch Task configuration for the integration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
integrationConfigParameters ↔ List<GoogleCloudIntegrationsV1alphaIntegrationConfigParameter>?
Config Parameters that are expected to be passed to the integration when an integration is published.
getter/setter pair
integrationParameters ↔ List<GoogleCloudIntegrationsV1alphaIntegrationParameter>?
Parameters that are expected to be passed to the integration when an event is triggered.
getter/setter pair
integrationParametersInternal ↔ EnterpriseCrmFrontendsEventbusProtoWorkflowParameters?
Parameters that are expected to be passed to the integration when an event is triggered.
getter/setter pair
lastModifierEmail ↔ String?
The last modifier's email address.
getter/setter pair
lockHolder ↔ String?
The edit lock holder's email address.
getter/setter pair
name ↔ String?
Auto-generated primary key.
getter/setter pair
origin ↔ String?
The origin that indicates where this integration is coming from.
getter/setter pair
parentTemplateId ↔ String?
The id of the template which was used to create this integration_version.
getter/setter pair
runAsServiceAccount ↔ String?
The run-as service account email, if set and auth config is not configured, that will be used to generate auth token to be used in Connector task, Rest caller task and Cloud function task.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotNumber ↔ String?
An increasing sequence that is set when a new snapshot is created.
getter/setter pair
state ↔ String?
User should not set it as an input.
getter/setter pair
status ↔ String?
Generated by eventbus.
getter/setter pair
taskConfigs ↔ List<GoogleCloudIntegrationsV1alphaTaskConfig>?
Task configuration for the integration.
getter/setter pair
taskConfigsInternal ↔ List<EnterpriseCrmFrontendsEventbusProtoTaskConfig>?
Task configuration for the integration.
getter/setter pair
teardown ↔ EnterpriseCrmEventbusProtoTeardown?
Contains a graph of tasks that will be executed before putting the event in a terminal state (SUCCEEDED/FAILED/FATAL), regardless of success or failure, similar to "finally" in code.
getter/setter pair
triggerConfigs ↔ List<GoogleCloudIntegrationsV1alphaTriggerConfig>?
Trigger configurations.
getter/setter pair
triggerConfigsInternal ↔ List<EnterpriseCrmFrontendsEventbusProtoTriggerConfig>?
Trigger configurations.
getter/setter pair
updateTime ↔ String?
Auto-generated.
getter/setter pair
userLabel ↔ String?
A user-defined label that annotates an integration version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited