GoogleCloudIntegrationsV1alphaProjectProperties class

Metadata information for the given project

Constructors

GoogleCloudIntegrationsV1alphaProjectProperties({String? billingType, String? ipEnablementState, List<String>? provisionedRegions})
GoogleCloudIntegrationsV1alphaProjectProperties.fromJson(Map json_)

Properties

billingType ↔ String?
Required: The client billing type that was requested
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipEnablementState ↔ String?
An enum value of what the enablement state is for the given project Possible string values are:
getter/setter pair
provisionedRegions ↔ List<String>?
A list of provisioned regions on the current project
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited