GoogleCloudIntegrationsV1alphaSerializedFile class

To store string representation of Integration file.

Properties

content ↔ String?
String representation of the file content.
getter/setter pair
file ↔ String?
File information like Integration version, Integration Config variables etc. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited