GoogleCloudIntegrationsV1alphaTestIntegrationsRequest class

The request for testing an integration.

Properties

clientId ↔ String?
This is used to identify the client on whose behalf the event will be executed.
getter/setter pair
configParameters ↔ Map<String, Object?>?
Config parameters used during integration execution.
getter/setter pair
deadlineSecondsTime ↔ String?
custom deadline of the rpc
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputParameters ↔ Map<String, GoogleCloudIntegrationsV1alphaValueType>?
Input parameters used during integration execution.
getter/setter pair
integrationVersion ↔ GoogleCloudIntegrationsV1alphaIntegrationVersion?
integration config to execute the workflow
getter/setter pair
parameters ↔ EnterpriseCrmFrontendsEventbusProtoEventParameters?
Passed in as parameters to each integration execution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testMode ↔ bool?
Can be specified in the event request, otherwise false (default).
getter/setter pair
triggerId ↔ String?
The trigger id of the integration trigger config.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited