GoogleCloudIntegrationsV1alphaTestIntegrationsResponse class

The response for testing an integration.

Properties

eventParameters ↔ EnterpriseCrmFrontendsEventbusProtoEventParameters?
Details for the integration that were executed.
getter/setter pair
executionFailed ↔ bool?
Is true if any execution in the integration failed.
getter/setter pair
executionId ↔ String?
The id of the execution corresponding to this run of integration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parameterEntries ↔ List<EnterpriseCrmFrontendsEventbusProtoParameterEntry>?
Parameters are a part of Event and can be used to communicate between different tasks that are part of the same integration execution.
getter/setter pair
parameters ↔ Map<String, GoogleCloudIntegrationsV1alphaValueType>?
Parameters are a part of Event and can be used to communicate between different tasks that are part of the same integration execution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited