GoogleCloudIntegrationsV1alphaTestTaskConfig class

The task mock configuration details and assertions for functional tests.

Next available id: 6

Properties

assertions ↔ List<GoogleCloudIntegrationsV1alphaAssertion>?
List of conditions or expressions which should be evaluated to true unless there is a bug/problem in the integration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mockConfig ↔ GoogleCloudIntegrationsV1alphaMockConfig?
Defines how to mock the given task during test execution
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task ↔ String?
This defines in the test case, the task name in integration which will be mocked by this test task config
getter/setter pair
taskConfig ↔ GoogleCloudIntegrationsV1alphaTaskConfig?
Auto-generated.
getter/setter pair
taskNumber ↔ String?
This defines in the test case, the task in integration which will be mocked by this test task config
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited