GoogleCloudIntegrationsV1alphaToggleHttpRequest class

Request to enable/disable http call for a provisioned client

Properties

enableHttpCall ↔ bool?
REQUIRED: True if http call feature should be turned on for this region
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited