GoogleCloudIntegrationsV1alphaTriggerConfig class

Configuration detail of a trigger.

Properties

alertConfig ↔ List<GoogleCloudIntegrationsV1alphaIntegrationAlertConfig>?
An alert threshold configuration for the [trigger + client + integration] tuple.
getter/setter pair
cloudSchedulerConfig ↔ EnterpriseCrmEventbusProtoCloudSchedulerConfig?
Cloud Scheduler Trigger related metadata
getter/setter pair
description ↔ String?
User-provided description intended to give additional business context about the task.
getter/setter pair
errorCatcherId ↔ String?
Optional Error catcher id of the error catch flow which will be executed when execution error happens in the task
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputVariables ↔ EnterpriseCrmFrontendsEventbusProtoTriggerConfigVariables?
List of input variables for the api trigger.
getter/setter pair
label ↔ String?
The user created label for a particular trigger.
getter/setter pair
nextTasksExecutionPolicy ↔ String?
Dictates how next tasks will be executed.
getter/setter pair
outputVariables ↔ EnterpriseCrmFrontendsEventbusProtoTriggerConfigVariables?
List of output variables for the api trigger.
getter/setter pair
position ↔ GoogleCloudIntegrationsV1alphaCoordinate?
Informs the front-end application where to draw this error catcher config on the UI.
getter/setter pair
properties ↔ Map<String, String>?
Configurable properties of the trigger, not to be confused with integration parameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTasks ↔ List<GoogleCloudIntegrationsV1alphaNextTask>?
Set of tasks numbers from where the integration execution is started by this trigger.
getter/setter pair
trigger ↔ String?
Name of the trigger.
getter/setter pair
triggerId ↔ String?
Auto-generated trigger ID.
getter/setter pair
triggerNumber ↔ String?
A number to uniquely identify each trigger config within the integration on UI.
getter/setter pair
triggerType ↔ String?
Type of trigger
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited