GoogleCloudIntegrationsV1alphaValueType class

The type of the parameter.

Properties

booleanArray ↔ GoogleCloudIntegrationsV1alphaBooleanParameterArray?
Boolean Array.
getter/setter pair
booleanValue ↔ bool?
Boolean.
getter/setter pair
doubleArray ↔ GoogleCloudIntegrationsV1alphaDoubleParameterArray?
Double Number Array.
getter/setter pair
doubleValue ↔ double?
Double Number.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intArray ↔ GoogleCloudIntegrationsV1alphaIntParameterArray?
Integer Array.
getter/setter pair
intValue ↔ String?
Integer.
getter/setter pair
jsonValue ↔ String?
Json.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringArray ↔ GoogleCloudIntegrationsV1alphaStringParameterArray?
String Array.
getter/setter pair
stringValue ↔ String?
String.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited