BucketRange class

Represents starting and ending value of a range in double.

Constructors

BucketRange({double? from, double? to})
BucketRange.fromJson(Map json_)

Properties

from ↔ double?
Starting value of the bucket range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to ↔ double?
Ending value of the bucket range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited