CommuteFilter class

Input only.

Parameters needed for commute search.

Constructors

CommuteFilter({bool? allowImpreciseAddresses, String? commuteMethod, TimeOfDay? departureTime, String? roadTraffic, LatLng? startCoordinates, String? travelDuration})
CommuteFilter.fromJson(Map json_)

Properties

allowImpreciseAddresses ↔ bool?
If true, jobs without "precise" addresses (street level addresses or GPS coordinates) might also be returned.
getter/setter pair
commuteMethod ↔ String?
The method of transportation for which to calculate the commute time.
getter/setter pair
departureTime ↔ TimeOfDay?
The departure time used to calculate traffic impact, represented as google.type.TimeOfDay in local time zone.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
roadTraffic ↔ String?
Specifies the traffic density to use when calculating commute time.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCoordinates ↔ LatLng?
The latitude and longitude of the location from which to calculate the commute time.
getter/setter pair
travelDuration ↔ String?
The maximum travel time in seconds.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited