CompensationEntry class

A compensation entry that represents one component of compensation, such as base pay, bonus, or other compensation type.

Annualization: One compensation entry can be annualized if - it contains valid amount or range. - and its expected_units_per_year is set or can be derived. Its annualized range is determined as (amount or range) times expected_units_per_year.

Constructors

CompensationEntry({Money? amount, String? description, double? expectedUnitsPerYear, CompensationRange? range, String? type, String? unit})
CompensationEntry.fromJson(Map json_)

Properties

amount ↔ Money?
Compensation amount.
getter/setter pair
description ↔ String?
Compensation description.
getter/setter pair
expectedUnitsPerYear ↔ double?
Expected number of units paid each year.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
range ↔ CompensationRange?
Compensation range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Compensation type.
getter/setter pair
unit ↔ String?
Frequency of the specified amount.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited