CompleteQueryResponse class

Response of auto-complete query.

Output only.

Constructors

CompleteQueryResponse({List<CompletionResult>? completionResults, ResponseMetadata? metadata})
CompleteQueryResponse.fromJson(Map json_)

Properties

completionResults ↔ List<CompletionResult>?
Results of the matching job/company candidates.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ ResponseMetadata?
Additional information for the API invocation, such as the request tracking id.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited