CustomAttributeHistogramRequest class

Custom attributes histogram request.

An error is thrown if neither string_value_histogram or long_value_histogram_bucketing_option has been defined.

Constructors

CustomAttributeHistogramRequest({String? key, NumericBucketingOption? longValueHistogramBucketingOption, bool? stringValueHistogram})
CustomAttributeHistogramRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
Specifies the custom field key to perform a histogram on.
getter/setter pair
longValueHistogramBucketingOption ↔ NumericBucketingOption?
Specifies buckets used to perform a range histogram on Job's filterable long custom field values, or min/max value requirements.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringValueHistogram ↔ bool?
If set to true, the response includes the histogram value for each key as a string.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited