Job class

A Job resource represents a job posting (also referred to as a "job listing" or "job requisition").

A job belongs to a Company, which is the hiring entity responsible for the job.

Constructors

Job({List<String>? addresses, ApplicationInfo? applicationInfo, String? companyDisplayName, String? companyName, CompensationInfo? compensationInfo, Map<String, CustomAttribute>? customAttributes, List<String>? degreeTypes, String? department, JobDerivedInfo? derivedInfo, String? description, List<String>? employmentTypes, String? incentives, List<String>? jobBenefits, String? jobEndTime, String? jobLevel, String? jobStartTime, String? languageCode, String? name, String? postingCreateTime, String? postingExpireTime, String? postingPublishTime, String? postingRegion, String? postingUpdateTime, ProcessingOptions? processingOptions, int? promotionValue, String? qualifications, String? requisitionId, String? responsibilities, String? title, String? visibility})
Job.fromJson(Map json_)

Properties

addresses ↔ List<String>?
Optional but strongly recommended for the best service experience.
getter/setter pair
applicationInfo ↔ ApplicationInfo?
At least one field within ApplicationInfo must be specified.
getter/setter pair
companyDisplayName ↔ String?
Display name of the company listing the job.
getter/setter pair
companyName ↔ String?
The resource name of the company listing the job, such as "projects/api-test-project/companies/foo".
getter/setter pair
compensationInfo ↔ CompensationInfo?
Job compensation information.
getter/setter pair
customAttributes ↔ Map<String, CustomAttribute>?
A map of fields to hold both filterable and non-filterable custom job attributes that are not covered by the provided structured fields.
getter/setter pair
degreeTypes ↔ List<String>?
The desired education degrees for the job, such as Bachelors, Masters.
getter/setter pair
department ↔ String?
The department or functional area within the company with the open position.
getter/setter pair
derivedInfo ↔ JobDerivedInfo?
Derived details about the job posting.
getter/setter pair
description ↔ String?
The description of the job, which typically includes a multi-paragraph description of the company and related information.
getter/setter pair
employmentTypes ↔ List<String>?
The employment type(s) of a job, for example, full time or part time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
incentives ↔ String?
A description of bonus, commission, and other compensation incentives associated with the job not including salary or pay.
getter/setter pair
jobBenefits ↔ List<String>?
The benefits included with the job.
getter/setter pair
jobEndTime ↔ String?
The end timestamp of the job.
getter/setter pair
jobLevel ↔ String?
The experience level associated with the job, such as "Entry Level".
getter/setter pair
jobStartTime ↔ String?
The start timestamp of the job in UTC time zone.
getter/setter pair
languageCode ↔ String?
The language of the posting.
getter/setter pair
name ↔ String?
Required during job update.
getter/setter pair
postingCreateTime ↔ String?
The timestamp when this job posting was created.
getter/setter pair
postingExpireTime ↔ String?
Optional but strongly recommended for the best service experience.
getter/setter pair
postingPublishTime ↔ String?
The timestamp this job posting was most recently published.
getter/setter pair
postingRegion ↔ String?
The job PostingRegion (for example, state, country) throughout which the job is available.
getter/setter pair
postingUpdateTime ↔ String?
The timestamp when this job posting was last updated.
getter/setter pair
processingOptions ↔ ProcessingOptions?
Options for job processing.
getter/setter pair
promotionValue ↔ int?
A promotion value of the job, as determined by the client.
getter/setter pair
qualifications ↔ String?
A description of the qualifications required to perform the job.
getter/setter pair
requisitionId ↔ String?
The requisition ID, also referred to as the posting ID, assigned by the client to identify a job.
getter/setter pair
responsibilities ↔ String?
A description of job responsibilities.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The title of the job, such as "Software Engineer" The maximum number of allowed characters is 500.
getter/setter pair
visibility ↔ String?
The job is only visible to the owner.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited