ProjectsJobsResource class

Constructors

ProjectsJobsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

batchDelete(BatchDeleteJobsRequest request, String parent, {String? $fields}) → Future<Empty>
Deletes a list of Jobs by filter.
create(CreateJobRequest request, String parent, {String? $fields}) → Future<Job>
Creates a new job.
delete(String name, {String? $fields}) → Future<Empty>
Deletes the specified job.
get(String name, {String? $fields}) → Future<Job>
Retrieves the specified job, whose status is OPEN or recently EXPIRED within the last 90 days.
list(String parent, {String? filter, String? jobView, int? pageSize, String? pageToken, String? $fields}) → Future<ListJobsResponse>
Lists jobs by filter.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(UpdateJobRequest request, String name, {String? $fields}) → Future<Job>
Updates specified job.
Searches for jobs using the provided SearchJobsRequest.
searchForAlert(SearchJobsRequest request, String parent, {String? $fields}) → Future<SearchJobsResponse>
Searches for jobs using the provided SearchJobsRequest.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited