ListItem class

A single list item in a note's list.

Constructors

ListItem({bool? checked, List<ListItem>? childListItems, TextContent? text})
ListItem.fromJson(Map json_)

Properties

checked ↔ bool?
Whether this item has been checked off or not.
getter/setter pair
childListItems ↔ List<ListItem>?
If set, list of list items nested under this list item.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ TextContent?
The text of this item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited