Note class

A single note.

Constructors

Note({List<Attachment>? attachments, Section? body, String? createTime, String? name, List<Permission>? permissions, String? title, String? trashTime, bool? trashed, String? updateTime})
Note.fromJson(Map json_)

Properties

attachments ↔ List<Attachment>?
The attachments attached to this note.
getter/setter pair
body ↔ Section?
The body of the note.
getter/setter pair
createTime ↔ String?
When this note was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of this note.
getter/setter pair
permissions ↔ List<Permission>?
The list of permissions set on the note.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The title of the note.
getter/setter pair
trashed ↔ bool?
true if this note has been trashed.
getter/setter pair
trashTime ↔ String?
When this note was trashed.
getter/setter pair
updateTime ↔ String?
When this note was last modified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited