Section class

The content of the note.

Constructors

Section({ListContent? list, TextContent? text})
Section.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
list ↔ ListContent?
Used if this section's content is a list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ TextContent?
Used if this section's content is a block of text.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited