AnalyzeSyntaxRequest class

The syntax analysis request message.

Constructors

AnalyzeSyntaxRequest({Document? document, String? encodingType})
AnalyzeSyntaxRequest.fromJson(Map json_)

Properties

document ↔ Document?
Input document.
getter/setter pair
encodingType ↔ String?
The encoding type used by the API to calculate offsets. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited