AnnotateTextResponse class

The text annotations response message.

Constructors

AnnotateTextResponse({List<ClassificationCategory>? categories, Sentiment? documentSentiment, List<Entity>? entities, String? language, List<ClassificationCategory>? moderationCategories, List<Sentence>? sentences, List<Token>? tokens})
AnnotateTextResponse.fromJson(Map json_)

Properties

categories ↔ List<ClassificationCategory>?
Categories identified in the input document.
getter/setter pair
documentSentiment ↔ Sentiment?
The overall sentiment for the document.
getter/setter pair
entities ↔ List<Entity>?
Entities, along with their semantic information, in the input document.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
language ↔ String?
The language of the text, which will be the same as the language specified in the request or, if not specified, the automatically-detected language.
getter/setter pair
moderationCategories ↔ List<ClassificationCategory>?
Harmful and sensitive categories identified in the input document.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentences ↔ List<Sentence>?
Sentences in the input document.
getter/setter pair
tokens ↔ List<Token>?
Tokens, along with their syntactic information, in the input document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited