DependencyEdge class

Represents dependency parse tree information for a token.

(For more information on dependency labels, see http://www.aclweb.org/anthology/P13-2017

Constructors

DependencyEdge({int? headTokenIndex, String? label})
DependencyEdge.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
headTokenIndex ↔ int?
Represents the head of this token in the dependency tree.
getter/setter pair
label ↔ String?
The parse label for the token. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited