Token class

Represents the smallest syntactic building block of the text.

Constructors

Token({DependencyEdge? dependencyEdge, String? lemma, PartOfSpeech? partOfSpeech, TextSpan? text})
Token.fromJson(Map json_)

Properties

dependencyEdge ↔ DependencyEdge?
Dependency tree parse for this token.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lemma ↔ String?
Lemma of the token.
getter/setter pair
partOfSpeech ↔ PartOfSpeech?
Parts of speech tag for this token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ TextSpan?
The token text.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited