AnalyzeEntitiesResponse class

The entity analysis response message.

Constructors

AnalyzeEntitiesResponse({List<Entity>? entities, String? languageCode, bool? languageSupported})
AnalyzeEntitiesResponse.fromJson(Map json_)

Properties

entities ↔ List<Entity>?
The recognized entities in the input document.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The language of the text, which will be the same as the language specified in the request or, if not specified, the automatically-detected language.
getter/setter pair
languageSupported ↔ bool?
Whether the language is officially supported.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited