AnalyzeSentimentResponse class

The sentiment analysis response message.

Constructors

AnalyzeSentimentResponse({Sentiment? documentSentiment, String? languageCode, bool? languageSupported, List<Sentence>? sentences})
AnalyzeSentimentResponse.fromJson(Map json_)

Properties

documentSentiment ↔ Sentiment?
The overall sentiment of the input document.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The language of the text, which will be the same as the language specified in the request or, if not specified, the automatically-detected language.
getter/setter pair
languageSupported ↔ bool?
Whether the language is officially supported.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentences ↔ List<Sentence>?
The sentiment for all the sentences in the document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited