ClassificationCategory class

Represents a category returned from the text classifier.

Constructors

ClassificationCategory({double? confidence, String? name, double? severity})
ClassificationCategory.fromJson(Map json_)

Properties

confidence ↔ double?
The classifier's confidence of the category.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the category representing the document.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ double?
The classifier's severity of the category.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited