LicenseAssignment class

Representation of a license assignment.

Constructors

LicenseAssignment({String? etags, String? kind, String? productId, String? productName, String? selfLink, String? skuId, String? skuName, String? userId})
LicenseAssignment.fromJson(Map json_)

Properties

etags ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies the resource as a LicenseAssignment, which is licensing#licenseAssignment.
getter/setter pair
productId ↔ String?
A product's unique identifier.
getter/setter pair
productName ↔ String?
Display Name of the product.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Link to this page.
getter/setter pair
skuId ↔ String?
A product SKU's unique identifier.
getter/setter pair
skuName ↔ String?
Display Name of the sku of the product.
getter/setter pair
userId ↔ String?
The user's current primary email address.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited