LicenseAssignmentList class

Constructors

LicenseAssignmentList({String? etag, List<LicenseAssignment>? items, String? kind, String? nextPageToken})
LicenseAssignmentList.fromJson(Map json_)

Properties

etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<LicenseAssignment>?
The LicenseAssignments in this page of results.
getter/setter pair
kind ↔ String?
Identifies the resource as a collection of LicenseAssignments.
getter/setter pair
nextPageToken ↔ String?
The token that you must submit in a subsequent request to retrieve additional license results matching your query parameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited