AppHub class

Metadata associated with App Hub.

Constructors

AppHub({AppHubApplication? application, AppHubService? service, AppHubWorkload? workload})
AppHub.fromJson(Map json_)

Properties

application ↔ AppHubApplication?
Metadata associated with the application.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ AppHubService?
Metadata associated with the service.
getter/setter pair
workload ↔ AppHubWorkload?
Metadata associated with the workload.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited