AppHubService class

Metadata associated with an App Hub service.

Constructors

AppHubService({String? criticalityType, String? environmentType, String? id})
AppHubService.fromJson(Map json_)

Properties

criticalityType ↔ String?
Service criticality type Example: "CRITICAL"
getter/setter pair
environmentType ↔ String?
Service environment type Example: "DEV"
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Service Id.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited