projectedField property
A projected field option for when a user wants to use a field with some additional transformations such as casting or extractions.
Implementation
ProjectedField? projectedField;
A projected field option for when a user wants to use a field with some additional transformations such as casting or extractions.
ProjectedField? projectedField;