FilterExpression class

This is a leaf of the FilterPredicate.

Ex: { field: json_payload.message.error_code, filter_value: {numeric_value: 400}, comparator: EQUAL_TO} The field will be schema field that is selected using the . annotation to display the drill down value. The value will be the user inputted text that the filter is comparing against.

Constructors

FilterExpression({String? comparator, FieldSource? fieldSource, FieldSource? fieldSourceValue, bool? isNegation, Object? literalValue})
FilterExpression.fromJson(Map json_)

Properties

comparator String?
The comparison type to use for the filter. Possible string values are:
getter/setter pair
fieldSource FieldSource?
Can be one of the FieldSource types: field name, alias ref, variable ref, or a literal value.
getter/setter pair
fieldSourceValue FieldSource?
The field.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isNegation bool?
Determines if the NOT flag should be added to the comparator.
getter/setter pair
literalValue Object?
The Value will be used to hold user defined constants set as the Right Hand Side of the filter.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited