fieldSource property
Can be one of the FieldSource types: field name, alias ref, variable ref, or a literal value.
Implementation
FieldSource? fieldSource;
Can be one of the FieldSource types: field name, alias ref, variable ref, or a literal value.
FieldSource? fieldSource;