fieldSourceValue property
The field.
This will be the field that is set as the Right Hand Side of the filter.
Implementation
FieldSource? fieldSourceValue;
The field.
This will be the field that is set as the Right Hand Side of the filter.
FieldSource? fieldSourceValue;