childPredicates property
The children of the filter predicate.
This equates to the branches of the filter predicate that could contain further nested leaves.
Implementation
core.List<FilterPredicate>? childPredicates;
The children of the filter predicate.
This equates to the branches of the filter predicate that could contain further nested leaves.
core.List<FilterPredicate>? childPredicates;