leafPredicate property
The leaves of the filter predicate.
This equates to the last leaves of the filter predicate associated with an operator.
Implementation
FilterExpression? leafPredicate;
The leaves of the filter predicate.
This equates to the last leaves of the filter predicate associated with an operator.
FilterExpression? leafPredicate;