FoldersResource class
Methods
getCmekSettings (String name , {String ? $fields })
→ Future <CmekSettings >
Gets the Logging CMEK settings for the given resource.Note: CMEK for the
Log Router can be configured for Google Cloud projects, folders,
organizations, and billing accounts.
getSettings (String name , {String ? $fields })
→ Future <Settings >
Gets the settings for the given resource.Note: Settings can be retrieved
for Google Cloud projects, folders, organizations, and billing
accounts.See View default resource settings for Logging
(https://docs.cloud.google.com/logging/docs/default-settings#view-org-settings )
for more information.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited
updateSettings (Settings request , String name , {String ? updateMask , String ? $fields })
→ Future <Settings >
Updates the settings for the given resource.