FunctionApplication class

Defines the aggregation function to apply to this field.

This message is used only when operation is set to AGGREGATE.

Constructors

FunctionApplication({List<Object?>? parameters, String? type})
FunctionApplication.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
parameters List<Object?>?
Parameters to be applied to the aggregation.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Specifies the aggregation function.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited