Lists information about the supported locations for this service.This
method lists locations based on the resource scope provided in the
ListLocationsRequest.name field: Global locations: If name is empty, the
method lists the public locations available to all projects.