errorGroups property

List<LogErrorGroup>? errorGroups
getter/setter pair

The Error Reporting (https://cloud.google.com/error-reporting) error groups associated with this LogEntry.

Error Reporting sets the values for this field during error group creation.This field is populated only when log entries are stored in Cloud Logging storage (Logs Explorer and Observability Analytics). It is not available for use in log sink filters, log-based metrics, or log-based alerts, and it is excluded from log exports (Cloud Storage, BigQuery, and Pub/Sub).For more information, see View error details( https://cloud.google.com/error-reporting/docs/viewing-errors#view_error_details)

Output only.

Implementation

core.List<LogErrorGroup>? errorGroups;