otel property

Map<String, Object?>? otel
getter/setter pair

The structured OpenTelemetry protocol payload.

Contains the OpenTelemetry Resource, Instrumentation Scope, and Entities attributes for this log as they are defined in the OTLP specification, and any other fields that do not have a direct analog in the LogEntry. See https://opentelemetry.io/docs/specs/otel/logs/data-model/

Optional.

The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.

Implementation

core.Map<core.String, core.Object?>? otel;