timestamp property

String? timestamp
getter/setter pair

The time the event described by the log entry occurred.

This time is used to compute the log entry's age and to enforce the logs retention period. If this field is omitted in a new log entry, then Logging assigns it the current time. Timestamps have nanosecond accuracy, but trailing zeros in the fractional seconds might be omitted when the timestamp is displayed.

Optional.

Implementation

core.String? timestamp;