OpsAnalyticsQuery class

Describes a query that can be run in Log Analytics.

Constructors

OpsAnalyticsQuery({QueryBuilderConfig? queryBuilder, String? sqlQueryText})
OpsAnalyticsQuery.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
queryBuilder QueryBuilderConfig?
A query builder configuration used in Log Analytics.If both query_builder and sql_query_text fields are set, then the sql_query_text will be used, if its non-empty.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sqlQueryText String?
A Log Analytics SQL query in text format.If both sql_query_text and query_builder fields are set, then the sql_query_text will be used, if its non-empty.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited