field property

String? field
getter/setter pair

The field name.

This will be the field that is selected using the dot notation to display the drill down value.

Optional.

Implementation

core.String? field;