truncationGranularity property

String? truncationGranularity
getter/setter pair

The truncation granularity when grouping by a time/date field.

This will be used to truncate the field to the granularity specified. This can be either a date or a time granularity found at https://cloud.google.com/bigquery/docs/reference/standard-sql/timestamp_functions#timestamp_trunc_granularity_date and https://cloud.google.com/bigquery/docs/reference/standard-sql/timestamp_functions#timestamp_trunc_granularity_time respectively.

Implementation

core.String? truncationGranularity;