virtualField property

VirtualField? virtualField
getter/setter pair

A virtual field definition, used in place of field to define a field that is computed from other fields rather than being directly present in the data schema.For example, a virtual field can be defined using COALESCE to select the first non-null value from a list of fields.If virtual_field is set, field must not be set.

Optional.

Implementation

VirtualField? virtualField;