ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

buckets ProjectsLocationsBucketsResource
no setter
hashCode int
The hash code for this object.
no setterinherited
logScopes ProjectsLocationsLogScopesResource
no setter
operations ProjectsLocationsOperationsResource
no setter
recentQueries ProjectsLocationsRecentQueriesResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savedQueries ProjectsLocationsSavedQueriesResource
no setter

Methods

get(String name, {String? $fields}) Future<Location>
Gets information about a location.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) Future<ListLocationsResponse>
Lists information about the supported locations for this service.This method lists locations based on the resource scope provided in the ListLocationsRequest.name field: Global locations: If name is empty, the method lists the public locations available to all projects.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited