QueryBuilderConfig class

Defines a structured query configuration that can be used instead of writing raw SQL.

This configuration represents the components of a SQL query (FROM, SELECT, WHERE, ORDER BY, LIMIT) and is typically converted into an executable query (e.g., BigQuery SQL) by the backend service to retrieve data for analysis or visualization.

Constructors

QueryBuilderConfig({List<FieldSource>? fieldSources, FilterPredicate? filter, String? limit, List<SortOrderParameter>? orderBys, List<String>? resourceNames, String? searchTerm})
QueryBuilderConfig.fromJson(Map json_)

Properties

fieldSources List<FieldSource>?
Defines the items to include in the query result, analogous to a SQL SELECT clause.
getter/setter pair
filter FilterPredicate?
The filter to use for the query.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
limit String?
The limit to use for the query.
getter/setter pair
orderBys List<SortOrderParameter>?
The sort orders to use for the query.
getter/setter pair
resourceNames List<String>?
The view/resource to query.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchTerm String?
The plain text search to use for the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited