fieldSource property
The field to sort on.
Can be one of the FieldSource types: field name, alias ref, variable ref, or a literal value.
Implementation
FieldSource? fieldSource;
The field to sort on.
Can be one of the FieldSource types: field name, alias ref, variable ref, or a literal value.
FieldSource? fieldSource;