sortOrderDirection property

String? sortOrderDirection
getter/setter pair

The sort order to use for the query. Possible string values are:

  • "SORT_ORDER_UNSPECIFIED" : Invalid value, do not use.
  • "SORT_ORDER_NONE" : No sorting will be applied. This is used to determine if the query is in pass thru mode. To correctly chart a query in pass thru mode, NONE will need to be sent
  • "SORT_ORDER_ASCENDING" : The lowest-valued entries will be selected.
  • "SORT_ORDER_DESCENDING" : The highest-valued entries will be selected.

Implementation

core.String? sortOrderDirection;