ControlledEgressConfig class

Controlled egress configuration.

Constructors

ControlledEgressConfig({List<String>? egressFqdns, bool? marketplaceEnabled, List<String>? webProxyIps})
ControlledEgressConfig.fromJson(Map json_)

Properties

egressFqdns ↔ List<String>?
List of fully qualified domain names to be added to the allowlist for outbound traffic.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
marketplaceEnabled ↔ bool?
Whether marketplace is enabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webProxyIps ↔ List<String>?
The list of IP addresses used by Secure Web Proxy for outbound traffic.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited