ExportInstanceRequest class

Request options for exporting data of an Instance.

Constructors

ExportInstanceRequest({ExportEncryptionConfig? encryptionConfig, String? gcsUri})
ExportInstanceRequest.fromJson(Map json_)

Properties

encryptionConfig ↔ ExportEncryptionConfig?
Encryption configuration (CMEK).
getter/setter pair
gcsUri ↔ String?
The path to the folder in Google Cloud Storage where the export will be stored.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited