IngressIpAllowlistConfig class
Ingress IP allowlist configuration.
Constructors
-
IngressIpAllowlistConfig({List<
IngressIpAllowlistRule> ? allowlistRules, bool? enabled, bool? googleServicesEnabled}) - IngressIpAllowlistConfig.fromJson(Map json_)
Properties
-
allowlistRules
↔ List<
IngressIpAllowlistRule> ? -
List of IP range rules to allow ingress traffic.
getter/setter pair
- enabled ↔ bool?
-
Whether ingress IP allowlist functionality is enabled on the Looker
instance.
getter/setter pair
- googleServicesEnabled ↔ bool?
-
Whether google service connections are enabled for the instance.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited