Instance class

A Looker instance.

Constructors

Instance({bool? acceleratedSecurityPatchEnabled, AdminSettings? adminSettings, bool? catalogIntegrationOptOut, String? classType, String? consumerNetwork, ControlledEgressConfig? controlledEgressConfig, bool? controlledEgressEnabled, String? createTime, CustomDomain? customDomain, DenyMaintenancePeriod? denyMaintenancePeriod, String? egressPublicIp, EncryptionConfig? encryptionConfig, bool? fipsEnabled, bool? geminiEnabled, IngressIpAllowlistConfig? ingressIpAllowlistConfig, String? ingressPrivateIp, String? ingressPublicIp, DenyMaintenancePeriod? lastDenyMaintenancePeriod, String? linkedLspProjectNumber, String? lookerUri, String? lookerVersion, MaintenanceSchedule? maintenanceSchedule, MaintenanceWindow? maintenanceWindow, String? name, OAuthConfig? oauthConfig, PeriodicExportConfig? periodicExportConfig, String? platformEdition, bool? privateIpEnabled, PscConfig? pscConfig, bool? pscEnabled, bool? publicIpEnabled, String? releaseChannel, String? reservedRange, bool? satisfiesPzi, bool? satisfiesPzs, String? softDeleteReason, String? state, String? suspendedTime, String? updateTime, UserMetadata? userMetadata})
Instance.fromJson(Map json_)

Properties

acceleratedSecurityPatchEnabled ↔ bool?
Accelerated security patch enabled for the instance.
getter/setter pair
adminSettings ↔ AdminSettings?
Looker Instance Admin settings.
getter/setter pair
catalogIntegrationOptOut ↔ bool?
Indicates whether catalog integration is disabled for the Looker instance.
getter/setter pair
classType ↔ String?
Storage class of the instance.
getter/setter pair
consumerNetwork ↔ String?
Network name in the consumer project.
getter/setter pair
controlledEgressConfig ↔ ControlledEgressConfig?
Controlled egress configuration.
getter/setter pair
controlledEgressEnabled ↔ bool?
Whether controlled egress is enabled on the Looker instance.
getter/setter pair
createTime ↔ String?
The time when the Looker instance provisioning was first requested.
getter/setter pair
customDomain ↔ CustomDomain?
Custom domain configuration for the instance.
getter/setter pair
denyMaintenancePeriod ↔ DenyMaintenancePeriod?
Maintenance denial period for this instance.
getter/setter pair
egressPublicIp ↔ String?
Public Egress IP (IPv4).
getter/setter pair
encryptionConfig ↔ EncryptionConfig?
Encryption configuration (CMEK).
getter/setter pair
fipsEnabled ↔ bool?
Whether FIPS is enabled on the Looker instance.
getter/setter pair
geminiEnabled ↔ bool?
Whether Gemini feature is enabled on the Looker instance or not.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ingressIpAllowlistConfig ↔ IngressIpAllowlistConfig?
Ingress IP allowlist configuration for the Looker instance.
getter/setter pair
ingressPrivateIp ↔ String?
Private Ingress IP (IPv4).
getter/setter pair
ingressPublicIp ↔ String?
Public Ingress IP (IPv4).
getter/setter pair
lastDenyMaintenancePeriod ↔ DenyMaintenancePeriod?
Last computed maintenance denial period for this instance.
getter/setter pair
linkedLspProjectNumber ↔ String?
Linked Google Cloud Project Number for Looker Studio Pro.
getter/setter pair
lookerUri ↔ String?
Looker instance URI which can be used to access the Looker Instance UI.
getter/setter pair
lookerVersion ↔ String?
The Looker version that the instance is using.
getter/setter pair
maintenanceSchedule ↔ MaintenanceSchedule?
Maintenance schedule for this instance.
getter/setter pair
maintenanceWindow ↔ MaintenanceWindow?
Maintenance window for this instance.
getter/setter pair
name ↔ String?
Format: projects/{project}/locations/{location}/instances/{instance}.
getter/setter pair
oauthConfig ↔ OAuthConfig?
Looker instance OAuth login settings.
getter/setter pair
periodicExportConfig ↔ PeriodicExportConfig?
Configuration for periodic export.
getter/setter pair
platformEdition ↔ String?
Platform edition. Possible string values are:
getter/setter pair
privateIpEnabled ↔ bool?
Whether private IP is enabled on the Looker instance.
getter/setter pair
pscConfig ↔ PscConfig?
PSC configuration.
getter/setter pair
pscEnabled ↔ bool?
Whether to use Private Service Connect (PSC) for private IP connectivity.
getter/setter pair
publicIpEnabled ↔ bool?
Whether public IP is enabled on the Looker instance.
getter/setter pair
releaseChannel ↔ String?
The selected release channel for the instance.
getter/setter pair
reservedRange ↔ String?
Name of a reserved IP address range within the Instance.consumer_network, to be used for private services access connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
softDeleteReason ↔ String?
The reason for the instance being in a soft-deleted state.
getter/setter pair
state ↔ String?
The state of the instance.
getter/setter pair
suspendedTime ↔ String?
The time when the Looker instance was suspended (soft deleted).
getter/setter pair
updateTime ↔ String?
The time when the Looker instance was last updated.
getter/setter pair
userMetadata ↔ UserMetadata?
User metadata.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited