catalogIntegrationOptOut property
Indicates whether catalog integration is disabled for the Looker instance.
Optional.
Implementation
core.bool? catalogIntegrationOptOut;
Indicates whether catalog integration is disabled for the Looker instance.
Optional.
core.bool? catalogIntegrationOptOut;