MaintenanceWindow class

Specifies the recurring maintenance window.

Constructors

MaintenanceWindow({String? dayOfWeek, TimeOfDay? startTime})
MaintenanceWindow.fromJson(Map json_)

Properties

dayOfWeek ↔ String?
Day of the week for this MaintenanceWindow (in UTC).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ TimeOfDay?
Time in UTC when the period starts.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited