sharedOauthClientEnabled property
Whether to use the shared OAuth client.
Instances specifying this field do not need to provide client_id and client_secret.
Optional.
Implementation
core.bool? sharedOauthClientEnabled;
Whether to use the shared OAuth client.
Instances specifying this field do not need to provide client_id and client_secret.
Optional.
core.bool? sharedOauthClientEnabled;