ServiceAttachment class

Service attachment configuration.

Constructors

ServiceAttachment({String? connectionStatus, String? failureReason, String? localFqdn, List<String>? localFqdns, String? targetServiceAttachmentUri})
ServiceAttachment.fromJson(Map json_)

Properties

connectionStatus ↔ String?
Connection status.
getter/setter pair
failureReason ↔ String?
Reason the service attachment creation failed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localFqdn ↔ String?
Fully qualified domain name that will be used in the private DNS record created for the service attachment.
getter/setter pair
localFqdns ↔ List<String>?
List of fully qualified domain names that will be used in the private DNS record created for the service attachment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetServiceAttachmentUri ↔ String?
URI of the service attachment to connect to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited