Backup class

Represents a Managed Microsoft Identities backup.

Constructors

Backup({String? createTime, Map<String, String>? labels, String? name, String? state, String? statusMessage, String? type, String? updateTime})
Backup.fromJson(Map json_)

Properties

createTime ↔ String?
The time the backups was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
name ↔ String?
The unique name of the Backup in the form of projects/{project_id}/locations/global/domains/{domain_name}/backups/{name}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of the backup.
getter/setter pair
statusMessage ↔ String?
Additional information about the current status of this backup, if available.
getter/setter pair
type ↔ String?
Indicates whether it’s an on-demand backup or scheduled.
getter/setter pair
updateTime ↔ String?
Last update time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited