Domain class

Represents a managed Microsoft Active Directory domain.

If the domain is being changed, it will be placed into the UPDATING state, which indicates that the resource is being reconciled. At this point, Get will reflect an intermediate state.

Constructors

Domain({String? admin, bool? auditLogsEnabled, List<String>? authorizedNetworks, String? createTime, String? fqdn, Map<String, String>? labels, List<String>? locations, String? name, String? reservedIpRange, String? state, String? statusMessage, List<Trust>? trusts, String? updateTime})
Domain.fromJson(Map json_)

Properties

admin ↔ String?
The name of delegated administrator account used to perform Active Directory operations.
getter/setter pair
auditLogsEnabled ↔ bool?
Configuration for audit logs.
getter/setter pair
authorizedNetworks ↔ List<String>?
The full names of the Google Compute Engine [networks](/compute/docs/networks-and-firewalls#networks) the domain instance is connected to.
getter/setter pair
createTime ↔ String?
The time the instance was created.
getter/setter pair
fqdn ↔ String?
The fully-qualified domain name of the exposed domain used by clients to connect to the service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels that can contain user-provided metadata.
getter/setter pair
locations ↔ List<String>?
Locations where domain needs to be provisioned.
getter/setter pair
name ↔ String?
The unique name of the domain using the form: projects/{project_id}/locations/global/domains/{domain_name}.
getter/setter pair
reservedIpRange ↔ String?
The CIDR range of internal addresses that are reserved for this domain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of this domain.
getter/setter pair
statusMessage ↔ String?
Additional information about the current status of this domain, if available.
getter/setter pair
trusts ↔ List<Trust>?
The current trusts associated with the domain.
getter/setter pair
updateTime ↔ String?
The last update time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited