DomainJoinMachineRequest class

DomainJoinMachineRequest is the request message for DomainJoinMachine method

Constructors

DomainJoinMachineRequest({bool? force, String? ouName, String? vmIdToken})
DomainJoinMachineRequest.fromJson(Map json_)

Properties

force ↔ bool?
force if True, forces domain join even if the computer account already exists.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ouName ↔ String?
OU name where the VM needs to be domain joined
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vmIdToken ↔ String?
Full instance id token of compute engine VM to verify instance identity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited