ListSqlIntegrationsResponse class

ListSqlIntegrationsResponse is the response message for ListSqlIntegrations method.

Constructors

ListSqlIntegrationsResponse({String? nextPageToken, List<SqlIntegration>? sqlIntegrations, List<String>? unreachable})
ListSqlIntegrationsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to retrieve the next page of results, or empty if there are no more results in the list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlIntegrations ↔ List<SqlIntegration>?
A list of SQLIntegrations of a domain.
getter/setter pair
unreachable ↔ List<String>?
A list of locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited