Trust class

Represents a relationship between two domains.

This allows a controller in one domain to authenticate a user in another domain. If the trust is being changed, it will be placed into the UPDATING state, which indicates that the resource is being reconciled. At this point, Get will reflect an intermediate state.

Constructors

Trust({String? createTime, String? lastTrustHeartbeatTime, bool? selectiveAuthentication, String? state, String? stateDescription, List<String>? targetDnsIpAddresses, String? targetDomainName, String? trustDirection, String? trustHandshakeSecret, String? trustType, String? updateTime})
Trust.fromJson(Map json_)

Properties

createTime ↔ String?
The time the instance was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastTrustHeartbeatTime ↔ String?
The last heartbeat time when the trust was known to be connected.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectiveAuthentication ↔ bool?
The trust authentication type, which decides whether the trusted side has forest/domain wide access or selective access to an approved set of resources.
getter/setter pair
state ↔ String?
The current state of the trust.
getter/setter pair
stateDescription ↔ String?
Additional information about the current state of the trust, if available.
getter/setter pair
targetDnsIpAddresses ↔ List<String>?
The target DNS server IP addresses which can resolve the remote domain involved in the trust.
getter/setter pair
targetDomainName ↔ String?
The fully qualified target domain name which will be in trust with the current domain.
getter/setter pair
trustDirection ↔ String?
The trust direction, which decides if the current domain is trusted, trusting, or both.
getter/setter pair
trustHandshakeSecret ↔ String?
The trust secret used for the handshake with the target domain.
getter/setter pair
trustType ↔ String?
The type of trust represented by the trust resource.
getter/setter pair
updateTime ↔ String?
The last update time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited