AddAclEntryResponse class

Response for AddAclEntry.

Constructors

AddAclEntryResponse({Acl? acl, bool? aclCreated})
AddAclEntryResponse.fromJson(Map json_)

Properties

acl ↔ Acl?
The updated acl.
getter/setter pair
aclCreated ↔ bool?
Whether the acl was created as a result of adding the acl entry.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited