ConsumerPartitionMetadata class

Metadata for a consumer group corresponding to a specific partition.

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ String?
The associated metadata for this partition, or empty if it does not exist.
getter/setter pair
offset ↔ String?
The current offset for this partition, or 0 if no offset has been committed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited