CreateSchemaRegistryRequest class

Request to create a schema registry instance.

Constructors

CreateSchemaRegistryRequest({SchemaRegistry? schemaRegistry, String? schemaRegistryId})
CreateSchemaRegistryRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaRegistry ↔ SchemaRegistry?
The schema registry instance to create.
getter/setter pair
schemaRegistryId ↔ String?
The schema registry instance ID to use for this schema registry.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited