CreateVersionRequest class

Request for CreateVersion.

Constructors

CreateVersionRequest({int? id, bool? normalize, List<SchemaReference>? references, String? schema, String? schemaType, int? version})
CreateVersionRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ int?
The schema ID of the schema.
getter/setter pair
normalize ↔ bool?
If true, the schema will be normalized before being stored.
getter/setter pair
references ↔ List<SchemaReference>?
The schema references used by the schema.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ String?
The schema payload
getter/setter pair
schemaType ↔ String?
The type of the schema.
getter/setter pair
version ↔ int?
The version to create.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited