ProjectsLocationsClustersResource class

Constructors

ProjectsLocationsClustersResource(ApiRequester client)

Properties

acls → ProjectsLocationsClustersAclsResource
no setter
consumerGroups → ProjectsLocationsClustersConsumerGroupsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topics → ProjectsLocationsClustersTopicsResource
no setter

Methods

create(Cluster request, String parent, {String? clusterId, String? requestId, String? $fields}) → Future<Operation>
Creates a new cluster in a given project and location.
delete(String name, {String? requestId, String? $fields}) → Future<Operation>
Deletes a single cluster.
get(String name, {String? view, String? $fields}) → Future<Cluster>
Returns the properties of a single cluster.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) → Future<ListClustersResponse>
Lists the clusters in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Cluster request, String name, {String? requestId, String? updateMask, String? $fields}) → Future<Operation>
Updates the properties of a single cluster.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited