RemoveAclEntryResponse class

Response for RemoveAclEntry.

Constructors

RemoveAclEntryResponse({Acl? acl, bool? aclDeleted})
RemoveAclEntryResponse.fromJson(Map json_)

Properties

acl ↔ Acl?
The updated acl.
getter/setter pair
aclDeleted ↔ bool?
Returned with value true if the removed acl entry was the last entry in the acl, resulting in acl deletion.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited