SchemaConfig class

SchemaConfig represents configuration for a schema registry or a specific subject.

Constructors

SchemaConfig({String? alias, String? compatibility, bool? normalize})
SchemaConfig.fromJson(Map json_)

Properties

alias ↔ String?
The subject to which this subject is an alias of.
getter/setter pair
compatibility ↔ String?
The compatibility type of the schema.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
normalize ↔ bool?
If true, the schema will be normalized before being stored or looked up.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited