TlsConfig class

The TLS configuration for the Kafka cluster.

Constructors

TlsConfig({String? sslPrincipalMappingRules, TrustConfig? trustConfig})
TlsConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sslPrincipalMappingRules ↔ String?
A list of rules for mapping from SSL principal names to short names.
getter/setter pair
trustConfig ↔ TrustConfig?
The configuration of the broker truststore.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited