Topic class

A Kafka topic in a given cluster.

Constructors

Topic({Map<String, String>? configs, String? name, int? partitionCount, int? replicationFactor})
Topic.fromJson(Map json_)

Properties

configs ↔ Map<String, String>?
Configurations for the topic that are overridden from the cluster defaults.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
partitionCount ↔ int?
The number of partitions this topic has.
getter/setter pair
replicationFactor ↔ int?
The number of replicas of each partition.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited