TrustConfig class

Sources of CA certificates to install in the broker's truststore.

Properties

casConfigs ↔ List<CertificateAuthorityServiceConfig>?
Configuration for the Google Certificate Authority Service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited