UpdateSchemaConfigRequest class

Request for updating schema config.

On a SchemaSubject-level SchemaConfig, an unset field will be removed from the SchemaConfig.

Constructors

UpdateSchemaConfigRequest({String? compatibility, bool? normalize})
UpdateSchemaConfigRequest.fromJson(Map json_)

Properties

compatibility ↔ String?
The compatibility type of the schemas.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
normalize ↔ bool?
If true, the schema will be normalized before being stored or looked up.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited