meet/v2 library

Classes

ActiveConference
Active conference.
AnonymousUser
User who joins anonymously (meaning not signed into a Google Account).
ArtifactConfig
Configuration related to meeting artifacts potentially generated by this meeting space.
ConferenceRecord
Single instance of a meeting held in a space.
ConferenceRecordsParticipantsParticipantSessionsResource
ConferenceRecordsParticipantsResource
ConferenceRecordsRecordingsResource
ConferenceRecordsResource
ConferenceRecordsSmartNotesResource
ConferenceRecordsTranscriptsEntriesResource
ConferenceRecordsTranscriptsResource
DocsDestination
Google Docs location where the transcript file is saved.
DriveDestination
Export location where a recording file is saved in Google Drive.
GatewaySipAccess
Details how to join the conference through a SIP gateway.
ListConferenceRecordsResponse
Response of ListConferenceRecords method.
ListParticipantSessionsResponse
Response of ListParticipants method.
ListParticipantsResponse
Response of ListParticipants method.
ListRecordingsResponse
Response for ListRecordings method.
ListSmartNotesResponse
Response for ListSmartNotes method.
ListTranscriptEntriesResponse
Response for ListTranscriptEntries method.
ListTranscriptsResponse
Response for ListTranscripts method.
MeetApi
Create and manage meetings in Google Meet.
ModerationRestrictions
Defines restrictions for features when the meeting is moderated.
Participant
User who attended or is attending a conference.
ParticipantSession
Refers to each unique join or leave session when a user joins a conference from a device.
PhoneAccess
Phone access contains information required to dial into a conference using a regional phone number and a PIN that is specific to that phone number.
PhoneUser
User dialing in from a phone where the user's identity is unknown because they haven't signed in with a Google Account.
Recording
Metadata about a recording created during a conference.
RecordingConfig
Configuration related to recording in a meeting space.
SignedinUser
A signed-in user can be: a) An individual joining from a personal computer, mobile device, or through companion mode.
SmartNote
Metadata for a smart note generated from a conference.
SmartNotesConfig
Configuration related to smart notes in a meeting space.
Space
Virtual place where conferences are held.
SpaceConfig
The configuration pertaining to a meeting space.
SpacesResource
Transcript
Metadata for a transcript generated from a conference.
TranscriptEntry
Single entry for one user’s speech during a transcript session.
TranscriptionConfig
Configuration related to transcription in a meeting space.

Typedefs

Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
EndActiveConferenceRequest = $Empty
Request to end an ongoing conference of a space.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.