ConferenceRecordsResource class

Constructors

ConferenceRecordsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
participants → ConferenceRecordsParticipantsResource
no setter
recordings → ConferenceRecordsRecordingsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smartNotes → ConferenceRecordsSmartNotesResource
no setter
transcripts → ConferenceRecordsTranscriptsResource
no setter

Methods

get(String name, {String? $fields}) → Future<ConferenceRecord>
Gets a conference record by conference ID.
list({String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListConferenceRecordsResponse>
Lists the conference records.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited