GatewaySipAccess class
Details how to join the conference through a SIP gateway.
Constructors
- GatewaySipAccess({String? sipAccessCode, String? uri})
- GatewaySipAccess.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sipAccessCode ↔ String?
-
The permanent numeric code for manual entry on specially configured
devices.
getter/setter pair
- uri ↔ String?
-
The Session Initiation Protocol (SIP) URI the conference can be reached
through.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited