ListConferenceRecordsResponse class

Response of ListConferenceRecords method.

Constructors

ListConferenceRecordsResponse({List<ConferenceRecord>? conferenceRecords, String? nextPageToken})
ListConferenceRecordsResponse.fromJson(Map json_)

Properties

conferenceRecords ↔ List<ConferenceRecord>?
List of conferences in one page.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to be circulated back for further List call if current List does NOT include all the Conferences.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited