ListSmartNotesResponse class
Response for ListSmartNotes method.
Constructors
-
ListSmartNotesResponse({String? nextPageToken, List<
SmartNote> ? smartNotes}) - ListSmartNotesResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
Token to be circulated back for further List call if current List doesn't
include all the smart notes.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
smartNotes
↔ List<
SmartNote> ? -
List of smart notes in one page.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited