ListTranscriptEntriesResponse class

Response for ListTranscriptEntries method.

Constructors

ListTranscriptEntriesResponse({String? nextPageToken, List<TranscriptEntry>? transcriptEntries})
ListTranscriptEntriesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to be circulated back for further List call if current List doesn't include all the transcript entries.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transcriptEntries ↔ List<TranscriptEntry>?
List of TranscriptEntries in one page.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited