ListTranscriptsResponse class

Response for ListTranscripts method.

Constructors

ListTranscriptsResponse({String? nextPageToken, List<Transcript>? transcripts})
ListTranscriptsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to be circulated back for further List call if current List doesn't include all the transcripts.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transcripts ↔ List<Transcript>?
List of transcripts in one page.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited