pin property

String? pin
getter/setter pair

The PIN that users must enter after dialing the given number.

The PIN consists of only decimal digits and the length may vary.

Implementation

core.String? pin;