regionCode property
The CLDR/ISO 3166 region code for the country associated with this phone access.
To be parsed by the i18n RegionCode utility. Example: "SE" for Sweden.
Implementation
core.String? regionCode;
The CLDR/ISO 3166 region code for the country associated with this phone access.
To be parsed by the i18n RegionCode utility. Example: "SE" for Sweden.
core.String? regionCode;