PhoneUser class

User dialing in from a phone where the user's identity is unknown because they haven't signed in with a Google Account.

Constructors

PhoneUser({String? displayName})
PhoneUser.fromJson(Map json_)

Properties

displayName ↔ String?
Partially redacted user's phone number when calling.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited