Recording class

Metadata about a recording created during a conference.

Constructors

Recording({DriveDestination? driveDestination, String? endTime, String? name, String? startTime, String? state})
Recording.fromJson(Map json_)

Properties

driveDestination ↔ DriveDestination?
Recording is saved to Google Drive as an MP4 file.
getter/setter pair
endTime ↔ String?
Timestamp when the recording ended.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of the recording.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Timestamp when the recording started.
getter/setter pair
state ↔ String?
Current state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited