docsDestination property
The Google Doc destination where the smart notes are saved.
Output only.
Implementation
DocsDestination? docsDestination;
The Google Doc destination where the smart notes are saved.
Output only.
DocsDestination? docsDestination;