state property
Current state.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : Default, never used.
- "STARTED" : An active smart notes session has started.
- "ENDED" : This smart notes session has ended, but the smart notes file hasn't been generated yet.
- "FILE_GENERATED" : Smart notes file is generated and ready to download.
Implementation
core.String? state;