Space class

Virtual place where conferences are held.

Only one active conference can be held in one space at any given time.

Constructors

Space({ActiveConference? activeConference, SpaceConfig? config, List<GatewaySipAccess>? gatewaySipAccess, String? meetingCode, String? meetingUri, String? name, List<PhoneAccess>? phoneAccess})
Space.fromJson(Map json_)

Properties

activeConference ↔ ActiveConference?
Active conference, if it exists.
getter/setter pair
config ↔ SpaceConfig?
Configuration pertaining to the meeting space.
getter/setter pair
gatewaySipAccess ↔ List<GatewaySipAccess>?
The SIP-based access methods that can be used to join the conference.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
meetingCode ↔ String?
Type friendly unique string used to join the meeting.
getter/setter pair
meetingUri ↔ String?
URI used to join meetings consisting of https://meet.google.com/ followed by the meeting_code.
getter/setter pair
name ↔ String?
Resource name of the space.
getter/setter pair
phoneAccess ↔ List<PhoneAccess>?
All regional phone access methods for this meeting space.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited