gatewaySipAccess property
The SIP-based access methods that can be used to join the conference.
Can be empty.
Output only.
Implementation
core.List<GatewaySipAccess>? gatewaySipAccess;
The SIP-based access methods that can be used to join the conference.
Can be empty.
Output only.
core.List<GatewaySipAccess>? gatewaySipAccess;