phoneAccess property
All regional phone access methods for this meeting space.
Can be empty.
Output only.
Implementation
core.List<PhoneAccess>? phoneAccess;
All regional phone access methods for this meeting space.
Can be empty.
Output only.
core.List<PhoneAccess>? phoneAccess;