Transcript class

Metadata for a transcript generated from a conference.

It refers to the ASR (Automatic Speech Recognition) result of user's speech during the conference.

Constructors

Transcript({DocsDestination? docsDestination, String? endTime, String? name, String? startTime, String? state})
Transcript.fromJson(Map json_)

Properties

docsDestination ↔ DocsDestination?
Where the Google Docs transcript is saved.
getter/setter pair
endTime ↔ String?
Timestamp when the transcript stopped.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Resource name of the transcript.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Timestamp when the transcript started.
getter/setter pair
state ↔ String?
Current state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited