TranscriptEntry class

Single entry for one user’s speech during a transcript session.

Constructors

TranscriptEntry({String? endTime, String? languageCode, String? name, String? participant, String? startTime, String? text})
TranscriptEntry.fromJson(Map json_)

Properties

endTime ↔ String?
Timestamp when the transcript entry ended.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
Language of spoken text, such as "en-US".
getter/setter pair
name ↔ String?
Resource name of the entry.
getter/setter pair
participant ↔ String?
Refers to the participant who speaks.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Timestamp when the transcript entry started.
getter/setter pair
text ↔ String?
The transcribed text of the participant's voice, at maximum 10K words.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited