MemcacheParameters class

Constructors

MemcacheParameters({String? id, Map<String, String>? params})
MemcacheParameters.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique ID associated with this set of parameters.
getter/setter pair
params ↔ Map<String, String>?
User defined set of parameters to use in the memcached process.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited