NodeConfig class

Configuration for a Memcached Node.

Constructors

NodeConfig({int? cpuCount, int? memorySizeMb})
NodeConfig.fromJson(Map json_)

Properties

cpuCount ↔ int?
Number of cpus per Memcached node.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memorySizeMb ↔ int?
Memory size in MiB for each Memcached node.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited