RescheduleMaintenanceRequest class

Request for RescheduleMaintenance.

Constructors

RescheduleMaintenanceRequest({String? rescheduleType, String? scheduleTime})
RescheduleMaintenanceRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
rescheduleType ↔ String?
If reschedule type is SPECIFIC_TIME, must set up schedule_time as well.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleTime ↔ String?
Timestamp when the maintenance shall be rescheduled to if reschedule_type=SPECIFIC_TIME, in RFC 3339 format, for example 2012-11-15T16:19:00.094Z.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited