GoogleAnalyticsLink class

"Google Analytics Link" sources can be used to get conversion data from an existing Google Analytics property into the linked Merchant Center account.

Constructors

GoogleAnalyticsLink({AttributionSettings? attributionSettings, String? property, String? propertyId})
GoogleAnalyticsLink.fromJson(Map json_)

Properties

attributionSettings ↔ AttributionSettings?
Attribution settings for the linked Google Analytics property.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
property ↔ String?
Name of the Google Analytics property the merchant is linked to.
getter/setter pair
propertyId ↔ String?
ID of the Google Analytics property the merchant is linked to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited