MerchantCenterDestination class

"Merchant Center Destination" sources can be used to send conversion events from an online store using a Google tag directly to a Merchant Center account where the source is created.

Constructors

MerchantCenterDestination({AttributionSettings? attributionSettings, String? currencyCode, String? destination, String? displayName})
MerchantCenterDestination.fromJson(Map json_)

Properties

attributionSettings ↔ AttributionSettings?
Attribution settings used for the Merchant Center Destination.
getter/setter pair
currencyCode ↔ String?
Three-letter currency code (ISO 4217).
getter/setter pair
destination ↔ String?
Merchant Center Destination ID.
getter/setter pair
displayName ↔ String?
Merchant-specified display name for the destination.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited