DataSource class

The [data source](/merchant/api/guides/data-sources/overview) for the Merchant Center account.

Constructors

DataSource({String? dataSourceId, String? displayName, FileInput? fileInput, String? input, LocalInventoryDataSource? localInventoryDataSource, MerchantReviewDataSource? merchantReviewDataSource, String? name, PrimaryProductDataSource? primaryProductDataSource, ProductReviewDataSource? productReviewDataSource, PromotionDataSource? promotionDataSource, RegionalInventoryDataSource? regionalInventoryDataSource, SupplementalProductDataSource? supplementalProductDataSource})
DataSource.fromJson(Map json_)

Properties

dataSourceId ↔ String?
The data source id.
getter/setter pair
displayName ↔ String?
The displayed data source name in the Merchant Center UI.
getter/setter pair
fileInput ↔ FileInput?
The field is used only when data is managed through a file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
input ↔ String?
Determines the type of input to the data source.
getter/setter pair
localInventoryDataSource ↔ LocalInventoryDataSource?
The local inventory data source.
getter/setter pair
merchantReviewDataSource ↔ MerchantReviewDataSource?
The merchant review data source.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
primaryProductDataSource ↔ PrimaryProductDataSource?
The primary data source for local and online products.
getter/setter pair
productReviewDataSource ↔ MerchantReviewDataSource?
The product review data source.
getter/setter pair
promotionDataSource ↔ PromotionDataSource?
The promotion data source.
getter/setter pair
regionalInventoryDataSource ↔ RegionalInventoryDataSource?
The regional inventory data source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supplementalProductDataSource ↔ SupplementalProductDataSource?
The supplemental data source for local and online products.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited