DataSourceReference class

Data source reference can be used to manage related data sources within the data source service.

Constructors

DataSourceReference({String? primaryDataSourceName, bool? self, String? supplementalDataSourceName})
DataSourceReference.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
primaryDataSourceName ↔ String?
Deprecated: Use self instead to reference the primary data source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
self ↔ bool?
Self should be used to reference the primary data source itself.
getter/setter pair
supplementalDataSourceName ↔ String?
The name of the supplemental data source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited