Issue class

An error occurring in the data source, like "invalid price".

Constructors

Issue({String? code, String? count, String? description, String? documentationUri, String? severity, String? title})
Issue.fromJson(Map json_)

Properties

code ↔ String?
The code of the error, for example, "validation/invalid_value".
getter/setter pair
count ↔ String?
The number of occurrences of the error in the file upload.
getter/setter pair
description ↔ String?
The error description, for example, "Your data source contains items which have too many attributes, or are too big.
getter/setter pair
documentationUri ↔ String?
Link to the documentation explaining the issue in more details, if available.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of the issue.
getter/setter pair
title ↔ String?
The title of the issue, for example, "Item too big".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited