LocalInventoryDataSource class

The local inventory data source type is only available for file inputs and can't be used to create API local inventory data sources.

Constructors

LocalInventoryDataSource({String? contentLanguage, String? feedLabel})
LocalInventoryDataSource.fromJson(Map json_)

Properties

contentLanguage ↔ String?
The two-letter ISO 639-1 language of the items to which the local inventory is provided.
getter/setter pair
feedLabel ↔ String?
The feed label of the offers to which the local inventory is provided.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited