feedLabel property

String? feedLabel
getter/setter pair

The feed label that is specified on the data source level.

Must be less than or equal to 20 uppercase letters (A-Z), numbers (0-9), and dashes (-). For more information about feed label, see Create a primary data source for products. feedLabel and contentLanguage must be either both set or unset for data sources with product content type. They must be set for data sources with a file input. If set, the data source will only accept products matching this combination. If unset, the data source will accept products without that restriction.

Optional. Immutable.

Implementation

core.String? feedLabel;