name property

String? name
getter/setter pair

The name of the LocalInventory resource.

Format: accounts/{account}/products/{product}/localInventories/{store_code} The {product} segment is a unique identifier for the product. This identifier must be unique within a merchant account and generally follows the structure: content_language~feed_label~offer_id. Example: en~US~sku123 For legacy local products, the structure is: local~content_language~feed_label~offer_id. Example: local~en~US~sku123 The format of the {product} segment in the URL is automatically detected by the server, supporting two options: 1. Encoded Format: The {product} segment is an unpadded base64url encoded string (RFC 4648 Section 5). The decoded string must result in the content_language~feed_label~offer_id structure. This encoding MUST be used if any part of the product identifier (like offer_id) contains characters such as /, %, or ~. * Example: To represent the product ID en~US~sku/123 for store_code "store123", the {product} segment must be the base64url encoding of this string, which is ZW5-VVMtc2t1LzEyMw. The full resource name for the local inventory would be accounts/123/products/ZW5-VVMtc2t1LzEyMw/localInventories/store123. 2. Plain Format: The {product} segment is the tilde-separated string content_language~feed_label~offer_id. This format is suitable only when content_language, feed_label, and offer_id do not contain URL-problematic characters like /, %, or ~. We recommend using the Encoded Format for all product IDs to ensure correct parsing, especially those containing special characters. The presence of tilde (~) characters in the {product} segment is used to differentiate between the two formats. Note: For calls to the v1beta version, the plain format for the product segment is channel~content_language~feed_label~offer_id. For example, the full resource name for a local inventory at store_code "store123" would be: accounts/123/products/online~en~US~sku123/localInventories/store123.

Output only.

Implementation

core.String? name;