localShippingLabel property

String? localShippingLabel
getter/setter pair

Specifies a label associated with the shipping for the LocalInventory resource.

Can be used to group local shipping services to this particular inventory item. For accepted field format, see the Local delivery

Optional.

Implementation

core.String? localShippingLabel;