Action class

An actionable step that can be executed to solve the issue.

Constructors

Action({BuiltInSimpleAction? builtinSimpleAction, BuiltInUserInputAction? builtinUserInputAction, String? buttonLabel, ExternalAction? externalAction, bool? isAvailable, List<Reason>? reasons})
Action.fromJson(Map json_)

Properties

builtinSimpleAction ↔ BuiltInSimpleAction?
Action implemented and performed in (your) third-party application.
getter/setter pair
builtinUserInputAction ↔ BuiltInUserInputAction?
Action implemented and performed in (your) third-party application.
getter/setter pair
buttonLabel ↔ String?
Label of the action button.
getter/setter pair
externalAction ↔ ExternalAction?
Action that is implemented and performed outside of (your) third-party application.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAvailable ↔ bool?
Controlling whether the button is active or disabled.
getter/setter pair
reasons ↔ List<Reason>?
List of reasons why the action is not available.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited