AggregateProductStatus class

Aggregate product statuses for a given reporting context and country.

Constructors

AggregateProductStatus({String? country, List<ItemLevelIssue>? itemLevelIssues, String? name, String? reportingContext, Stats? stats})
AggregateProductStatus.fromJson(Map json_)

Properties

country ↔ String?
The country of the aggregate product statuses.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemLevelIssues ↔ List<ItemLevelIssue>?
The product issues that affect the given reporting context and country.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
reportingContext ↔ String?
The reporting context of the aggregate product statuses. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stats ↔ Stats?
Products statistics for the given reporting context and country.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited