ItemLevelIssue class

The ItemLevelIssue of the product status.

Constructors

ItemLevelIssue({String? attribute, String? code, String? description, String? detail, String? documentationUri, String? productCount, String? resolution, String? severity})
ItemLevelIssue.fromJson(Map json_)

Properties

attribute ↔ String?
The attribute's name, if the issue is caused by a single attribute.
getter/setter pair
code ↔ String?
The error code of the issue.
getter/setter pair
description ↔ String?
A short issue description in English.
getter/setter pair
detail ↔ String?
A detailed issue description in English.
getter/setter pair
documentationUri ↔ String?
The URL of a web page to help with resolving this issue.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
productCount ↔ String?
The number of products affected by this issue.
getter/setter pair
resolution ↔ String?
Whether the issue can be resolved by the merchant. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
How this issue affects serving of the offer. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited