Reason class

A single reason why the action is not available.

Constructors

Reason({Action? action, String? detail, String? message})
Reason.fromJson(Map json_)

Properties

action ↔ Action?
An action that needs to be performed to solve the problem represented by this reason.
getter/setter pair
detail ↔ String?
Detailed explanation of the reason.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
Messages summarizing the reason, why the action is not available.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited