Stats class

Products statistics.

Constructors

Stats({String? activeCount, String? disapprovedCount, String? expiringCount, String? pendingCount})
Stats.fromJson(Map json_)

Properties

activeCount ↔ String?
The number of products that are active.
getter/setter pair
disapprovedCount ↔ String?
The number of products that are disapproved.
getter/setter pair
expiringCount ↔ String?
The number of products that are expiring.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pendingCount ↔ String?
The number of products that are pending.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited