LfpMerchantState class

The LFP state of a merchant.

Constructors

LfpMerchantState({List<CountrySettings>? countrySettings, InventoryStats? inventoryStats, String? linkedGbps, String? name, List<LfpStoreState>? storeStates})
LfpMerchantState.fromJson(Map json_)

Properties

countrySettings ↔ List<CountrySettings>?
Country-specific settings for the merchant.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inventoryStats ↔ InventoryStats?
The inventory statistics for the merchant.
getter/setter pair
linkedGbps ↔ String?
Number of GBPs this merchant has access to.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeStates ↔ List<LfpStoreState>?
The state per store from the specified merchant.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited