LfpStoreState class

The state of a specific merchant's store.

Constructors

LfpStoreState({String? matchingState, String? matchingStateHint, String? storeCode})
LfpStoreState.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
matchingState ↔ String?
The store matching state.
getter/setter pair
matchingStateHint ↔ String?
The hint of why the matching has failed (only set if matching_state is FAILED).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeCode ↔ String?
The identifier of this store.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited