UserIdentifier class

The user identifiers associated with the customer.

At least one of the fields within this message must be provided.

Constructors

UserIdentifier({AddressInfo? address, String? emailAddress, String? phoneNumber})
UserIdentifier.fromJson(Map json_)

Properties

address AddressInfo?
The customer’s physical address.
getter/setter pair
emailAddress String?
The customer’s email address.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
phoneNumber String?
The customer's phone number, in E.164 format (e.g., "+16502530000").
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited