NotificationSubscription class

Represents a notification subscription owned by a Merchant account.

See [Decode notifications](/merchant/api/guides/accounts/notifications#decode_notifications) for information on how to decode the notification payload and how to interpret its contents.

Constructors

NotificationSubscription({bool? allManagedAccounts, String? callBackUri, String? name, String? registeredEvent, String? targetAccount})
NotificationSubscription.fromJson(Map json_)

Properties

allManagedAccounts ↔ bool?
If this value is true, the requesting account is notified of the specified event for all managed accounts (can be subaccounts or other linked accounts) including newly added accounts on a daily basis.
getter/setter pair
callBackUri ↔ String?
URL to be used to push the notification to the merchant.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the notification configuration.
getter/setter pair
registeredEvent ↔ String?
The event that the merchant wants to be notified about. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetAccount ↔ String?
The name of the account you want to receive notifications for.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited