OrderTrackingSignal class

Represents a business trade from which signals are extracted, such as shipping.

Constructors

OrderTrackingSignal({Price? customerShippingFee, String? deliveryPostalCode, String? deliveryRegionCode, List<LineItemDetails>? lineItems, String? merchantId, DateTime? orderCreatedTime, String? orderId, String? orderTrackingSignalId, List<ShipmentLineItemMapping>? shipmentLineItemMapping, List<ShippingInfo>? shippingInfo})
OrderTrackingSignal.fromJson(Map json_)

Properties

customerShippingFee ↔ Price?
The shipping fee of the order; this value should be set to zero in the case of free shipping.
getter/setter pair
deliveryPostalCode ↔ String?
The delivery postal code, as a continuous string without spaces or dashes, for example "95016".
getter/setter pair
deliveryRegionCode ↔ String?
The CLDR territory code for the shipping destination.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineItems ↔ List<LineItemDetails>?
Information about line items in the order.
getter/setter pair
merchantId ↔ String?
The Google Merchant Center ID of this order tracking signal.
getter/setter pair
orderCreatedTime ↔ DateTime?
The time when the order was created on the businesses side.
getter/setter pair
orderId ↔ String?
The ID of the order on the businesses side.
getter/setter pair
orderTrackingSignalId ↔ String?
The ID that uniquely identifies this order tracking signal.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipmentLineItemMapping ↔ List<ShipmentLineItemMapping>?
The mapping of the line items to the shipment information.
getter/setter pair
shippingInfo ↔ List<ShippingInfo>?
The shipping information for the order.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited