merchantapi/products_v1 library

Merchant API - products_v1

Programmatically manage your Merchant Center Accounts.

For more information, see developers.google.com/merchant/api

Create an instance of MerchantApi to access these resources:

Classes

AccountsProductInputsResource
AccountsProductsResource
AccountsResource
AutomatedDiscounts
Information regarding Automated Discounts.
CarrierShipping
Carrier-based shipping configuration.
CloudExportAdditionalProperties
Product property for the Cloud Retail API.
Co2Emissions
The co2 emission of the vehicle.
CustomAttribute
A message that represents custom attributes.
DestinationStatus
The destination status of the product status.
DisplayAddress
The display address of the property.
EnergyConsumption
The energy consumption of the vehicle.
FreeShippingThreshold
Conditions to be met for a product to have free shipping.
FuelConsumption
The fuel consumption of the vehicle.
HandlingCutoffTime
Configuration for offer or offer-country level shipping handling cutoff time.
ItemLevelIssue
The ItemLevelIssue of the product status.
LeaseTerm
The lease term of the property.
ListProductsResponse
Response message for the ListProducts method.
LoyaltyPoints
A message that represents loyalty points.
LoyaltyProgram
A message that represents loyalty program.
MerchantApi
Programmatically manage your Merchant Center Accounts.
Mileage
The mileage of the vehicle.
PetPolicy
The pet policy of the property.
PickupCost
The pickup cost of the item.
Product
The processed product, built from multiple product inputs after applying rules and supplemental data sources.
ProductAttributes
Product attributes.
ProductCertification
Product certification, initially introduced for EU energy efficiency labeling compliance using the EU EPREL database.
ProductFee
The product fee attribute containing type and amount.
ProductInput
This resource represents input data you submit for a product, not the processed product that you see in Merchant Center, in Shopping ads, or across Google surfaces.
ProductInstallment
A message that represents installment.
ProductMinimumOrderValue
The minimum order value in the cart before the checkout is permitted.
ProductStatus
The status of a product, data validation issues, that is, information about a product computed asynchronously.
ProductSustainabilityIncentive
Information regarding sustainability-related incentive programs such as rebates or tax relief.
QuestionAndAnswer
The question and answer for the product.
RelatedProduct
Specifies how other products are related to this product.
Returns
The returns of the product.
Shipping
The Shipping of the product.
ShippingBusinessDaysConfig
The business days during which orders are on their path to fulfillment.
StructuredDescription
Structured description, for algorithmically (AI)-generated descriptions.
StructuredTitle
Structured title, for algorithmically (AI)-generated titles.
SubscriptionCost
The SubscriptionCost of the product.
UnitArea
The unit area of the property.
VariantOption
Additional product variants for the product.
Warranty
The warranty of the vehicle.

Typedefs

Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Interval = $Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Price = $Price
The price represented as a number and currency.
ProductDetail = $ProductDetail
The product details.
ProductDimension = $ProductDimension
The dimension of the product.
ProductWeight = $ProductWeight
The weight of the product.
ShippingDimension = $ShippingDimension
The ShippingDimension of the product.
ShippingWeight = $ShippingWeight
The ShippingWeight of the product.
UnitPricingBaseMeasure = $UnitPricingBaseMeasure
The UnitPricingBaseMeasure of the product.
UnitPricingMeasure = $UnitPricingMeasure
The UnitPricingMeasure of the product.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.