DestinationStatus class

The destination status of the product status.

Equivalent to StatusPerReportingContext in Reports API.

Constructors

DestinationStatus({List<String>? approvedCountries, List<String>? disapprovedCountries, List<String>? pendingCountries, String? reportingContext})
DestinationStatus.fromJson(Map json_)

Properties

approvedCountries ↔ List<String>?
List of country codes (ISO 3166-1 alpha-2) where the offer is approved.
getter/setter pair
disapprovedCountries ↔ List<String>?
List of country codes (ISO 3166-1 alpha-2) where the offer is disapproved.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pendingCountries ↔ List<String>?
List of country codes (ISO 3166-1 alpha-2) where the offer is pending approval.
getter/setter pair
reportingContext ↔ String?
The name of the reporting context. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited