DisplayAddress class

The display address of the property.

Constructors

DisplayAddress({String? city, String? postalCode, String? region, String? streetName, String? streetNumber})
DisplayAddress.fromJson(Map json_)

Properties

city String?
The city such as Seattle, New York, etc.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
postalCode String?
The postal code, such as 94043.
getter/setter pair
region String?
The region(state), such as WA, OH, etc.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streetName String?
The street name.
getter/setter pair
streetNumber String?
The street number.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited