PickupCost class

The pickup cost of the item.

Constructors

PickupCost({Price? flatRate, Price? freeThreshold})
PickupCost.fromJson(Map json_)

Properties

flatRate Price?
The flat rate pickup cost of the item.
getter/setter pair
freeThreshold Price?
The price threshold above which pickup is free of charge.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited