ProductAttributes class

Product attributes.

Constructors

ProductAttributes({List<String>? additionalImageLinks, String? adsGrouping, List<String>? adsLabels, String? adsRedirect, bool? adult, String? ageGroup, List<String>? amenityFeature, Price? autoPricingMinPrice, String? availability, String? availabilityDate, String? bodyStyle, String? brand, String? canonicalLink, List<CarrierShipping>? carrierShipping, List<ProductCertification>? certifications, bool? certifiedPreOwned, List<CloudExportAdditionalProperties>? cloudExportAdditionalProperties, Co2Emissions? co2Emissions, String? color, String? condition, Price? costOfGoodsSold, String? customLabel0, String? customLabel1, String? customLabel2, String? customLabel3, String? customLabel4, String? dateFirstRegistered, String? description, String? disclosureDate, DisplayAddress? displayAddress, String? displayAdsId, String? displayAdsLink, List<String>? displayAdsSimilarIds, String? displayAdsTitle, double? displayAdsValue, List<String>? documentLinks, Mileage? electricRange, String? emissionsStandard, EnergyConsumption? energyConsumption, String? energyEfficiencyClass, String? engine, List<String>? excludedDestinations, String? expirationDate, String? externalSellerId, List<FreeShippingThreshold>? freeShippingThreshold, FuelConsumption? fuelConsumption, FuelConsumption? fuelConsumptionDischargedBattery, String? gender, String? googleProductCategory, List<String>? gtins, List<HandlingCutoffTime>? handlingCutoffTimes, bool? identifierExists, String? imageLink, List<String>? includedDestinations, ProductInstallment? installment, bool? isBundle, String? itemGroupId, String? itemGroupTitle, double? latitude, LeaseTerm? leaseTerm, List<String>? lifestyleImageLinks, String? link, String? linkTemplate, double? longitude, LoyaltyPoints? loyaltyPoints, List<LoyaltyProgram>? loyaltyPrograms, String? material, String? maxEnergyEfficiencyClass, String? maxHandlingTime, Price? maximumRetailPrice, Mileage? mileage, String? minEnergyEfficiencyClass, String? minHandlingTime, List<ProductMinimumOrderValue>? minimumOrderValues, String? mobileLink, String? mobileLinkTemplate, String? model, String? mpn, String? multipack, String? neighborhood, double? numberOfBathrooms, double? numberOfBedrooms, String? numberOfUnits, String? pattern, String? pause, PetPolicy? petPolicy, PickupCost? pickupCost, String? pickupMethod, String? pickupSla, double? popularityRank, Price? price, List<ProductDetail>? productDetails, List<ProductFee>? productFee, ProductDimension? productHeight, List<String>? productHighlights, ProductDimension? productLength, List<String>? productTypes, ProductWeight? productWeight, ProductDimension? productWidth, List<String>? promotionIds, String? propertyName, String? propertyType, List<QuestionAndAnswer>? questionsAndAnswers, List<RelatedProduct>? relatedProducts, String? returnPolicyLabel, List<Returns>? returns, Price? salePrice, Interval? salePriceEffectiveDate, String? sellOnGoogleQuantity, List<Shipping>? shipping, List<ShippingBusinessDaysConfig>? shippingHandlingBusinessDays, ShippingDimension? shippingHeight, String? shippingLabel, ShippingDimension? shippingLength, List<ShippingBusinessDaysConfig>? shippingTransitBusinessDays, ShippingWeight? shippingWeight, ShippingDimension? shippingWidth, List<String>? shoppingAdsExcludedCountries, String? shortTitle, String? size, String? sizeSystem, List<String>? sizeTypes, String? specialtyHousingType, StructuredDescription? structuredDescription, StructuredTitle? structuredTitle, SubscriptionCost? subscriptionCost, List<ProductSustainabilityIncentive>? sustainabilityIncentives, String? title, String? transitTimeLabel, String? trim, UnitArea? unitArea, UnitPricingBaseMeasure? unitPricingBaseMeasure, UnitPricingMeasure? unitPricingMeasure, List<String>? utilitiesIncluded, List<VariantOption>? variantOptions, Price? vehicleAllInPrice, Price? vehicleExpenses, bool? vehicleMandatoryInspectionIncluded, Price? vehicleMsrp, String? vehiclePriceType, List<String>? videoLinks, String? vin, String? virtualModelLink, Warranty? warranty, String? year})
ProductAttributes.fromJson(Map json_)

Properties

Additional URLs of images of the item.
getter/setter pair
adsGrouping String?
Used to group items in an arbitrary way.
getter/setter pair
adsLabels List<String>?
Similar to ads_grouping, but only works on CPC.
getter/setter pair
adsRedirect String?
Allows advertisers to override the item URL when the product is shown within the context of Product ads.
getter/setter pair
adult bool?
Set to true if the item is targeted towards adults.
getter/setter pair
ageGroup String?
Target age group of the item. Possible string values are:
getter/setter pair
amenityFeature List<String>?
The amenity features for the property.
getter/setter pair
autoPricingMinPrice Price?
A safeguard in the automated discounts and "Dynamic Promotions" (https://support.google.com/merchants/answer/13949249) projects, ensuring that discounts on business offers do not fall below this value, thereby preserving the offer's value and profitability.
getter/setter pair
availability String?
Availability status of the item. Possible string values are:
getter/setter pair
availabilityDate String?
The day a pre-ordered product becomes available for delivery, in ISO 8601 format.
getter/setter pair
bodyStyle String?
The body style of the vehicle. Possible string values are:
getter/setter pair
brand String?
Brand of the item.
getter/setter pair
URL for the canonical version of your item's landing page.
getter/setter pair
carrierShipping List<CarrierShipping>?
Rules for carrier-based shipping.
getter/setter pair
certifications List<ProductCertification>?
Product Certifications, for example for energy efficiency labeling of products recorded in the EU EPREL database.
getter/setter pair
certifiedPreOwned bool?
Whether the vehicle is OEM [certified pre-owned](https://support.google.com/google-ads/answer/14156475).
getter/setter pair
cloudExportAdditionalProperties List<CloudExportAdditionalProperties>?
Extra fields to export to the Cloud Retail program.
getter/setter pair
co2Emissions Co2Emissions?
The co2 emission of the vehicle.
getter/setter pair
color String?
Color of the item.
getter/setter pair
condition String?
Condition or state of the item. Possible string values are:
getter/setter pair
costOfGoodsSold Price?
Cost of goods sold.
getter/setter pair
customLabel0 String?
Custom label 0 for custom grouping of items in a Shopping campaign.
getter/setter pair
customLabel1 String?
Custom label 1 for custom grouping of items in a Shopping campaign.
getter/setter pair
customLabel2 String?
Custom label 2 for custom grouping of items in a Shopping campaign.
getter/setter pair
customLabel3 String?
Custom label 3 for custom grouping of items in a Shopping campaign.
getter/setter pair
customLabel4 String?
Custom label 4 for custom grouping of items in a Shopping campaign.
getter/setter pair
dateFirstRegistered String?
The date the vehicle was first registered.
getter/setter pair
description String?
Description of the item.
getter/setter pair
disclosureDate String?
The date time when an offer becomes visible in search results across Google’s YouTube surfaces, in ISO 8601 format.
getter/setter pair
displayAddress DisplayAddress?
The display address of the property.
getter/setter pair
displayAdsId String?
An identifier for an item for dynamic remarketing campaigns.
getter/setter pair
URL directly to your item's landing page for dynamic remarketing campaigns.
getter/setter pair
displayAdsSimilarIds List<String>?
Advertiser-specified recommendations.
getter/setter pair
displayAdsTitle String?
Title of an item for dynamic remarketing campaigns.
getter/setter pair
displayAdsValue double?
Offer margin for dynamic remarketing campaigns.
getter/setter pair
Contains a list of PDF document URLs for the product.
getter/setter pair
electricRange Mileage?
The electric range of the vehicle in miles/kms.
getter/setter pair
emissionsStandard String?
The emission standard of the vehicle. Possible string values are:
getter/setter pair
energyConsumption EnergyConsumption?
The energy consumption of the vehicle.
getter/setter pair
energyEfficiencyClass String?
The energy efficiency class as defined in EU directive 2010/30/EU. Possible string values are:
getter/setter pair
engine String?
The engine type of the vehicle. Possible string values are:
getter/setter pair
excludedDestinations List<String>?
The list of destinations to exclude for this target (corresponds to unchecked check boxes in Merchant Center).
getter/setter pair
expirationDate String?
Date on which the item should expire, as specified upon insertion, in ISO 8601 format.
getter/setter pair
externalSellerId String?
Required for multi-seller accounts.
getter/setter pair
freeShippingThreshold List<FreeShippingThreshold>?
Conditions to be met for a product to have free shipping.
getter/setter pair
fuelConsumption FuelConsumption?
The fuel consumption of the vehicle.
getter/setter pair
fuelConsumptionDischargedBattery FuelConsumption?
The fuel consumption of the vehicle when the hybrid battery is discharged.
getter/setter pair
gender String?
Target gender of the item. Possible string values are:
getter/setter pair
googleProductCategory String?
Google's category of the item (see Google product taxonomy).
getter/setter pair
gtins List<String>?
Global Trade Item Numbers (GTIN) of the item.
getter/setter pair
handlingCutoffTimes List<HandlingCutoffTime>?
The handling cutoff times for shipping.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
identifierExists bool?
Set this value to false when the item does not have unique product identifiers appropriate to its category, such as GTIN, MPN, and brand.
getter/setter pair
URL of an image of the item.
getter/setter pair
includedDestinations List<String>?
The list of destinations to include for this target (corresponds to checked check boxes in Merchant Center).
getter/setter pair
installment ProductInstallment?
Number and amount of installments to pay for an item.
getter/setter pair
isBundle bool?
Whether the item is a business-defined sub-API.
getter/setter pair
itemGroupId String?
Shared identifier for all variants of the same product.
getter/setter pair
itemGroupTitle String?
Represents the title of the product group to which this variant product belongs.
getter/setter pair
latitude double?
The latitude of the property.
getter/setter pair
leaseTerm LeaseTerm?
The lease term of the property.
getter/setter pair
Additional URLs of lifestyle images of the item, used to explicitly identify images that showcase your item in a real-world context.
getter/setter pair
URL directly linking to your item's page on your online store.
getter/setter pair
linkTemplate String?
Link template for business hosted local storefront.
getter/setter pair
longitude double?
The longitude of the property.
getter/setter pair
loyaltyPoints LoyaltyPoints?
Loyalty points that users receive after purchasing the item.
getter/setter pair
loyaltyPrograms List<LoyaltyProgram>?
A list of loyalty program information that is used to surface loyalty benefits (for example, better pricing, points, etc) to the user of this item.
getter/setter pair
material String?
The material of which the item is made.
getter/setter pair
maxEnergyEfficiencyClass String?
The energy efficiency class as defined in EU directive 2010/30/EU. Possible string values are:
getter/setter pair
maxHandlingTime String?
Maximal product handling time (in business days).
getter/setter pair
maximumRetailPrice Price?
Maximum retail price (MRP) of the item.
getter/setter pair
mileage Mileage?
The number of miles/kms on the vehicle.
getter/setter pair
minEnergyEfficiencyClass String?
The energy efficiency class as defined in EU directive 2010/30/EU. Possible string values are:
getter/setter pair
minHandlingTime String?
Minimal product handling time (in business days).
getter/setter pair
minimumOrderValues List<ProductMinimumOrderValue>?
The minimum value in the cart before a customer can initiate checkout.
getter/setter pair
URL for the mobile-optimized version of your item's landing page.
getter/setter pair
mobileLinkTemplate String?
Link template for business hosted local storefront optimized for mobile devices.
getter/setter pair
model String?
The Model of the vehicle, such as LX, EX, and others.
getter/setter pair
mpn String?
Manufacturer Part Number (MPN) of the item.
getter/setter pair
multipack String?
The number of identical products in a business-defined multipack.
getter/setter pair
neighborhood String?
The neighborhood (locality) of the property, such as Wallingford, Greenwood, etc.
getter/setter pair
numberOfBathrooms double?
The number of bathrooms in the property.
getter/setter pair
numberOfBedrooms double?
The number of bedrooms in the property.
getter/setter pair
numberOfUnits String?
The number of units available for a specific floor plan of the property.
getter/setter pair
pattern String?
The item's pattern.
getter/setter pair
pause String?
Publication of this item will be temporarily paused. Possible string values are:
getter/setter pair
petPolicy PetPolicy?
The pet policy for the property.
getter/setter pair
pickupCost PickupCost?
The pickup cost for an item when a customer buys it online and picks it up at a store.
getter/setter pair
pickupMethod String?
The pickup option for the item. Possible string values are:
getter/setter pair
pickupSla String?
Item store pickup timeline.
getter/setter pair
popularityRank double?
Indicates the popularity of the product in a merchant's inventory.
getter/setter pair
price Price?
Price of the item.
getter/setter pair
productDetails List<ProductDetail>?
Technical specification or additional product details.
getter/setter pair
productFee List<ProductFee>?
The product fee for the property.
getter/setter pair
productHeight ProductDimension?
The height of the product in the units provided.
getter/setter pair
productHighlights List<String>?
Bullet points describing the most relevant product highlights.
getter/setter pair
productLength ProductDimension?
The length of the product in the units provided.
getter/setter pair
productTypes List<String>?
Categories of the item (formatted as in product data specification).
getter/setter pair
productWeight ProductWeight?
The weight of the product in the units provided.
getter/setter pair
productWidth ProductDimension?
The width of the product in the units provided.
getter/setter pair
promotionIds List<String>?
The unique ID of a promotion.
getter/setter pair
propertyName String?
The name of the property.
getter/setter pair
propertyType String?
The type of property. Possible string values are:
getter/setter pair
questionsAndAnswers List<QuestionAndAnswer>?
Contains user-, merchant-, and manufacturer-authored questions and answers about the product.
getter/setter pair
relatedProducts List<RelatedProduct>?
Specifies how other products are related to this product.
getter/setter pair
returnPolicyLabel String?
The return label of the product, used to group products in account-level return policies.
getter/setter pair
returns List<Returns>?
Return rules for the product.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salePrice Price?
Advertised sale price of the item.
getter/setter pair
salePriceEffectiveDate Interval?
Date range during which the item is on sale, see product data specification.
getter/setter pair
sellOnGoogleQuantity String?
The quantity of the product that is available for selling on Google.
getter/setter pair
shipping List<Shipping>?
Shipping rules.
getter/setter pair
shippingHandlingBusinessDays List<ShippingBusinessDaysConfig>?
The business days during which orders can be handled.
getter/setter pair
shippingHeight ShippingDimension?
Height of the item for shipping.
getter/setter pair
shippingLabel String?
The shipping label of the product, used to group products in account-level shipping rules.
getter/setter pair
shippingLength ShippingDimension?
Length of the item for shipping.
getter/setter pair
shippingTransitBusinessDays List<ShippingBusinessDaysConfig>?
The business days during which orders are in transit.
getter/setter pair
shippingWeight ShippingWeight?
Weight of the item for shipping.
getter/setter pair
shippingWidth ShippingDimension?
Width of the item for shipping.
getter/setter pair
shoppingAdsExcludedCountries List<String>?
List of country codes [(ISO 3166-1 alpha-2)](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2) to exclude the offer from Shopping Ads destination.
getter/setter pair
shortTitle String?
The short title of the item.
getter/setter pair
size String?
Size of the item.
getter/setter pair
sizeSystem String?
System in which the size is specified.
getter/setter pair
sizeTypes List<String>?
The cut of the item.
getter/setter pair
specialtyHousingType String?
The specialty housing type for the property. Possible string values are:
getter/setter pair
structuredDescription StructuredDescription?
Structured description, for algorithmically (AI)-generated descriptions.
getter/setter pair
structuredTitle StructuredTitle?
Structured title, for algorithmically (AI)-generated titles.
getter/setter pair
subscriptionCost SubscriptionCost?
Number of periods (weeks, months or years) and amount of payment per period for an item with an associated subscription contract.
getter/setter pair
sustainabilityIncentives List<ProductSustainabilityIncentive>?
The list of sustainability incentive programs.
getter/setter pair
title String?
Title of the item.
getter/setter pair
transitTimeLabel String?
The transit time label of the product, used to group product in account-level transit time tables.
getter/setter pair
trim String?
The Trim of the vehicle model, such as S, SV, SL and others.
getter/setter pair
unitArea UnitArea?
The unit area of the property, such as 1000 sqft.
getter/setter pair
unitPricingBaseMeasure UnitPricingBaseMeasure?
The preference of the denominator of the unit price.
getter/setter pair
unitPricingMeasure UnitPricingMeasure?
The measure and dimension of an item.
getter/setter pair
utilitiesIncluded List<String>?
The utilities included for the property.
getter/setter pair
variantOptions List<VariantOption>?
Contains the [list of all variant-identifying options](https://support.google.com/merchants/answer/17085214) of this product.
getter/setter pair
vehicleAllInPrice Price?
The all-in advertised price for a vehicle, which includes costs for the following – any accessories attached to the vehicle, environmental levies, extra warranty, fuel, freight, pre-delivery inspection (PDI), dealer fees for handling licensing, provincial regulatory fees, miscellaneous dealer charges for security etching and nitrogen tire fill, and factory-to-customer or dealer-to-customer discounts or incentives.
getter/setter pair
vehicleExpenses Price?
The miscellaneous expenses like insurance and registration fees of the vehicle.
getter/setter pair
vehicleMandatoryInspectionIncluded bool?
Whether the vehicle is sold with mandatory inspection and maintenance performed before delivery.
getter/setter pair
vehicleMsrp Price?
The MSRP (Manufacturer Suggested Retail Price) for the vehicle in its current configuration.
getter/setter pair
vehiclePriceType String?
The price type of the vehicle. Possible string values are:
getter/setter pair
A list of video URLs for the item.
getter/setter pair
vin String?
The [Vehicle Identification Number (VIN)](https://support.google.com/google-ads/answer/14154510) of the vehicle.
getter/setter pair
URL of the 3D image of the item.
getter/setter pair
warranty Warranty?
The warranty of the vehicle.
getter/setter pair
year String?
The Year of the vehicle model.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited