minimumOrderValues property

List<ProductMinimumOrderValue>? minimumOrderValues
getter/setter pair

The minimum value in the cart before a customer can initiate checkout.

Supports multiple minimum order values. Different minimum order values can be specified per country, service and surface. Maximum entries: 100.

Implementation

core.List<ProductMinimumOrderValue>? minimumOrderValues;