popularityRank property
Indicates the popularity of the product in a merchant's inventory.
Using a scale of 0.0 (lowest) to 100.0 (highest).
Optional.
Implementation
core.double? popularityRank;
Indicates the popularity of the product in a merchant's inventory.
Using a scale of 0.0 (lowest) to 100.0 (highest).
Optional.
core.double? popularityRank;