ProductFee class

The product fee attribute containing type and amount.

Constructors

ProductFee({Price? amount, String? type})
ProductFee.fromJson(Map json_)

Properties

amount Price?
The amount of product fee.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of product fee. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited