base64EncodedName property

String? base64EncodedName
getter/setter pair

The unpadded base64url encoded name of the product input.

Format: accounts/{account}/productInputs/{productinput} where the last section productinput is the unpadded base64url encoding of the content_language~feed_label~offer_id name. Example: accounts/123/productInputs/ZW5-VVN-c2t1LzEyMw for the decoded product input name accounts/123/productInputs/en~US~sku/123. This field can be used directly as input to the API methods that require the product input name to be encoded if it contains special characters, for example [GetProductInput](https://developers.google.com/merchant/api/reference/rest/products_v1/accounts.productInputs/get).

Output only.

Implementation

core.String? base64EncodedName;