base64EncodedProduct property

String? base64EncodedProduct
getter/setter pair

The unpadded base64url encoded name of the processed product.

Format: accounts/{account}/products/{product} where the last section product is the unpadded base64url encoding of the content_language~feed_label~offer_id name. Example: accounts/123/products/ZW5-VVN-c2t1LzEyMw for the decoded product name accounts/123/products/en~US~sku/123. This field can be used directly as input to the API methods that require the product name to be encoded if it contains special characters, for example [GetProduct](https://developers.google.com/merchant/api/reference/rest/products_v1/accounts.products/get).

Output only.

Implementation

core.String? base64EncodedProduct;