QuestionAndAnswer class

The question and answer for the product.

Constructors

QuestionAndAnswer({String? answer, String? question})
QuestionAndAnswer.fromJson(Map json_)

Properties

answer String?
The answer text.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
question String?
The question text.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited