RelatedProduct class

Specifies how other products are related to this product.

Constructors

RelatedProduct({String? id, String? idType, String? relationshipType})
RelatedProduct.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
The identifier of the related product.
getter/setter pair
idType String?
The type of the identifier of the related product.
getter/setter pair
relationshipType String?
The type of the relationship between this product and the related product.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited