Attributes class

Attributes.

Constructors

Attributes({String? audience, List<String>? brandExclusion, List<String>? brandInclusion, String? couponValueType, String? customRedemptionRestriction, String? eventApplicability, String? freeGiftDescription, String? freeGiftItemId, Price? freeGiftValue, String? genericRedemptionCode, String? getThisQuantityDiscounted, List<String>? googleProductCategories, List<String>? itemGroupIdExclusion, List<String>? itemGroupIdInclusion, List<String>? itemIdExclusion, List<String>? itemIdInclusion, String? limitQuantity, Price? limitValue, String? longTitle, Price? maxDiscountAmount, Price? maxMoneyOffAmount, String? maxPercentOff, Price? minMoneyOffAmount, String? minPercentOff, Price? minimumPurchaseAmount, String? minimumPurchaseQuantity, Price? moneyOffAmount, String? offerType, String? percentOff, String? productApplicability, List<String>? productTypeExclusion, List<String>? productTypeInclusion, List<String>? promotionDestinations, Interval? promotionDisplayTimePeriod, Interval? promotionEffectiveTimePeriod, String? promotionUrl, String? redemptionRestriction, List<String>? regionIdInclusion, String? storeApplicability, List<String>? storeCodesExclusion, List<String>? storeCodesInclusion})
Attributes.fromJson(Map json_)

Properties

audience ↔ String?
This field defines the audience a promotion will be visible to.
getter/setter pair
brandExclusion ↔ List<String>?
Product filter by brand exclusion for the promotion.
getter/setter pair
brandInclusion ↔ List<String>?
Product filter by brand for the promotion.
getter/setter pair
couponValueType ↔ String?
The coupon value type attribute to signal the type of promotion that you are running.
getter/setter pair
customRedemptionRestriction ↔ String?
The custom redemption restriction for the promotion.
getter/setter pair
eventApplicability ↔ String?
Event applicability for this promotion.
getter/setter pair
freeGiftDescription ↔ String?
Free gift description for the promotion.
getter/setter pair
freeGiftItemId ↔ String?
Free gift item ID for the promotion.
getter/setter pair
freeGiftValue ↔ Price?
Free gift value for the promotion.
getter/setter pair
genericRedemptionCode ↔ String?
Generic redemption code for the promotion.
getter/setter pair
getThisQuantityDiscounted ↔ String?
The number of items discounted in the promotion.
getter/setter pair
googleProductCategories ↔ List<String>?
A list of Google product categories for this promotion.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemGroupIdExclusion ↔ List<String>?
Product filter by item group ID.
getter/setter pair
itemGroupIdInclusion ↔ List<String>?
Product filter by item group ID for the promotion.
getter/setter pair
itemIdExclusion ↔ List<String>?
Product filter by item ID exclusion for the promotion.
getter/setter pair
itemIdInclusion ↔ List<String>?
Product filter by item ID for the promotion.
getter/setter pair
limitQuantity ↔ String?
Maximum purchase quantity for the promotion.
getter/setter pair
limitValue ↔ Price?
Maximum product price for promotion.
getter/setter pair
longTitle ↔ String?
Long title for the promotion.
getter/setter pair
maxDiscountAmount ↔ Price?
The maximum monetary discount a customer can receive for the promotion.
getter/setter pair
maxMoneyOffAmount ↔ Price?
Maximum money off amount for a promotion with MONEY_OFF_RANGE coupon value type.
getter/setter pair
maxPercentOff ↔ String?
Maximum percent off for a promotion with PERCENT_OFF_RANGE coupon value type.
getter/setter pair
minimumPurchaseAmount ↔ Price?
Minimum purchase amount for the promotion.
getter/setter pair
minimumPurchaseQuantity ↔ String?
getter/setter pair
minMoneyOffAmount ↔ Price?
Minimum money off amount for a promotion with MONEY_OFF_RANGE coupon value type.
getter/setter pair
minPercentOff ↔ String?
Minimum percent off for a promotion with PERCENT_OFF_RANGE coupon value type.
getter/setter pair
moneyOffAmount ↔ Price?
The money off amount offered in the promotion.
getter/setter pair
offerType ↔ String?
Type of the promotion.
getter/setter pair
percentOff ↔ String?
The percentage discount offered in the promotion.
getter/setter pair
productApplicability ↔ String?
Applicability of the promotion to either all products or only specific products.
getter/setter pair
productTypeExclusion ↔ List<String>?
Product filter by product type exclusion for the promotion.
getter/setter pair
productTypeInclusion ↔ List<String>?
Product filter by product type for the promotion.
getter/setter pair
promotionDestinations ↔ List<String>?
The list of destinations (also known as Marketing methods) where the promotion applies to.
getter/setter pair
promotionDisplayTimePeriod ↔ Interval?
TimePeriod representation of the promotion's display dates.
getter/setter pair
promotionEffectiveTimePeriod ↔ Interval?
TimePeriod representation of the promotion's effective dates.
getter/setter pair
promotionUrl ↔ String?
URL to the page on the merchant's site where the promotion shows.
getter/setter pair
redemptionRestriction ↔ String?
A restriction customers must meet before they can redeem the promotion.
getter/setter pair
regionIdInclusion ↔ List<String>?
A list of regions where the promotion is applicable.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeApplicability ↔ String?
Whether the promotion applies to all stores, or only specified stores.
getter/setter pair
storeCodesExclusion ↔ List<String>?
Store codes to exclude for the promotion.
getter/setter pair
storeCodesInclusion ↔ List<String>?
Store codes to include for the promotion.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited