maxMoneyOffAmount property

Price? maxMoneyOffAmount
getter/setter pair

Maximum money off amount for a promotion with MONEY_OFF_RANGE coupon value type.

At least one of min_money_off_amount or max_money_off_amount must be present when the coupon value type is MONEY_OFF_RANGE. If neither is provided an INVALID_PROMOTION_MISSING_BENEFIT_OR_RESTRICTION error is returned.

Optional.

Implementation

Price? maxMoneyOffAmount;