DestinationStatus class

The status for the specified destination.

Constructors

DestinationStatus({String? reportingContext, String? status})
DestinationStatus.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
reportingContext ↔ String?
The name of the promotion destination.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status for the specified destination.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited