CompetitiveVisibilityBenchmarkView class

Fields available for query in competitive_visibility_benchmark_view table.

Competitive visibility report with the category benchmark. Values are only set for fields requested explicitly in the request's search query.

Constructors

CompetitiveVisibilityBenchmarkView({double? categoryBenchmarkVisibilityTrend, Date? date, String? reportCategoryId, String? reportCountryCode, String? trafficSource, double? yourDomainVisibilityTrend})
CompetitiveVisibilityBenchmarkView.fromJson(Map json_)

Properties

categoryBenchmarkVisibilityTrend ↔ double?
Change in visibility based on impressions with respect to the start of the selected time range (or first day with non-zero impressions) for a combined set of merchants with highest visibility approximating the market.
getter/setter pair
date ↔ Date?
Date of this row.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reportCategoryId ↔ String?
Google product category ID to calculate the report for, represented in Google's product taxonomy.
getter/setter pair
reportCountryCode ↔ String?
Country where impressions appeared.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficSource ↔ String?
Traffic source of impressions.
getter/setter pair
yourDomainVisibilityTrend ↔ double?
Change in visibility based on impressions for your domain with respect to the start of the selected time range (or first day with non-zero impressions).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited