ItemIssueSeverity class

How the issue affects the serving of the product.

Constructors

ItemIssueSeverity({String? aggregatedSeverity, List<IssueSeverityPerReportingContext>? severityPerReportingContext})
ItemIssueSeverity.fromJson(Map json_)

Properties

aggregatedSeverity ↔ String?
Aggregated severity of the issue for all reporting contexts it affects.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityPerReportingContext ↔ List<IssueSeverityPerReportingContext>?
Issue severity per reporting context.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited