ProductPerformanceView class

Fields available for query in product_performance_view table.

Product performance data for your account, including performance metrics (for example, clicks) and dimensions according to which performance metrics are segmented (for example, offer_id). Values of product dimensions, such as offer_id, reflect the state of a product at the time of the impression. Segment fields cannot be selected in queries without also selecting at least one metric field. Values are only set for fields requested explicitly in the request's search query.

Constructors

ProductPerformanceView({String? brand, String? categoryL1, String? categoryL2, String? categoryL3, String? categoryL4, String? categoryL5, double? clickThroughRate, String? clicks, double? conversionRate, Price? conversionValue, double? conversions, String? customLabel0, String? customLabel1, String? customLabel2, String? customLabel3, String? customLabel4, String? customerCountryCode, Date? date, String? impressions, String? marketingMethod, String? offerId, String? productTypeL1, String? productTypeL2, String? productTypeL3, String? productTypeL4, String? productTypeL5, String? storeType, String? title, Date? week})
ProductPerformanceView.fromJson(Map json_)

Properties

brand ↔ String?
Brand of the product.
getter/setter pair
categoryL1 ↔ String?
[Product category (1st level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
categoryL2 ↔ String?
[Product category (2nd level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
categoryL3 ↔ String?
[Product category (3rd level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
categoryL4 ↔ String?
[Product category (4th level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
categoryL5 ↔ String?
[Product category (5th level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in Google's product taxonomy.
getter/setter pair
clicks ↔ String?
Number of clicks.
getter/setter pair
clickThroughRate ↔ double?
Click-through rate - the number of clicks merchant's products receive (clicks) divided by the number of times the products are shown (impressions).
getter/setter pair
conversionRate ↔ double?
Number of conversions divided by the number of clicks, reported on the impression date.
getter/setter pair
conversions ↔ double?
Number of conversions attributed to the product, reported on the conversion date.
getter/setter pair
conversionValue ↔ Price?
Value of conversions attributed to the product, reported on the conversion date.
getter/setter pair
customerCountryCode ↔ String?
Code of the country where the customer is located at the time of the event.
getter/setter pair
customLabel0 ↔ String?
Custom label 0 for custom grouping of products.
getter/setter pair
customLabel1 ↔ String?
Custom label 1 for custom grouping of products.
getter/setter pair
customLabel2 ↔ String?
Custom label 2 for custom grouping of products.
getter/setter pair
customLabel3 ↔ String?
Custom label 3 for custom grouping of products.
getter/setter pair
customLabel4 ↔ String?
Custom label 4 for custom grouping of products.
getter/setter pair
date ↔ Date?
Date in the Merchant Center account timezone to which metrics apply.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
impressions ↔ String?
Number of times merchant's products are shown.
getter/setter pair
marketingMethod ↔ String?
Marketing method to which metrics apply.
getter/setter pair
offerId ↔ String?
Merchant-provided id of the product.
getter/setter pair
productTypeL1 ↔ String?
[Product type (1st level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
productTypeL2 ↔ String?
[Product type (2nd level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
productTypeL3 ↔ String?
[Product type (3rd level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
productTypeL4 ↔ String?
[Product type (4th level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
productTypeL5 ↔ String?
[Product type (5th level)](https://developers.google.com/shopping-content/guides/reports/segmentation#category_and_product_type) in merchant's own product taxonomy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeType ↔ String?
Store type to which metrics apply.
getter/setter pair
title ↔ String?
Title of the product.
getter/setter pair
week ↔ Date?
First day of the week (Monday) of the metrics date in the Merchant Center account timezone.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited