ProductView class

Fields available for query in product_view table.

Products in the current inventory. Products in this table are the same as in Products sub-API but not all product attributes from Products sub-API are available for query in this table. In contrast to Products sub-API, this table allows to filter the returned list of products by product attributes. To retrieve a single product by id or list all products, Products sub-API should be used. Values are only set for fields requested explicitly in the request's search query.

Constructors

ProductView({String? aggregatedReportingContextStatus, String? availability, String? brand, String? categoryL1, String? categoryL2, String? categoryL3, String? categoryL4, String? categoryL5, String? channel, String? clickPotential, String? clickPotentialRank, String? condition, String? creationTime, Date? expirationDate, String? feedLabel, List<String>? gtin, String? id, String? itemGroupId, List<ItemIssue>? itemIssues, String? languageCode, String? offerId, Price? price, String? productTypeL1, String? productTypeL2, String? productTypeL3, String? productTypeL4, String? productTypeL5, String? shippingLabel, String? thumbnailLink, String? title})
ProductView.fromJson(Map json_)

Properties

aggregatedReportingContextStatus ↔ String?
Aggregated status. Possible string values are:
getter/setter pair
availability ↔ String?
Availability of the product.
getter/setter pair
brand ↔ String?
Brand of the product.
getter/setter pair
categoryL1 ↔ String?
Product category (1st level) in Google's product taxonomy.
getter/setter pair
categoryL2 ↔ String?
Product category (2nd level) in Google's product taxonomy.
getter/setter pair
categoryL3 ↔ String?
Product category (3rd level) in Google's product taxonomy.
getter/setter pair
categoryL4 ↔ String?
Product category (4th level) in Google's product taxonomy.
getter/setter pair
categoryL5 ↔ String?
Product category (5th level) in Google's product taxonomy.
getter/setter pair
channel ↔ String?
Channel of the product.
getter/setter pair
clickPotential ↔ String?
Estimated performance potential compared to highest performing products of the merchant. Possible string values are:
getter/setter pair
clickPotentialRank ↔ String?
Normalized click potential of the product.
getter/setter pair
condition ↔ String?
Condition of the product.
getter/setter pair
creationTime ↔ String?
The time the merchant created the product in timestamp seconds.
getter/setter pair
expirationDate ↔ Date?
Expiration date for the product, specified on insertion.
getter/setter pair
feedLabel ↔ String?
Feed label of the product.
getter/setter pair
gtin ↔ List<String>?
List of Global Trade Item Numbers (GTINs) of the product.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
REST ID of the product, in the form of channel~languageCode~feedLabel~offerId.
getter/setter pair
itemGroupId ↔ String?
Item group id provided by the merchant for grouping variants together.
getter/setter pair
itemIssues ↔ List<ItemIssue>?
List of item issues for the product.
getter/setter pair
languageCode ↔ String?
Language code of the product in BCP 47 format.
getter/setter pair
offerId ↔ String?
Merchant-provided id of the product.
getter/setter pair
price ↔ Price?
Product price.
getter/setter pair
productTypeL1 ↔ String?
Product type (1st level) in merchant's own product taxonomy.
getter/setter pair
productTypeL2 ↔ String?
Product type (2nd level) in merchant's own product taxonomy.
getter/setter pair
productTypeL3 ↔ String?
Product type (3rd level) in merchant's own product taxonomy.
getter/setter pair
productTypeL4 ↔ String?
Product type (4th level) in merchant's own product taxonomy.
getter/setter pair
productTypeL5 ↔ String?
Product type (5th level) in merchant's own product taxonomy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shippingLabel ↔ String?
Normalized shipping label specified in the data source.
getter/setter pair
Link to the processed image of the product, hosted on the Google infrastructure.
getter/setter pair
title ↔ String?
Title of the product.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited