reportingContext property

String? reportingContext
getter/setter pair

Reporting context to restrict the query to.

Restricts the reporting contexts returned in status_per_reporting_context and item_issues, and used to compute aggregated_reporting_context_status. This field can only be used in the WHERE clause and cannot be selected in the SELECT clause. Possible string values are:

Implementation

core.String? reportingContext;