statusPerReportingContext property

List<StatusPerReportingContext>? statusPerReportingContext
getter/setter pair

Detailed product status per reporting context.

Reporting contexts included in this list can be restricted using a filter on the reporting_context field. Equivalent to ProductStatus.destination_statuses in Products API. This field cannot be used for sorting or filtering the results.

Implementation

core.List<StatusPerReportingContext>? statusPerReportingContext;