query property

String? query
getter/setter pair

Query that defines a report to be retrieved.

For details on how to construct your query, see the [Query Language guide](/merchant/api/guides/reports/query-language). For the full list of available tables and fields, see the Available fields.

Required.

Implementation

core.String? query;