AutoscalingConfig class

Represents the autoscaling configuration of a metastore service.

Constructors

AutoscalingConfig({bool? autoscalingEnabled, double? autoscalingFactor, LimitConfig? limitConfig})
AutoscalingConfig.fromJson(Map json_)

Properties

autoscalingEnabled ↔ bool?
Whether or not autoscaling is enabled for this service.
getter/setter pair
autoscalingFactor ↔ double?
The scaling factor of a service with autoscaling enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limitConfig ↔ LimitConfig?
The LimitConfig of the service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited