Backup class

The details of a backup resource.

Constructors

Backup({String? createTime, String? description, String? endTime, String? name, List<String>? restoringServices, Service? serviceRevision, String? state})
Backup.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the backup was started.
getter/setter pair
description ↔ String?
The description of the backup.
getter/setter pair
endTime ↔ String?
The time when the backup finished creating.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
restoringServices ↔ List<String>?
Services that are restoring from the backup.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceRevision ↔ Service?
The revision of the service at the time of backup.
getter/setter pair
state ↔ String?
The current state of the backup.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited