CdcConfig class

Configuration information to start the Change Data Capture (CDC) streams from customer database to backend database of Dataproc Metastore.

Constructors

CdcConfig({String? bucket, String? password, String? reverseProxySubnet, String? rootPath, String? subnetIpRange, String? username, String? vpcNetwork})
CdcConfig.fromJson(Map json_)

Properties

bucket ↔ String?
The bucket to write the intermediate stream event data in.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
password ↔ String?
Input only.
getter/setter pair
reverseProxySubnet ↔ String?
The URL of the subnetwork resource to create the VM instance hosting the reverse proxy in.
getter/setter pair
rootPath ↔ String?
The root path inside the Cloud Storage bucket.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetIpRange ↔ String?
A /29 CIDR IP range for peering with datastream.
getter/setter pair
username ↔ String?
The username that the Datastream service should use for the MySQL connection.
getter/setter pair
vpcNetwork ↔ String?
Fully qualified name of the Cloud SQL instance's VPC network or the shared VPC network that Datastream will peer to, in the following format: projects/{project_id}/locations/global/networks/{network_id}.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited