Consumer class

Contains information of the customer's network configurations.

Constructors

Consumer({String? endpointLocation, String? endpointUri, String? subnetwork})
Consumer.fromJson(Map json_)

Properties

endpointLocation ↔ String?
The location of the endpoint URI.
getter/setter pair
endpointUri ↔ String?
The URI of the endpoint used to access the metastore service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetwork ↔ String?
The subnetwork of the customer project from which an IP address is reserved and used as the Dataproc Metastore service's endpoint.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited