DataCatalogConfig class

Specifies how metastore metadata should be integrated with the Data Catalog service.

Constructors

DataCatalogConfig({bool? enabled})
DataCatalogConfig.fromJson(Map json_)

Properties

enabled ↔ bool?
Defines whether the metastore metadata should be synced to Data Catalog.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited