EncryptionConfig class

Encryption settings for the service.

Constructors

EncryptionConfig({String? kmsKey})
EncryptionConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKey ↔ String?
The fully qualified customer provided Cloud KMS key name to use for customer data encryption, in the following format:projects/{project_number}/locations/{location_id}/keyRings/{key_ring_id}/cryptoKeys/{crypto_key_id}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited