LatestBackup class

The details of the latest scheduled backup.

Constructors

LatestBackup({String? backupId, String? duration, String? startTime, String? state})
LatestBackup.fromJson(Map json_)

Properties

backupId ↔ String?
The ID of an in-progress scheduled backup.
getter/setter pair
duration ↔ String?
The duration of the backup completion.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time when the backup was started.
getter/setter pair
state ↔ String?
The current state of the backup.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited