MetadataExport class

The details of a metadata export operation.

Constructors

MetadataExport({String? databaseDumpType, String? destinationGcsUri, String? endTime, String? startTime, String? state})
MetadataExport.fromJson(Map json_)

Properties

databaseDumpType ↔ String?
The type of the database dump.
getter/setter pair
destinationGcsUri ↔ String?
A Cloud Storage URI of a folder that metadata are exported to, in the form of gs:////, where is automatically generated.
getter/setter pair
endTime ↔ String?
The time when the export ended.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time when the export started.
getter/setter pair
state ↔ String?
The current state of the export.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited