MetadataImport class

A metastore resource that imports metadata.

Constructors

MetadataImport({String? createTime, DatabaseDump? databaseDump, String? description, String? endTime, String? name, String? state, String? updateTime})
MetadataImport.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the metadata import was started.
getter/setter pair
databaseDump ↔ DatabaseDump?
A database dump from a pre-existing metastore's database.
getter/setter pair
description ↔ String?
The description of the metadata import.
getter/setter pair
endTime ↔ String?
The time when the metadata import finished.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of the metadata import.
getter/setter pair
updateTime ↔ String?
The time when the metadata import was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited