MetadataIntegration class

Specifies how metastore metadata should be integrated with external services.

Constructors

MetadataIntegration({DataCatalogConfig? dataCatalogConfig})
MetadataIntegration.fromJson(Map json_)

Properties

dataCatalogConfig ↔ DataCatalogConfig?
The integration config for the Data Catalog service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited