phase property
- @Deprecated('Not supported. Member documentation may have more information.')
getter/setter pair
Deprecated: Phase was designed for incoming migrations to Dataproc Metastore, not applicable when migrating away from it.
The current phase of the migration execution.
Output only. Possible string values are:
- "PHASE_UNSPECIFIED" : The phase of the migration execution is unknown.
- "REPLICATION" : Replication phase refers to the migration phase when Dataproc Metastore is running a pipeline to replicate changes in the customer database to its backend database. During this phase, Dataproc Metastore uses the customer database as the hive metastore backend database.
- "CUTOVER" : Cutover phase refers to the migration phase when Dataproc Metastore switches to using its own backend database. Migration enters this phase when customer is done migrating all their clusters/workloads to Dataproc Metastore and triggers CompleteMigration.
Implementation
@core.Deprecated(
'Not supported. Member documentation may have more information.',
)
core.String? phase;