ScalingConfig class

Represents the scaling configuration of a metastore service.

Constructors

ScalingConfig({AutoscalingConfig? autoscalingConfig, String? instanceSize, double? scalingFactor})
ScalingConfig.fromJson(Map json_)

Properties

autoscalingConfig ↔ AutoscalingConfig?
The autoscaling configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceSize ↔ String?
An enum of readable instance sizes, with each instance size mapping to a float value (e.g. InstanceSize.EXTRA_SMALL = scaling_factor(0.1)) Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalingFactor ↔ double?
Scaling factor, increments of 0.1 for values less than 1.0, and increments of 1.0 for values greater than 1.0.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited