Service class

A managed metastore service that serves metadata queries.

Constructors

Service({String? artifactGcsUri, String? createTime, String? databaseType, bool? deletionProtection, EncryptionConfig? encryptionConfig, String? endpointUri, HiveMetastoreConfig? hiveMetastoreConfig, Map<String, String>? labels, MaintenanceWindow? maintenanceWindow, MetadataIntegration? metadataIntegration, MetadataManagementActivity? metadataManagementActivity, String? name, String? network, NetworkConfig? networkConfig, int? port, String? releaseChannel, ScalingConfig? scalingConfig, ScheduledBackup? scheduledBackup, String? state, String? stateMessage, Map<String, String>? tags, TelemetryConfig? telemetryConfig, String? tier, String? uid, String? updateTime})
Service.fromJson(Map json_)

Properties

artifactGcsUri ↔ String?
A Cloud Storage URI (starting with gs://) that specifies where artifacts related to the metastore service are stored.
getter/setter pair
createTime ↔ String?
The time when the metastore service was created.
getter/setter pair
databaseType ↔ String?
The database type that the Metastore service stores its data.
getter/setter pair
deletionProtection ↔ bool?
Indicates if the dataproc metastore should be protected against accidental deletions.
getter/setter pair
encryptionConfig ↔ EncryptionConfig?
Information used to configure the Dataproc Metastore service to encrypt customer data at rest.
getter/setter pair
endpointUri ↔ String?
The URI of the endpoint used to access the metastore service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hiveMetastoreConfig ↔ HiveMetastoreConfig?
Configuration information specific to running Hive metastore software as the metastore service.
getter/setter pair
labels ↔ Map<String, String>?
User-defined labels for the metastore service.
getter/setter pair
maintenanceWindow ↔ MaintenanceWindow?
The one hour maintenance window of the metastore service.
getter/setter pair
metadataIntegration ↔ MetadataIntegration?
The setting that defines how metastore metadata should be integrated with external services and systems.
getter/setter pair
metadataManagementActivity ↔ MetadataManagementActivity?
The metadata management activities of the metastore service.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
network ↔ String?
The relative resource name of the VPC network on which the instance can be accessed.
getter/setter pair
networkConfig ↔ NetworkConfig?
The configuration specifying the network settings for the Dataproc Metastore service.
getter/setter pair
port ↔ int?
The TCP port at which the metastore service is reached.
getter/setter pair
releaseChannel ↔ String?
The release channel of the service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scalingConfig ↔ ScalingConfig?
Scaling configuration of the metastore service.
getter/setter pair
scheduledBackup ↔ ScheduledBackup?
The configuration of scheduled backup for the metastore service.
getter/setter pair
state ↔ String?
The current state of the metastore service.
getter/setter pair
stateMessage ↔ String?
Additional information about the current state of the metastore service, if available.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
telemetryConfig ↔ TelemetryConfig?
The configuration specifying telemetry settings for the Dataproc Metastore service.
getter/setter pair
tier ↔ String?
The tier of the service.
getter/setter pair
uid ↔ String?
The globally unique resource identifier of the metastore service.
getter/setter pair
updateTime ↔ String?
The time when the metastore service was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited