AddAssetsToGroupRequest class

A request to add assets to a group.

Constructors

AddAssetsToGroupRequest({bool? allowExisting, AssetList? assets, String? requestId})
AddAssetsToGroupRequest.fromJson(Map json_)

Properties

allowExisting ↔ bool?
When this value is set to false and one of the given assets is already an existing member of the group, the operation fails with an Already Exists error.
getter/setter pair
assets ↔ AssetList?
List of assets to be added.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
An optional request ID to identify requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited