AggregateAssetsValuesRequest class

A request to aggregate one or more values.

Constructors

AggregateAssetsValuesRequest({List<Aggregation>? aggregations, String? filter, bool? showHidden})
AggregateAssetsValuesRequest.fromJson(Map json_)

Properties

aggregations ↔ List<Aggregation>?
Array of aggregations to perform.
getter/setter pair
filter ↔ String?
The aggregation will be performed on assets that match the provided filter.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showHidden ↔ bool?
When this value is set to 'true' the response will include all assets, including those that are hidden.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited