Aggregation class

Message describing an aggregation.

The message includes the aggregation type, parameters, and the field on which to perform the aggregation.

Constructors

Aggregation({AggregationCount? count, String? field, AggregationFrequency? frequency, AggregationHistogram? histogram, AggregationSum? sum})
Aggregation.fromJson(Map json_)

Properties

count ↔ AggregationCount?
Count the number of matching objects.
getter/setter pair
field ↔ String?
The name of the field on which to aggregate.
getter/setter pair
frequency ↔ AggregationCount?
Creates a frequency distribution of all field values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
histogram ↔ AggregationHistogram?
Creates a bucketed histogram of field values.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sum ↔ AggregationCount?
Sum over a numeric field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited