Asset class

An asset represents a resource in your environment.

Asset types include virtual machines and databases.

Constructors

Asset({List<String>? assignedGroups, Map<String, String>? attributes, String? createTime, DatabaseDeploymentDetails? databaseDeploymentDetails, DatabaseDetails? databaseDetails, bool? hidden, String? hideReason, String? hideTime, InsightList? insightList, Map<String, String>? labels, MachineDetails? machineDetails, String? name, AssetPerformanceData? performanceData, List<String>? sources, String? title, String? updateTime})
Asset.fromJson(Map json_)

Properties

assignedGroups ↔ List<String>?
The list of groups that the asset is assigned to.
getter/setter pair
attributes ↔ Map<String, String>?
Generic asset attributes.
getter/setter pair
createTime ↔ String?
The timestamp when the asset was created.
getter/setter pair
databaseDeploymentDetails ↔ DatabaseDeploymentDetails?
Asset information specific for database deployments.
getter/setter pair
databaseDetails ↔ DatabaseDetails?
Asset information specific for logical databases.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hidden ↔ bool?
Indicates if the asset is hidden.
getter/setter pair
hideReason ↔ String?
An optional reason for marking this asset as hidden.
getter/setter pair
hideTime ↔ String?
The timestamp when the asset was marked as hidden.
getter/setter pair
insightList ↔ InsightList?
The list of insights associated with the asset.
getter/setter pair
labels ↔ Map<String, String>?
Labels as key value pairs.
getter/setter pair
machineDetails ↔ MachineDetails?
Asset information specific for virtual and physical machines.
getter/setter pair
name ↔ String?
The full name of the asset.
getter/setter pair
performanceData ↔ AssetPerformanceData?
Performance data for the asset.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources ↔ List<String>?
The list of sources contributing to the asset.
getter/setter pair
title ↔ String?
Server generated human readable name of the asset.
getter/setter pair
updateTime ↔ String?
The timestamp when the asset was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited