AssetPerformanceData class

Performance data for an asset.

Constructors

AssetPerformanceData({List<DailyResourceUsageAggregation>? dailyResourceUsageAggregations})
AssetPerformanceData.fromJson(Map json_)

Properties

dailyResourceUsageAggregations ↔ List<DailyResourceUsageAggregation>?
Daily resource usage aggregations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited