BatchDeleteAssetsRequest class

A request to delete a list of asset.

Constructors

BatchDeleteAssetsRequest({bool? allowMissing, List<CascadingRule>? cascadingRules, List<String>? names})
BatchDeleteAssetsRequest.fromJson(Map json_)

Properties

allowMissing ↔ bool?
When this value is set to true the request is a no-op for non-existing assets.
getter/setter pair
cascadingRules ↔ List<CascadingRule>?
Optional cascading rules for deleting related assets.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
names ↔ List<String>?
The IDs of the assets to delete.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited