ComputeEnginePreferences class

The user preferences relating to Compute Engine target platform.

Constructors

ComputeEnginePreferences({String? licenseType, MachinePreferences? machinePreferences, String? persistentDiskType})
ComputeEnginePreferences.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
licenseType ↔ String?
License type to consider when calculating costs for virtual machine insights and recommendations.
getter/setter pair
machinePreferences ↔ MachinePreferences?
Preferences concerning the machine types to consider on Compute Engine.
getter/setter pair
persistentDiskType ↔ String?
Persistent disk type to use.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited