ComputeEngineShapeDescriptor class

Compute Engine target shape descriptor.

Constructors

ComputeEngineShapeDescriptor({int? logicalCoreCount, String? machineType, int? memoryMb, int? physicalCoreCount, String? series, List<ComputeStorageDescriptor>? storage})
ComputeEngineShapeDescriptor.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logicalCoreCount ↔ int?
Number of logical cores.
getter/setter pair
machineType ↔ String?
Compute Engine machine type.
getter/setter pair
memoryMb ↔ int?
Memory in mebibytes.
getter/setter pair
physicalCoreCount ↔ int?
Number of physical cores.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
series ↔ String?
Compute Engine machine series.
getter/setter pair
storage ↔ List<ComputeStorageDescriptor>?
Compute Engine storage.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited