DailyResourceUsageAggregation class

Usage data aggregation for a single day.

Properties

cpu ↔ DailyResourceUsageAggregationCPU?
CPU usage.
getter/setter pair
date ↔ Date?
Aggregation date.
getter/setter pair
disk ↔ DailyResourceUsageAggregationDisk?
Disk usage.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memory ↔ DailyResourceUsageAggregationMemory?
Memory usage.
getter/setter pair
network ↔ DailyResourceUsageAggregationNetwork?
Network usage.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited