DailyResourceUsageAggregationStats class

Statistical aggregation of samples for a single resource usage.

Constructors

DailyResourceUsageAggregationStats({double? average, double? median, double? ninteyFifthPercentile, double? peak})
DailyResourceUsageAggregationStats.fromJson(Map json_)

Properties

average ↔ double?
Average usage value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
median ↔ double?
Median usage value.
getter/setter pair
ninteyFifthPercentile ↔ double?
95th percentile usage value.
getter/setter pair
peak ↔ double?
Peak usage value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited