DatabaseDeploymentDetails class

The details of a database deployment asset.

Constructors

DatabaseDeploymentDetails({DatabaseDeploymentDetailsAggregatedStats? aggregatedStats, AwsRds? awsRds, String? edition, String? generatedId, String? manualUniqueId, MysqlDatabaseDeployment? mysql, PostgreSqlDatabaseDeployment? postgresql, SqlServerDatabaseDeployment? sqlServer, DatabaseDeploymentTopology? topology, String? version})
DatabaseDeploymentDetails.fromJson(Map json_)

Properties

aggregatedStats ↔ DatabaseDeploymentDetailsAggregatedStats?
Aggregated stats for the database deployment.
getter/setter pair
awsRds ↔ AggregationCount?
Details of an AWS RDS instance.
getter/setter pair
edition ↔ String?
The database deployment edition.
getter/setter pair
generatedId ↔ String?
The database deployment generated ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manualUniqueId ↔ String?
A manual unique ID set by the user.
getter/setter pair
mysql ↔ MysqlDatabaseDeployment?
Details of a MYSQL database deployment.
getter/setter pair
postgresql ↔ PostgreSqlDatabaseDeployment?
Details of a PostgreSQL database deployment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sqlServer ↔ SqlServerDatabaseDeployment?
Details of a Microsoft SQL Server database deployment.
getter/setter pair
topology ↔ DatabaseDeploymentTopology?
Details of the database deployment topology.
getter/setter pair
version ↔ String?
The database deployment version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited