DatabaseDetails class

Details of a logical database.

Constructors

DatabaseDetails({String? allocatedStorageBytes, String? databaseName, DatabaseDetailsParentDatabaseDeployment? parentDatabaseDeployment, List<DatabaseSchema>? schemas})
DatabaseDetails.fromJson(Map json_)

Properties

allocatedStorageBytes ↔ String?
The allocated storage for the database in bytes.
getter/setter pair
databaseName ↔ String?
The name of the database.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
parentDatabaseDeployment ↔ DatabaseDetailsParentDatabaseDeployment?
The parent database deployment that contains the logical database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemas ↔ List<DatabaseSchema>?
The database schemas.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited