DatabaseDetailsParentDatabaseDeployment class

The identifiers of the parent database deployment.

Properties

generatedId ↔ String?
The parent database deployment generated ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manualUniqueId ↔ String?
The parent database deployment optional manual unique ID set by the user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited