DatabaseObjects class

Details of a group of database objects.

Constructors

DatabaseObjects({String? category, String? count})
DatabaseObjects.fromJson(Map json_)

Properties

category ↔ String?
The category of the objects.
getter/setter pair
count ↔ String?
The number of objects.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited