DatabaseSchema class

Details of a database schema.

Constructors

DatabaseSchema({MySqlSchemaDetails? mysql, List<DatabaseObjects>? objects, PostgreSqlSchemaDetails? postgresql, String? schemaName, SqlServerSchemaDetails? sqlServer, String? tablesSizeBytes})
DatabaseSchema.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mysql ↔ MySqlSchemaDetails?
Details of a Mysql schema.
getter/setter pair
objects ↔ List<DatabaseObjects>?
List of details of objects by category.
getter/setter pair
postgresql ↔ PostgreSqlSchemaDetails?
Details of a PostgreSql schema.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaName ↔ String?
The name of the schema.
getter/setter pair
sqlServer ↔ SqlServerSchemaDetails?
Details of a SqlServer schema.
getter/setter pair
tablesSizeBytes ↔ String?
The total size of tables in bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited