DiskUsageSample class

Disk usage sample.

Values are across all disks.

Constructors

DiskUsageSample({double? averageIops, double? averageReadIops, double? averageWriteIops})
DiskUsageSample.fromJson(Map json_)

Properties

averageIops ↔ double?
Average IOPS sampled over a short window.
getter/setter pair
averageReadIops ↔ double?
Average read IOPS sampled over a short window.
getter/setter pair
averageWriteIops ↔ double?
Average write IOPS sampled over a short window.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited