ExecutionReport class

A resource that reports result of the import job execution.

Constructors

ExecutionReport({ValidationReport? executionErrors, int? framesReported, int? totalRowsCount})
ExecutionReport.fromJson(Map json_)

Properties

executionErrors ↔ ValidationReport?
Validation errors encountered during the execution of the import job.
getter/setter pair
framesReported ↔ int?
Total number of asset frames reported for the import job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalRowsCount ↔ int?
Total number of rows in the import job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited