FileValidationReport class

A resource that aggregates the validation errors found in an import job file.

Constructors

FileValidationReport({List<ImportError>? fileErrors, String? fileName, bool? partialReport, List<ImportRowError>? rowErrors})
FileValidationReport.fromJson(Map json_)

Properties

fileErrors ↔ List<ImportError>?
List of file level errors.
getter/setter pair
fileName ↔ String?
The name of the file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partialReport ↔ bool?
Flag indicating that processing was aborted due to maximum number of errors.
getter/setter pair
rowErrors ↔ List<ImportRowError>?
Partial list of rows that encountered validation error.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited