FitDescriptor class

Describes the fit level of an asset for migration to a specific target.

Constructors

FitDescriptor({String? fitLevel})
FitDescriptor.fromJson(Map json_)

Properties

fitLevel ↔ String?
Fit level.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited