FstabEntry class

Single fstab entry.

Constructors

FstabEntry({String? file, int? freq, String? mntops, int? passno, String? spec, String? vfstype})
FstabEntry.fromJson(Map json_)

Properties

file ↔ String?
The mount point for the filesystem.
getter/setter pair
freq ↔ int?
Used by dump to determine which filesystems need to be dumped.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mntops ↔ String?
Mount options associated with the filesystem.
getter/setter pair
passno ↔ int?
Used by the fsck(8) program to determine the order in which filesystem checks are done at reboot time.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ String?
The block special device or remote filesystem to be mounted.
getter/setter pair
vfstype ↔ String?
The type of the filesystem.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited