GenericPlatformDetails class

Generic platform details.

Constructors

GenericPlatformDetails({String? hyperthreading, String? location})
GenericPlatformDetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hyperthreading ↔ String?
Whether the machine is hyperthreaded. Possible string values are:
getter/setter pair
location ↔ String?
Free text representation of the machine location.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited