ImportDataFile class

A resource that represents a payload file in an import job.

Constructors

ImportDataFile({String? createTime, String? displayName, String? format, String? name, String? state, UploadFileInfo? uploadFileInfo})
ImportDataFile.fromJson(Map json_)

Properties

createTime ↔ String?
The timestamp when the file was created.
getter/setter pair
displayName ↔ String?
User-friendly display name.
getter/setter pair
format ↔ String?
The payload format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the import data file.
getter/setter pair
uploadFileInfo ↔ UploadFileInfo?
Information about a file that is uploaded to a storage service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited