ImportError class

A resource that reports the errors encountered while processing an import job.

Constructors

ImportError({String? errorDetails, String? severity})
ImportError.fromJson(Map json_)

Properties

errorDetails ↔ String?
The error information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of the error. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited