MachineDetails class

Details of a machine.

Constructors

MachineDetails({MachineArchitectureDetails? architecture, int? coreCount, String? createTime, DiskPartitionDetails? diskPartitions, MachineDiskDetails? disks, GuestOsDetails? guestOs, String? machineName, int? memoryMb, MachineNetworkDetails? network, PlatformDetails? platform, String? powerState, String? uuid})
MachineDetails.fromJson(Map json_)

Properties

architecture ↔ MachineArchitectureDetails?
Architecture details (vendor, CPU architecture).
getter/setter pair
coreCount ↔ int?
Number of logical CPU cores in the machine.
getter/setter pair
createTime ↔ String?
Machine creation time.
getter/setter pair
diskPartitions ↔ DiskPartitionDetails?
Disk partitions details.
getter/setter pair
disks ↔ MachineDiskDetails?
Disk details.
getter/setter pair
guestOs ↔ GuestOsDetails?
Guest OS information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
machineName ↔ String?
Machine name.
getter/setter pair
memoryMb ↔ int?
The amount of memory in the machine.
getter/setter pair
network ↔ MachineNetworkDetails?
Network details.
getter/setter pair
platform ↔ PlatformDetails?
Platform specific information.
getter/setter pair
powerState ↔ String?
Power state of the machine. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid ↔ String?
Machine unique identifier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited