MachineNetworkDetails class

Details of network adapters and settings.

Constructors

MachineNetworkDetails({NetworkAdapterList? adapters, String? defaultGateway, String? primaryIpAddress, String? primaryMacAddress, String? publicIpAddress})
MachineNetworkDetails.fromJson(Map json_)

Properties

adapters ↔ NetworkAdapterList?
List of network adapters.
getter/setter pair
defaultGateway ↔ String?
Default gateway address.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
primaryIpAddress ↔ String?
The primary IP address of the machine.
getter/setter pair
primaryMacAddress ↔ String?
MAC address of the machine.
getter/setter pair
publicIpAddress ↔ String?
The public IP address of the machine.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited