MachinePreferences class

The type of machines to consider when calculating virtual machine migration insights and recommendations.

Not all machine types are available in all zones and regions.

Constructors

MachinePreferences({List<MachineSeries>? allowedMachineSeries})
MachinePreferences.fromJson(Map json_)

Properties

allowedMachineSeries ↔ List<MachineSeries>?
Compute Engine machine series to consider for insights and recommendations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited