MysqlDatabaseDeployment class

Specific details for a Mysql database deployment.

Constructors

MysqlDatabaseDeployment({List<MySqlPlugin>? plugins, List<MySqlProperty>? properties, int? resourceGroupsCount, List<MySqlVariable>? variables})
MysqlDatabaseDeployment.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
plugins ↔ List<MySqlPlugin>?
List of MySql plugins.
getter/setter pair
properties ↔ List<MySqlProperty>?
List of MySql properties.
getter/setter pair
resourceGroupsCount ↔ int?
Number of resource groups.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variables ↔ List<MySqlVariable>?
List of MySql variables.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited