NetworkAdapterDetails class

Details of network adapter.

Constructors

NetworkAdapterDetails({String? adapterType, NetworkAddressList? addresses, String? macAddress})
NetworkAdapterDetails.fromJson(Map json_)

Properties

adapterType ↔ String?
Network adapter type (e.g. VMXNET3).
getter/setter pair
addresses ↔ NetworkAddressList?
NetworkAddressList
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
macAddress ↔ String?
MAC address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited