NetworkAddress class

Details of network address.

Constructors

NetworkAddress({String? assignment, String? bcast, String? fqdn, String? ipAddress, String? subnetMask})
NetworkAddress.fromJson(Map json_)

Properties

assignment ↔ String?
Whether DHCP is used to assign addresses. Possible string values are:
getter/setter pair
bcast ↔ String?
Broadcast address.
getter/setter pair
fqdn ↔ String?
Fully qualified domain name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String?
Assigned or configured IP Address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetMask ↔ String?
Subnet mask.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited