NetworkConnection class

Constructors

NetworkConnection({String? localIpAddress, int? localPort, String? pid, String? processName, String? protocol, String? remoteIpAddress, int? remotePort, String? state})
NetworkConnection.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
localIpAddress ↔ String?
Local IP address.
getter/setter pair
localPort ↔ int?
Local port.
getter/setter pair
pid ↔ String?
Process ID.
getter/setter pair
processName ↔ String?
Process or service name.
getter/setter pair
protocol ↔ String?
Connection protocol (e.g. TCP/UDP).
getter/setter pair
remoteIpAddress ↔ String?
Remote IP address.
getter/setter pair
remotePort ↔ int?
Remote port.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Network connection state. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited