OpenFileDetails class

Open file Information.

Constructors

OpenFileDetails({String? command, String? filePath, String? fileType, String? user})
OpenFileDetails.fromJson(Map json_)

Properties

command ↔ String?
Opened file command.
getter/setter pair
filePath ↔ String?
Opened file file path.
getter/setter pair
fileType ↔ String?
Opened file file type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user ↔ String?
Opened file user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited