OutputFile class

Contains a single output file.

Constructors

OutputFile({CsvOutputFile? csvOutputFile, String? fileSizeBytes, XlsxOutputFile? xlsxOutputFile})
OutputFile.fromJson(Map json_)

Properties

csvOutputFile ↔ CsvOutputFile?
CSV output file.
getter/setter pair
fileSizeBytes ↔ String?
File size in bytes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xlsxOutputFile ↔ XlsxOutputFile?
XLSX output file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited