PostgreSqlSetting class

PostgreSql setting.

Constructors

PostgreSqlSetting({bool? boolValue, String? intValue, double? realValue, String? setting, String? source, String? stringValue, String? unit})
PostgreSqlSetting.fromJson(Map json_)

Properties

boolValue ↔ bool?
The setting boolean value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
intValue ↔ String?
The setting int value.
getter/setter pair
realValue ↔ double?
The setting real value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setting ↔ String?
The setting name.
getter/setter pair
source ↔ String?
The setting source.
getter/setter pair
stringValue ↔ String?
The setting string value.
getter/setter pair
unit ↔ String?
The setting unit.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited