ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

assets → ProjectsLocationsAssetsResource
no setter
discoveryClients → ProjectsLocationsDiscoveryClientsResource
no setter
groups → ProjectsLocationsGroupsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
importJobs → ProjectsLocationsImportJobsResource
no setter
operations → ProjectsLocationsOperationsResource
no setter
preferenceSets → ProjectsLocationsPreferenceSetsResource
no setter
relations → ProjectsLocationsRelationsResource
no setter
reportConfigs → ProjectsLocationsReportConfigsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources → ProjectsLocationsSourcesResource
no setter

Methods

get(String name, {String? $fields}) → Future<Location>
Gets information about a location.
getSettings(String name, {String? $fields}) → Future<Settings>
Gets the details of regional settings.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateSettings(Settings request, String name, {String? requestId, String? updateMask, String? $fields}) → Future<Operation>
Updates the regional-level project settings.

Operators

operator ==(Object other) → bool
The equality operator.
inherited