Relation class

Message representing a relation between 2 resource.

Constructors

Relation({String? createTime, String? dstAsset, String? name, String? srcAsset, String? type})
Relation.fromJson(Map json_)

Properties

createTime ↔ String?
The timestamp when the relation was created.
getter/setter pair
dstAsset ↔ String?
The destination asset name in the relation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcAsset ↔ String?
The source asset name in the relation.
getter/setter pair
type ↔ String?
The type of the relation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited