Report class

Report represents a point-in-time rendering of the ReportConfig results.

Constructors

Report({String? createTime, String? description, String? displayName, String? name, String? state, ReportSummary? summary, String? type, String? updateTime})
Report.fromJson(Map json_)

Properties

createTime ↔ String?
Creation timestamp.
getter/setter pair
description ↔ String?
Free-text description.
getter/setter pair
displayName ↔ String?
User-friendly display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Report creation state. Possible string values are:
getter/setter pair
summary ↔ ReportSummary?
Summary view of the Report.
getter/setter pair
type ↔ String?
Report type. Possible string values are:
getter/setter pair
updateTime ↔ String?
Last update timestamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited