ReportConfig class

The groups and associated preference sets on which we can generate reports.

Constructors

ReportConfig({String? createTime, String? description, String? displayName, List<ReportConfigGroupPreferenceSetAssignment>? groupPreferencesetAssignments, String? name, String? updateTime})
ReportConfig.fromJson(Map json_)

Properties

createTime ↔ String?
The timestamp when the resource was created.
getter/setter pair
description ↔ String?
Free-text description.
getter/setter pair
displayName ↔ String?
User-friendly display name.
getter/setter pair
groupPreferencesetAssignments ↔ List<ReportConfigGroupPreferenceSetAssignment>?
Collection of combinations of groups and preference sets.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The timestamp when the resource was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited