ReportConfigGroupPreferenceSetAssignment class

Represents a combination of a group with a preference set.

Properties

group ↔ String?
Name of the group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
preferenceSet ↔ String?
Name of the Preference Set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited