ReportSummaryAssetAggregateStats class

Aggregate statistics for a collection of assets.

Constructors

ReportSummaryAssetAggregateStats({ReportSummaryHistogramChartData? coreCountHistogram, ReportSummaryHistogramChartData? memoryBytesHistogram, ReportSummaryUtilizationChartData? memoryUtilizationChart, ReportSummaryChartData? operatingSystem, ReportSummaryChartData? softwareInstances, ReportSummaryHistogramChartData? storageBytesHistogram, ReportSummaryUtilizationChartData? storageUtilizationChart, String? totalAssets, String? totalCores, String? totalMemoryBytes, String? totalStorageBytes})
ReportSummaryAssetAggregateStats.fromJson(Map json_)

Properties

coreCountHistogram ↔ ReportSummaryHistogramChartData?
Histogram showing a distribution of logical CPU core counts.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memoryBytesHistogram ↔ ReportSummaryHistogramChartData?
Histogram showing a distribution of memory sizes.
getter/setter pair
memoryUtilizationChart ↔ ReportSummaryUtilizationChartData?
Total memory split into Used/Free buckets.
getter/setter pair
operatingSystem ↔ ReportSummaryChartData?
Count of assets grouped by Operating System families.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softwareInstances ↔ ReportSummaryChartData?
Count of assets grouped by software name.
getter/setter pair
storageBytesHistogram ↔ ReportSummaryHistogramChartData?
Histogram showing a distribution of storage sizes.
getter/setter pair
storageUtilizationChart ↔ ReportSummaryUtilizationChartData?
Total memory split into Used/Free buckets.
getter/setter pair
totalAssets ↔ String?
Count of the number of unique assets in this collection.
getter/setter pair
totalCores ↔ String?
Sum of the CPU core count of all the assets in this collection.
getter/setter pair
totalMemoryBytes ↔ String?
Sum of the memory in bytes of all the assets in this collection.
getter/setter pair
totalStorageBytes ↔ String?
Sum of persistent storage in bytes of all the assets in this collection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited