ReportSummaryChartData class

Describes a collection of data points rendered as a Chart.

Properties

dataPoints ↔ List<ReportSummaryChartDataDataPoint>?
Each data point in the chart is represented as a name-value pair with the name being the x-axis label, and the value being the y-axis value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited