ReportSummaryGroupPreferenceSetFinding class

Summary Findings for a specific Group/PreferenceSet combination.

Constructors

ReportSummaryGroupPreferenceSetFinding({ReportSummaryComputeEngineFinding? computeEngineFinding, String? description, String? displayName, VirtualMachinePreferences? machinePreferences, Money? monthlyCostCompute, Money? monthlyCostNetworkEgress, Money? monthlyCostOsLicense, Money? monthlyCostOther, Money? monthlyCostStorage, Money? monthlyCostTotal, ReportSummarySoleTenantFinding? soleTenantFinding, ReportSummaryVmwareEngineFinding? vmwareEngineFinding})
ReportSummaryGroupPreferenceSetFinding.fromJson(Map json_)

Properties

computeEngineFinding ↔ ReportSummaryComputeEngineFinding?
A set of findings that applies to Compute Engine machines in the input.
getter/setter pair
description ↔ String?
Description for the Preference Set.
getter/setter pair
displayName ↔ String?
Display Name of the Preference Set
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
machinePreferences ↔ VirtualMachinePreferences?
A set of preferences that applies to all machines in the context.
getter/setter pair
monthlyCostCompute ↔ Money?
Compute monthly cost for this preference set.
getter/setter pair
monthlyCostNetworkEgress ↔ Money?
Network Egress monthly cost for this preference set.
getter/setter pair
monthlyCostOsLicense ↔ Money?
Licensing monthly cost for this preference set.
getter/setter pair
monthlyCostOther ↔ Money?
Miscellaneous monthly cost for this preference set.
getter/setter pair
monthlyCostStorage ↔ Money?
Storage monthly cost for this preference set.
getter/setter pair
monthlyCostTotal ↔ Money?
Total monthly cost for this preference set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
soleTenantFinding ↔ ReportSummarySoleTenantFinding?
A set of findings that applies to Sole-Tenant machines in the input.
getter/setter pair
vmwareEngineFinding ↔ ReportSummaryVmwareEngineFinding?
A set of findings that applies to VMWare machines in the input.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited