ReportSummaryHistogramChartData class

A Histogram Chart shows a distribution of values into buckets, showing a count of values which fall into a bucket.

Properties

buckets ↔ List<ReportSummaryHistogramChartDataBucket>?
Buckets in the histogram.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited