ReportSummaryMachineSeriesAllocation class

Represents a data point tracking the count of assets allocated for a specific Machine Series.

Properties

allocatedAssetCount ↔ String?
Count of assets allocated to this machine series.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
machineSeries ↔ MachineSeries?
The Machine Series (e.g. "E2", "N2")
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited