ReportSummaryUtilizationChartData class

Utilization Chart is a specific type of visualization which displays a metric classified into "Used" and "Free" buckets.

Properties

free ↔ String?
Aggregate value which falls into the "Free" bucket.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
used ↔ String?
Aggregate value which falls into the "Used" bucket.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited