RunningProcess class

Guest OS running process details.

Constructors

RunningProcess({Map<String, String>? attributes, String? cmdline, String? exePath, String? pid, String? user})
RunningProcess.fromJson(Map json_)

Properties

attributes ↔ Map<String, String>?
Process extended attributes.
getter/setter pair
cmdline ↔ String?
Process full command line.
getter/setter pair
exePath ↔ String?
Process binary path.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pid ↔ String?
Process ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user ↔ String?
User running the process.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited