RuntimeNetworkInfo class

Runtime networking information.

Constructors

RuntimeNetworkInfo({NetworkConnectionList? connections, String? scanTime})
RuntimeNetworkInfo.fromJson(Map json_)

Properties

connections ↔ NetworkConnectionList?
Network connections.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanTime ↔ String?
Time of the last network scan.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited