Source class

Source represents an object from which asset information is streamed to Migration Center.

Constructors

Source({String? createTime, String? description, String? displayName, int? errorFrameCount, bool? managed, String? name, int? pendingFrameCount, int? priority, String? state, String? type, String? updateTime})
Source.fromJson(Map json_)

Properties

createTime ↔ String?
The timestamp when the source was created.
getter/setter pair
description ↔ String?
Free-text description.
getter/setter pair
displayName ↔ String?
User-friendly display name.
getter/setter pair
errorFrameCount ↔ int?
The number of frames that were reported by the source and contained errors.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
managed ↔ bool?
If true, the source is managed by other service(s).
getter/setter pair
name ↔ String?
The full name of the source.
getter/setter pair
pendingFrameCount ↔ int?
Number of frames that are still being processed.
getter/setter pair
priority ↔ int?
The information confidence of the source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the source.
getter/setter pair
type ↔ String?
Data source type. Possible string values are:
getter/setter pair
updateTime ↔ String?
The timestamp when the source was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited