SqlServerDatabaseDeployment class

Specific details for a Microsoft SQL Server database deployment.

Properties

features ↔ List<SqlServerFeature>?
List of SQL Server features.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverFlags ↔ List<SqlServerServerFlag>?
List of SQL Server server flags.
getter/setter pair
traceFlags ↔ List<SqlServerTraceFlag>?
List of SQL Server trace flags.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited