SqlServerFeature class

SQL Server feature details.

Constructors

SqlServerFeature({bool? enabled, String? featureName})
SqlServerFeature.fromJson(Map json_)

Properties

enabled ↔ bool?
Field enabled is set when a feature is used on the source deployment.
getter/setter pair
featureName ↔ String?
The feature name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited