SqlServerServerFlag class

SQL Server server flag details.

Constructors

SqlServerServerFlag({String? serverFlagName, String? value, String? valueInUse})
SqlServerServerFlag.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverFlagName ↔ String?
The server flag name.
getter/setter pair
value ↔ String?
The server flag value set by the user.
getter/setter pair
valueInUse ↔ String?
The server flag actual value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited