UpdateAssetRequest class

A request to update an asset.

Constructors

UpdateAssetRequest({Asset? asset, String? requestId, String? updateMask})
UpdateAssetRequest.fromJson(Map json_)

Properties

asset ↔ Asset?
The resource being updated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
An optional request ID to identify requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask ↔ String?
Field mask is used to specify the fields to be overwritten in the Asset resource by the update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited