ValidationReport class

A resource that aggregates errors across import job files.

Constructors

ValidationReport({List<FileValidationReport>? fileValidations, List<ImportError>? jobErrors})
ValidationReport.fromJson(Map json_)

Properties

fileValidations ↔ List<FileValidationReport>?
List of errors found in files.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobErrors ↔ List<ImportError>?
List of job level errors.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited