VmwareDiskConfig class

VMware disk config details.

Constructors

VmwareDiskConfig({String? backingType, String? rdmCompatibility, bool? shared, String? vmdkMode})
VmwareDiskConfig.fromJson(Map json_)

Properties

backingType ↔ String?
VMDK backing type. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rdmCompatibility ↔ String?
RDM compatibility mode. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shared ↔ bool?
Is VMDK shared with other VMs.
getter/setter pair
vmdkMode ↔ String?
VMDK disk mode. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited