GoogleCloudMlV1BuiltInAlgorithmOutput class

Represents output related to a built-in algorithm Job.

Constructors

GoogleCloudMlV1BuiltInAlgorithmOutput({String? framework, String? modelPath, String? pythonVersion, String? runtimeVersion})
GoogleCloudMlV1BuiltInAlgorithmOutput.fromJson(Map json_)

Properties

framework ↔ String?
Framework on which the built-in algorithm was trained.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
modelPath ↔ String?
The Cloud Storage path to the model/ directory where the training job saves the trained model.
getter/setter pair
pythonVersion ↔ String?
Python version on which the built-in algorithm was trained.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeVersion ↔ String?
AI Platform runtime version on which the built-in algorithm was trained.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited