ProjectsResource class

Constructors

ProjectsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
jobs → ProjectsJobsResource
no setter
locations → ProjectsLocationsResource
no setter
models → ProjectsModelsResource
no setter
operations → ProjectsOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

explain(GoogleCloudMlV1ExplainRequest request, String name, {String? $fields}) → Future<GoogleApiHttpBody>
Performs explanation on the data in the request.
getConfig(String name, {String? $fields}) → Future<GoogleCloudMlV1GetConfigResponse>
Get the service account information associated with your project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
predict(GoogleCloudMlV1PredictRequest request, String name, {String? $fields}) → Future<GoogleApiHttpBody>
Performs online prediction on the data in the request.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited