AlertPolicy class

A description of the conditions under which some aspect of your system is considered to be "unhealthy" and the ways to notify people or services about this state.

For an overview of alerting policies, see Introduction to Alerting (https://cloud.google.com/monitoring/alerts/).

Constructors

AlertPolicy({AlertStrategy? alertStrategy, String? combiner, List<Condition>? conditions, MutationRecord? creationRecord, String? displayName, Documentation? documentation, bool? enabled, MutationRecord? mutationRecord, String? name, List<String>? notificationChannels, String? severity, Map<String, String>? userLabels, Status? validity})
AlertPolicy.fromJson(Map json_)

Properties

alertStrategy ↔ AlertStrategy?
Control over how this alerting policy's notification channels are notified.
getter/setter pair
combiner ↔ String?
How to combine the results of multiple conditions to determine if an incident should be opened.
getter/setter pair
conditions ↔ List<Condition>?
A list of conditions for the policy.
getter/setter pair
creationRecord ↔ MutationRecord?
A read-only record of the creation of the alerting policy.
getter/setter pair
displayName ↔ String?
A short name or phrase used to identify the policy in dashboards, notifications, and incidents.
getter/setter pair
documentation ↔ Documentation?
Documentation that is included with notifications and incidents related to this policy.
getter/setter pair
enabled ↔ bool?
Whether or not the policy is enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mutationRecord ↔ MutationRecord?
A read-only record of the most recent change to the alerting policy.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
notificationChannels ↔ List<String>?
Identifies the notification channels to which notifications should be sent when incidents are opened or closed or when new violations occur on an already opened incident.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of an alerting policy indicates how important incidents generated by that policy are.
getter/setter pair
userLabels ↔ Map<String, String>?
User-supplied key/value data to be used for organizing and identifying the AlertPolicy objects.The field can contain up to 64 entries.
getter/setter pair
validity ↔ Status?
Read-only description of how the alerting policy is invalid.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited