BooleanTest class

A test that uses an alerting result in a boolean column produced by the SQL query.

Constructors

BooleanTest({String? column})
BooleanTest.fromJson(Map json_)

Properties

column ↔ String?
The name of the column containing the boolean value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited