CloudRun class

Cloud Run service.

Learn more at https://cloud.google.com/run.

Constructors

CloudRun({String? location, String? serviceName})
CloudRun.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
The location the service is run.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceName ↔ String?
The name of the Cloud Run service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited