CollectdPayloadError class

Describes the error status for payloads that were not written.

Constructors

CollectdPayloadError({Status? error, int? index, List<CollectdValueError>? valueErrors})
CollectdPayloadError.fromJson(Map json_)

Properties

error ↔ Status?
Records the error status for the payload.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int?
The zero-based index in CreateCollectdTimeSeriesRequest.collectd_payloads.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueErrors ↔ List<CollectdValueError>?
Records the error status for values that were not written due to an error.Failed payloads for which nothing is written will not include partial value errors.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited