CreateCollectdTimeSeriesRequest class

The CreateCollectdTimeSeries request.

Constructors

CreateCollectdTimeSeriesRequest({List<CollectdPayload>? collectdPayloads, String? collectdVersion, MonitoredResource? resource})
CreateCollectdTimeSeriesRequest.fromJson(Map json_)

Properties

collectdPayloads ↔ List<CollectdPayload>?
The collectd payloads representing the time series data.
getter/setter pair
collectdVersion ↔ String?
The version of collectd that collected the data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resource ↔ MonitoredResource?
The monitored resource associated with the time series.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited