Daily class

Used to schedule the query to run every so many days.

Constructors

Daily({TimeOfDay? executionTime, int? periodicity})
Daily.fromJson(Map json_)

Properties

executionTime ↔ TimeOfDay?
The time of day (in UTC) at which the query should run.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
periodicity ↔ int?
The number of days between runs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited