GkeService class

GKE Service.

The "service" here represents a Kubernetes service object (https://kubernetes.io/docs/concepts/services-networking/service). The field names correspond to the resource labels on k8s_service monitored resources (https://cloud.google.com/monitoring/api/resources#tag_k8s_service).

Constructors

GkeService({String? clusterName, String? location, String? namespaceName, String? projectId, String? serviceName})
GkeService.fromJson(Map json_)

Properties

clusterName ↔ String?
The name of the parent cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
The location of the parent cluster.
getter/setter pair
namespaceName ↔ String?
The name of the parent namespace.
getter/setter pair
projectId ↔ String?
The project this resource lives in.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceName ↔ String?
The name of this service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited