GoogleMonitoringV3Range class

Range of numerical values within min and max.

Properties

hashCode → int
The hash code for this object.
no setterinherited
max ↔ double?
Range maximum.
getter/setter pair
min ↔ double?
Range minimum.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited