HttpCheck class

Information involved in an HTTP/HTTPS Uptime check request.

Constructors

HttpCheck({List<ResponseStatusCode>? acceptedResponseStatusCodes, BasicAuthentication? authInfo, String? body, String? contentType, String? customContentType, Map<String, String>? headers, bool? maskHeaders, String? path, PingConfig? pingConfig, int? port, String? requestMethod, ServiceAgentAuthentication? serviceAgentAuthentication, bool? useSsl, bool? validateSsl})
HttpCheck.fromJson(Map json_)

Properties

acceptedResponseStatusCodes ↔ List<ResponseStatusCode>?
If present, the check will only pass if the HTTP response status code is in this set of status codes.
getter/setter pair
authInfo ↔ BasicAuthentication?
The authentication information.
getter/setter pair
body ↔ String?
The request body associated with the HTTP POST request.
getter/setter pair
bodyAsBytes ↔ List<int>
getter/setter pair
contentType ↔ String?
The content type header to use for the check.
getter/setter pair
customContentType ↔ String?
A user provided content type header to use for the check.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
The list of headers to send as part of the Uptime check request.
getter/setter pair
maskHeaders ↔ bool?
Boolean specifying whether to encrypt the header information.
getter/setter pair
path ↔ String?
Optional (defaults to "/").
getter/setter pair
pingConfig ↔ PingConfig?
Contains information needed to add pings to an HTTP check.
getter/setter pair
port ↔ int?
Optional (defaults to 80 when use_ssl is false, and 443 when use_ssl is true).
getter/setter pair
requestMethod ↔ String?
The HTTP request method to use for the check.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAgentAuthentication ↔ ServiceAgentAuthentication?
If specified, Uptime will generate and attach an OIDC JWT token for the Monitoring service agent service account as an Authorization header in the HTTP request when probing.
getter/setter pair
useSsl ↔ bool?
If true, use HTTPS instead of HTTP to run the check.
getter/setter pair
validateSsl ↔ bool?
Boolean specifying whether to include SSL certificate validation as a part of the Uptime check.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited