JsonPathMatcher class

Information needed to perform a JSONPath content match.

Used for ContentMatcherOption::MATCHES_JSON_PATH and ContentMatcherOption::NOT_MATCHES_JSON_PATH.

Constructors

JsonPathMatcher({String? jsonMatcher, String? jsonPath})
JsonPathMatcher.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
jsonMatcher ↔ String?
The type of JSONPath match that will be applied to the JSON output (ContentMatcher.content) Possible string values are:
getter/setter pair
jsonPath ↔ String?
JSONPath within the response output pointing to the expected ContentMatcher::content to match against.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited