Link class

Links to content such as playbooks, repositories, and other resources.

Constructors

Link({String? displayName, String? url})
Link.fromJson(Map json_)

Properties

displayName ↔ String?
A short display name for the link.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The url of a webpage.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited