ListAlertsResponse class

The ListAlerts response.

Constructors

ListAlertsResponse({List<Alert>? alerts, String? nextPageToken, int? totalSize})
ListAlertsResponse.fromJson(Map json_)

Properties

alerts ↔ List<Alert>?
The list of alerts.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If not empty, indicates that there may be more results that match the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize ↔ int?
The estimated total number of matching results for this query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited