ListServiceLevelObjectivesResponse class

The ListServiceLevelObjectives response.

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If there are more results than have been returned, then this field is set to a non-empty value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceLevelObjectives ↔ List<ServiceLevelObjective>?
The ServiceLevelObjectives matching the specified filter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited