LogMetadata class

Information about the log for log-based alerts.

Constructors

LogMetadata({Map<String, String>? extractedLabels})
LogMetadata.fromJson(Map json_)

Properties

extractedLabels ↔ Map<String, String>?
The labels extracted from the log.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited