Metric class

A specific metric, identified by specifying values for all of the labels of a MetricDescriptor.

Constructors

Metric({Map<String, String>? labels, String? type})
Metric.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The set of label values that uniquely identify this metric.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
An existing metric type, see google.api.MetricDescriptor.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited