MutationRecord class

Describes a change made to a configuration.

Constructors

MutationRecord({String? mutateTime, String? mutatedBy})
MutationRecord.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mutatedBy ↔ String?
The email address of the user making the change.
getter/setter pair
mutateTime ↔ String?
When the change occurred.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited