PerformanceThreshold class

A PerformanceThreshold is used when each window is good when that window has a sufficiently high performance.

Constructors

PerformanceThreshold({BasicSli? basicSliPerformance, RequestBasedSli? performance, double? threshold})
PerformanceThreshold.fromJson(Map json_)

Properties

basicSliPerformance ↔ BasicSli?
BasicSli to evaluate to judge window quality.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
performance ↔ RequestBasedSli?
RequestBasedSli to evaluate to judge window quality.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold ↔ double?
If window performance >= threshold, the window is counted as good.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited