Point class

A single data point in a time series.

Constructors

Point({TimeInterval? interval, TypedValue? value})
Point.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
interval ↔ TimeInterval?
The time interval to which the data point applies.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ TypedValue?
The value of the data point.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited