PolicySnapshot class

The state of the policy at the time the alert was generated.

Constructors

PolicySnapshot({String? displayName, String? name, String? severity, Map<String, String>? userLabels})
PolicySnapshot.fromJson(Map json_)

Properties

displayName ↔ String?
The display name of the alert policy.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the alert policy resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of the alert policy. Possible string values are:
getter/setter pair
userLabels ↔ Map<String, String>?
The user labels for the alert policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited