QueryTimeSeriesResponse class

The QueryTimeSeries response.

For information about the status of Monitoring Query Language (MQL), see the MQL deprecation notice (https://cloud.google.com/stackdriver/docs/deprecations/mql).

Constructors

QueryTimeSeriesResponse({String? nextPageToken, List<Status>? partialErrors, List<TimeSeriesData>? timeSeriesData, TimeSeriesDescriptor? timeSeriesDescriptor})
QueryTimeSeriesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If there are more results than have been returned, then this field is set to a non-empty value.
getter/setter pair
partialErrors ↔ List<Status>?
Query execution errors that may have caused the time series data returned to be incomplete.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeSeriesData ↔ List<TimeSeriesData>?
The time series data.
getter/setter pair
timeSeriesDescriptor ↔ TimeSeriesDescriptor?
The descriptor for the time series data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited