Range class

The range of the population values.

Constructors

Range({double? max, double? min})
Range.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
max ↔ double?
The maximum of the population values.
getter/setter pair
min ↔ double?
The minimum of the population values.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited