RequestBasedSli class

Service Level Indicators for which atomic units of service are counted directly.

Constructors

RequestBasedSli({DistributionCut? distributionCut, TimeSeriesRatio? goodTotalRatio})
RequestBasedSli.fromJson(Map json_)

Properties

distributionCut ↔ DistributionCut?
distribution_cut is used when good_service is a count of values aggregated in a Distribution that fall into a good range.
getter/setter pair
goodTotalRatio ↔ TimeSeriesRatio?
good_total_ratio is used when the ratio of good_service to total_service is computed from two TimeSeries.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited