ResourceGroup class

The resource submessage for group checks.

It can be used instead of a monitored resource, when multiple resources are being monitored.

Constructors

ResourceGroup({String? groupId, String? resourceType})
ResourceGroup.fromJson(Map json_)

Properties

groupId ↔ String?
The group of resources being monitored.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resourceType ↔ String?
The resource type of the group members. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited