RowCountTest class

A test that checks if the number of rows in the result set violates some threshold.

Constructors

RowCountTest({String? comparison, String? threshold})
RowCountTest.fromJson(Map json_)

Properties

comparison ↔ String?
The comparison to apply between the number of rows returned by the query and the threshold.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold ↔ String?
The value against which to compare the row count.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited