ServiceLevelObjective class

A Service-Level Objective (SLO) describes a level of desired good service.

It consists of a service-level indicator (SLI), a performance goal, and a period over which the objective is to be evaluated against that goal. The SLO can use SLIs defined in a number of different manners. Typical SLOs might include "99% of requests in each rolling week have latency below 200 milliseconds" or "99.5% of requests in each calendar month return successfully."

Constructors

ServiceLevelObjective({String? calendarPeriod, String? displayName, double? goal, String? name, String? rollingPeriod, ServiceLevelIndicator? serviceLevelIndicator, Map<String, String>? userLabels})
ServiceLevelObjective.fromJson(Map json_)

Properties

calendarPeriod ↔ String?
A calendar period, semantically "since the start of the current ".
getter/setter pair
displayName ↔ String?
Name used for UI elements listing this SLO.
getter/setter pair
goal ↔ double?
The fraction of service that must be good in order for this objective to be met.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
rollingPeriod ↔ String?
A rolling time period, semantically "in the past ".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceLevelIndicator ↔ ServiceLevelIndicator?
The definition of good service, used to measure and calculate the quality of the Service's performance with respect to a single aspect of service quality.
getter/setter pair
userLabels ↔ Map<String, String>?
Labels which have been used to annotate the service-level objective.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited