Trigger class

Specifies how many time series must fail a predicate to trigger a condition.

If not specified, then a {count: 1} trigger is used.

Constructors

Trigger({int? count, double? percent})
Trigger.fromJson(Map json_)

Properties

count ↔ int?
The absolute number of time series that must fail the predicate for the condition to be triggered.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
percent ↔ double?
The percentage of time series that must fail the predicate for the condition to be triggered.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited