ValueDescriptor class

A descriptor for the value columns in a data point.

Constructors

ValueDescriptor({String? key, String? metricKind, String? unit, String? valueType})
ValueDescriptor.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The value key.
getter/setter pair
metricKind ↔ String?
The value stream kind. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit ↔ String?
The unit in which time_series point values are reported.
getter/setter pair
valueType ↔ String?
The value type. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited