ActiveDirectory class

ActiveDirectory is the public representation of the active directory config.

Constructors

ActiveDirectory({List<String>? administrators, bool? aesEncryption, List<String>? backupOperators, String? createTime, String? description, String? dns, String? domain, bool? encryptDcConnections, String? kdcHostname, String? kdcIp, Map<String, String>? labels, bool? ldapSigning, String? name, String? netBiosPrefix, bool? nfsUsersWithLdap, String? organizationalUnit, String? password, List<String>? securityOperators, String? site, String? state, String? stateDetails, String? username})
ActiveDirectory.fromJson(Map json_)

Properties

administrators ↔ List<String>?
Users to be added to the Built-in Admininstrators group.
getter/setter pair
aesEncryption ↔ bool?
If enabled, AES encryption will be enabled for SMB communication.
getter/setter pair
backupOperators ↔ List<String>?
Users to be added to the Built-in Backup Operator active directory group.
getter/setter pair
createTime ↔ String?
Create time of the active directory.
getter/setter pair
description ↔ String?
Description of the active directory.
getter/setter pair
dns ↔ String?
Comma separated list of DNS server IP addresses for the Active Directory domain.
getter/setter pair
domain ↔ String?
Name of the Active Directory domain
getter/setter pair
encryptDcConnections ↔ bool?
If enabled, traffic between the SMB server to Domain Controller (DC) will be encrypted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kdcHostname ↔ String?
Name of the active directory machine.
getter/setter pair
kdcIp ↔ String?
KDC server IP address for the active directory machine.
getter/setter pair
labels ↔ Map<String, String>?
Labels for the active directory.
getter/setter pair
ldapSigning ↔ bool?
Specifies whether or not the LDAP traffic needs to be signed.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
netBiosPrefix ↔ String?
NetBIOSPrefix is used as a prefix for SMB server name.
getter/setter pair
nfsUsersWithLdap ↔ bool?
If enabled, will allow access to local users and LDAP users.
getter/setter pair
organizationalUnit ↔ String?
The Organizational Unit (OU) within the Windows Active Directory the user belongs to.
getter/setter pair
password ↔ String?
Password of the Active Directory domain administrator.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityOperators ↔ List<String>?
Domain users to be given the SeSecurityPrivilege.
getter/setter pair
site ↔ String?
The Active Directory site the service will limit Domain Controller discovery too.
getter/setter pair
state ↔ String?
The state of the AD.
getter/setter pair
stateDetails ↔ String?
The state details of the Active Directory.
getter/setter pair
username ↔ String?
Username of the Active Directory domain administrator.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited