BackupPolicy class

Backup Policy.

Constructors

BackupPolicy({int? assignedVolumeCount, String? createTime, int? dailyBackupLimit, String? description, bool? enabled, Map<String, String>? labels, int? monthlyBackupLimit, String? name, String? state, int? weeklyBackupLimit})
BackupPolicy.fromJson(Map json_)

Properties

assignedVolumeCount ↔ int?
The total number of volumes assigned by this backup policy.
getter/setter pair
createTime ↔ String?
The time when the backup policy was created.
getter/setter pair
dailyBackupLimit ↔ int?
Number of daily backups to keep.
getter/setter pair
description ↔ String?
Description of the backup policy.
getter/setter pair
enabled ↔ bool?
If enabled, make backups automatically according to the schedules.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
monthlyBackupLimit ↔ int?
Number of monthly backups to keep.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The backup policy state.
getter/setter pair
weeklyBackupLimit ↔ int?
Number of weekly backups to keep.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited