BackupRetentionPolicy class

Retention policy for backups in the backup vault

Constructors

BackupRetentionPolicy({int? backupMinimumEnforcedRetentionDays, bool? dailyBackupImmutable, bool? manualBackupImmutable, bool? monthlyBackupImmutable, bool? weeklyBackupImmutable})
BackupRetentionPolicy.fromJson(Map json_)

Properties

backupMinimumEnforcedRetentionDays ↔ int?
Minimum retention duration in days for backups in the backup vault.
getter/setter pair
dailyBackupImmutable ↔ bool?
Indicates if the daily backups are immutable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
manualBackupImmutable ↔ bool?
Indicates if the manual backups are immutable.
getter/setter pair
monthlyBackupImmutable ↔ bool?
Indicates if the monthly backups are immutable.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weeklyBackupImmutable ↔ bool?
Indicates if the weekly backups are immutable.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited