BackupSource class

Represents the backup source of the restore operation.

Constructors

BackupSource({String? backup, List<String>? fileList})
BackupSource.fromJson(Map json_)

Properties

backup ↔ String?
The backup resource name.
getter/setter pair
fileList ↔ List<String>?
List of files to be restored in the form of their absolute path as in source volume.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited