fileList property

List<String>? fileList
getter/setter pair

List of files to be restored in the form of their absolute path as in source volume.

If provided, only these files will be restored. If not provided, the entire backup will be restored (Full Backup Restore)

Optional.

Implementation

core.List<core.String>? fileList;