BackupVault class

A NetApp BackupVault.

Constructors

BackupVault({String? backupRegion, BackupRetentionPolicy? backupRetentionPolicy, String? backupVaultType, String? backupsCryptoKeyVersion, String? createTime, String? description, String? destinationBackupVault, String? encryptionState, String? kmsConfig, Map<String, String>? labels, String? name, String? sourceBackupVault, String? sourceRegion, String? state})
BackupVault.fromJson(Map json_)

Properties

backupRegion ↔ String?
Region where the backups are stored.
getter/setter pair
backupRetentionPolicy ↔ BackupRetentionPolicy?
Backup retention policy defining the retention of backups.
getter/setter pair
backupsCryptoKeyVersion ↔ String?
The crypto key version used to encrypt the backup vault.
getter/setter pair
backupVaultType ↔ String?
Type of backup vault to be created.
getter/setter pair
createTime ↔ String?
Create time of the backup vault.
getter/setter pair
description ↔ String?
Description of the backup vault.
getter/setter pair
destinationBackupVault ↔ String?
Name of the Backup vault created in backup region.
getter/setter pair
encryptionState ↔ String?
Field indicating encryption state of CMEK backups.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsConfig ↔ String?
Specifies the Key Management System (KMS) configuration to be used for backup encryption.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceBackupVault ↔ String?
Name of the Backup vault created in source region.
getter/setter pair
sourceRegion ↔ String?
Region in which the backup vault is created.
getter/setter pair
state ↔ String?
The backup vault state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited