CachePrePopulate class

Pre-populate cache volume with data from the origin volume.

Constructors

CachePrePopulate({List<String>? excludePathList, List<String>? pathList, bool? recursion})
CachePrePopulate.fromJson(Map json_)

Properties

excludePathList ↔ List<String>?
List of directory-paths to be excluded for pre-population for the FlexCache volume.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pathList ↔ List<String>?
List of directory-paths to be pre-populated for the FlexCache volume.
getter/setter pair
recursion ↔ bool?
Flag indicating whether the directories listed with the path_list need to be recursively pre-populated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited