CloneDetails class

Details about a clone volume.

Constructors

CloneDetails({String? sharedSpaceGib, String? sourceSnapshot, String? sourceVolume, String? splitState})
CloneDetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedSpaceGib ↔ String?
Shared space in GiB.
getter/setter pair
sourceSnapshot ↔ String?
Specifies the full resource name of the source snapshot from which this volume was cloned.
getter/setter pair
sourceVolume ↔ String?
Full name of the source volume resource.
getter/setter pair
splitState ↔ String?
The current state of the clone split operation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited