DailySchedule class

Make a snapshot every day e.g. at 04:00, 05:20, 23:50

Constructors

DailySchedule({double? hour, double? minute, double? snapshotsToKeep})
DailySchedule.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hour ↔ double?
Set the hour to start the snapshot (0-23), defaults to midnight (0).
getter/setter pair
minute ↔ double?
Set the minute of the hour to start the snapshot (0-59), defaults to the top of the hour (0).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotsToKeep ↔ double?
The maximum number of Snapshots to keep for the hourly schedule
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited