DestinationVolumeParameters class

DestinationVolumeParameters specify input parameters used for creating destination volume.

Constructors

DestinationVolumeParameters({String? description, String? shareName, String? storagePool, TieringPolicy? tieringPolicy, String? volumeId})
DestinationVolumeParameters.fromJson(Map json_)

Properties

description ↔ String?
Description for the destination volume.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareName ↔ String?
Destination volume's share name.
getter/setter pair
storagePool ↔ String?
Existing destination StoragePool name.
getter/setter pair
tieringPolicy ↔ TieringPolicy?
Tiering policy for the volume.
getter/setter pair
volumeId ↔ String?
Desired destination volume resource id.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited