ExportPolicy class

Defines the export policy for the volume.

Properties

hashCode → int
The hash code for this object.
no setterinherited
rules ↔ List<SimpleExportPolicyRule>?
List of export policy rules
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited