HostGroup class

Host group is a collection of hosts that can be used for accessing a Block Volume.

Constructors

HostGroup({String? createTime, String? description, List<String>? hosts, Map<String, String>? labels, String? name, String? osType, String? state, String? type})
HostGroup.fromJson(Map json_)

Properties

createTime ↔ String?
Create time of the host group.
getter/setter pair
description ↔ String?
Description of the host group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hosts ↔ List<String>?
The list of hosts associated with the host group.
getter/setter pair
labels ↔ Map<String, String>?
Labels of the host group.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
osType ↔ String?
The OS type of the host group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the host group.
getter/setter pair
type ↔ String?
Type of the host group.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited