LargeCapacityConfig class

Configuration for a Large Capacity Volume.

A Large Capacity Volume supports sizes ranging from 4.8 TiB to 20 PiB; it is composed of multiple internal constituents, and must be created in a large capacity pool.

Constructors

LargeCapacityConfig({int? constituentCount})
LargeCapacityConfig.fromJson(Map json_)

Properties

constituentCount int?
The number of internal constituents (e.g., FlexVols) for this large volume.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited