ListBackupConfigsResponse class

Message for response to listing BackupConfigs in an ONTAP StoragePool.

Constructors

ListBackupConfigsResponse({String? nextPageToken, List<String>? unreachable, List<VolumeBackupConfig>? volumeBackupConfigs})
ListBackupConfigsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The token you can use to retrieve the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unordered list.
getter/setter pair
volumeBackupConfigs ↔ List<VolumeBackupConfig>?
A list of backup configurations for volumes in the pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited