volumeBackupConfigs property
A list of backup configurations for volumes in the pool.
Implementation
core.List<VolumeBackupConfig>? volumeBackupConfigs;
A list of backup configurations for volumes in the pool.
core.List<VolumeBackupConfig>? volumeBackupConfigs;