ListBackupVaultsResponse class

ListBackupVaultsResponse is the result of ListBackupVaultsRequest.

Constructors

ListBackupVaultsResponse({List<BackupVault>? backupVaults, String? nextPageToken, List<String>? unreachable})
ListBackupVaultsResponse.fromJson(Map json_)

Properties

backupVaults ↔ List<BackupVault>?
A list of backupVaults in the project for the specified location.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The token you can use to retrieve the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited