MountOption class

View only mount options for a volume.

Constructors

MountOption({String? export, String? exportFull, String? instructions, String? ipAddress, String? protocol})
MountOption.fromJson(Map json_)

Properties

export ↔ String?
Export string
getter/setter pair
exportFull ↔ String?
Full export string
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instructions ↔ String?
Instructions for mounting
getter/setter pair
ipAddress ↔ String?
IP Address.
getter/setter pair
protocol ↔ String?
Protocol to mount with. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited