storagePool property
Name of the storage pool.
This must be specified for creating backups for ONTAP mode volumes.
Format:
projects/{projects_id}/locations/{location}/storagePools/{storage_pool_id}
Required.
Implementation
core.String? storagePool;
Name of the storage pool.
This must be specified for creating backups for ONTAP mode volumes.
Format:
projects/{projects_id}/locations/{location}/storagePools/{storage_pool_id}
Required.
core.String? storagePool;