ProjectsLocationsStoragePoolsOntapResource class

Constructors

ProjectsLocationsStoragePoolsOntapResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

executeOntapDelete(String ontapPath, {String? $fields}) Future<ExecuteOntapDeleteResponse>
ExecuteOntapDelete sends the ONTAP DELETE request to the StoragePool cluster.
executeOntapGet(String ontapPath, {String? $fields}) Future<ExecuteOntapDeleteResponse>
ExecuteOntapGet sends the ONTAP GET request to the StoragePool cluster.
executeOntapPatch(ExecuteOntapPatchRequest request, String ontapPath, {String? $fields}) Future<ExecuteOntapDeleteResponse>
ExecuteOntapPatch sends the ONTAP PATCH request to the StoragePool cluster.
executeOntapPost(ExecuteOntapPostRequest request, String ontapPath, {String? $fields}) Future<ExecuteOntapDeleteResponse>
ExecuteOntapPost sends the ONTAP POST request to the StoragePool cluster.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited