executeOntapDelete method

Future<ExecuteOntapDeleteResponse> executeOntapDelete(
  1. String ontapPath, {
  2. String? $fields,
})

ExecuteOntapDelete sends the ONTAP DELETE request to the StoragePool cluster.

Request parameters:

ontapPath - Required. The resource path of the ONTAP resource. Format: projects/{project_number}/locations/{location_id}/storagePools/{storage_pool_id}/ontap/{ontap_resource_path}. For example: projects/123456789/locations/us-central1/storagePools/my-storage-pool/ontap/api/storage/volumes. Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/storagePools/\[^/\]+/ontap/.*$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a ExecuteOntapDeleteResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<ExecuteOntapDeleteResponse> executeOntapDelete(
  core.String ontapPath, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$ontapPath');

  final response_ = await _requester.request(
    url_,
    'DELETE',
    queryParams: queryParams_,
  );
  return ExecuteOntapDeleteResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}