ProjectsLocationsStoragePoolsResource class
Methods
-
create(StoragePool request, String parent, {String? storagePoolId, String? $fields})
→ Future<Operation>
-
Creates a new storage pool.
-
delete(String name, {String? $fields})
→ Future<Operation>
-
Warning! This operation will permanently delete the storage pool.
-
get(String name, {String? $fields})
→ Future<StoragePool>
-
Returns the description of the specified storage pool by poolId.
-
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields})
→ Future<ListStoragePoolsResponse>
-
Returns descriptions of all storage pools owned by the caller.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(StoragePool request, String name, {String? updateMask, String? $fields})
→ Future<Operation>
-
Updates the storage pool properties with the full spec
-
restoreVolume(RestoreVolumeRequest request, String name, {String? $fields})
→ Future<Operation>
-
Restores a backup to an ONTAP-mode volume.
-
switch_(SwitchActiveReplicaZoneRequest request, String name, {String? $fields})
→ Future<Operation>
-
This operation will switch the active/replica zone for a regional
storagePool.
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateBackupConfig(UpdateBackupConfigRequest request, String name, {String? $fields})
→ Future<Operation>
-
Updates the backup configuration for an ONTAP-mode volume.
-
validateDirectoryService(ValidateDirectoryServiceRequest request, String name, {String? $fields})
→ Future<Operation>
-
ValidateDirectoryService does a connectivity check for a directory service
policy attached to the storage pool.