getSplitStatus method

Future<SplitStatus> getSplitStatus(
  1. String name, {
  2. String? $fields,
})

Retrieves the current state, progress, and details of a split operation for a volume.

This method is relevant when the volume is a clone. For volumes that are not clones, this method will return an error.

Request parameters:

name - Required. The full name of the volume. Format: projects/{project_number}/locations/{location}/volumes/{volume_id} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/volumes/\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a SplitStatus.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<SplitStatus> getSplitStatus(
  core.String name, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':getSplitStatus';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return SplitStatus.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}