QuotaRule class

QuotaRule specifies the maximum disk space a user or group can use within a volume.

They can be used for creating default and individual quota rules.

Constructors

QuotaRule({String? createTime, String? description, int? diskLimitMib, Map<String, String>? labels, String? name, String? state, String? stateDetails, String? target, String? type})
QuotaRule.fromJson(Map json_)

Properties

createTime ↔ String?
Create time of the quota rule
getter/setter pair
description ↔ String?
Description of the quota rule
getter/setter pair
diskLimitMib ↔ int?
The maximum allowed disk space in MiB.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels of the quota rule
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the quota rule
getter/setter pair
stateDetails ↔ String?
State details of the quota rule
getter/setter pair
target ↔ String?
The quota rule applies to the specified user or group, identified by a Unix UID/GID, Windows SID, or null for default.
getter/setter pair
type ↔ String?
The type of quota rule.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited