Replication class

Replication is a nested resource under Volume, that describes a cross-region replication relationship between 2 volumes in different regions.

Constructors

Replication({String? clusterLocation, String? createTime, String? description, String? destinationVolume, DestinationVolumeParameters? destinationVolumeParameters, bool? healthy, HybridPeeringDetails? hybridPeeringDetails, String? hybridReplicationType, UserCommands? hybridReplicationUserCommands, Map<String, String>? labels, String? mirrorState, String? name, String? replicationSchedule, String? role, String? sourceVolume, String? state, String? stateDetails, TransferStats? transferStats})
Replication.fromJson(Map json_)

Properties

clusterLocation ↔ String?
Location of the user cluster.
getter/setter pair
createTime ↔ String?
Replication create time.
getter/setter pair
description ↔ String?
A description about this replication relationship.
getter/setter pair
destinationVolume ↔ String?
Full name of destination volume resource.
getter/setter pair
destinationVolumeParameters ↔ DestinationVolumeParameters?
Input only.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthy ↔ bool?
Condition of the relationship.
getter/setter pair
hybridPeeringDetails ↔ HybridPeeringDetails?
Hybrid peering details.
getter/setter pair
hybridReplicationType ↔ String?
Type of the hybrid replication.
getter/setter pair
hybridReplicationUserCommands ↔ UserCommands?
Copy pastable snapmirror commands to be executed on onprem cluster by the customer.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata.
getter/setter pair
mirrorState ↔ String?
Indicates the state of mirroring.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
replicationSchedule ↔ String?
Indicates the schedule for replication.
getter/setter pair
role ↔ String?
Indicates whether this points to source or destination.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceVolume ↔ String?
Full name of source volume resource.
getter/setter pair
state ↔ String?
State of the replication.
getter/setter pair
stateDetails ↔ String?
State details of the replication.
getter/setter pair
transferStats ↔ TransferStats?
Replication transfer statistics.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited