RestoreParameters class

The RestoreParameters if volume is created from a snapshot or backup.

Constructors

RestoreParameters({String? sourceBackup, String? sourceSnapshot})
RestoreParameters.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceBackup ↔ String?
Full name of the backup resource.
getter/setter pair
sourceSnapshot ↔ String?
Full name of the snapshot resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited