RestoreVolumeRequest class
Request message for RestoreVolume API.
Constructors
- RestoreVolumeRequest({BackupSource? backupSource, OntapVolumeTarget? ontapVolumeTarget})
- RestoreVolumeRequest.fromJson(Map json_)
Properties
- backupSource ↔ BackupSource?
-
The backup source of the restore operation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ontapVolumeTarget ↔ OntapVolumeTarget?
-
The ONTAP volume target of the restore operation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited