SimpleExportPolicyRule class

An export policy rule describing various export options.

Constructors

SimpleExportPolicyRule({String? accessType, String? allowedClients, String? anonUid, String? hasRootAccess, bool? kerberos5ReadOnly, bool? kerberos5ReadWrite, bool? kerberos5iReadOnly, bool? kerberos5iReadWrite, bool? kerberos5pReadOnly, bool? kerberos5pReadWrite, bool? nfsv3, bool? nfsv4, String? squashMode})
SimpleExportPolicyRule.fromJson(Map json_)

Properties

accessType ↔ String?
Access type (ReadWrite, ReadOnly, None) Possible string values are:
getter/setter pair
allowedClients ↔ String?
Comma separated list of allowed clients IP addresses
getter/setter pair
anonUid ↔ String?
An integer representing the anonymous user ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasRootAccess ↔ String?
Whether Unix root access will be granted.
getter/setter pair
kerberos5iReadOnly ↔ bool?
If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification.
getter/setter pair
kerberos5iReadWrite ↔ bool?
If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification.
getter/setter pair
kerberos5pReadOnly ↔ bool?
If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification.
getter/setter pair
kerberos5pReadWrite ↔ bool?
If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification.
getter/setter pair
kerberos5ReadOnly ↔ bool?
If enabled (true) the rule defines a read only access for clients matching the 'allowedClients' specification.
getter/setter pair
kerberos5ReadWrite ↔ bool?
If enabled (true) the rule defines read and write access for clients matching the 'allowedClients' specification.
getter/setter pair
nfsv3 ↔ bool?
NFS V3 protocol.
getter/setter pair
nfsv4 ↔ bool?
NFS V4 protocol.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
squashMode ↔ String?
Defines how user identity squashing is applied for this export rule.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited