progressPercent property
The estimated progress percentage of the split operation (0-100).
This is meaningful primarily when split_state is IN_PROGRESS.
Output only.
Implementation
core.int? progressPercent;
The estimated progress percentage of the split operation (0-100).
This is meaningful primarily when split_state is IN_PROGRESS.
Output only.
core.int? progressPercent;