StoragePool class

StoragePool is a container for volumes with a service level and capacity.

Volumes can be created in a pool of sufficient available capacity. StoragePool capacity is what you are billed for.

Constructors

StoragePool({String? activeDirectory, bool? allowAutoTiering, double? availableThroughputMibps, String? capacityGib, String? coldTierSizeUsedGib, String? createTime, bool? customPerformanceEnabled, String? description, bool? enableHotTierAutoResize, String? encryptionType, bool? globalAccessAllowed, String? hotTierSizeGib, String? hotTierSizeUsedGib, String? kmsConfig, Map<String, String>? labels, bool? ldapEnabled, String? name, String? network, String? psaRange, String? qosType, String? replicaZone, bool? satisfiesPzi, bool? satisfiesPzs, String? serviceLevel, String? state, String? stateDetails, String? totalIops, String? totalThroughputMibps, String? type, String? volumeCapacityGib, int? volumeCount, String? zone})
StoragePool.fromJson(Map json_)

Properties

activeDirectory ↔ String?
Specifies the Active Directory to be used for creating a SMB volume.
getter/setter pair
allowAutoTiering ↔ bool?
True if the storage pool supports Auto Tiering enabled volumes.
getter/setter pair
availableThroughputMibps ↔ double?
Available throughput of the storage pool (in MiB/s).
getter/setter pair
capacityGib ↔ String?
Capacity in GIB of the pool
getter/setter pair
coldTierSizeUsedGib ↔ String?
Total cold tier data rounded down to the nearest GiB used by the storage pool.
getter/setter pair
createTime ↔ String?
Create time of the storage pool
getter/setter pair
customPerformanceEnabled ↔ bool?
True if using Independent Scaling of capacity and performance (Hyperdisk) By default set to false
getter/setter pair
description ↔ String?
Description of the storage pool
getter/setter pair
enableHotTierAutoResize ↔ bool?
Flag indicating that the hot-tier threshold will be auto-increased by 10% of the hot-tier when it hits 100%.
getter/setter pair
encryptionType ↔ String?
Specifies the current pool encryption key source.
getter/setter pair
globalAccessAllowed ↔ bool?
Used to allow SO pool to access AD or DNS server from other regions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hotTierSizeGib ↔ String?
Total hot tier capacity for the Storage Pool.
getter/setter pair
hotTierSizeUsedGib ↔ String?
Total hot tier data rounded down to the nearest GiB used by the storage pool.
getter/setter pair
kmsConfig ↔ String?
Specifies the KMS config to be used for volume encryption.
getter/setter pair
labels ↔ Map<String, String>?
Labels as key value pairs
getter/setter pair
ldapEnabled ↔ bool?
Flag indicating if the pool is NFS LDAP enabled or not.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
network ↔ String?
VPC Network name.
getter/setter pair
psaRange ↔ String?
This field is not implemented.
getter/setter pair
qosType ↔ String?
QoS (Quality of Service) Type of the storage pool
getter/setter pair
replicaZone ↔ String?
Specifies the replica zone for regional storagePool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use
getter/setter pair
serviceLevel ↔ String?
Service level of the storage pool
getter/setter pair
state ↔ String?
State of the storage pool
getter/setter pair
stateDetails ↔ String?
State details of the storage pool
getter/setter pair
totalIops ↔ String?
Custom Performance Total IOPS of the pool if not provided, it will be calculated based on the total_throughput_mibps
getter/setter pair
totalThroughputMibps ↔ String?
Custom Performance Total Throughput of the pool (in MiBps)
getter/setter pair
type ↔ String?
Type of the storage pool.
getter/setter pair
volumeCapacityGib ↔ String?
Allocated size of all volumes in GIB in the storage pool
getter/setter pair
volumeCount ↔ int?
Volume count of the storage pool
getter/setter pair
zone ↔ String?
Specifies the active zone for regional storagePool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited