type property

String? type
getter/setter pair

Type of the storage pool.

This field is used to control whether the pool supports FILE based volumes only or UNIFIED (both FILE and BLOCK) volumes. If not specified during creation, it defaults to FILE.

Optional. Possible string values are:

  • "STORAGE_POOL_TYPE_UNSPECIFIED" : Storage pool type is not specified.
  • "FILE" : Storage pool type is file.
  • "UNIFIED" : Storage pool type is unified.

Implementation

core.String? type;