TieringPolicy class

Defines tiering policy for the volume.

Constructors

TieringPolicy({int? coolingThresholdDays, bool? hotTierBypassModeEnabled, String? tierAction})
TieringPolicy.fromJson(Map json_)

Properties

coolingThresholdDays ↔ int?
Time in days to mark the volume's data block as cold and make it eligible for tiering, can be range from 2-183.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hotTierBypassModeEnabled ↔ bool?
Flag indicating that the hot tier bypass mode is enabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tierAction ↔ String?
Flag indicating if the volume has tiering policy enable/pause.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited