TransferStats class

TransferStats reports all statistics related to replication transfer.

Constructors

TransferStats({String? lagDuration, String? lastTransferBytes, String? lastTransferDuration, String? lastTransferEndTime, String? lastTransferError, String? totalTransferDuration, String? transferBytes, String? updateTime})
TransferStats.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lagDuration ↔ String?
Lag duration indicates the duration by which Destination region volume content lags behind the primary region volume content.
getter/setter pair
lastTransferBytes ↔ String?
Last transfer size in bytes.
getter/setter pair
lastTransferDuration ↔ String?
Time taken during last transfer.
getter/setter pair
lastTransferEndTime ↔ String?
Time when last transfer completed.
getter/setter pair
lastTransferError ↔ String?
A message describing the cause of the last transfer failure.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalTransferDuration ↔ String?
Cumulative time taken across all transfers for the replication relationship.
getter/setter pair
transferBytes ↔ String?
Cumulative bytes transferred so far for the replication relationship.
getter/setter pair
updateTime ↔ String?
Time when progress was updated last.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited