UpdateBackupConfigRequest class

Request message for UpdateBackupConfig

Constructors

UpdateBackupConfigRequest({BackupConfig? backupConfig, String? updateMask, String? volumeUuid})
UpdateBackupConfigRequest.fromJson(Map json_)

Properties

backupConfig ↔ BackupConfig?
Backup configuration to apply.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask ↔ String?
Field mask is used to specify the fields to be overwritten in the BackupConfig for the Volume.
getter/setter pair
volumeUuid ↔ String?
The UUID of the ONTAP-mode volume.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited