updateMask property

String? updateMask
getter/setter pair

Field mask is used to specify the fields to be overwritten in the BackupConfig for the Volume.

The fields specified in the update_mask are relative to the resource, not the full request. A field will be overwritten if it is in the mask.

Required.

Implementation

core.String? updateMask;