VerifyKmsConfigResponse class

VerifyKmsConfigResponse contains the information if the config is correctly and error message.

Constructors

VerifyKmsConfigResponse({String? healthError, bool? healthy, String? instructions})
VerifyKmsConfigResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthError ↔ String?
Error message if config is not healthy.
getter/setter pair
healthy ↔ bool?
If the customer key configured correctly to the encrypt volume.
getter/setter pair
instructions ↔ String?
Instructions for the customers to provide the access to the encryption key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited