Volume class

Volume provides a filesystem that you can mount.

Constructors

Volume({String? activeDirectory, BackupConfig? backupConfig, List<BlockDevice>? blockDevices, CacheParameters? cacheParameters, String? capacityGib, String? coldTierSizeGib, String? createTime, String? description, String? encryptionType, ExportPolicy? exportPolicy, bool? hasReplication, String? hotTierSizeUsedGib, HybridReplicationParameters? hybridReplicationParameters, bool? kerberosEnabled, String? kmsConfig, Map<String, String>? labels, bool? largeCapacity, bool? ldapEnabled, List<MountOption>? mountOptions, bool? multipleEndpoints, String? name, String? network, List<String>? protocols, String? psaRange, String? replicaZone, RestoreParameters? restoreParameters, List<String>? restrictedActions, String? securityStyle, String? serviceLevel, String? shareName, List<String>? smbSettings, double? snapReserve, bool? snapshotDirectory, SnapshotPolicy? snapshotPolicy, String? state, String? stateDetails, String? storagePool, double? throughputMibps, TieringPolicy? tieringPolicy, String? unixPermissions, String? usedGib, String? zone})
Volume.fromJson(Map json_)

Properties

activeDirectory ↔ String?
Specifies the ActiveDirectory name of a SMB volume.
getter/setter pair
backupConfig ↔ BackupConfig?
BackupConfig of the volume.
getter/setter pair
blockDevices ↔ List<BlockDevice>?
Block devices for the volume.
getter/setter pair
cacheParameters ↔ CacheParameters?
Cache parameters for the volume.
getter/setter pair
capacityGib ↔ String?
Capacity in GIB of the volume
getter/setter pair
coldTierSizeGib ↔ String?
Size of the volume cold tier data rounded down to the nearest GiB.
getter/setter pair
createTime ↔ String?
Create time of the volume
getter/setter pair
description ↔ String?
Description of the volume
getter/setter pair
encryptionType ↔ String?
Specified the current volume encryption key source.
getter/setter pair
exportPolicy ↔ ExportPolicy?
Export policy of the volume
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasReplication ↔ bool?
Indicates whether the volume is part of a replication relationship.
getter/setter pair
hotTierSizeUsedGib ↔ String?
Total hot tier data rounded down to the nearest GiB used by the Volume.
getter/setter pair
hybridReplicationParameters ↔ HybridReplicationParameters?
The Hybrid Replication parameters for the volume.
getter/setter pair
kerberosEnabled ↔ bool?
Flag indicating if the volume is a kerberos volume or not, export policy rules control kerberos security modes (krb5, krb5i, krb5p).
getter/setter pair
kmsConfig ↔ String?
Specifies the KMS config to be used for volume encryption.
getter/setter pair
labels ↔ Map<String, String>?
Labels as key value pairs
getter/setter pair
largeCapacity ↔ bool?
Flag indicating if the volume will be a large capacity volume or a regular volume.
getter/setter pair
ldapEnabled ↔ bool?
Flag indicating if the volume is NFS LDAP enabled or not.
getter/setter pair
mountOptions ↔ List<MountOption>?
Mount options of this volume
getter/setter pair
multipleEndpoints ↔ bool?
Flag indicating if the volume will have an IP address per node for volumes supporting multiple IP endpoints.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
network ↔ String?
VPC Network name.
getter/setter pair
protocols ↔ List<String>?
Protocols required for the volume
getter/setter pair
psaRange ↔ String?
This field is not implemented.
getter/setter pair
replicaZone ↔ String?
Specifies the replica zone for regional volume.
getter/setter pair
restoreParameters ↔ RestoreParameters?
Specifies the source of the volume to be created from.
getter/setter pair
restrictedActions ↔ List<String>?
List of actions that are restricted on this volume.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityStyle ↔ String?
Security Style of the Volume
getter/setter pair
serviceLevel ↔ String?
Service level of the volume
getter/setter pair
shareName ↔ String?
Share name of the volume
getter/setter pair
smbSettings ↔ List<String>?
SMB share settings for the volume.
getter/setter pair
snapReserve ↔ double?
Snap_reserve specifies percentage of volume storage reserved for snapshot storage.
getter/setter pair
snapshotDirectory ↔ bool?
Snapshot_directory if enabled (true) the volume will contain a read-only .snapshot directory which provides access to each of the volume's snapshots.
getter/setter pair
snapshotPolicy ↔ SnapshotPolicy?
SnapshotPolicy for a volume.
getter/setter pair
state ↔ String?
State of the volume
getter/setter pair
stateDetails ↔ String?
State details of the volume
getter/setter pair
storagePool ↔ String?
StoragePool name of the volume
getter/setter pair
throughputMibps ↔ double?
Throughput of the volume (in MiB/s)
getter/setter pair
tieringPolicy ↔ TieringPolicy?
Tiering policy for the volume.
getter/setter pair
unixPermissions ↔ String?
Default unix style permission (e.g. 777) the mount point will be created with.
getter/setter pair
usedGib ↔ String?
Used capacity in GIB of the volume.
getter/setter pair
zone ↔ String?
Specifies the active zone for regional volume.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited