VolumeBackupConfig class

Backup configuration for a volume in a pool.

Constructors

VolumeBackupConfig({BackupConfig? backupConfig, String? volumeUuid})
VolumeBackupConfig.fromJson(Map json_)

Properties

backupConfig ↔ BackupConfig?
Backup configuration for the volume.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volumeUuid ↔ String?
Provides the Ontap UUID of the volume within the pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited