WeeklySchedule class

Make a snapshot every week e.g. at Monday 04:00, Wednesday 05:20, Sunday 23:50

Constructors

WeeklySchedule({String? day, double? hour, double? minute, double? snapshotsToKeep})
WeeklySchedule.fromJson(Map json_)

Properties

day ↔ String?
Set the day or days of the week to make a snapshot.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hour ↔ double?
Set the hour to start the snapshot (0-23), defaults to midnight (0).
getter/setter pair
minute ↔ double?
Set the minute of the hour to start the snapshot (0-59), defaults to the top of the hour (0).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshotsToKeep ↔ double?
The maximum number of Snapshots to keep for the hourly schedule
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited