AllocationOptions class

Range auto-allocation options, to be optionally used when CIDR block is not explicitly set.

Constructors

AllocationOptions({String? allocationStrategy, int? firstAvailableRangesLookupSize})
AllocationOptions.fromJson(Map json_)

Properties

allocationStrategy ↔ String?
Allocation strategy Not setting this field when the allocation is requested means an implementation defined strategy is used.
getter/setter pair
firstAvailableRangesLookupSize ↔ int?
This field must be set only when allocation_strategy is set to RANDOM_FIRST_N_AVAILABLE.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited