CheckConsumerConfigRequest class

Request for CheckConsumerConfig.

Constructors

CheckConsumerConfigRequest({String? consumerNetwork, String? endpointProject, String? requestedIpVersion, String? serviceClass})
CheckConsumerConfigRequest.fromJson(Map json_)

Properties

consumerNetwork ↔ String?
Full resource name of the consumer network.
getter/setter pair
endpointProject ↔ String?
The project number or ID where the PSC endpoint is to be created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestedIpVersion ↔ String?
The requested IP Version Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceClass ↔ String?
The service class identifier of the producer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited