Config class

Defines the configuration of a DNS record.

Constructors

Config({List<String>? rrdatas, String? ttl})
Config.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
rrdatas ↔ List<String>?
The list of resource record data strings.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl ↔ String?
Number of seconds that this DNS record can be cached by resolvers.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited