ConsumerPscConnection class

PSC connection details on consumer side.

Constructors

ConsumerPscConnection({DnsAutomationStatus? dnsAutomationStatus, GoogleRpcStatus? error, GoogleRpcErrorInfo? errorInfo, String? errorType, String? forwardingRule, String? gceOperation, String? ip, String? ipVersion, String? network, String? producerInstanceId, Map<String, String>? producerInstanceMetadata, String? project, String? pscConnectionId, String? selectedSubnetwork, String? serviceAttachmentUri, String? state})
ConsumerPscConnection.fromJson(Map json_)

Properties

dnsAutomationStatus ↔ DnsAutomationStatus?
The status of DNS automation for this PSC connection.
getter/setter pair
error ↔ GoogleRpcStatus?
The most recent error during operating this connection.
getter/setter pair
errorInfo ↔ GoogleRpcErrorInfo?
The error info for the latest error during operating this connection.
getter/setter pair
errorType ↔ String?
The error type indicates whether the error is consumer facing, producer facing or system internal. Possible string values are:
getter/setter pair
forwardingRule ↔ String?
The URI of the consumer forwarding rule created.
getter/setter pair
gceOperation ↔ String?
The last Compute Engine operation to setup PSC connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ip ↔ String?
The IP literal allocated on the consumer network for the PSC forwarding rule that is created to connect to the producer service attachment in this service connection map.
getter/setter pair
ipVersion ↔ String?
The requested IP version for the PSC connection. Possible string values are:
getter/setter pair
network ↔ String?
The consumer network whose PSC forwarding rule is connected to the service attachments in this service connection map.
getter/setter pair
producerInstanceId ↔ String?
Use producer_instance_metadata instead.
getter/setter pair
producerInstanceMetadata ↔ Map<String, String>?
An immutable map for the producer instance metadata.
getter/setter pair
project ↔ String?
The consumer project whose PSC forwarding rule is connected to the service attachments in this service connection map.
getter/setter pair
pscConnectionId ↔ String?
The PSC connection id of the PSC forwarding rule connected to the service attachments in this service connection map.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedSubnetwork ↔ String?
The URI of the selected subnetwork selected to allocate IP address for this connection.
getter/setter pair
serviceAttachmentUri ↔ String?
The URI of a service attachment which is the target of the PSC connection.
getter/setter pair
state ↔ String?
The state of the PSC connection. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited