Destination class

The Destination resource.

It specifies the IP prefix and the associated autonomous system numbers (ASN) that you want to include in a MulticloudDataTransferConfig resource.

Constructors

Destination({String? createTime, String? description, List<DestinationEndpoint>? endpoints, String? etag, String? ipPrefix, Map<String, String>? labels, String? name, StateTimeline? stateTimeline, String? uid, String? updateTime})
Destination.fromJson(Map json_)

Properties

createTime ↔ String?
Time when the Destination resource was created.
getter/setter pair
description ↔ String?
A description of this resource.
getter/setter pair
endpoints ↔ List<DestinationEndpoint>?
Unordered list.
getter/setter pair
etag ↔ String?
The etag is computed by the server, and might be sent with update and delete requests so that the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipPrefix ↔ String?
The IP prefix that represents your workload on another CSP.
getter/setter pair
labels ↔ Map<String, String>?
User-defined labels.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateTimeline ↔ StateTimeline?
The timeline of the expected Destination states or the current rest state.
getter/setter pair
uid ↔ String?
The Google-generated unique ID for the Destination resource.
getter/setter pair
updateTime ↔ String?
Time when the Destination resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited