DestinationEndpoint class

The metadata for a DestinationEndpoint resource.

Constructors

DestinationEndpoint({String? asn, String? csp, String? state, String? updateTime})
DestinationEndpoint.fromJson(Map json_)

Properties

asn ↔ String?
The ASN of the remote IP prefix.
getter/setter pair
csp ↔ String?
The CSP of the remote IP prefix.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the DestinationEndpoint resource.
getter/setter pair
updateTime ↔ String?
Time when the DestinationEndpoint resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited