Filter class

Filter matches L4 traffic.

Constructors

Filter({String? destRange, String? ipProtocol, String? protocolVersion, String? srcRange})
Filter.fromJson(Map json_)

Properties

destRange ↔ String?
The destination IP range of outgoing packets that this policy-based route applies to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipProtocol ↔ String?
The IP protocol that this policy-based route applies to.
getter/setter pair
protocolVersion ↔ String?
Internet protocol versions this policy-based route applies to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcRange ↔ String?
The source IP range of outgoing packets that this policy-based route applies to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited