uniqueId property

String? uniqueId
getter/setter pair

The Google-generated UUID for the gateway advertised route.

This value is unique across all gateway advertised route resources. If a gateway advertised route is deleted and another with the same name is created, the new route is assigned a different unique_id.

Output only.

Implementation

core.String? uniqueId;