Group class

A group represents a subset of spokes attached to a hub.

Constructors

Group({AutoAccept? autoAccept, String? createTime, String? description, Map<String, String>? labels, String? name, String? routeTable, String? state, String? uid, String? updateTime})
Group.fromJson(Map json_)

Properties

autoAccept ↔ AutoAccept?
The auto-accept setting for this group.
getter/setter pair
createTime ↔ String?
The time the group was created.
getter/setter pair
description ↔ String?
The description of the group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels in key-value pair format.
getter/setter pair
name ↔ String?
The name of the group.
getter/setter pair
routeTable ↔ String?
The name of the route table that corresponds to this group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current lifecycle state of this group.
getter/setter pair
uid ↔ String?
The Google-generated UUID for the group.
getter/setter pair
updateTime ↔ String?
The time the group was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited