IpRangeReservation class

A list of IP ranges that are reserved for this gateway's internal intfrastructure.

Constructors

IpRangeReservation({String? ipRange})
IpRangeReservation.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
ipRange String?
A block of IP addresses used to allocate supporting infrastructure for this gateway.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited