LinkedRouterApplianceInstances class
A collection of router appliance instances.
If you configure multiple router appliance instances to receive data from the same set of sites outside of Google Cloud, we recommend that you associate those instances with the same spoke.
Constructors
-
LinkedRouterApplianceInstances({List<
String> ? excludeExportRanges, List<String> ? excludeImportRanges, List<String> ? includeExportRanges, List<String> ? includeImportRanges, List<RouterApplianceInstance> ? instances, bool? siteToSiteDataTransfer, String? vpcNetwork}) - LinkedRouterApplianceInstances.fromJson(Map json_)
Properties
-
excludeExportRanges
↔ List<
String> ? -
Dynamic routes overlapped/encompassed by exclude export ranges are
excluded during export to hub.
getter/setter pair
-
excludeImportRanges
↔ List<
String> ? -
Hub routes overlapped/encompassed by exclude import ranges are excluded
during import from hub.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
includeExportRanges
↔ List<
String> ? -
Dynamic routes fully encompassed by include export ranges are included
during export to hub.
getter/setter pair
-
includeImportRanges
↔ List<
String> ? -
Hub routes fully encompassed by include import ranges are included during
import from hub.
getter/setter pair
-
instances
↔ List<
RouterApplianceInstance> ? -
The list of router appliance instances.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- siteToSiteDataTransfer ↔ bool?
-
A value that controls whether site-to-site data transfer is enabled for
these resources.
getter/setter pair
- vpcNetwork ↔ String?
-
The VPC network where these router appliance instances are located.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited