ListMulticloudDataTransferConfigsResponse class

Response message to list MulticloudDataTransferConfig resources.

Constructors

ListMulticloudDataTransferConfigsResponse({List<MulticloudDataTransferConfig>? multicloudDataTransferConfigs, String? nextPageToken, List<String>? unreachable})
ListMulticloudDataTransferConfigsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
multicloudDataTransferConfigs ↔ List<MulticloudDataTransferConfig>?
The list of MulticloudDataTransferConfig resources to be listed.
getter/setter pair
nextPageToken ↔ String?
The next page token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited