Migration class

Specification for migration with source and target resource names.

Constructors

Migration({String? source, String? target})
Migration.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ String?
Resource path as an URI of the source resource, for example a subnet.
getter/setter pair
target ↔ String?
Resource path of the target resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited