MulticloudDataTransferConfig class

The MulticloudDataTransferConfig resource.

It lists the services that you configure for Data Transfer Essentials billing and metering.

Constructors

MulticloudDataTransferConfig({String? createTime, String? description, int? destinationsActiveCount, int? destinationsCount, String? etag, Map<String, String>? labels, String? name, Map<String, StateTimeline>? services, String? uid, String? updateTime})
MulticloudDataTransferConfig.fromJson(Map json_)

Properties

createTime ↔ String?
Time when the MulticloudDataTransferConfig resource was created.
getter/setter pair
description ↔ String?
A description of this resource.
getter/setter pair
destinationsActiveCount ↔ int?
The number of Destination resources in use with the MulticloudDataTransferConfig resource.
getter/setter pair
destinationsCount ↔ int?
The number of Destination resources configured for the MulticloudDataTransferConfig resource.
getter/setter pair
etag ↔ String?
The etag is computed by the server, and might be sent with update and delete requests so that the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
User-defined labels.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services ↔ Map<String, StateTimeline>?
Maps services to their current or planned states.
getter/setter pair
uid ↔ String?
The Google-generated unique ID for the MulticloudDataTransferConfig resource.
getter/setter pair
updateTime ↔ String?
Time when the MulticloudDataTransferConfig resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited