PolicyBasedRoute class

Policy-based routes route L4 network traffic based on not just destination IP address, but also source IP address, protocol, and more.

If a policy-based route conflicts with other types of routes, the policy-based route always takes precedence.

Constructors

PolicyBasedRoute({String? createTime, String? description, Filter? filter, InterconnectAttachment? interconnectAttachment, String? kind, Map<String, String>? labels, String? name, String? network, String? nextHopIlbIp, String? nextHopOtherRoutes, int? priority, String? selfLink, String? updateTime, VirtualMachine? virtualMachine, List<Warnings>? warnings})
PolicyBasedRoute.fromJson(Map json_)

Properties

createTime ↔ String?
Time when the policy-based route was created.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
filter ↔ Filter?
The filter to match L4 traffic.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interconnectAttachment ↔ InterconnectAttachment?
The interconnect attachments that this policy-based route applies to.
getter/setter pair
kind ↔ String?
Type of this resource.
getter/setter pair
labels ↔ Map<String, String>?
User-defined labels.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
network ↔ String?
Fully-qualified URL of the network that this route applies to, for example: projects/my-project/global/networks/my-network.
getter/setter pair
nextHopIlbIp ↔ String?
The IP address of a global-access-enabled L4 ILB that is the next hop for matching packets.
getter/setter pair
nextHopOtherRoutes ↔ String?
Other routes that will be referenced to determine the next hop of the packet.
getter/setter pair
priority ↔ int?
The priority of this policy-based route.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined fully-qualified URL for this resource.
getter/setter pair
updateTime ↔ String?
Time when the policy-based route was updated.
getter/setter pair
virtualMachine ↔ VirtualMachine?
VM instances that this policy-based route applies to.
getter/setter pair
warnings ↔ List<Warnings>?
If potential misconfigurations are detected for this route, this field will be populated with warning messages.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited