RejectSpokeUpdateRequest class

The request for HubService.RejectSpokeUpdate.

Constructors

RejectSpokeUpdateRequest({String? details, String? requestId, String? spokeEtag, String? spokeUri})
RejectSpokeUpdateRequest.fromJson(Map json_)

Properties

details ↔ String?
Additional information provided by the hub administrator.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
A request ID to identify requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spokeEtag ↔ String?
The etag of the spoke to reject update.
getter/setter pair
spokeUri ↔ String?
The URI of the spoke to reject update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited