RemoteTransportProfile class
Message describing RemoteTransportProfile object.
Constructors
Properties
- description ↔ String?
-
Description of the profile.
getter/setter pair
- displayName ↔ String?
-
Human readable name of this profile, used to identify this profile in the
UI.
getter/setter pair
- flow ↔ String?
-
Type of provisioning flows supported by this profile.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
Labels as key value pairs.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- orderState ↔ String?
-
Order state for this profile.
getter/setter pair
- provider ↔ String?
-
Name of the provider on the other end of this profile.
getter/setter pair
- providerSite ↔ String?
-
If the profile is a Cloud Service Provider with compute resources, this is
populated with the region where connectivity is being established.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sla ↔ String?
-
Availability class that will be configured for this particular
RemoteTransportProfile.
getter/setter pair
-
supportedBandwidths
↔ List<
String> ? -
List of bandwidth enum values that are supported by this profile.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited