displayName property
Human readable name of this profile, used to identify this profile in the UI.
Output only.
Implementation
core.String? displayName;
Human readable name of this profile, used to identify this profile in the UI.
Output only.
core.String? displayName;