Route class

A route defines a path from VM instances within a spoke to a specific destination resource.

Only VPC spokes have routes.

Constructors

Route({String? createTime, String? description, String? ipCidrRange, Map<String, String>? labels, String? location, String? name, NextHopInterconnectAttachment? nextHopInterconnectAttachment, NextHopRouterApplianceInstance? nextHopRouterApplianceInstance, NextHopSpoke? nextHopSpoke, NextHopVpcNetwork? nextHopVpcNetwork, NextHopVPNTunnel? nextHopVpnTunnel, String? priority, String? spoke, String? state, String? type, String? uid, String? updateTime})
Route.fromJson(Map json_)

Properties

createTime ↔ String?
The time the route was created.
getter/setter pair
description ↔ String?
An optional description of the route.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipCidrRange ↔ String?
The destination IP address range.
getter/setter pair
labels ↔ Map<String, String>?
Optional labels in key-value pair format.
getter/setter pair
location ↔ String?
The origin location of the route.
getter/setter pair
name ↔ String?
The name of the route.
getter/setter pair
nextHopInterconnectAttachment ↔ NextHopInterconnectAttachment?
The next-hop VLAN attachment for packets on this route.
getter/setter pair
nextHopRouterApplianceInstance ↔ NextHopRouterApplianceInstance?
The next-hop Router appliance instance for packets on this route.
getter/setter pair
nextHopSpoke ↔ NextHopSpoke?
The next-hop spoke for packets on this route.
getter/setter pair
nextHopVpcNetwork ↔ NextHopVpcNetwork?
The destination VPC network for packets on this route.
getter/setter pair
nextHopVpnTunnel ↔ NextHopVPNTunnel?
The next-hop VPN tunnel for packets on this route.
getter/setter pair
priority ↔ String?
The priority of this route.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spoke ↔ String?
The spoke that this route leads to.
getter/setter pair
state ↔ String?
The current lifecycle state of the route.
getter/setter pair
type ↔ String?
The route's type.
getter/setter pair
uid ↔ String?
The Google-generated UUID for the route.
getter/setter pair
updateTime ↔ String?
The time the route was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited