ServiceConnectionMap class

The ServiceConnectionMap resource.

Constructors

ServiceConnectionMap({List<ConsumerPscConfig>? consumerPscConfigs, List<ConsumerPscConnection>? consumerPscConnections, String? createTime, String? description, String? etag, String? infrastructure, Map<String, String>? labels, String? name, List<ProducerPscConfig>? producerPscConfigs, String? serviceClass, String? serviceClassUri, String? token, String? updateTime})
ServiceConnectionMap.fromJson(Map json_)

Properties

consumerPscConfigs ↔ List<ConsumerPscConfig>?
The PSC configurations on consumer side.
getter/setter pair
consumerPscConnections ↔ List<ConsumerPscConnection>?
PSC connection details on consumer side.
getter/setter pair
createTime ↔ String?
Time when the ServiceConnectionMap was created.
getter/setter pair
description ↔ String?
A description of this resource.
getter/setter pair
etag ↔ String?
The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infrastructure ↔ String?
The infrastructure used for connections between consumers/producers.
getter/setter pair
labels ↔ Map<String, String>?
User-defined labels.
getter/setter pair
name ↔ String?
The name of a ServiceConnectionMap.
getter/setter pair
producerPscConfigs ↔ List<ProducerPscConfig>?
The PSC configurations on producer side.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceClass ↔ String?
The service class identifier this ServiceConnectionMap is for.
getter/setter pair
serviceClassUri ↔ String?
The service class uri this ServiceConnectionMap is for.
getter/setter pair
token ↔ String?
The token provided by the consumer.
getter/setter pair
updateTime ↔ String?
Time when the ServiceConnectionMap was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited