ServiceConnectionPolicy class

The ServiceConnectionPolicy resource.

Constructors

ServiceConnectionPolicy({AutoCreatedSubnetworkInfo? autoCreatedSubnetInfo, String? createTime, String? description, String? etag, String? infrastructure, Map<String, String>? labels, String? name, String? network, PscConfig? pscConfig, List<PscConnection>? pscConnections, String? serviceClass, String? updateTime})
ServiceConnectionPolicy.fromJson(Map json_)

Properties

autoCreatedSubnetInfo ↔ AutoCreatedSubnetworkInfo?
Information for the automatically created subnetwork and its associated IR.
getter/setter pair
createTime ↔ String?
Time when the ServiceConnectionPolicy was created.
getter/setter pair
description ↔ String?
A description of this resource.
getter/setter pair
etag ↔ String?
The etag is computed by the server, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
infrastructure ↔ String?
The type of underlying resources used to create the connection.
getter/setter pair
labels ↔ Map<String, String>?
User-defined labels.
getter/setter pair
name ↔ String?
The name of a ServiceConnectionPolicy.
getter/setter pair
network ↔ String?
The resource path of the consumer network.
getter/setter pair
pscConfig ↔ PscConfig?
Configuration used for Private Service Connect connections.
getter/setter pair
pscConnections ↔ List<PscConnection>?
Information about each Private Service Connect connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceClass ↔ String?
The service class identifier for which this ServiceConnectionPolicy is for.
getter/setter pair
updateTime ↔ String?
Time when the ServiceConnectionPolicy was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited