Spoke class

A Network Connectivity Center spoke represents one or more network connectivity resources.

When you create a spoke, you associate it with a hub. You must also identify a value for exactly one of the following fields: * linked_vpn_tunnels * linked_interconnect_attachments * linked_router_appliance_instances * linked_vpc_network

Constructors

Spoke({String? createTime, String? description, String? etag, List<String>? fieldPathsPendingUpdate, Gateway? gateway, String? group, String? hub, Map<String, String>? labels, LinkedInterconnectAttachments? linkedInterconnectAttachments, LinkedProducerVpcNetwork? linkedProducerVpcNetwork, LinkedRouterApplianceInstances? linkedRouterApplianceInstances, LinkedVpcNetwork? linkedVpcNetwork, LinkedVpnTunnels? linkedVpnTunnels, String? name, List<StateReason>? reasons, String? spokeType, String? state, String? uniqueId, String? updateTime})
Spoke.fromJson(Map json_)

Properties

createTime ↔ String?
The time the spoke was created.
getter/setter pair
description ↔ String?
An optional description of the spoke.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
fieldPathsPendingUpdate ↔ List<String>?
The list of fields waiting for hub administrator's approval.
getter/setter pair
gateway ↔ Gateway?
This is a gateway that can apply specialized processing to traffic going through it.
getter/setter pair
group ↔ String?
The name of the group that this spoke is associated with.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hub ↔ String?
The name of the hub that this spoke is attached to.
getter/setter pair
labels ↔ Map<String, String>?
Optional labels in key-value pair format.
getter/setter pair
linkedInterconnectAttachments ↔ LinkedInterconnectAttachments?
VLAN attachments that are associated with the spoke.
getter/setter pair
linkedProducerVpcNetwork ↔ LinkedProducerVpcNetwork?
The linked producer VPC that is associated with the spoke.
getter/setter pair
linkedRouterApplianceInstances ↔ LinkedRouterApplianceInstances?
Router appliance instances that are associated with the spoke.
getter/setter pair
linkedVpcNetwork ↔ LinkedVpcNetwork?
VPC network that is associated with the spoke.
getter/setter pair
linkedVpnTunnels ↔ LinkedVpnTunnels?
VPN tunnels that are associated with the spoke.
getter/setter pair
name ↔ String?
The name of the spoke.
getter/setter pair
reasons ↔ List<StateReason>?
The reasons for current state of the spoke.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spokeType ↔ String?
The type of resource associated with the spoke.
getter/setter pair
state ↔ String?
The current lifecycle state of this spoke.
getter/setter pair
uniqueId ↔ String?
The Google-generated UUID for the spoke.
getter/setter pair
updateTime ↔ String?
The time the spoke was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited