gateway property
This is a gateway that can apply specialized processing to traffic going through it.
Optional.
Implementation
Gateway? gateway;
This is a gateway that can apply specialized processing to traffic going through it.
Optional.
Gateway? gateway;