StateMetadata class

The state and activation time details of the resource state.

Constructors

StateMetadata({String? effectiveTime, String? state})
StateMetadata.fromJson(Map json_)

Properties

effectiveTime ↔ String?
Accompanies only the transient states, which include ADDING, DELETING, and SUSPENDING, to denote the time until which the transient state of the resource will be effective.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited