StateReason class

The reason for the current state of the spoke.

Constructors

StateReason({String? code, String? message, String? userDetails})
StateReason.fromJson(Map json_)

Properties

code ↔ String?
The code associated with this reason. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
Human-readable details about this reason.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userDetails ↔ String?
Additional information provided by the user in the RejectSpoke call.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited