bandwidth property
Bandwidth of the Transport.
This must be one of the supported bandwidths for the remote profile, and must be set when no activation key is being provided.
Optional. Possible string values are:
- "BANDWIDTH_UNSPECIFIED" : Unspecified bandwidth.
- "BPS_50M" : 50 Megabits per second.
- "BPS_100M" : 100 Megabits per second.
- "BPS_200M" : 200 Megabits per second.
- "BPS_300M" : 300 Megabits per second.
- "BPS_400M" : 400 Megabits per second.
- "BPS_500M" : 500 Megabits per second.
- "BPS_1G" : 1 Gigabit per second.
- "BPS_2G" : 2 Gigabits per second.
- "BPS_5G" : 5 Gigabits per second.
- "BPS_10G" : 10 Gigabits per second.
- "BPS_20G" : 20 Gigabits per second.
- "BPS_50G" : 50 Gigabits per second.
- "BPS_100G" : 100 Gigabits per second.
Implementation
core.String? bandwidth;