peeringNetwork property
VPC Network URI that was created for the VPC Peering connection to the
provided network.
If VPC Peering is disconnected, this can be used to re-establish.
Output only.
Implementation
core.String? peeringNetwork;
VPC Network URI that was created for the VPC Peering connection to the
provided network.
If VPC Peering is disconnected, this can be used to re-establish.
Output only.
core.String? peeringNetwork;