AppEngineVersionInfo class

For display only.

Metadata associated with an App Engine version.

Constructors

AppEngineVersionInfo({String? displayName, String? environment, String? runtime, String? uri})
AppEngineVersionInfo.fromJson(Map json_)

Properties

displayName ↔ String?
Name of an App Engine version.
getter/setter pair
environment ↔ String?
App Engine execution environment for a version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtime ↔ String?
Runtime of the App Engine version.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
URI of an App Engine version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited