CloudFunctionInfo class

For display only.

Metadata associated with a Cloud Function.

Constructors

CloudFunctionInfo({String? displayName, String? location, String? uri, String? versionId})
CloudFunctionInfo.fromJson(Map json_)

Properties

displayName ↔ String?
Name of a Cloud Function.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
Location in which the Cloud Function is deployed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
URI of the Cloud Function.
getter/setter pair
versionId ↔ String?
Latest successfully deployed version id of the Cloud Function.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited