networkUri property
URI of a Cloud SQL instance network or empty string if the instance does not have one.
In format "projects/{project}/global/networks/{network}".
Implementation
core.String? networkUri;
URI of a Cloud SQL instance network or empty string if the instance does not have one.
In format "projects/{project}/global/networks/{network}".
core.String? networkUri;