ConnectivityTest class

A Connectivity Test for a network reachability analysis.

Constructors

ConnectivityTest({bool? bypassFirewallChecks, String? createTime, String? description, Endpoint? destination, String? displayName, Map<String, String>? labels, String? name, ProbingDetails? probingDetails, String? protocol, ReachabilityDetails? reachabilityDetails, List<String>? relatedProjects, ReachabilityDetails? returnReachabilityDetails, bool? roundTrip, Endpoint? source, String? updateTime})
ConnectivityTest.fromJson(Map json_)

Properties

bypassFirewallChecks ↔ bool?
Whether the analysis should skip firewall checking.
getter/setter pair
createTime ↔ String?
The time the test was created.
getter/setter pair
description ↔ String?
The user-supplied description of the Connectivity Test.
getter/setter pair
destination ↔ Endpoint?
Destination specification of the Connectivity Test.
getter/setter pair
displayName ↔ String?
The display name of a Connectivity Test.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Resource labels to represent user-provided metadata.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
probingDetails ↔ ProbingDetails?
The probing details of this test from the latest run, present for applicable tests only.
getter/setter pair
protocol ↔ String?
IP Protocol of the test.
getter/setter pair
reachabilityDetails ↔ ReachabilityDetails?
The reachability details of this test from the latest run.
getter/setter pair
relatedProjects ↔ List<String>?
Other projects that may be relevant for reachability analysis.
getter/setter pair
returnReachabilityDetails ↔ ReachabilityDetails?
The reachability details of this test from the latest run for the return path.
getter/setter pair
roundTrip ↔ bool?
Whether run analysis for the return path from destination to source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Endpoint?
Source specification of the Connectivity Test.
getter/setter pair
updateTime ↔ String?
The time the test's configuration was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited