DirectVpcEgressConnectionInfo class

For display only.

Metadata associated with a serverless direct VPC egress connection.

Constructors

DirectVpcEgressConnectionInfo({String? networkUri, String? region, String? selectedIpAddress, String? selectedIpRange, String? subnetworkUri})
DirectVpcEgressConnectionInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkUri ↔ String?
URI of the VPC network for direct egress.
getter/setter pair
region ↔ String?
Region in which the Direct VPC egress is deployed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedIpAddress ↔ String?
Selected starting IP address, from the selected IP range.
getter/setter pair
selectedIpRange ↔ String?
Selected IP range.
getter/setter pair
subnetworkUri ↔ String?
URI of the subnetwork for direct egress.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited