EffectiveVpcFlowLogsConfig class

A configuration to generate a response for GetEffectiveVpcFlowLogsConfig request.

Constructors

EffectiveVpcFlowLogsConfig({String? aggregationInterval, String? crossProjectMetadata, String? filterExpr, double? flowSampling, String? interconnectAttachment, String? metadata, List<String>? metadataFields, String? name, String? network, String? scope, String? state, String? subnet, String? vpnTunnel})
EffectiveVpcFlowLogsConfig.fromJson(Map json_)

Properties

aggregationInterval ↔ String?
The aggregation interval for the logs.
getter/setter pair
crossProjectMetadata ↔ String?
Determines whether to include cross project annotations in the logs.
getter/setter pair
filterExpr ↔ String?
Export filter used to define which VPC Flow Logs should be logged.
getter/setter pair
flowSampling ↔ double?
The value of the field must be in (0, 1].
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interconnectAttachment ↔ String?
Traffic will be logged from the Interconnect Attachment.
getter/setter pair
metadata ↔ String?
Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs.
getter/setter pair
metadataFields ↔ List<String>?
Custom metadata fields to include in the reported VPC flow logs.
getter/setter pair
name ↔ String?
Unique name of the configuration.
getter/setter pair
network ↔ String?
Traffic will be logged from VMs, VPN tunnels and Interconnect Attachments within the network.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
Specifies the scope of the config (e.g., SUBNET, NETWORK, ORGANIZATION..). Possible string values are:
getter/setter pair
state ↔ String?
The state of the VPC Flow Log configuration.
getter/setter pair
subnet ↔ String?
Traffic will be logged from VMs within the subnetwork.
getter/setter pair
vpnTunnel ↔ String?
Traffic will be logged from the VPN Tunnel.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited