Endpoint class

Source or destination of the Connectivity Test.

Constructors

Endpoint({AppEngineVersionEndpoint? appEngineVersion, CloudFunctionEndpoint? cloudFunction, CloudRunRevisionEndpoint? cloudRunRevision, String? cloudSqlInstance, String? forwardingRule, String? forwardingRuleTarget, String? fqdn, String? gkeMasterCluster, String? gkePod, String? instance, String? ipAddress, String? loadBalancerId, String? loadBalancerType, String? network, String? networkType, int? port, String? projectId, String? redisCluster, String? redisInstance})
Endpoint.fromJson(Map json_)

Properties

appEngineVersion ↔ AppEngineVersionEndpoint?
An App Engine service version.
getter/setter pair
cloudFunction ↔ CloudFunctionEndpoint?
A Cloud Function.
getter/setter pair
cloudRunRevision ↔ CloudRunRevisionEndpoint?
A Cloud Run revision Applicable only to source endpoint.
getter/setter pair
cloudSqlInstance ↔ String?
A Cloud SQL instance URI.
getter/setter pair
forwardingRule ↔ String?
A forwarding rule and its corresponding IP address represent the frontend configuration of a Google Cloud load balancer.
getter/setter pair
forwardingRuleTarget ↔ String?
Specifies the type of the target of the forwarding rule.
getter/setter pair
fqdn ↔ String?
DNS endpoint of Google Kubernetes Engine cluster control plane.
getter/setter pair
gkeMasterCluster ↔ String?
A cluster URI for Google Kubernetes Engine cluster control plane.
getter/setter pair
gkePod ↔ String?
A GKE Pod URI.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instance ↔ String?
A Compute Engine instance URI.
getter/setter pair
ipAddress ↔ String?
The IP address of the endpoint, which can be an external or internal IP.
getter/setter pair
loadBalancerId ↔ String?
ID of the load balancer the forwarding rule points to.
getter/setter pair
loadBalancerType ↔ String?
Type of the load balancer the forwarding rule points to.
getter/setter pair
network ↔ String?
A VPC network URI.
getter/setter pair
networkType ↔ String?
For source endpoints, type of the network where the endpoint is located.
getter/setter pair
port ↔ int?
The IP protocol port of the endpoint.
getter/setter pair
projectId ↔ String?
For source endpoints, endpoint project ID.
getter/setter pair
redisCluster ↔ String?
A Redis Cluster URI.
getter/setter pair
redisInstance ↔ String?
A Redis Instance URI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited