sourceNetworkUri property
URI of the network where this packet originates from.
Format: projects/{project_id}/global/networks/{network_id}
Implementation
core.String? sourceNetworkUri;
URI of the network where this packet originates from.
Format: projects/{project_id}/global/networks/{network_id}
core.String? sourceNetworkUri;