FirewallInfo class

For display only.

Metadata associated with a VPC firewall rule, an implied VPC firewall rule, or a firewall policy rule.

Constructors

FirewallInfo({String? action, String? direction, String? displayName, String? firewallRuleType, String? networkUri, String? policy, int? policyPriority, String? policyUri, int? priority, List<String>? targetServiceAccounts, List<String>? targetTags, String? targetType, String? uri})
FirewallInfo.fromJson(Map json_)

Properties

action ↔ String?
Possible values: ALLOW, DENY, APPLY_SECURITY_PROFILE_GROUP
getter/setter pair
direction ↔ String?
Possible values: INGRESS, EGRESS
getter/setter pair
displayName ↔ String?
The display name of the firewall rule.
getter/setter pair
firewallRuleType ↔ String?
The firewall rule's type. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
networkUri ↔ String?
The URI of the VPC network that the firewall rule is associated with in format "projects/{project}/global/networks/{network}".
getter/setter pair
policy ↔ String?
The name of the firewall policy that this rule is associated with.
getter/setter pair
policyPriority ↔ int?
The priority of the firewall policy that this rule is associated with.
getter/setter pair
policyUri ↔ String?
The URI of the firewall policy that this rule is associated with.
getter/setter pair
priority ↔ int?
The priority of the firewall rule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetServiceAccounts ↔ List<String>?
The target service accounts specified by the firewall rule.
getter/setter pair
targetTags ↔ List<String>?
The target tags defined by the VPC firewall rule.
getter/setter pair
targetType ↔ String?
Target type of the firewall rule. Possible string values are:
getter/setter pair
uri ↔ String?
The URI of the firewall rule in format "projects/{project}/global/firewalls/{firewall}".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited