networkUri property

String? networkUri
getter/setter pair

The URI of the VPC network that the firewall rule is associated with in format "projects/{project}/global/networks/{network}".

This field is not applicable to hierarchical firewall policy rules.

Implementation

core.String? networkUri;