ForwardingRuleInfo class

For display only.

Metadata associated with a Compute Engine forwarding rule.

Constructors

ForwardingRuleInfo({String? displayName, String? envoyHealthCheckFirewallsConfigState, String? loadBalancerName, String? matchedPortRange, String? matchedProtocol, String? networkUri, String? pscGoogleApiTarget, String? pscServiceAttachmentUri, String? region, String? target, String? uri, String? vip})
ForwardingRuleInfo.fromJson(Map json_)

Properties

displayName String?
Name of the forwarding rule.
getter/setter pair
envoyHealthCheckFirewallsConfigState String?
State of the firewalls allowing health check traffic to the load balancer frontend (Envoy proxies).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
loadBalancerName String?
Name of the load balancer the forwarding rule belongs to.
getter/setter pair
matchedPortRange String?
Port range defined in the forwarding rule that matches the packet.
getter/setter pair
matchedProtocol String?
Protocol defined in the forwarding rule that matches the packet.
getter/setter pair
networkUri String?
URI of a VPC network where the forwarding rule is located in format "projects/{project}/global/networks/{network}".
getter/setter pair
pscGoogleApiTarget String?
PSC Google API target this forwarding rule targets (if applicable).
getter/setter pair
pscServiceAttachmentUri String?
URI of the PSC service attachment this forwarding rule targets (if applicable) in format "projects/{project}/regions/{region}/serviceAttachments/{service_attachment}".
getter/setter pair
region String?
Region of the forwarding rule.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target String?
Target type of the forwarding rule.
getter/setter pair
uri String?
URI of the forwarding rule in format "projects/{project}/global/forwardingRules/{forwarding_rule}" (global) or "projects/{project}/regions/{region}/forwardingRules/{forwarding_rule}" (regional).
getter/setter pair
vip String?
VIP of the forwarding rule.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited