envoyHealthCheckFirewallsConfigState property
State of the firewalls allowing health check traffic to the load balancer frontend (Envoy proxies).
This is the result of the firewall configuration analysis verifying that health check traffic from required IP ranges to the the Envoy-based load balancer frontend is allowed by firewall rules with the load balancer target.
Output only. Possible string values are:
- "HEALTH_CHECK_FIREWALLS_CONFIG_STATE_UNSPECIFIED" : Configuration state unspecified. It usually means that there are no relevant health checks for this load balancer frontend, or there was an unexpected configuration error preventing Connectivity Tests from verifying health check configuration.
- "FIREWALLS_CONFIGURED" : Firewall rules (policies) allow health check traffic to the load balancer frontend.
- "FIREWALLS_PARTIALLY_CONFIGURED" : Firewall rules (policies) allow health check traffic to the load balancer frontend only from a part of the required IP ranges.
- "FIREWALLS_NOT_CONFIGURED" : Firewall rules (policies) deny health check traffic to the load balancer frontend.
- "FIREWALLS_UNSUPPORTED" : Connectivity Tests doesn't support evaluating some of the firewall rules in the network, so it's not able to verify health check configuration status.
Implementation
core.String? envoyHealthCheckFirewallsConfigState;