GenerateMonitoringPointConfigResponse class
Message for response for getting Monitoring Point configuration of a NetworkMonitoringProvider resource.
Constructors
-
GenerateMonitoringPointConfigResponse({Map<
String, Object?> ? config}) - GenerateMonitoringPointConfigResponse.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited