GenerateProviderAccessTokenResponse class

Message for response for generating an access token for a NetworkMonitoringProvider resource.

Properties

hashCode int
The hash code for this object.
no setterinherited
providerAccessToken String?
Provider access token for the NetworkMonitoringProvider resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited