GkeNetworkPolicyInfo class

For display only.

Metadata associated with a GKE Network Policy.

Constructors

GkeNetworkPolicyInfo({String? action, String? direction, String? displayName, String? uri})
GkeNetworkPolicyInfo.fromJson(Map json_)

Properties

action String?
Possible values: ALLOW, DENY
getter/setter pair
direction String?
Possible values: INGRESS, EGRESS
getter/setter pair
displayName String?
The name of the Network Policy.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
The URI of the Network Policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited