cloudRouterUri property
URI of the Cloud Router to be used for dynamic routing.
Format: projects/{project_id}/regions/{region}/routers/{router_id}
Implementation
core.String? cloudRouterUri;
URI of the Cloud Router to be used for dynamic routing.
Format: projects/{project_id}/regions/{region}/routers/{router_id}
core.String? cloudRouterUri;