LoadBalancerBackend class

For display only.

Metadata associated with a specific load balancer backend.

Constructors

LoadBalancerBackend({String? displayName, List<String>? healthCheckAllowingFirewallRules, List<String>? healthCheckBlockingFirewallRules, String? healthCheckFirewallState, String? uri})
LoadBalancerBackend.fromJson(Map json_)

Properties

displayName ↔ String?
Name of a Compute Engine instance or network endpoint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthCheckAllowingFirewallRules ↔ List<String>?
A list of firewall rule URIs allowing probes from health check IP ranges.
getter/setter pair
healthCheckBlockingFirewallRules ↔ List<String>?
A list of firewall rule URIs blocking probes from health check IP ranges.
getter/setter pair
healthCheckFirewallState ↔ String?
State of the health check firewall configuration. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
URI of a Compute Engine instance or network endpoint.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited