backendBucketUri property
URI of the backend bucket this backend targets (if applicable) in format "projects/{project}/global/backendBuckets/{backend_bucket}".
Implementation
core.String? backendBucketUri;
URI of the backend bucket this backend targets (if applicable) in format "projects/{project}/global/backendBuckets/{backend_bucket}".
core.String? backendBucketUri;