MonitoringPoint class

Message describing MonitoringPoint resource.

Constructors

MonitoringPoint({bool? autoGeoLocationEnabled, String? connectionStatus, String? createTime, String? displayName, List<String>? errors, GeoLocation? geoLocation, Host? host, String? hostname, String? name, List<NetworkInterface>? networkInterfaces, String? originatingIp, List<ProviderTag>? providerTags, String? type, String? updateTime, bool? upgradeAvailable, String? upgradeType, String? version})
MonitoringPoint.fromJson(Map json_)

Properties

autoGeoLocationEnabled ↔ bool?
Indicates if automaitic geographic location is enabled for the MonitoringPoint.
getter/setter pair
connectionStatus ↔ String?
Connection status of the MonitoringPoint.
getter/setter pair
createTime ↔ String?
The time the MonitoringPoint was created.
getter/setter pair
displayName ↔ String?
Display name of the MonitoringPoint.
getter/setter pair
errors ↔ List<String>?
The codes of errors detected in the MonitoringPoint.
getter/setter pair
geoLocation ↔ GeoLocation?
The geographical location of the MonitoringPoint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ Host?
The host information of the MonitoringPoint.
getter/setter pair
hostname ↔ String?
The hostname of the MonitoringPoint.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
networkInterfaces ↔ List<NetworkInterface>?
The network interfaces of the MonitoringPoint.
getter/setter pair
originatingIp ↔ String?
IP address visible when MonitoringPoint connects to the provider.
getter/setter pair
providerTags ↔ List<ProviderTag>?
The provider tags of the MonitoringPoint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Deployment type of the MonitoringPoint.
getter/setter pair
updateTime ↔ String?
The time the MonitoringPoint was updated.
getter/setter pair
upgradeAvailable ↔ bool?
Indicates if an upgrade is available for the MonitoringPoint.
getter/setter pair
upgradeType ↔ String?
The type of upgrade available for the MonitoringPoint.
getter/setter pair
version ↔ String?
Version of the software running on the MonitoringPoint.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited