NetworkInfo class

For display only.

Metadata associated with a Compute Engine network.

Constructors

NetworkInfo({String? displayName, String? matchedIpRange, String? matchedSubnetUri, String? region, String? uri})
NetworkInfo.fromJson(Map json_)

Properties

displayName ↔ String?
Name of a Compute Engine network.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchedIpRange ↔ String?
The IP range of the subnet matching the source IP address of the test.
getter/setter pair
matchedSubnetUri ↔ String?
URI of the subnet matching the source IP address of the test.
getter/setter pair
region ↔ String?
The region of the subnet matching the source IP address of the test.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
URI of a Compute Engine network.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited