NetworkMonitoringProvider class

Message describing NetworkMonitoringProvider resource.

Constructors

NetworkMonitoringProvider({String? createTime, List<String>? errors, String? name, String? providerType, String? providerUri, String? state, String? updateTime})
NetworkMonitoringProvider.fromJson(Map json_)

Properties

createTime ↔ String?
The time the NetworkMonitoringProvider was created.
getter/setter pair
errors ↔ List<String>?
The list of error messages detected for the NetworkMonitoringProvider.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
providerType ↔ String?
Type of the NetworkMonitoringProvider.
getter/setter pair
providerUri ↔ String?
Link to the provider's UI.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the NetworkMonitoringProvider.
getter/setter pair
updateTime ↔ String?
The time the NetworkMonitoringProvider was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited