destinationMonitoringPointId property
Provider's UUID of the destination MonitoringPoint.
This id may not point to a resource in the Google Cloud.
Output only.
Implementation
core.String? destinationMonitoringPointId;
Provider's UUID of the destination MonitoringPoint.
This id may not point to a resource in the Google Cloud.
Output only.
core.String? destinationMonitoringPointId;