NgfwPacketInspectionInfo class

For display only.

Metadata associated with a layer 7 packet inspection by the firewall.

Constructors

NgfwPacketInspectionInfo({String? securityProfileGroupUri})
NgfwPacketInspectionInfo.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityProfileGroupUri String?
URI of the security profile group associated with this firewall packet inspection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited