ProjectsLocationsNetworkMonitoringProvidersMonitoringPointsResource class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

downloadInstallScript(String parent, {String? P_password, String? hostname, String? monitoringPointType, String? ntpServerAddress, String? ntpServerSecondaryAddress, bool? privateConnectivityEnabled, String? staticIpAddress_dnsServerAddress, String? staticIpAddress_dnsServerSecondaryAddress, String? staticIpAddress_domain, String? staticIpAddress_gatewayAddress, String? staticIpAddress_ipAddress, String? staticIpAddress_netmask, String? timeZone_id, String? timeZone_version, bool? useDhcp, String? $fields}) Future<HttpBody>
Downloads an install script for MonitoringPoints for a given network monitoring provider.
downloadRecreateInstallScript(String name, {String? hostname, String? $fields}) Future<HttpBody>
Downloads an install script for a specific Container MonitoringPoint.
downloadServerConnectConfig(String parent, {String? $fields}) Future<HttpBody>
Downloads the server connect configuration for a given network monitoring provider.
get(String name, {String? $fields}) Future<MonitoringPoint>
Gets the MonitoringPoint resource.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<ListMonitoringPointsResponse>
Lists MonitoringPoints for a given network monitoring provider.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited