downloadRecreateInstallScript method

Future<HttpBody> downloadRecreateInstallScript(
  1. String name, {
  2. String? hostname,
  3. String? $fields,
})

Downloads an install script for a specific Container MonitoringPoint.

Request parameters:

name - Required. Resource name of the MonitoringPoint. Format: projects/{project}/locations/{location}/networkMonitoringProviders/{network_monitoring_provider}/monitoringPoints/{monitoring_point} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/networkMonitoringProviders/\[^/\]+/monitoringPoints/\[^/\]+$.

hostname - Optional. The hostname of the MonitoringPoint, e.g. "test-vm"

$fields - Selector specifying which fields to include in a partial response.

Completes with a HttpBody.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<HttpBody> downloadRecreateInstallScript(
  core.String name, {
  core.String? hostname,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'hostname': ?hostname == null ? null : [hostname],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'v1/' + core.Uri.encodeFull('$name') + ':downloadRecreateInstallScript';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return HttpBody.fromJson(response_ as core.Map<core.String, core.dynamic>);
}