downloadServerConnectConfig method
Downloads the server connect configuration for a given network monitoring provider.
Request parameters:
parent - Required. Parent value for DownloadServerConnectConfigRequest.
Format:
projects/{project}/locations/{location}/networkMonitoringProviders/{network_monitoring_provider}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/networkMonitoringProviders/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a HttpBody.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<HttpBody> downloadServerConnectConfig(
core.String parent, {
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v1/' +
core.Uri.encodeFull('$parent') +
'/monitoringPoints:downloadServerConnectConfig';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return HttpBody.fromJson(response_ as core.Map<core.String, core.dynamic>);
}