generateMonitoringPointConfig method

Future<GenerateMonitoringPointConfigResponse> generateMonitoringPointConfig(
  1. String name, {
  2. bool? privateConnectivityEnabled,
  3. String? $fields,
})

Generates Monitoring Point configuration of a NetworkMonitoringProvider resource.

Request parameters:

name - Required. Name of the resource. Format: projects/{project}/locations/{location}/networkMonitoringProviders/{network_monitoring_provider} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/networkMonitoringProviders/\[^/\]+$.

privateConnectivityEnabled - Optional. For Google Cloud MPs, this field indicates whether the Monitoring Point is deployed in a Private Service Connect deployment. Not used for non-Google Cloud MPs.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GenerateMonitoringPointConfigResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GenerateMonitoringPointConfigResponse>
generateMonitoringPointConfig(
  core.String name, {
  core.bool? privateConnectivityEnabled,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'privateConnectivityEnabled': ?privateConnectivityEnabled == null
        ? null
        : ['${privateConnectivityEnabled}'],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'v1/' + core.Uri.encodeFull('$name') + ':generateMonitoringPointConfig';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return GenerateMonitoringPointConfigResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}