generateProviderAccessToken method

Future<GenerateProviderAccessTokenResponse> generateProviderAccessToken(
  1. String name, {
  2. String? gcpAccessToken,
  3. String? $fields,
})

Generates a provider access token for a given Google access token.

Provider access token is a short-lived token that is used to access resources in the provider's platform.

Request parameters:

name - Required. Name of the resource. Format: projects/{project}/locations/{location}/networkMonitoringProviders/{network_monitoring_provider} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/networkMonitoringProviders/\[^/\]+$.

gcpAccessToken - Required. Google access token.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GenerateProviderAccessTokenResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GenerateProviderAccessTokenResponse> generateProviderAccessToken(
  core.String name, {
  core.String? gcpAccessToken,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'gcpAccessToken': ?gcpAccessToken == null ? null : [gcpAccessToken],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'v1/' + core.Uri.encodeFull('$name') + ':generateProviderAccessToken';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return GenerateProviderAccessTokenResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}