ProviderTag class

Message describing the provider tag.

Constructors

ProviderTag({String? category, String? resourceType, String? value})
ProviderTag.fromJson(Map json_)

Properties

category ↔ String?
The category of the provider tag.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resourceType ↔ String?
The resource type of the provider tag.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The value of the provider tag.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited