ProxyConnectionInfo class

For display only.

Metadata associated with ProxyConnection.

Constructors

ProxyConnectionInfo({String? networkUri, String? newDestinationIp, int? newDestinationPort, String? newSourceIp, int? newSourcePort, String? oldDestinationIp, int? oldDestinationPort, String? oldSourceIp, int? oldSourcePort, String? protocol, String? subnetUri})
ProxyConnectionInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkUri ↔ String?
URI of the network where connection is proxied.
getter/setter pair
newDestinationIp ↔ String?
Destination IP address of a new connection.
getter/setter pair
newDestinationPort ↔ int?
Destination port of a new connection.
getter/setter pair
newSourceIp ↔ String?
Source IP address of a new connection.
getter/setter pair
newSourcePort ↔ int?
Source port of a new connection.
getter/setter pair
oldDestinationIp ↔ String?
Destination IP address of an original connection
getter/setter pair
oldDestinationPort ↔ int?
Destination port of an original connection.
getter/setter pair
oldSourceIp ↔ String?
Source IP address of an original connection.
getter/setter pair
oldSourcePort ↔ int?
Source port of an original connection.
getter/setter pair
protocol ↔ String?
IP protocol in string format, for example: "TCP", "UDP", "ICMP".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnetUri ↔ String?
Uri of proxy subnet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited