RedisInstanceInfo class

For display only.

Metadata associated with a Cloud Redis Instance.

Constructors

RedisInstanceInfo({String? displayName, String? networkUri, String? primaryEndpointIp, String? readEndpointIp, String? region, String? uri})
RedisInstanceInfo.fromJson(Map json_)

Properties

displayName ↔ String?
Name of a Cloud Redis Instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
networkUri ↔ String?
URI of a Cloud Redis Instance network.
getter/setter pair
primaryEndpointIp ↔ String?
Primary endpoint IP address of a Cloud Redis Instance.
getter/setter pair
readEndpointIp ↔ String?
Read endpoint IP address of a Cloud Redis Instance (if applicable).
getter/setter pair
region ↔ String?
Region in which the Cloud Redis Instance is defined.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
URI of a Cloud Redis Instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited