RouteInfo class

For display only.

Metadata associated with a Compute Engine route.

Constructors

RouteInfo({String? advertisedRouteNextHopUri, String? advertisedRouteSourceRouterUri, String? destIpRange, List<String>? destPortRanges, String? displayName, List<String>? instanceTags, String? nccHubRouteUri, String? nccHubUri, String? nccSpokeUri, String? networkUri, String? nextHop, String? nextHopNetworkUri, String? nextHopType, String? nextHopUri, String? originatingRouteDisplayName, String? originatingRouteUri, int? priority, List<String>? protocols, String? region, String? routeScope, String? routeType, String? srcIpRange, List<String>? srcPortRanges, String? uri})
RouteInfo.fromJson(Map json_)

Properties

advertisedRouteNextHopUri ↔ String?
For ADVERTISED routes, the URI of their next hop, i.e. the URI of the hybrid endpoint (VPN tunnel, Interconnect attachment, NCC router appliance) the advertised prefix is advertised through, or URI of the source peered network.
getter/setter pair
advertisedRouteSourceRouterUri ↔ String?
For ADVERTISED dynamic routes, the URI of the Cloud Router that advertised the corresponding IP prefix in format "projects/{project}/regions/{region}/routers/{router}".
getter/setter pair
destIpRange ↔ String?
Destination IP range of the route.
getter/setter pair
destPortRanges ↔ List<String>?
Destination port ranges of the route.
getter/setter pair
displayName ↔ String?
Name of a route.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceTags ↔ List<String>?
Instance tags of the route.
getter/setter pair
nccHubRouteUri ↔ String?
For PEERING_SUBNET and PEERING_DYNAMIC routes that are advertised by NCC Hub, the URI of the corresponding route in NCC Hub's routing table.
getter/setter pair
nccHubUri ↔ String?
URI of the NCC Hub the route is advertised by in format "projects/{project}/locations/global/hubs/{hub}".
getter/setter pair
nccSpokeUri ↔ String?
URI of the destination NCC Spoke in format "projects/{project}/locations/{location}/spokes/{spoke}" (regional) or "projects/{project}/locations/global/spokes/{spoke}" (global).
getter/setter pair
networkUri ↔ String?
URI of a VPC network where route is located in format "projects/{project}/global/networks/{network}".
getter/setter pair
nextHop ↔ String?
String type of the next hop of the route (for example, "VPN tunnel").
getter/setter pair
nextHopNetworkUri ↔ String?
URI of a VPC network where the next hop resource is located in format "projects/{project}/global/networks/{network}".
getter/setter pair
nextHopType ↔ String?
Type of next hop. Possible string values are:
getter/setter pair
nextHopUri ↔ String?
URI of the next hop resource.
getter/setter pair
originatingRouteDisplayName ↔ String?
For PEERING_SUBNET, PEERING_STATIC and PEERING_DYNAMIC routes, the name of the originating SUBNET/STATIC/DYNAMIC route.
getter/setter pair
originatingRouteUri ↔ String?
For PEERING_SUBNET and PEERING_STATIC routes, the URI of the originating SUBNET/STATIC route.
getter/setter pair
priority ↔ int?
Priority of the route.
getter/setter pair
protocols ↔ List<String>?
Protocols of the route.
getter/setter pair
region ↔ String?
Region of the route.
getter/setter pair
routeScope ↔ String?
Indicates where route is applicable.
getter/setter pair
routeType ↔ String?
Type of route. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
srcIpRange ↔ String?
Source IP address range of the route.
getter/setter pair
srcPortRanges ↔ List<String>?
Source port ranges of the route.
getter/setter pair
uri ↔ String?
URI of a route in format "projects/{project}/global/routes/{route}".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited