networkUri property
URI of a VPC network where route is located in format "projects/{project}/global/networks/{network}".
Implementation
core.String? networkUri;
URI of a VPC network where route is located in format "projects/{project}/global/networks/{network}".
core.String? networkUri;