ServerlessNegInfo class
For display only.
Metadata associated with the serverless network endpoint group backend.
Constructors
- ServerlessNegInfo({String? negUri})
- ServerlessNegInfo.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- negUri ↔ String?
-
URI of the serverless network endpoint group in format
"projects/{project}/regions/{region}/networkEndpointGroups/{network_endpoint_group}".
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited