Step class

A simulated forwarding path is composed of multiple steps.

Each step has a well-defined state and an associated configuration.

Constructors

Step({AbortInfo? abort, AppEngineVersionInfo? appEngineVersion, bool? causesDrop, CloudFunctionInfo? cloudFunction, CloudRunRevisionInfo? cloudRunRevision, CloudSQLInstanceInfo? cloudSqlInstance, DeliverInfo? deliver, String? description, DirectVpcEgressConnectionInfo? directVpcEgressConnection, DropInfo? drop, EndpointInfo? endpoint, FirewallInfo? firewall, ForwardInfo? forward, ForwardingRuleInfo? forwardingRule, GKEMasterInfo? gkeMaster, GkePodInfo? gkePod, GoogleServiceInfo? googleService, HybridSubnetInfo? hybridSubnet, InstanceInfo? instance, InterconnectAttachmentInfo? interconnectAttachment, IpMasqueradingSkippedInfo? ipMasqueradingSkipped, LoadBalancerInfo? loadBalancer, LoadBalancerBackendInfo? loadBalancerBackendInfo, NatInfo? nat, NetworkInfo? network, String? projectId, ProxyConnectionInfo? proxyConnection, RedisClusterInfo? redisCluster, RedisInstanceInfo? redisInstance, RouteInfo? route, ServerlessExternalConnectionInfo? serverlessExternalConnection, ServerlessNegInfo? serverlessNeg, String? state, StorageBucketInfo? storageBucket, VpcConnectorInfo? vpcConnector, VpnGatewayInfo? vpnGateway, VpnTunnelInfo? vpnTunnel})
Step.fromJson(Map json_)

Properties

abort ↔ AbortInfo?
Display information of the final state "abort" and reason.
getter/setter pair
appEngineVersion ↔ AppEngineVersionInfo?
Display information of an App Engine service version.
getter/setter pair
causesDrop ↔ bool?
This is a step that leads to the final state Drop.
getter/setter pair
cloudFunction ↔ CloudFunctionInfo?
Display information of a Cloud Function.
getter/setter pair
cloudRunRevision ↔ CloudRunRevisionInfo?
Display information of a Cloud Run revision.
getter/setter pair
cloudSqlInstance ↔ CloudSQLInstanceInfo?
Display information of a Cloud SQL instance.
getter/setter pair
deliver ↔ DeliverInfo?
Display information of the final state "deliver" and reason.
getter/setter pair
description ↔ String?
A description of the step.
getter/setter pair
directVpcEgressConnection ↔ DirectVpcEgressConnectionInfo?
Display information of a serverless direct VPC egress connection.
getter/setter pair
drop ↔ DropInfo?
Display information of the final state "drop" and reason.
getter/setter pair
endpoint ↔ EndpointInfo?
Display information of the source and destination under analysis.
getter/setter pair
firewall ↔ FirewallInfo?
Display information of a Compute Engine firewall rule.
getter/setter pair
forward ↔ ForwardInfo?
Display information of the final state "forward" and reason.
getter/setter pair
forwardingRule ↔ ForwardingRuleInfo?
Display information of a Compute Engine forwarding rule.
getter/setter pair
gkeMaster ↔ GKEMasterInfo?
Display information of a Google Kubernetes Engine cluster master.
getter/setter pair
gkePod ↔ GkePodInfo?
Display information of a Google Kubernetes Engine Pod.
getter/setter pair
googleService ↔ GoogleServiceInfo?
Display information of a Google service
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hybridSubnet ↔ HybridSubnetInfo?
Display information of a hybrid subnet.
getter/setter pair
instance ↔ InstanceInfo?
Display information of a Compute Engine instance.
getter/setter pair
interconnectAttachment ↔ InterconnectAttachmentInfo?
Display information of an interconnect attachment.
getter/setter pair
ipMasqueradingSkipped ↔ IpMasqueradingSkippedInfo?
Display information of the reason why GKE Pod IP masquerading was skipped.
getter/setter pair
loadBalancer ↔ LoadBalancerInfo?
Display information of the load balancers.
getter/setter pair
loadBalancerBackendInfo ↔ LoadBalancerBackendInfo?
Display information of a specific load balancer backend.
getter/setter pair
nat ↔ NatInfo?
Display information of a NAT.
getter/setter pair
network ↔ NetworkInfo?
Display information of a Google Cloud network.
getter/setter pair
projectId ↔ String?
Project ID that contains the configuration this step is validating.
getter/setter pair
proxyConnection ↔ ProxyConnectionInfo?
Display information of a ProxyConnection.
getter/setter pair
redisCluster ↔ RedisClusterInfo?
Display information of a Redis Cluster.
getter/setter pair
redisInstance ↔ RedisInstanceInfo?
Display information of a Redis Instance.
getter/setter pair
route ↔ RouteInfo?
Display information of a Compute Engine route.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverlessExternalConnection ↔ ServerlessExternalConnectionInfo?
Display information of a serverless public (external) connection.
getter/setter pair
serverlessNeg ↔ ServerlessNegInfo?
Display information of a Serverless network endpoint group backend.
getter/setter pair
state ↔ String?
Each step is in one of the pre-defined states. Possible string values are:
getter/setter pair
storageBucket ↔ StorageBucketInfo?
Display information of a Storage Bucket.
getter/setter pair
vpcConnector ↔ VpcConnectorInfo?
Display information of a VPC connector.
getter/setter pair
vpnGateway ↔ VpnGatewayInfo?
Display information of a Compute Engine VPN gateway.
getter/setter pair
vpnTunnel ↔ VpnTunnelInfo?
Display information of a Compute Engine VPN tunnel.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited