StorageBucketInfo class

For display only.

Metadata associated with Storage Bucket.

Constructors

StorageBucketInfo({String? bucket})
StorageBucketInfo.fromJson(Map json_)

Properties

bucket ↔ String?
Cloud Storage Bucket name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited