ViewerPermissionMissingInfo class

For display only.

Metadata associated with a step that was redacted due to missing permissions.

Properties

hashCode int
The hash code for this object.
no setterinherited
resourceTypes List<String>?
Types of the resources that the user does not have permission to view.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited