VpcFlowLogsConfig class

A configuration to generate VPC Flow Logs.

Constructors

VpcFlowLogsConfig({String? aggregationInterval, String? createTime, String? crossProjectMetadata, String? description, String? filterExpr, double? flowSampling, String? interconnectAttachment, Map<String, String>? labels, String? metadata, List<String>? metadataFields, String? name, String? network, String? state, String? subnet, String? targetResourceState, String? updateTime, String? vpnTunnel})
VpcFlowLogsConfig.fromJson(Map json_)

Properties

aggregationInterval ↔ String?
The aggregation interval for the logs.
getter/setter pair
createTime ↔ String?
The time the config was created.
getter/setter pair
crossProjectMetadata ↔ String?
Determines whether to include cross project annotations in the logs.
getter/setter pair
description ↔ String?
The user-supplied description of the VPC Flow Logs configuration.
getter/setter pair
filterExpr ↔ String?
Export filter used to define which VPC Flow Logs should be logged.
getter/setter pair
flowSampling ↔ double?
The value of the field must be in (0, 1].
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interconnectAttachment ↔ String?
Traffic will be logged from the Interconnect Attachment.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user-provided metadata.
getter/setter pair
metadata ↔ String?
Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs.
getter/setter pair
metadataFields ↔ List<String>?
Custom metadata fields to include in the reported VPC flow logs.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
network ↔ String?
Traffic will be logged from VMs, VPN tunnels and Interconnect Attachments within the network.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the VPC Flow Log configuration.
getter/setter pair
subnet ↔ String?
Traffic will be logged from VMs within the subnetwork.
getter/setter pair
targetResourceState ↔ String?
Describes the state of the configured target resource for diagnostic purposes.
getter/setter pair
updateTime ↔ String?
The time the config was updated.
getter/setter pair
vpnTunnel ↔ String?
Traffic will be logged from the VPN Tunnel.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited