AntivirusOverride class

Defines what action to take for antivirus threats per protocol.

Constructors

AntivirusOverride({String? action, String? protocol})
AntivirusOverride.fromJson(Map json_)

Properties

action ↔ String?
Threat action override.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
protocol ↔ String?
Protocol to match.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited