policyProfile property

String? policyProfile
getter/setter pair

Defines the type of authorization being performed.

If not specified, REQUEST_AUTHZ is applied. This field cannot be changed once AuthzPolicy is created.

Optional. Immutable. Possible string values are:

  • "POLICY_PROFILE_UNSPECIFIED" : Unspecified policy profile.
  • "REQUEST_AUTHZ" : Applies to request authorization. CUSTOM authorization policies with Authz extensions will be allowed with EXT_AUTHZ_GRPC or EXT_PROC_GRPC protocols. Extensions are invoked only for request header events.
  • "CONTENT_AUTHZ" : Applies to content security, sanitization, etc. Only CUSTOM action is allowed in this policy profile. AuthzExtensions in the custom provider must support EXT_PROC_GRPC protocol only and be capable of receiving all EXT_PROC_GRPC events (REQUEST_HEADERS, REQUEST_BODY, REQUEST_TRAILERS, RESPONSE_HEADERS, RESPONSE_BODY, RESPONSE_TRAILERS) with FULL_DUPLEX_STREAMED body send mode.

Implementation

core.String? policyProfile;