AuthzPolicyAuthzRulePrincipal class

Describes the properties of a principal to be matched against.

Properties

hashCode → int
The hash code for this object.
no setterinherited
principal ↔ AuthzPolicyAuthzRuleStringMatch?
A non-empty string whose value is matched against the principal value based on the principal_selector.
getter/setter pair
principalSelector ↔ String?
An enum to decide what principal value the principal rule will match against.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited