loadBalancingScheme property
All gateways and forwarding rules referenced by this policy and extensions must share the same load balancing scheme.
Required only when targeting forwarding rules. If targeting Secure Web
Proxy, this field must be INTERNAL_MANAGED or not specified. Must not be
specified when targeting Agent Gateway. Supported values:
INTERNAL_MANAGED and EXTERNAL_MANAGED. For more information, refer to
Backend services overview.
Optional. Possible string values are:
- "LOAD_BALANCING_SCHEME_UNSPECIFIED" : Default value. Do not use.
- "INTERNAL_MANAGED" : Signifies that this is used for Regional internal or Cross-region internal Application Load Balancing.
- "EXTERNAL_MANAGED" : Signifies that this is used for Global external or Regional external Application Load Balancing.
- "INTERNAL_SELF_MANAGED" : Signifies that this is used for Cloud Service Mesh. Meant for use by CSM GKE controller only.
Implementation
core.String? loadBalancingScheme;