GoogleCloudNetworksecurityV1CertificateProvider class

Specification of certificate provider.

Defines the mechanism to obtain the certificate and private key for peer to peer authentication.

Properties

certificateProviderInstance ↔ CertificateProviderInstance?
The certificate provider instance specification that will be passed to the data plane, which will be used to load necessary credential information.
getter/setter pair
grpcEndpoint ↔ GoogleCloudNetworksecurityV1GrpcEndpoint?
gRPC specific configuration to access the gRPC server to obtain the cert and private key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited