MTLSPolicy class

Specification of the MTLSPolicy.

Constructors

MTLSPolicy({List<ValidationCA>? clientValidationCa, String? clientValidationMode, String? clientValidationTrustConfig})
MTLSPolicy.fromJson(Map json_)

Properties

clientValidationCa ↔ List<ValidationCA>?
Required if the policy is to be used with Traffic Director.
getter/setter pair
clientValidationMode ↔ String?
When the client presents an invalid certificate or no certificate to the load balancer, the client_validation_mode specifies how the client connection is handled.
getter/setter pair
clientValidationTrustConfig ↔ String?
Reference to the TrustConfig from certificatemanager.googleapis.com namespace.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited