ProjectsLocationsSacAttachmentsResource class

Constructors

ProjectsLocationsSacAttachmentsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(SACAttachment request, String parent, {String? requestId, String? sacAttachmentId, String? $fields}) Future<Operation>
Creates a new SACAttachment in a given project and location.
delete(String name, {String? requestId, String? $fields}) Future<Operation>
Deletes the specified attachment.
get(String name, {String? $fields}) Future<SACAttachment>
Returns the specified attachment.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListSACAttachmentsResponse>
Lists SACAttachments in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited