SACRealm class

Represents a Secure Access Connect (SAC) realm resource.

A Secure Access Connect realm establishes a connection between your Google Cloud project and an SSE service.

Constructors

SACRealm({String? createTime, Map<String, String>? labels, String? name, SACRealmPairingKey? pairingKey, String? securityService, String? state, String? updateTime})
SACRealm.fromJson(Map json_)

Properties

createTime String?
Timestamp when the realm was created.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
Optional list of labels applied to the resource.
getter/setter pair
name String?
Identifier.
getter/setter pair
pairingKey SACRealmPairingKey?
Key to be shared with SSE service provider during pairing.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityService String?
SSE service provider associated with the realm.
getter/setter pair
state String?
State of the realm.
getter/setter pair
updateTime String?
Timestamp when the realm was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited