state property
State of the realm.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : No state specified. This should not be used.
- "PENDING_PARTNER_ATTACHMENT" : Has never been attached to a partner. Used only for Prisma Access.
- "PARTNER_ATTACHED" : Currently attached to a partner.
- "PARTNER_DETACHED" : Was once attached to a partner but has been detached.
- "KEY_EXPIRED" : Is not attached to a partner and has an expired pairing key. Used only for Prisma Access.
Implementation
core.String? state;