SeverityOverride class

Defines what action to take for a specific severity match.

Constructors

SeverityOverride({String? action, String? severity})
SeverityOverride.fromJson(Map json_)

Properties

action ↔ String?
Threat action override.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Severity level to match.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited