ThreatOverride class

Defines what action to take for a specific threat_id match.

Constructors

ThreatOverride({String? action, String? threatId, String? type})
ThreatOverride.fromJson(Map json_)

Properties

action ↔ String?
Threat action override.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threatId ↔ String?
Vendor-specific ID of a threat to override.
getter/setter pair
type ↔ String?
Type of the threat (read only).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited