ThreatPreventionProfile class

ThreatPreventionProfile defines an action for specific threat signatures or severity levels.

Constructors

ThreatPreventionProfile({List<AntivirusOverride>? antivirusOverrides, List<SeverityOverride>? severityOverrides, List<ThreatOverride>? threatOverrides})
ThreatPreventionProfile.fromJson(Map json_)

Properties

antivirusOverrides ↔ List<AntivirusOverride>?
Configuration for overriding antivirus actions per protocol.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severityOverrides ↔ List<SeverityOverride>?
Configuration for overriding threats actions by severity match.
getter/setter pair
threatOverrides ↔ List<ThreatOverride>?
Configuration for overriding threats actions by threat_id match.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited