TlsInspectionPolicy class

The TlsInspectionPolicy resource contains references to CA pools in Certificate Authority Service and associated metadata.

Constructors

TlsInspectionPolicy({String? caPool, String? createTime, List<String>? customTlsFeatures, String? description, bool? excludePublicCaSet, String? minTlsVersion, String? name, String? tlsFeatureProfile, String? trustConfig, String? updateTime})
TlsInspectionPolicy.fromJson(Map json_)

Properties

caPool ↔ String?
A CA pool resource used to issue interception certificates.
getter/setter pair
createTime ↔ String?
The timestamp when the resource was created.
getter/setter pair
customTlsFeatures ↔ List<String>?
List of custom TLS cipher suites selected.
getter/setter pair
description ↔ String?
Free-text description of the resource.
getter/setter pair
excludePublicCaSet ↔ bool?
If FALSE (the default), use our default set of public CAs in addition to any CAs specified in trust_config.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minTlsVersion ↔ String?
Minimum TLS version that the firewall should use when negotiating connections with both clients and servers.
getter/setter pair
name ↔ String?
Name of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tlsFeatureProfile ↔ String?
The selected Profile.
getter/setter pair
trustConfig ↔ String?
A TrustConfig resource used when making a connection to the TLS server.
getter/setter pair
updateTime ↔ String?
The timestamp when the resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited