UrlFilter class

A URL filter defines an action to take for some URL match.

Constructors

UrlFilter({String? filteringAction, int? priority, List<String>? urls})
UrlFilter.fromJson(Map json_)

Properties

filteringAction String?
The action taken when this filter is applied.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
priority int?
The priority of this filter within the URL Filtering Profile.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urls List<String>?
The list of strings that a URL must match with for this filter to be applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited