UrlFilteringProfile class

UrlFilteringProfile defines filters based on URL.

Constructors

UrlFilteringProfile({List<UrlFilter>? urlFilters})
UrlFilteringProfile.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlFilters List<UrlFilter>?
The list of filtering configs in which each config defines an action to take for some URL match.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited