AgentConnectivityTemplate class

AgentConnectivityTemplate represents a reusable network configuration.

Constructors

AgentConnectivityTemplate({String? accessPath, List<String>? accessTypes, String? agentCompute, String? createTime, String? deploymentModel, String? description, EgressNetworkConfig? egressNetworkConfig, String? etag, Map<String, String>? labels, String? name, String? updateTime})
AgentConnectivityTemplate.fromJson(Map json_)

Properties

accessPath String?
The path of the access.
getter/setter pair
accessTypes List<String>?
The types of network access provided to the gateway.
getter/setter pair
agentCompute String?
The compute environment where the agent is hosted.
getter/setter pair
createTime String?
The timestamp when the resource was created.
getter/setter pair
deploymentModel String?
The deployment model for the gateway.
getter/setter pair
description String?
A free-text description of the resource.
getter/setter pair
egressNetworkConfig EgressNetworkConfig?
Configuration for egress network traffic.
getter/setter pair
etag String?
Etag of the resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
Set of label tags associated with the AgentConnectivityTemplate resource.
getter/setter pair
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTime String?
The timestamp when the resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited