AgentGateway class

AgentGateway represents the agent gateway resource.

Constructors

AgentGateway({String? agentConnectivityTemplate, AgentGatewayAgentGatewayOutputCard? agentGatewayCard, String? createTime, String? description, String? etag, AgentGatewayGoogleManaged? googleManaged, Map<String, String>? labels, String? name, AgentGatewayNetworkConfig? networkConfig, List<String>? protocols, List<String>? registries, AgentGatewaySelfManaged? selfManaged, String? updateTime})
AgentGateway.fromJson(Map json_)

Properties

agentConnectivityTemplate String?
The resource name of the AgentConnectivityTemplate.
getter/setter pair
agentGatewayCard AgentGatewayAgentGatewayOutputCard?
Field for populated AgentGateway card.
getter/setter pair
createTime String?
The timestamp when the resource was created.
getter/setter pair
description String?
A free-text description of the resource.
getter/setter pair
etag String?
Etag of the resource.
getter/setter pair
googleManaged AgentGatewayGoogleManaged?
Proxy is orchestrated and managed by GoogleCloud in a tenant project.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
Set of label tags associated with the AgentGateway resource.
getter/setter pair
name String?
Identifier.
getter/setter pair
networkConfig AgentGatewayNetworkConfig?
Network configuration for the AgentGateway.
getter/setter pair
protocols List<String>?
Deprecated.
getter/setter pair
registries List<String>?
A list of Agent registries containing the agents, MCP servers and tools governed by the Agent Gateway.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfManaged AgentGatewaySelfManaged?
Attach to existing Application Load Balancers or Secure Web Proxies.
getter/setter pair
updateTime String?
The timestamp when the resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited