AgentGatewayAgentGatewayOutputCard class

AgentGatewayOutputCard contains informational output-only fields

Constructors

AgentGatewayAgentGatewayOutputCard({String? mtlsEndpoint, List<String>? rootCertificates, String? serviceExtensionsServiceAccount})
AgentGatewayAgentGatewayOutputCard.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
mtlsEndpoint String?
mTLS Endpoint associated with this AgentGateway
getter/setter pair
rootCertificates List<String>?
Root Certificates for Agents to validate this AgentGateway
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceExtensionsServiceAccount String?
Service Account used by Service Extensions to operate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited