AgentGatewayGoogleManaged class

Configuration for Google Managed deployment mode.

Proxy is orchestrated and managed by GoogleCloud in a tenant project.

Constructors

AgentGatewayGoogleManaged({String? governedAccessPath})
AgentGatewayGoogleManaged.fromJson(Map json_)

Properties

governedAccessPath String?
Operating Mode of Agent Gateway.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited