AgentGatewayNetworkConfig class

NetworkConfig contains network configurations for the AgentGateway.

Properties

dnsPeeringConfig AgentGatewayNetworkConfigDnsPeeringConfig?
Optional DNS peering configuration for connectivity to your private VPC network.
getter/setter pair
egress AgentGatewayNetworkConfigEgress?
Optional PSC-Interface network attachment for connectivity to your private VPCs network.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited