AgentGatewayNetworkConfigDnsPeeringConfig class

DNS peering config for the user VPC network.

Properties

domains List<String>?
Domain names for which DNS queries should be forwarded to the target network.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetNetwork String?
Target network in 'target project' to which DNS queries should be forwarded to.
getter/setter pair
targetProject String?
Target project ID to which DNS queries should be forwarded to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited