targetProject property
Target project ID to which DNS queries should be forwarded to.
This can be the same project that contains the AgentGateway or a different project.
Required.
Implementation
core.String? targetProject;
Target project ID to which DNS queries should be forwarded to.
This can be the same project that contains the AgentGateway or a different project.
Required.
core.String? targetProject;