DnsPeeringConfig class

DNS Peering configuration.

Constructors

DnsPeeringConfig({String? domain, String? targetNetwork})
DnsPeeringConfig.fromJson(Map json_)

Properties

domain String?
The domain to peer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetNetwork String?
The target network resource name for DNS peering.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited