EndpointMatcherMetadataLabelMatcher class

The matcher that is based on node metadata presented by xDS clients.

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadataLabelMatchCriteria ↔ String?
Specifies how matching should be done.
getter/setter pair
metadataLabels ↔ List<EndpointMatcherMetadataLabelMatcherMetadataLabels>?
The list of label value pairs that must match labels in the provided metadata based on filterMatchCriteria This list can have at most 64 entries.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited