EndpointMatcherMetadataLabelMatcherMetadataLabels class

Defines a name-pair value for a single label.

Properties

hashCode → int
The hash code for this object.
no setterinherited
labelName ↔ String?
Label name presented as key in xDS Node Metadata.
getter/setter pair
labelValue ↔ String?
Label value presented as value corresponding to the above key, in xDS Node Metadata.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited