ExtensionBinding class

ExtensionBinding is a resource representing the attachment of an extension to a service.

Constructors

ExtensionBinding({String? createTime, String? description, String? etag, bool? failOpen, Map<String, String>? labels, List<ExtensionBindingMatchCondition>? matchConditions, String? name, int? priority, String? producerExtension, Map<String, String>? producerMetadata, ExtensionBindingTarget? target, String? updateTime})
ExtensionBinding.fromJson(Map json_)

Properties

createTime String?
The timestamp when the resource was created.
getter/setter pair
description String?
A human-readable description of the resource.
getter/setter pair
etag String?
Etag of the resource.
getter/setter pair
failOpen bool?
Determines the behavior of the extension binding when the call to the extension fails or times out.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
Set of labels associated with the ExtensionBinding resource.
getter/setter pair
matchConditions List<ExtensionBindingMatchCondition>?
A list of match conditions to match against the incoming request.
getter/setter pair
name String?
Identifier.
getter/setter pair
priority int?
Priority of the extension binding.
getter/setter pair
producerExtension String?
The name of the extension that this binding should attach to target resources.
getter/setter pair
producerMetadata Map<String, String>?
Additional metadata that should be passed to the attached extension with each request.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target ExtensionBindingTarget?
Specifies a target to which this ExtensionBinding should be attached.
getter/setter pair
updateTime String?
The timestamp when the resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited