priority property

int? priority
getter/setter pair

Priority of the extension binding.

Lower numbers indicate higher priority. Priority of extension bindings are used to determine the order in which extension bindings are applied to a request.

Optional.

Implementation

core.int? priority;