target property
Specifies a target to which this ExtensionBinding should be attached.
The target can be either a single resource or a scope of resources.
Required.
Implementation
ExtensionBindingTarget? target;
Specifies a target to which this ExtensionBinding should be attached.
The target can be either a single resource or a scope of resources.
Required.
ExtensionBindingTarget? target;