ExtensionBindingMatchConditionHeaderMatch class

Determines how an HTTP header should be matched.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Specifies the name of the header in the request.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value ExtensionBindingMatchConditionStringMatch?
Specifies how the header match will be performed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited