prefix property
The input string must have the prefix specified here.
Note: empty prefix is not allowed. Examples: * abc matches the value
abc.xyz
Optional.
Implementation
core.String? prefix;
The input string must have the prefix specified here.
Note: empty prefix is not allowed. Examples: * abc matches the value
abc.xyz
Optional.
core.String? prefix;