ExtensionBindingMatchConditionTo class
Describes properties of one or more destinations of a request.
Constructors
- ExtensionBindingMatchConditionTo({ExtensionBindingMatchConditionToDestination? destination, ExtensionBindingMatchConditionToDestination? notDestination})
- ExtensionBindingMatchConditionTo.fromJson(Map json_)
Properties
- destination ↔ ExtensionBindingMatchConditionToDestination?
-
Describes properties of destination of a request.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- notDestination ↔ ExtensionBindingMatchConditionToDestination?
-
Describes the negated properties of the request destination.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited