headerSet property
A set of HTTP headers to match against.
If not specified, requests with any headers are matched.
Optional.
Implementation
ExtensionBindingMatchConditionToDestinationHeaderSet? headerSet;
A set of HTTP headers to match against.
If not specified, requests with any headers are matched.
Optional.
ExtensionBindingMatchConditionToDestinationHeaderSet? headerSet;