hosts property

List<ExtensionBindingMatchConditionStringMatch>? hosts
getter/setter pair

A list of HTTP Hosts to match against.

Limited to 10 hosts. If not specified, any host is allowed. If specified, a match occurs if any of the hosts matches the host value in the request.

Optional.

Implementation

core.List<ExtensionBindingMatchConditionStringMatch>? hosts;