headers property

List<ExtensionBindingMatchConditionHeaderMatch>? headers
getter/setter pair

A list of headers to match against in http header.

If multiple header matches are provided, they will be evaluated as an AND, i.e. all header matches must match for the request to match.

Required.

Implementation

core.List<ExtensionBindingMatchConditionHeaderMatch>? headers;