ExtensionBindingTarget class
Specifies a list of targets to which this ExtensionBinding should attach.
Constructors
-
ExtensionBindingTarget({List<
String> ? resources, ExtensionBindingTargetScope? scope}) - ExtensionBindingTarget.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
resources
↔ List<
String> ? -
The reference to the target resource, to which this binding should attach.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope ↔ ExtensionBindingTargetScope?
-
Specifies the scope of resources to which this binding should attach.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited