resources property

List<String>? resources
getter/setter pair

The reference to the target resource, to which this binding should attach.

Exactly one of resources or scope must be set.

Optional.

Implementation

core.List<core.String>? resources;