ExtensionBindingTargetScope class

Specifies the scope of resources to which this binding should attach.

Constructors

ExtensionBindingTargetScope({String? parent, List<String>? resourceTypes})
ExtensionBindingTargetScope.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent ↔ String?
Parent resource name specification, in the format: projects/{project_number}.
getter/setter pair
resourceTypes ↔ List<String>?
Type of the resource to which the binding should attach.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited