ExtensionChain class

A single extension chain wrapper that contains the match conditions and extensions to execute.

Constructors

ExtensionChain({List<ExtensionChainExtension>? extensions, ExtensionChainMatchCondition? matchCondition, String? name})
ExtensionChain.fromJson(Map json_)

Properties

extensions ↔ List<ExtensionChainExtension>?
A set of extensions to execute for the matching request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchCondition ↔ ExtensionChainMatchCondition?
Conditions under which this chain is invoked for a request.
getter/setter pair
name ↔ String?
The name for this extension chain.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited