ExtensionChainExtension class

A single extension in the chain to execute for the matching request.

Constructors

ExtensionChainExtension({String? authority, bool? failOpen, List<String>? forwardAttributes, List<String>? forwardHeaders, Map<String, Object?>? metadata, String? name, bool? observabilityMode, String? requestBodySendMode, String? responseBodySendMode, String? service, List<String>? supportedEvents, String? timeout})
ExtensionChainExtension.fromJson(Map json_)

Properties

authority ↔ String?
The :authority header in the gRPC request sent from Envoy to the extension service.
getter/setter pair
failOpen ↔ bool?
Determines how the proxy behaves if the call to the extension fails or times out.
getter/setter pair
forwardAttributes ↔ List<String>?
List of the Envoy attributes to forward to the extension server.
getter/setter pair
forwardHeaders ↔ List<String>?
List of the HTTP headers to forward to the extension (from the client or backend).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, Object?>?
The metadata provided here is included as part of the metadata_context (of type google.protobuf.Struct) in the ProcessingRequest message sent to the extension server.
getter/setter pair
name ↔ String?
The name for this extension.
getter/setter pair
observabilityMode ↔ bool?
When set to true, the calls to the extension backend are performed asynchronously, without pausing the processing of the ongoing request.
getter/setter pair
requestBodySendMode ↔ String?
Configures the send mode for request body processing.
getter/setter pair
responseBodySendMode ↔ String?
Configures the send mode for response processing.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
The reference to the service that runs the extension.
getter/setter pair
supportedEvents ↔ List<String>?
A set of events during request or response processing for which this extension is called.
getter/setter pair
timeout ↔ String?
Specifies the timeout for each individual message on the stream.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited