supportedEvents property
A set of events during request or response processing for which this extension is called.
For the LbTrafficExtension resource, this field is required. For the
LbRouteExtension resource, this field is optional. If unspecified,
REQUEST_HEADERS event is assumed as supported. For the LbEdgeExtension
resource, this field is required and must only contain REQUEST_HEADERS
event.
Optional.
Implementation
core.List<core.String>? supportedEvents;