ExtensionChainMatchCondition class

Conditions under which this chain is invoked for a request.

Properties

celExpression ↔ String?
A Common Expression Language (CEL) expression that is used to match requests for which the extension chain is executed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited