GrpcRouteMethodMatch class

Specifies a match against a method.

Constructors

GrpcRouteMethodMatch({bool? caseSensitive, String? grpcMethod, String? grpcService, String? type})
GrpcRouteMethodMatch.fromJson(Map json_)

Properties

caseSensitive ↔ bool?
Specifies that matches are case sensitive.
getter/setter pair
grpcMethod ↔ String?
Name of the method to match against.
getter/setter pair
grpcService ↔ String?
Name of the service to match against.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Specifies how to match against the name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited