GrpcRouteRouteAction class

Specifies how to route matched traffic.

Constructors

GrpcRouteRouteAction({List<GrpcRouteDestination>? destinations, GrpcRouteFaultInjectionPolicy? faultInjectionPolicy, String? idleTimeout, GrpcRouteRetryPolicy? retryPolicy, GrpcRouteStatefulSessionAffinityPolicy? statefulSessionAffinity, String? timeout})
GrpcRouteRouteAction.fromJson(Map json_)

Properties

destinations ↔ List<GrpcRouteDestination>?
The destination services to which traffic should be forwarded.
getter/setter pair
faultInjectionPolicy ↔ GrpcRouteFaultInjectionPolicy?
The specification for fault injection introduced into traffic to test the resiliency of clients to destination service failure.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idleTimeout ↔ String?
Specifies the idle timeout for the selected route.
getter/setter pair
retryPolicy ↔ GrpcRouteRetryPolicy?
Specifies the retry policy associated with this route.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statefulSessionAffinity ↔ GrpcRouteStatefulSessionAffinityPolicy?
Specifies cookie-based stateful session affinity.
getter/setter pair
timeout ↔ String?
Specifies the timeout for selected route.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited