GrpcRouteRouteMatch class

Criteria for matching traffic.

A RouteMatch will be considered to match when all supplied fields match.

Properties

hashCode → int
The hash code for this object.
no setterinherited
headers ↔ List<GrpcRouteHeaderMatch>?
Specifies a collection of headers to match.
getter/setter pair
method ↔ GrpcRouteMethodMatch?
A gRPC method to match against.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited