HttpRouteCorsPolicy class

The Specification for allowing client side cross-origin requests.

Constructors

HttpRouteCorsPolicy({bool? allowCredentials, List<String>? allowHeaders, List<String>? allowMethods, List<String>? allowOriginRegexes, List<String>? allowOrigins, bool? disabled, List<String>? exposeHeaders, String? maxAge})
HttpRouteCorsPolicy.fromJson(Map json_)

Properties

allowCredentials ↔ bool?
In response to a preflight request, setting this to true indicates that the actual request can include user credentials.
getter/setter pair
allowHeaders ↔ List<String>?
Specifies the content for Access-Control-Allow-Headers header.
getter/setter pair
allowMethods ↔ List<String>?
Specifies the content for Access-Control-Allow-Methods header.
getter/setter pair
allowOriginRegexes ↔ List<String>?
Specifies the regular expression patterns that match allowed origins.
getter/setter pair
allowOrigins ↔ List<String>?
Specifies the list of origins that will be allowed to do CORS requests.
getter/setter pair
disabled ↔ bool?
If true, the CORS policy is disabled.
getter/setter pair
exposeHeaders ↔ List<String>?
Specifies the content for Access-Control-Expose-Headers header.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxAge ↔ String?
Specifies how long result of a preflight request can be cached in seconds.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited