HttpRouteFaultInjectionPolicy class

The specification for fault injection introduced into traffic to test the resiliency of clients to destination service failure.

As part of fault injection, when clients send requests to a destination, delays can be introduced by client proxy on a percentage of requests before sending those requests to the destination service. Similarly requests can be aborted by client proxy for a percentage of requests.

Properties

abort ↔ GrpcRouteFaultInjectionPolicyAbort?
The specification for aborting to client requests.
getter/setter pair
delay ↔ GrpcRouteFaultInjectionPolicyDelay?
The specification for injecting delay to client requests.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited