HttpRouteHeaderMatch class

Specifies how to select a route rule based on HTTP request headers.

Constructors

HttpRouteHeaderMatch({String? exactMatch, String? header, bool? invertMatch, String? prefixMatch, bool? presentMatch, HttpRouteHeaderMatchIntegerRange? rangeMatch, String? regexMatch, String? suffixMatch})
HttpRouteHeaderMatch.fromJson(Map json_)

Properties

exactMatch ↔ String?
The value of the header should match exactly the content of exact_match.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
The name of the HTTP header to match against.
getter/setter pair
invertMatch ↔ bool?
If specified, the match result will be inverted before checking.
getter/setter pair
prefixMatch ↔ String?
The value of the header must start with the contents of prefix_match.
getter/setter pair
presentMatch ↔ bool?
A header with header_name must exist.
getter/setter pair
rangeMatch ↔ HttpRouteHeaderMatchIntegerRange?
If specified, the rule will match if the request header value is within the range.
getter/setter pair
regexMatch ↔ String?
The value of the header must match the regular expression specified in regex_match.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suffixMatch ↔ String?
The value of the header must end with the contents of suffix_match.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited