HttpRouteHeaderModifier class

The specification for modifying HTTP header in HTTP request and HTTP response.

Properties

add ↔ Map<String, String>?
Add the headers with given map where key is the name of the header, value is the value of the header.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
remove ↔ List<String>?
Remove headers (matching by header names) specified in the list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
set ↔ Map<String, String>?
Completely overwrite/replace the headers with given map where key is the name of the header, value is the value of the header.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited