HttpRouteHttpDirectResponse class

Static HTTP response object to be returned.

Constructors

HttpRouteHttpDirectResponse({String? bytesBody, int? status, String? stringBody})
HttpRouteHttpDirectResponse.fromJson(Map json_)

Properties

bytesBody ↔ String?
Response body as bytes.
getter/setter pair
bytesBodyAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ int?
Status to return as part of HTTP Response.
getter/setter pair
stringBody ↔ String?
Response body as a string.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited