HttpRouteQueryParameterMatch class

Specifications to match a query parameter in the request.

Constructors

HttpRouteQueryParameterMatch({String? exactMatch, bool? presentMatch, String? queryParameter, String? regexMatch})
HttpRouteQueryParameterMatch.fromJson(Map json_)

Properties

exactMatch ↔ String?
The value of the query parameter must exactly match the contents of exact_match.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
presentMatch ↔ bool?
Specifies that the QueryParameterMatcher matches if request contains query parameter, irrespective of whether the parameter has a value or not.
getter/setter pair
queryParameter ↔ String?
The name of the query parameter to match.
getter/setter pair
regexMatch ↔ String?
The value of the query parameter must match the regular expression specified by regex_match.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited