HttpRouteRedirect class

The specification for redirecting traffic.

Constructors

HttpRouteRedirect({String? hostRedirect, bool? httpsRedirect, String? pathRedirect, int? portRedirect, String? prefixRewrite, String? responseCode, bool? stripQuery})
HttpRouteRedirect.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostRedirect ↔ String?
The host that will be used in the redirect response instead of the one that was supplied in the request.
getter/setter pair
httpsRedirect ↔ bool?
If set to true, the URL scheme in the redirected request is set to https.
getter/setter pair
pathRedirect ↔ String?
The path that will be used in the redirect response instead of the one that was supplied in the request.
getter/setter pair
portRedirect ↔ int?
The port that will be used in the redirected request instead of the one that was supplied in the request.
getter/setter pair
prefixRewrite ↔ String?
Indicates that during redirection, the matched prefix (or path) should be swapped with this value.
getter/setter pair
responseCode ↔ String?
The HTTP Status code to use for the redirect. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stripQuery ↔ bool?
if set to true, any accompanying query portion of the original URL is removed prior to redirecting the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited