HttpRouteRouteMatch class

RouteMatch defines specifications used to match requests.

If multiple match types are set, this RouteMatch will match if ALL type of matches are matched.

Constructors

HttpRouteRouteMatch({String? fullPathMatch, List<HttpRouteHeaderMatch>? headers, bool? ignoreCase, String? prefixMatch, List<HttpRouteQueryParameterMatch>? queryParameters, String? regexMatch})
HttpRouteRouteMatch.fromJson(Map json_)

Properties

fullPathMatch ↔ String?
The HTTP request path value should exactly match this value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ List<HttpRouteHeaderMatch>?
Specifies a list of HTTP request headers to match against.
getter/setter pair
ignoreCase ↔ bool?
Specifies if prefix_match and full_path_match matches are case sensitive.
getter/setter pair
prefixMatch ↔ String?
The HTTP request path value must begin with specified prefix_match.
getter/setter pair
queryParameters ↔ List<HttpRouteQueryParameterMatch>?
Specifies a list of query parameters to match against.
getter/setter pair
regexMatch ↔ String?
The HTTP request path value must satisfy the regular expression specified by regex_match after removing any query parameters and anchor supplied with the original URL.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited