HttpRouteURLRewrite class

The specification for modifying the URL of the request, prior to forwarding the request to the destination.

Constructors

HttpRouteURLRewrite({String? hostRewrite, String? pathPrefixRewrite})
HttpRouteURLRewrite.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostRewrite ↔ String?
Prior to forwarding the request to the selected destination, the requests host header is replaced by this value.
getter/setter pair
pathPrefixRewrite ↔ String?
Prior to forwarding the request to the selected destination, the matching portion of the requests path is replaced by this value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited