ListMeshRouteViewsResponse class

Response returned by the ListMeshRouteViews method.

Constructors

ListMeshRouteViewsResponse({List<MeshRouteView>? meshRouteViews, String? nextPageToken, List<String>? unreachable})
ListMeshRouteViewsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
meshRouteViews ↔ List<MeshRouteView>?
List of MeshRouteView resources.
getter/setter pair
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unreachable resources.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited