ListMulticastConsumerAssociationsResponse class

Response message for ListMulticastConsumerAssociations.

Constructors

ListMulticastConsumerAssociationsResponse({List<MulticastConsumerAssociation>? multicastConsumerAssociations, String? nextPageToken, List<String>? unreachable})
ListMulticastConsumerAssociationsResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
multicastConsumerAssociations List<MulticastConsumerAssociation>?
The list of multicast consumer associations.
getter/setter pair
nextPageToken String?
A page token from an earlier query, as returned in next_page_token.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unreachable List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited