MeshRouteView class

MeshRouteView defines view-only resource for Routes to a Mesh

Constructors

MeshRouteView({String? name, String? routeId, String? routeLocation, String? routeProjectNumber, String? routeType})
MeshRouteView.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
routeId ↔ String?
The resource id for the route.
getter/setter pair
routeLocation ↔ String?
Location where the route exists.
getter/setter pair
routeProjectNumber ↔ String?
Project number where the route exists.
getter/setter pair
routeType ↔ String?
Type of the route: HttpRoute,GrpcRoute,TcpRoute, or TlsRoute
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited