MulticastConsumerAssociation class

Multicast consumer association resource.

Constructors

MulticastConsumerAssociation({String? createTime, String? description, Map<String, String>? labels, String? multicastDomainActivation, String? name, String? network, String? placementPolicy, String? resourceState, MulticastResourceState? state, String? uniqueId, String? updateTime})
MulticastConsumerAssociation.fromJson(Map json_)

Properties

createTime ↔ String?
The timestamp when the multicast consumer association was created.
getter/setter pair
description ↔ String?
An optional text description of the multicast consumer association.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels as key-value pairs
getter/setter pair
multicastDomainActivation ↔ String?
The resource name of the multicast domain activation that is in the same zone as this multicast consumer association.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
network ↔ String?
The resource name of the multicast consumer VPC network.
getter/setter pair
placementPolicy ↔ String?
A Compute Engine (placement policy)[https://cloud.google.com/compute/docs/instances/placement-policies-overview] that can be used to place virtual machine (VM) instances as multicast consumers close to the multicast infrastructure created for this domain, on a best effort basis.
getter/setter pair
resourceState ↔ String?
The resource state of the multicast consumer association.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ MulticastResourceState?
The state of the resource.
getter/setter pair
uniqueId ↔ String?
The Google-generated UUID for the resource.
getter/setter pair
updateTime ↔ String?
The timestamp when the Multicast Consumer Association was most recently updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited