updateTime property
The timestamp when the Multicast Consumer Association was most recently updated.
Output only.
Implementation
core.String? updateTime;
The timestamp when the Multicast Consumer Association was most recently updated.
Output only.
core.String? updateTime;