createTime property
The timestamp when the multicast group consumer activation was created.
Output only.
Implementation
core.String? createTime;
The timestamp when the multicast group consumer activation was created.
Output only.
core.String? createTime;