multicastGroup property

  1. @Deprecated('Not supported. Member documentation may have more information.')
String? multicastGroup
getter/setter pair

The resource name of the multicast group created by the admin in the same zone as this multicast group consumer activation.

Use the following format: // projects / * /locations / * /multicastGroups / * . This field is deprecated. Use multicast_group_range_activation instead.

Optional.

Implementation

@core.Deprecated(
  'Not supported. Member documentation may have more information.',
)
core.String? multicastGroup;