name property
Identifier.
The resource name of the multicast group consumer activation. Use the
following format: projects / * /locations / * /multicastGroupConsumerActivations / * .
Implementation
core.String? name;
Identifier.
The resource name of the multicast group consumer activation. Use the
following format: projects / * /locations / * /multicastGroupConsumerActivations / * .
core.String? name;