state property

String? state
getter/setter pair

The state of the multicast resource.

Optional. Possible string values are:

  • "STATE_ENUM_UNSPECIFIED" : The resource is in unspecified state.
  • "CREATING" : The resource is being created.
  • "ACTIVE" : The resource is in a normal state and ready to use.
  • "DELETING" : The resource is being deleted.
  • "DELETE_FAILED" : The resource is failed to be deleted.
  • "UPDATING" : The resource is being updated.
  • "UPDATE_FAILED" : The resource is failed to be updated.
  • "INACTIVE" : The multicast consumer resource that is deactivated by the multicast administrator based on permission.
  • "OBSOLETE" : The multicast consumer resource that is obsoleted due to multicast admin setup teardown.

Implementation

core.String? state;