ProducerExtension class

ProducerExtension is a resource representing producer defined configuration for their service extension.

Constructors

ProducerExtension({String? createTime, String? description, String? etag, ProducerExtensionExtensionSettings? extensionSettings, Map<String, String>? labels, String? name, String? phase, String? updateTime})
ProducerExtension.fromJson(Map json_)

Properties

createTime String?
The timestamp when the resource was created.
getter/setter pair
description String?
A human-readable description of the resource.
getter/setter pair
etag String?
Etag of the resource.
getter/setter pair
extensionSettings ProducerExtensionExtensionSettings?
The configuration for the service that this ProducerExtension offers.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
Set of labels associated with the ProducerExtension resource.
getter/setter pair
name String?
Identifier.
getter/setter pair
phase String?
The phase in which this ProducerExtension should execute.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateTime String?
The timestamp when the resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited