ProjectsLocationsAgentGatewaysResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(AgentGateway request, String parent, {String? agentGatewayId, String? $fields})
→ Future<Operation>
-
Creates a new AgentGateway in a given project and location.
-
delete(String name, {String? etag, String? $fields})
→ Future<Operation>
-
Deletes a single AgentGateway.
-
get(String name, {String? $fields})
→ Future<AgentGateway>
-
Gets details of a single AgentGateway.
-
list(String parent, {int? pageSize, String? pageToken, bool? returnPartialSuccess, String? $fields})
→ Future<ListAgentGatewaysResponse>
-
Lists AgentGateways in a given project and location.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(AgentGateway request, String name, {String? updateMask, String? $fields})
→ Future<Operation>
-
Updates the parameters of a single AgentGateway.
-
toString()
→ String
-
A string representation of this object.
inherited