list method
Lists AgentGateways in a given project and location.
Request parameters:
parent - Required. The project and location from which the AgentGateways
should be listed, specified in the format projects / * /locations / * .
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
pageSize - Optional. Maximum number of AgentGateways to return per call.
pageToken - Optional. The value returned by the last
ListAgentGatewaysResponse Indicates that this is a continuation of a
prior ListAgentGateways call, and that the system should return the next
page of data.
returnPartialSuccess - Optional. If true, allow partial responses for
multi-regional Aggregated List requests. Otherwise if one of the locations
is down or unreachable, the Aggregated List request will fail.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListAgentGatewaysResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListAgentGatewaysResponse> list(
core.String parent, {
core.int? pageSize,
core.String? pageToken,
core.bool? returnPartialSuccess,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'returnPartialSuccess': ?returnPartialSuccess == null
? null
: ['${returnPartialSuccess}'],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/agentGateways';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListAgentGatewaysResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}