create method
Future<Operation>
create(
- ExtensionBinding request,
- String parent, {
- String? extensionBindingId,
- String? $fields,
Creates a new ExtensionBinding resource in a given project and location.
request - The metadata request object.
Request parameters:
parent - Required. The parent resource of the ExtensionBinding
resource. Must be in the format projects/{project}/locations/{location}.
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
extensionBindingId - Required. Short name of the ExtensionBinding
resource to be created.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Operation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Operation> create(
ExtensionBinding request,
core.String parent, {
core.String? extensionBindingId,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'extensionBindingId': ?extensionBindingId == null
? null
: [extensionBindingId],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/extensionBindings';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}