ProjectsLocationsMulticastGroupConsumerActivationsResource class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(MulticastGroupConsumerActivation request, String parent, {String? multicastGroupConsumerActivationId, String? requestId, String? $fields}) Future<Operation>
Creates a new multicast group consumer activation in a given project and location.
delete(String name, {String? requestId, String? $fields}) Future<Operation>
Deletes a single multicast group consumer activation.
get(String name, {String? $fields}) Future<MulticastGroupConsumerActivation>
Gets details of a single multicast group consumer activation.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListMulticastGroupConsumerActivationsResponse>
Lists multicast group consumer activations in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(MulticastGroupConsumerActivation request, String name, {String? requestId, String? updateMask, String? $fields}) Future<Operation>
Updates the parameters of a single multicast group consumer activation.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited