get method
Gets details of a single multicast group consumer activation.
Request parameters:
name - Required. The resource name of the multicast group consumer
activation to get. Use the following format: projects / * /locations / * /multicastGroupConsumerActivations / * .
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/multicastGroupConsumerActivations/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a MulticastGroupConsumerActivation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<MulticastGroupConsumerActivation> get(
core.String name, {
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return MulticastGroupConsumerActivation.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}