list method

Future<ListMulticastGroupConsumerActivationsResponse> list(
  1. String parent, {
  2. String? filter,
  3. String? orderBy,
  4. int? pageSize,
  5. String? pageToken,
  6. String? $fields,
})

Lists multicast group consumer activations in a given project and location.

Request parameters:

parent - Required. The parent resource for which to list multicast group consumer activations. Use the following format: `projects / * /locations /

  • . Value must have pattern ^projects/[^/]+/locations/[^/]+$`.

filter - Optional. A filter expression that filters the resources listed in the response. The expression must be of the form where operators: <, >, <=, >=, !=, =, : are supported (colon : represents a HAS operator which is roughly synonymous with equality). can refer to a proto or JSON field, or a synthetic field. Field names can be camelCase or snake_case. Examples: * Filter by name: name = "RESOURCE_NAME" * Filter by labels: * Resources that have a key named foo labels.foo:* * Resources that have a key named foo whose value is bar labels.foo = bar

orderBy - Optional. A field used to sort the results by a certain order.

pageSize - Optional. The maximum number of multicast group consumer activations to return per call.

pageToken - Optional. A page token from an earlier query, as returned in next_page_token.

$fields - Selector specifying which fields to include in a partial response.

Completes with a ListMulticastGroupConsumerActivationsResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<ListMulticastGroupConsumerActivationsResponse> list(
  core.String parent, {
  core.String? filter,
  core.String? orderBy,
  core.int? pageSize,
  core.String? pageToken,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'filter': ?filter == null ? null : [filter],
    'orderBy': ?orderBy == null ? null : [orderBy],
    'pageSize': ?pageSize == null ? null : ['${pageSize}'],
    'pageToken': ?pageToken == null ? null : [pageToken],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'v1/' +
      core.Uri.encodeFull('$parent') +
      '/multicastGroupConsumerActivations';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return ListMulticastGroupConsumerActivationsResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}