ServiceLbPolicyAutoCapacityDrain class

Option to specify if an unhealthy IG/NEG should be considered for global load balancing and traffic routing.

Properties

enable ↔ bool?
If set to 'True', an unhealthy IG/NEG will be set as drained.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited