ServiceLbPolicyFailoverConfig class

Option to specify health based failover behavior.

This is not related to Network load balancer FailoverPolicy.

Constructors

ServiceLbPolicyFailoverConfig({int? failoverHealthThreshold})
ServiceLbPolicyFailoverConfig.fromJson(Map json_)

Properties

failoverHealthThreshold ↔ int?
The percentage threshold that a load balancer will begin to send traffic to failover backends.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited