ServiceLbPolicyIsolationConfig class

Configuration to provide isolation support for the associated Backend Service.

Constructors

ServiceLbPolicyIsolationConfig({String? isolationGranularity, String? isolationMode})
ServiceLbPolicyIsolationConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isolationGranularity ↔ String?
The isolation granularity of the load balancer.
getter/setter pair
isolationMode ↔ String?
The isolation mode of the load balancer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited