TlsRouteRouteDestination class

Describe the destination for traffic to be routed to.

Constructors

TlsRouteRouteDestination({String? serviceName, int? weight})
TlsRouteRouteDestination.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceName ↔ String?
The URL of a BackendService to route traffic to.
getter/setter pair
weight ↔ int?
Specifies the proportion of requests forwarded to the backend referenced by the service_name field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited