TlsRouteRouteMatch class

RouteMatch defines the predicate used to match requests to a given action.

Multiple match types are "AND"ed for evaluation.

Constructors

TlsRouteRouteMatch({List<String>? alpn, List<String>? sniHost})
TlsRouteRouteMatch.fromJson(Map json_)

Properties

alpn ↔ List<String>?
ALPN (Application-Layer Protocol Negotiation) to match against.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sniHost ↔ List<String>?
SNI (server name indicator) to match against.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited