WasmPluginLogConfig class

Specifies the logging options for the activity performed by this plugin.

If logging is enabled, plugin logs are exported to Cloud Logging.

Constructors

WasmPluginLogConfig({bool? enable, String? minLogLevel, double? sampleRate})
WasmPluginLogConfig.fromJson(Map json_)

Properties

enable ↔ bool?
Specifies whether to enable logging for activity by this plugin.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minLogLevel ↔ String?
Non-empty default.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleRate ↔ double?
Non-empty default.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited