Environment class

Definition of a software environment that is used to start a notebook instance.

Constructors

Environment({ContainerImage? containerImage, String? createTime, String? description, String? displayName, String? name, String? postStartupScript, VmImage? vmImage})
Environment.fromJson(Map json_)

Properties

containerImage ↔ ContainerImage?
Use a container image to start the notebook instance.
getter/setter pair
createTime ↔ String?
The time at which this environment was created.
getter/setter pair
description ↔ String?
A brief description of this environment.
getter/setter pair
displayName ↔ String?
Display name of this environment for the UI.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of this environment.
getter/setter pair
postStartupScript ↔ String?
Path to a Bash script that automatically runs after a notebook instance fully boots up.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vmImage ↔ VmImage?
Use a Compute Engine VM image to start the notebook instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited