Execution class

The definition of a single executed notebook.

Constructors

Execution({String? createTime, String? description, String? displayName, ExecutionTemplate? executionTemplate, String? jobUri, String? name, String? outputNotebookFile, String? state, String? updateTime})
Execution.fromJson(Map json_)

Properties

createTime ↔ String?
Time the Execution was instantiated.
getter/setter pair
description ↔ String?
A brief description of this execution.
getter/setter pair
displayName ↔ String?
Name used for UI purposes.
getter/setter pair
executionTemplate ↔ ExecutionTemplate?
execute metadata including name, hardware spec, region, labels, etc.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jobUri ↔ String?
The URI of the external job used to execute the notebook.
getter/setter pair
name ↔ String?
The resource name of the execute.
getter/setter pair
outputNotebookFile ↔ String?
Output notebook file generated by this execution
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the underlying AI Platform job.
getter/setter pair
updateTime ↔ String?
Time the Execution was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited