ExecutionTemplate class

The description a notebook execution workload.

Constructors

ExecutionTemplate({SchedulerAcceleratorConfig? acceleratorConfig, String? containerImageUri, DataprocParameters? dataprocParameters, String? inputNotebookFile, String? jobType, String? kernelSpec, Map<String, String>? labels, String? masterType, String? outputNotebookFolder, String? parameters, String? paramsYamlFile, String? scaleTier, String? serviceAccount, String? tensorboard, VertexAIParameters? vertexAiParameters})
ExecutionTemplate.fromJson(Map json_)

Properties

acceleratorConfig ↔ SchedulerAcceleratorConfig?
Configuration (count and accelerator type) for hardware running notebook execution.
getter/setter pair
containerImageUri ↔ String?
Container Image URI to a DLVM Example: 'gcr.io/deeplearning-platform-release/base-cu100' More examples can be found at: https://cloud.google.com/ai-platform/deep-learning-containers/docs/choosing-container
getter/setter pair
dataprocParameters ↔ DataprocParameters?
Parameters used in Dataproc JobType executions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputNotebookFile ↔ String?
Path to the notebook file to execute.
getter/setter pair
jobType ↔ String?
The type of Job to be used on this execution. Possible string values are:
getter/setter pair
kernelSpec ↔ String?
Name of the kernel spec to use.
getter/setter pair
labels ↔ Map<String, String>?
Labels for execution.
getter/setter pair
masterType ↔ String?
Specifies the type of virtual machine to use for your training job's master worker.
getter/setter pair
outputNotebookFolder ↔ String?
Path to the notebook folder to write to.
getter/setter pair
parameters ↔ String?
Parameters used within the 'input_notebook_file' notebook.
getter/setter pair
paramsYamlFile ↔ String?
Parameters to be overridden in the notebook during execution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleTier ↔ String?
Scale tier of the hardware used for notebook execution.
getter/setter pair
serviceAccount ↔ String?
The email address of a service account to use when running the execution.
getter/setter pair
tensorboard ↔ String?
The name of a Vertex AI [Tensorboard] resource to which this execution will upload Tensorboard logs.
getter/setter pair
vertexAiParameters ↔ VertexAIParameters?
Parameters used in Vertex AI JobType executions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited