GetInstanceHealthResponse class

Response for checking if a notebook instance is healthy.

Constructors

GetInstanceHealthResponse({Map<String, String>? healthInfo, String? healthState})
GetInstanceHealthResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
healthInfo ↔ Map<String, String>?
Additional information about instance health.
getter/setter pair
healthState ↔ String?
Runtime health_state.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited