Instance class

The definition of a notebook instance.

Constructors

Instance({AcceleratorConfig? acceleratorConfig, String? bootDiskSizeGb, String? bootDiskType, bool? canIpForward, ContainerImage? containerImage, String? createTime, String? creator, String? customGpuDriverPath, String? dataDiskSizeGb, String? dataDiskType, String? diskEncryption, List<Disk>? disks, bool? installGpuDriver, InstanceMigrationEligibility? instanceMigrationEligibility, List<String>? instanceOwners, String? kmsKey, Map<String, String>? labels, String? machineType, Map<String, String>? metadata, bool? migrated, String? name, String? network, String? nicType, bool? noProxyAccess, bool? noPublicIp, bool? noRemoveDataDisk, String? postStartupScript, String? proxyUri, ReservationAffinity? reservationAffinity, String? serviceAccount, List<String>? serviceAccountScopes, ShieldedInstanceConfig? shieldedInstanceConfig, String? state, String? subnet, List<String>? tags, String? updateTime, List<UpgradeHistoryEntry>? upgradeHistory, VmImage? vmImage})
Instance.fromJson(Map json_)

Properties

acceleratorConfig ↔ AcceleratorConfig?
The hardware accelerator used on this instance.
getter/setter pair
bootDiskSizeGb ↔ String?
Input only.
getter/setter pair
bootDiskType ↔ String?
Input only.
getter/setter pair
canIpForward ↔ bool?
Flag to enable ip forwarding or not, default false/off.
getter/setter pair
containerImage ↔ ContainerImage?
Use a container image to start the notebook instance.
getter/setter pair
createTime ↔ String?
Instance creation time.
getter/setter pair
creator ↔ String?
Email address of entity that sent original CreateInstance request.
getter/setter pair
customGpuDriverPath ↔ String?
Specify a custom Cloud Storage path where the GPU driver is stored.
getter/setter pair
dataDiskSizeGb ↔ String?
Input only.
getter/setter pair
dataDiskType ↔ String?
Input only.
getter/setter pair
diskEncryption ↔ String?
Input only.
getter/setter pair
disks ↔ List<Disk>?
Attached disks to notebook instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installGpuDriver ↔ bool?
Whether the end user authorizes Google Cloud to install GPU driver on this instance.
getter/setter pair
instanceMigrationEligibility ↔ InstanceMigrationEligibility?
Checks how feasible a migration from UmN to WbI is.
getter/setter pair
instanceOwners ↔ List<String>?
Input only.
getter/setter pair
kmsKey ↔ String?
Input only.
getter/setter pair
labels ↔ Map<String, String>?
Labels to apply to this instance.
getter/setter pair
machineType ↔ String?
The Compute Engine machine type of this instance.
getter/setter pair
metadata ↔ Map<String, String>?
Custom metadata to apply to this instance.
getter/setter pair
migrated ↔ bool?
Bool indicating whether this notebook has been migrated to a Workbench Instance
getter/setter pair
name ↔ String?
The name of this notebook instance.
getter/setter pair
network ↔ String?
The name of the VPC that this instance is in.
getter/setter pair
nicType ↔ String?
The type of vNIC to be used on this interface.
getter/setter pair
noProxyAccess ↔ bool?
If true, the notebook instance will not register with the proxy.
getter/setter pair
noPublicIp ↔ bool?
If true, no external IP will be assigned to this instance.
getter/setter pair
noRemoveDataDisk ↔ bool?
Input only.
getter/setter pair
postStartupScript ↔ String?
Path to a Bash script that automatically runs after a notebook instance fully boots up.
getter/setter pair
proxyUri ↔ String?
The proxy endpoint that is used to access the Jupyter notebook.
getter/setter pair
reservationAffinity ↔ ReservationAffinity?
The optional reservation affinity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
The service account on this instance, giving access to other Google Cloud services.
getter/setter pair
serviceAccountScopes ↔ List<String>?
The URIs of service account scopes to be included in Compute Engine instances.
getter/setter pair
shieldedInstanceConfig ↔ ShieldedInstanceConfig?
Shielded VM configuration.
getter/setter pair
state ↔ String?
The state of this instance.
getter/setter pair
subnet ↔ String?
The name of the subnet that this instance is in.
getter/setter pair
tags ↔ List<String>?
The Compute Engine network tags to add to runtime (see Add network tags).
getter/setter pair
updateTime ↔ String?
Instance update time.
getter/setter pair
upgradeHistory ↔ List<UpgradeHistoryEntry>?
The upgrade history of this instance.
getter/setter pair
vmImage ↔ VmImage?
Use a Compute Engine VM image to start the notebook instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited