InstanceConfig class

Notebook instance configurations that can be updated.

Constructors

InstanceConfig({bool? enableHealthMonitoring, String? notebookUpgradeSchedule})
InstanceConfig.fromJson(Map json_)

Properties

enableHealthMonitoring ↔ bool?
Verifies core internal services are running.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
notebookUpgradeSchedule ↔ String?
Cron expression in UTC timezone, used to schedule instance auto upgrade.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited