ListEnvironmentsResponse class

Response for listing environments.

Constructors

ListEnvironmentsResponse({List<Environment>? environments, String? nextPageToken, List<String>? unreachable})
ListEnvironmentsResponse.fromJson(Map json_)

Properties

environments ↔ List<Environment>?
A list of returned environments.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A page token that can be used to continue listing from the last result in the next list call.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited