ListExecutionsResponse class

Response for listing scheduled notebook executions

Constructors

ListExecutionsResponse({List<Execution>? executions, String? nextPageToken, List<String>? unreachable})
ListExecutionsResponse.fromJson(Map json_)

Properties

executions ↔ List<Execution>?
A list of returned instances.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Page token that can be used to continue listing from the last result in the next list call.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Executions IDs that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited