MigrateRuntimeRequest class

Request for migrating a Runtime to a Workbench Instance.

Constructors

MigrateRuntimeRequest({String? network, String? postStartupScriptOption, String? requestId, String? serviceAccount, String? subnet})
MigrateRuntimeRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
network ↔ String?
Name of the VPC that the new Instance is in.
getter/setter pair
postStartupScriptOption ↔ String?
Specifies the behavior of post startup script during migration.
getter/setter pair
requestId ↔ String?
Idempotent request UUID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
The service account to be included in the Compute Engine instance of the new Workbench Instance when the Runtime uses "single user only" mode for permission.
getter/setter pair
subnet ↔ String?
Name of the subnet that the new Instance is in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited