Runtime class

The definition of a Runtime for a managed notebook instance.

Constructors

Runtime({RuntimeAccessConfig? accessConfig, String? createTime, String? healthState, Map<String, String>? labels, RuntimeMetrics? metrics, bool? migrated, String? name, RuntimeMigrationEligibility? runtimeMigrationEligibility, RuntimeSoftwareConfig? softwareConfig, String? state, String? updateTime, VirtualMachine? virtualMachine})
Runtime.fromJson(Map json_)

Properties

accessConfig ↔ RuntimeAccessConfig?
The config settings for accessing runtime.
getter/setter pair
createTime ↔ String?
Runtime creation time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
healthState ↔ String?
Runtime health_state.
getter/setter pair
labels ↔ Map<String, String>?
The labels to associate with this Managed Notebook or Runtime.
getter/setter pair
metrics ↔ RuntimeMetrics?
Contains Runtime daemon metrics such as Service status and JupyterLab stats.
getter/setter pair
migrated ↔ bool?
Bool indicating whether this notebook has been migrated to a Workbench Instance
getter/setter pair
name ↔ String?
The resource name of the runtime.
getter/setter pair
runtimeMigrationEligibility ↔ RuntimeMigrationEligibility?
Checks how feasible a migration from GmN to WbI is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
softwareConfig ↔ RuntimeSoftwareConfig?
The config settings for software inside the runtime.
getter/setter pair
state ↔ String?
Runtime state.
getter/setter pair
updateTime ↔ String?
Runtime update time.
getter/setter pair
virtualMachine ↔ VirtualMachine?
Use a Compute Engine VM image to start the managed notebook instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited