SwitchRuntimeRequest class

Request for switching a Managed Notebook Runtime.

Constructors

SwitchRuntimeRequest({RuntimeAcceleratorConfig? acceleratorConfig, String? machineType, String? requestId})
SwitchRuntimeRequest.fromJson(Map json_)

Properties

acceleratorConfig ↔ RuntimeAcceleratorConfig?
accelerator config.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
machineType ↔ String?
machine type.
getter/setter pair
requestId ↔ String?
Idempotent request UUID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited