VirtualMachine class

Runtime using Virtual Machine for computing.

Constructors

VirtualMachine({String? instanceId, String? instanceName, VirtualMachineConfig? virtualMachineConfig})
VirtualMachine.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceId ↔ String?
The unique identifier of the Managed Compute Engine instance.
getter/setter pair
instanceName ↔ String?
The user-friendly name of the Managed Compute Engine instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
virtualMachineConfig ↔ VirtualMachineConfig?
Virtual Machine configuration settings.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited