VirtualMachineConfig class

The config settings for virtual machine.

Constructors

VirtualMachineConfig({RuntimeAcceleratorConfig? acceleratorConfig, BootImage? bootImage, List<ContainerImage>? containerImages, LocalDisk? dataDisk, EncryptionConfig? encryptionConfig, Map<String, String>? guestAttributes, bool? internalIpOnly, Map<String, String>? labels, String? machineType, Map<String, String>? metadata, String? network, String? nicType, String? reservedIpRange, RuntimeShieldedInstanceConfig? shieldedInstanceConfig, String? subnet, List<String>? tags, String? zone})
VirtualMachineConfig.fromJson(Map json_)

Properties

acceleratorConfig ↔ RuntimeAcceleratorConfig?
The Compute Engine accelerator configuration for this runtime.
getter/setter pair
bootImage ↔ BootImage?
Boot image metadata used for runtime upgradeability.
getter/setter pair
containerImages ↔ List<ContainerImage>?
Use a list of container images to use as Kernels in the notebook instance.
getter/setter pair
dataDisk ↔ LocalDisk?
Data disk option configuration settings.
getter/setter pair
encryptionConfig ↔ EncryptionConfig?
Encryption settings for virtual machine data disk.
getter/setter pair
guestAttributes ↔ Map<String, String>?
The Compute Engine guest attributes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalIpOnly ↔ bool?
If true, runtime will only have internal IP addresses.
getter/setter pair
labels ↔ Map<String, String>?
The labels to associate with this runtime.
getter/setter pair
machineType ↔ String?
The Compute Engine machine type used for runtimes.
getter/setter pair
metadata ↔ Map<String, String>?
The Compute Engine metadata entries to add to virtual machine.
getter/setter pair
network ↔ String?
The Compute Engine network to be used for machine communications.
getter/setter pair
nicType ↔ String?
The type of vNIC to be used on this interface.
getter/setter pair
reservedIpRange ↔ String?
Reserved IP Range name is used for VPC Peering.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shieldedInstanceConfig ↔ ShieldedInstanceConfig?
Shielded VM Instance configuration settings.
getter/setter pair
subnet ↔ String?
The Compute Engine subnetwork to be used for machine communications.
getter/setter pair
tags ↔ List<String>?
The Compute Engine network tags to add to runtime (see Add network tags).
getter/setter pair
zone ↔ String?
The zone where the virtual machine is located.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited