AcceleratorConfig class

An accelerator configuration for a VM instance Definition of a hardware accelerator.

Note that there is no check on type and core_count combinations. TPUs are not supported. See GPUs on Compute Engine to find a valid combination.

Constructors

AcceleratorConfig({String? coreCount, String? type})
AcceleratorConfig.fromJson(Map json_)

Properties

coreCount ↔ String?
Count of cores of this accelerator.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of this accelerator.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited