BootDisk class

The definition of a boot disk.

Constructors

BootDisk({String? diskEncryption, String? diskSizeGb, String? diskType, String? kmsKey})
BootDisk.fromJson(Map json_)

Properties

diskEncryption ↔ String?
Input only.
getter/setter pair
diskSizeGb ↔ String?
The size of the boot disk in GB attached to this instance, up to a maximum of 64000 GB (64 TB).
getter/setter pair
diskType ↔ String?
Indicates the type of the disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKey ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited