CheckAuthorizationResponse class

Response message for checking authorization for the instance owner.

Constructors

CheckAuthorizationResponse({String? createTime, String? oauthUri, bool? success})
CheckAuthorizationResponse.fromJson(Map json_)

Properties

createTime ↔ String?
Timestamp when this Authorization request was created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oauthUri ↔ String?
If the user has not completed OAuth consent, then the oauth_url is returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success ↔ bool?
Success indicates that the user completed OAuth consent and access tokens can be generated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited