ConfidentialInstanceConfig class

A set of Confidential Instance options.

Constructors

ConfidentialInstanceConfig({String? confidentialInstanceType})
ConfidentialInstanceConfig.fromJson(Map json_)

Properties

confidentialInstanceType ↔ String?
Defines the type of technology used by the confidential instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited