Config class

Response for getting WbI configurations in a location

Constructors

Config({List<ImageRelease>? availableImages, DefaultValues? defaultValues, bool? disableWorkbenchLegacyCreation, SupportedValues? supportedValues})
Config.fromJson(Map json_)

Properties

availableImages ↔ List<ImageRelease>?
The list of available images to create a WbI.
getter/setter pair
defaultValues ↔ DefaultValues?
The default values for configuration.
getter/setter pair
disableWorkbenchLegacyCreation ↔ bool?
Flag to disable the creation of legacy Workbench notebooks (User-managed notebooks and Google-managed notebooks).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportedValues ↔ SupportedValues?
The supported values for configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited