diskType property
Indicates the type of the disk.
Optional. Possible string values are:
- "DISK_TYPE_UNSPECIFIED" : Disk type not set.
- "PD_STANDARD" : Standard persistent disk type.
- "PD_SSD" : SSD persistent disk type.
- "PD_BALANCED" : Balanced persistent disk type.
- "PD_EXTREME" : Extreme persistent disk type.
- "HYPERDISK_BALANCED" : Represents the Hyperdisk Balanced persistent disk type. Can be used as a boot disk or data disk.
- "HYPERDISK_EXTREME" : Represents the Hyperdisk Extreme persistent disk type. Can only be used as a data disk.
- "HYPERDISK_THROUGHPUT" : Represents the Hyperdisk Throughput persistent disk type. Can only be used as a data disk.
- "HYPERDISK_BALANCED_HIGH_AVAILABILITY" : Represents the Hyperdisk Balanced High Availability persistent disk type. Can be used as a boot disk or data disk.
- "HYPERDISK_ML" : Represents the Hyperdisk ML persistent disk type. Can be used as a boot disk or data disk.
Implementation
core.String? diskType;