DiagnoseInstanceRequest class

Request for creating a notebook instance diagnostic file.

Constructors

DiagnoseInstanceRequest({DiagnosticConfig? diagnosticConfig, int? timeoutMinutes})
DiagnoseInstanceRequest.fromJson(Map json_)

Properties

diagnosticConfig ↔ DiagnosticConfig?
Defines flags that are used to run the diagnostic tool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutMinutes ↔ int?
Maximum amount of time in minutes before the operation times out.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited