DiagnosticConfig class

Defines flags that are used to run the diagnostic tool

Constructors

DiagnosticConfig({bool? enableCopyHomeFilesFlag, bool? enablePacketCaptureFlag, bool? enableRepairFlag, String? gcsBucket, String? relativePath})
DiagnosticConfig.fromJson(Map json_)

Properties

enableCopyHomeFilesFlag ↔ bool?
Enables flag to copy all /home/jupyter folder contents
getter/setter pair
enablePacketCaptureFlag ↔ bool?
Enables flag to capture packets from the instance for 30 seconds
getter/setter pair
enableRepairFlag ↔ bool?
Enables flag to repair service for instance
getter/setter pair
gcsBucket ↔ String?
User Cloud Storage bucket location (REQUIRED).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
relativePath ↔ String?
Defines the relative storage path in the Cloud Storage bucket where the diagnostic logs will be written: Default path will be the root directory of the Cloud Storage bucket (gs://$GCS_BUCKET/$DATE_$TIME.tar.gz) Example of full path where Log file will be written: gs://$GCS_BUCKET/$RELATIVE_PATH/
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited