GceSetup class

The definition of how to configure a VM instance outside of Resources and Identity.

Constructors

GceSetup({List<AcceleratorConfig>? acceleratorConfigs, BootDisk? bootDisk, ConfidentialInstanceConfig? confidentialInstanceConfig, ContainerImage? containerImage, List<DataDisk>? dataDisks, bool? disablePublicIp, bool? enableIpForwarding, GPUDriverConfig? gpuDriverConfig, String? instanceId, String? machineType, Map<String, String>? metadata, String? minCpuPlatform, List<NetworkInterface>? networkInterfaces, ReservationAffinity? reservationAffinity, List<ServiceAccount>? serviceAccounts, ShieldedInstanceConfig? shieldedInstanceConfig, List<String>? tags, VmImage? vmImage})
GceSetup.fromJson(Map json_)

Properties

acceleratorConfigs ↔ List<AcceleratorConfig>?
The hardware accelerators used on this instance.
getter/setter pair
bootDisk ↔ BootDisk?
The boot disk for the VM.
getter/setter pair
confidentialInstanceConfig ↔ ConfidentialInstanceConfig?
Confidential instance configuration.
getter/setter pair
containerImage ↔ ContainerImage?
Use a container image to start the notebook instance.
getter/setter pair
dataDisks ↔ List<DataDisk>?
Data disks attached to the VM instance.
getter/setter pair
disablePublicIp ↔ bool?
If true, no external IP will be assigned to this VM instance.
getter/setter pair
enableIpForwarding ↔ bool?
Flag to enable ip forwarding or not, default false/off.
getter/setter pair
gpuDriverConfig ↔ GPUDriverConfig?
Configuration for GPU drivers.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceId ↔ String?
The unique ID of the Compute Engine instance resource.
getter/setter pair
machineType ↔ String?
The machine type of the VM instance.
getter/setter pair
metadata ↔ Map<String, String>?
Custom metadata to apply to this instance.
getter/setter pair
minCpuPlatform ↔ String?
The minimum CPU platform to use for this instance.
getter/setter pair
networkInterfaces ↔ List<NetworkInterface>?
The network interfaces for the VM.
getter/setter pair
reservationAffinity ↔ ReservationAffinity?
Specifies the reservations that this instance can consume from.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccounts ↔ List<ServiceAccount>?
The service account that serves as an identity for the VM instance.
getter/setter pair
shieldedInstanceConfig ↔ ShieldedInstanceConfig?
Shielded VM configuration.
getter/setter pair
tags ↔ List<String>?
The Compute Engine network tags to add to runtime (see Add network tags).
getter/setter pair
vmImage ↔ VmImage?
Use a Compute Engine VM image to start the notebook instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited