NetworkInterface class

The definition of a network interface resource attached to a VM.

Constructors

NetworkInterface({List<AccessConfig>? accessConfigs, String? network, String? nicType, String? subnet})
NetworkInterface.fromJson(Map json_)

Properties

accessConfigs ↔ List<AccessConfig>?
An array of configurations for this interface.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
network ↔ String?
The name of the VPC that this VM instance is in.
getter/setter pair
nicType ↔ String?
The type of vNIC to be used on this interface.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnet ↔ String?
The name of the subnet that this VM instance is in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited