ReservationAffinity class

A reservation that an instance can consume from.

Constructors

ReservationAffinity({String? consumeReservationType, String? key, List<String>? values})
ReservationAffinity.fromJson(Map json_)

Properties

consumeReservationType ↔ String?
Specifies the type of reservation from which this instance can consume resources: RESERVATION_ANY (default), RESERVATION_SPECIFIC, or RESERVATION_NONE.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
Corresponds to the label key of a reservation resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<String>?
Corresponds to the label values of a reservation resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited