ResizeDiskRequest class

Request for resizing the notebook instance disks

Constructors

ResizeDiskRequest({BootDisk? bootDisk, DataDisk? dataDisk})
ResizeDiskRequest.fromJson(Map json_)

Properties

bootDisk ↔ BootDisk?
The boot disk to be resized.
getter/setter pair
dataDisk ↔ DataDisk?
The data disk to be resized.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited