RollbackInstanceRequest class

Request for rollbacking a notebook instance

Constructors

RollbackInstanceRequest({String? revisionId, String? targetSnapshot})
RollbackInstanceRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
revisionId ↔ String?
Revision Id
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetSnapshot ↔ String?
The snapshot for rollback.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited