UpgradeInstanceRequest class
Request for upgrading a notebook instance
Constructors
- UpgradeInstanceRequest({String? imageFamily})
- UpgradeInstanceRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageFamily ↔ String?
-
The Compute Engine image family resource name to upgrade to.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited