imageDescription property

String? imageDescription
getter/setter pair

A human-readable description of the image running on the instance (for example, "Debian 11, Python 3.10"), derived at read time from the image release configuration (the source of truth).

Set to "Custom" for unrecognized boot-disk images.

Output only.

Implementation

core.String? imageDescription;