Tokeninfo class

Constructors

Tokeninfo({String? audience, String? email, int? expiresIn, String? issuedTo, String? scope, String? userId, bool? verifiedEmail})
Tokeninfo.fromJson(Map json_)

Properties

audience ↔ String?
Who is the intended audience for this token.
getter/setter pair
email ↔ String?
The email address of the user.
getter/setter pair
expiresIn ↔ int?
The expiry time of the token, as number of seconds left until expiry.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuedTo ↔ String?
To whom was the token issued to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
The space separated list of scopes granted to this token.
getter/setter pair
userId ↔ String?
The obfuscated user id.
getter/setter pair
verifiedEmail ↔ bool?
Boolean flag which is true if the email address is verified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited