Bucket class

Bucket configuration for storing observability data.

Constructors

Bucket({CmekSettings? cmekSettings, String? createTime, String? deleteTime, String? description, String? displayName, String? name, String? purgeTime, String? updateTime})
Bucket.fromJson(Map json_)

Properties

cmekSettings ↔ CmekSettings?
Settings for configuring CMEK on a bucket.
getter/setter pair
createTime ↔ String?
Create timestamp.
getter/setter pair
deleteTime ↔ String?
Delete timestamp.
getter/setter pair
description ↔ String?
Description of the bucket.
getter/setter pair
displayName ↔ String?
User friendly display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
purgeTime ↔ String?
Timestamp when the bucket in soft-deleted state is purged.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Update timestamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited