Link class

A link lets a dataset be accessible to BigQuery via usage of linked datasets.

Constructors

Link({String? createTime, String? description, String? displayName, String? name})
Link.fromJson(Map json_)

Properties

createTime ↔ String?
Create timestamp.
getter/setter pair
description ↔ String?
Description of the link.
getter/setter pair
displayName ↔ String?
A user friendly display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited