ListTraceScopesResponse class

Response for listing TraceScopes.

Constructors

ListTraceScopesResponse({String? nextPageToken, List<TraceScope>? traceScopes})
ListTraceScopesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If there might be more results than appear in this response, then next_page_token is included.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traceScopes ↔ List<TraceScope>?
A list of trace scopes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited