ProjectsLocationsBucketsResource class
Methods
-
create(Bucket request, String parent, {String? bucketId, String? $fields})
→ Future<Operation>
-
Create a new bucket.
-
get(String name, {String? $fields})
→ Future<Bucket>
-
Get bucket resource.
-
list(String parent, {int? pageSize, String? pageToken, bool? showDeleted, String? $fields})
→ Future<ListBucketsResponse>
-
List buckets of a project in a particular location.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(Bucket request, String name, {String? updateMask, String? $fields})
→ Future<Operation>
-
Update a bucket.
-
toString()
→ String
-
A string representation of this object.
inherited