Scope class

Message describing Scope object

Constructors

Scope({String? logScope, String? name, String? traceScope, String? updateTime})
Scope.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logScope ↔ String?
The full resource name of the LogScope.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traceScope ↔ String?
The resource name of the TraceScope.
getter/setter pair
updateTime ↔ String?
Update timestamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited