defaultStorageLocation property
The location which should be used when any regional resources are provisioned by Google Cloud.
Optional.
Implementation
core.String? defaultStorageLocation;
The location which should be used when any regional resources are provisioned by Google Cloud.
Optional.
core.String? defaultStorageLocation;