serviceAccountId property

String? serviceAccountId
getter/setter pair

The service account for the given resource container, such as project or folder.

This will be used by Cloud Observability to perform actions in the container's project like access KMS keys or create Links. Always the same service account per resource container regardless of region.

Output only.

Implementation

core.String? serviceAccountId;