lineNumber property

int? lineNumber
getter/setter pair

Line number in the file where the package is found.

Applies only to source repository scanning. Note: this field is marked as optional in other corresponding protos, but in edition 2023, the "optional" keyword is redundant.

Implementation

core.int? lineNumber;