IngestionSource class
Indicates where an extracted package originates from.
Constructors
- IngestionSource({String? attachmentUri, String? resourceUrl, String? source})
- IngestionSource.fromJson(Map json_)
Properties
- attachmentUri ↔ String?
-
The attachment URI that this package was extracted from.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceUrl ↔ String?
-
The resource URL of the resource that was scanned to find this package.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ String?
-
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited