ingestionSources property
The list of sources that were scanned to find this package.
This can be a Docker image, an SBOM attachment, or both, for example.
Implementation
core.List<IngestionSource>? ingestionSources;
The list of sources that were scanned to find this package.
This can be a Docker image, an SBOM attachment, or both, for example.
core.List<IngestionSource>? ingestionSources;