oracledatabase/v1 library
Oracle Database@Google Cloud API - v1
The Oracle Database@Google Cloud API provides a set of APIs to manage Oracle database services, such as Exadata and Autonomous Databases.
For more information, see cloud.google.com/oracle/database/docs
Create an instance of OracleDatabaseApi to access these resources:
- ProjectsResource
- ProjectsLocationsResource
- ProjectsLocationsAutonomousDatabaseBackupsResource
- ProjectsLocationsAutonomousDatabaseCharacterSetsResource
- ProjectsLocationsAutonomousDatabasesResource
- ProjectsLocationsAutonomousDbVersionsResource
- ProjectsLocationsCloudExadataInfrastructuresResource
- ProjectsLocationsCloudVmClustersResource
- ProjectsLocationsDatabaseCharacterSetsResource
- ProjectsLocationsDatabasesResource
- ProjectsLocationsDbSystemInitialStorageSizesResource
- ProjectsLocationsDbSystemShapesResource
- ProjectsLocationsDbSystemsResource
- ProjectsLocationsDbVersionsResource
- ProjectsLocationsEntitlementsResource
- ProjectsLocationsExadbVmClustersResource
- ProjectsLocationsExascaleDbStorageVaultsResource
- ProjectsLocationsGiVersionsResource
- ProjectsLocationsGoldengateConnectionAssignmentsResource
- ProjectsLocationsGoldengateConnectionTypesResource
- ProjectsLocationsGoldengateConnectionsResource
- ProjectsLocationsGoldengateDeploymentEnvironmentsResource
- ProjectsLocationsGoldengateDeploymentTypesResource
- ProjectsLocationsGoldengateDeploymentVersionsResource
- ProjectsLocationsGoldengateDeploymentsResource
- ProjectsLocationsOdbNetworksResource
- ProjectsLocationsOperationsResource
- ProjectsLocationsPluggableDatabasesResource
- ProjectsLocationsResource
Classes
- AllConnectionStrings
- A list of all connection strings that can be used to connect to the Autonomous Database.
- AmazonS3IcebergStorage
- The Amazon S3 Iceberg storage.
- AutonomousDatabase
- Details of the Autonomous Database resource.
- AutonomousDatabaseApex
- Oracle APEX Application Development.
- AutonomousDatabaseBackup
- Details of the Autonomous Database Backup resource.
- AutonomousDatabaseBackupProperties
- Properties of the Autonomous Database Backup resource.
- AutonomousDatabaseCharacterSet
- Details of the Autonomous Database character set resource.
- AutonomousDatabaseConnectionStrings
- The connection string used to connect to the Autonomous Database.
- AutonomousDatabaseConnectionUrls
- The URLs for accessing Oracle Application Express (APEX) and SQL Developer Web with a browser from a Compute instance.
- AutonomousDatabaseProperties
- The properties of an Autonomous Database.
- AutonomousDatabaseRefreshableClone
- An Autonomous Database refreshable clone
- AutonomousDatabaseRefreshableClones
- Response message for getting the Autonomous Database refreshable clones.
- AutonomousDatabaseStandbySummary
- Autonomous Data Guard standby database details.
- AutonomousDbVersion
- Details of the Autonomous Database version.
- AzureDataLakeStorageIcebergStorage
- The Azure Data Lake Storage Iceberg storage.
- BackupDestinationDetails
- The details of the database backup destination.
- CloudAccountDetails
- Details of the OCI Cloud Account.
- CloudExadataInfrastructure
- Represents CloudExadataInfrastructure resource.
- CloudExadataInfrastructureProperties
- Various properties of Exadata Infrastructure.
- CloudVmCluster
- Details of the Cloud VM Cluster resource.
- CloudVmClusterProperties
- Various properties and settings associated with Exadata VM cluster.
- ConfigureExascaleCloudExadataInfrastructureRequest
-
The request for
CloudExadataInfrastructure.ConfigureExascale. - CustomerContact
- The CustomerContact reference as defined by Oracle.
- Database
- Details of the Database resource.
- DatabaseCharacterSet
- Details of the Database character set resource.
- DatabaseConnectionStringProfile
- The connection string profile to allow clients to group.
- DatabaseManagementConfig
- The configuration of the Database Management service.
- DatabaseProperties
- The properties of a Database.
- DataCollectionOptions
- Data collection options for diagnostics.
- DataCollectionOptionsCommon
- Data collection options for diagnostics.
- DataCollectionOptionsDbSystem
- Data collection options for DbSystem.
- DbBackupConfig
- Backup Options for the Database.
- DbHome
- Details of the Database Home resource.
- DbNode
- Details of the database node resource.
- DbNodeProperties
- Various properties and settings associated with Db node.
- DbServer
- Details of the database server resource.
- DbServerProperties
- Various properties and settings associated with Exadata database server.
- DbSystem
- Details of the DbSystem (BaseDB) resource.
- DbSystemInitialStorageSize
- Summary of the DbSystem initial storage size.
- DbSystemInitialStorageSizeProperties
- The properties of a DbSystem initial storage size summary.
- DbSystemOptions
- Details of the DbSystem Options.
- DbSystemProperties
- The properties of a DbSystem.
- DbSystemShape
- Details of the Database System Shapes resource.
- DbVersion
- A valid Oracle Database version.
- DbVersionProperties
- The properties of a DbVersion.
- DefinedTagValue
- Wrapper message for the value of a defined tag.
- DeploymentDiagnosticData
- The deployment diagnostic data.
- EncryptionKey
- The encryption key used to encrypt the Autonomous Database.
- EncryptionKeyHistoryEntry
- The history of the encryption keys used to encrypt the Autonomous Database.
- Entitlement
- Details of the Entitlement resource.
- ExadbVmCluster
- ExadbVmCluster represents a cluster of VMs that are used to run Exadata workloads.
- ExadbVmClusterProperties
- The properties of an ExadbVmCluster.
- ExadbVmClusterStorageDetails
- The storage allocation for the exadbvmcluster, in gigabytes (GB).
- ExascaleConfig
- Details of the Exascale configuration for the Exadata Infrastructure.
- ExascaleDbStorageDetails
- The storage details of the ExascaleDbStorageVault.
- ExascaleDbStorageVault
- ExascaleDbStorageVault represents a storage vault exadb vm cluster resource.
- ExascaleDbStorageVaultProperties
- The properties of the ExascaleDbStorageVault.
- FailoverAutonomousDatabaseRequest
-
The request for
OracleDatabase.FailoverAutonomousDatabase. - GenerateAutonomousDatabaseWalletRequest
-
The request for
AutonomousDatabase.GenerateWallet. - GenerateAutonomousDatabaseWalletResponse
-
The response for
AutonomousDatabase.GenerateWallet. - GiVersion
- Details of the Oracle Grid Infrastructure (GI) version resource.
- GlueIcebergCatalog
- The Glue Iceberg catalog.
- GoldengateAmazonKinesisConnectionProperties
- The properties of GoldengateAmazonKinesisConnection.
- GoldengateAmazonRedshiftConnectionProperties
- The properties of GoldengateAmazonRedshiftConnection.
- GoldengateAmazonS3ConnectionProperties
- The properties of GoldengateAmazonS3Connection.
- GoldengateAzureDataLakeStorageConnectionProperties
- The properties of GoldengateAzureDataLakeStorageConnection.
- GoldengateAzureSynapseAnalyticsConnectionProperties
- The properties of GoldengateAzureSynapseAnalyticsConnection.
- GoldengateBackupSchedule
- The backup schedule of the GoldengateDeployment.
- GoldengateConnection
- Details of the GoldengateConnection resource.
- GoldengateConnectionAssignment
- Represents the metadata of a Goldengate Connection Assignment.
- GoldengateConnectionAssignmentProperties
- The properties of a GoldengateConnectionAssignment.
- GoldengateConnectionProperties
- The properties of a GoldengateConnection.
- GoldengateConnectionType
- Details of the Goldengate Connection Type resource.
- GoldengateDatabricksConnectionProperties
- The properties of GoldengateDatabricksConnection.
- GoldengateDb2ConnectionProperties
- The properties of GoldengateDb2Connection.
- GoldengateDeployment
- GoldengateDeployment Goldengate Deployment resource model.
- GoldengateDeploymentEnvironment
- Details of the Goldengate Deployment Environment resource.
- GoldengateDeploymentLock
- The lock of the GoldengateDeployment.
- GoldengateDeploymentProperties
- Properties of GoldengateDeployment.
- GoldengateDeploymentType
- Details of the Goldengate Deployment Type resource.
- GoldengateDeploymentVersion
- Details of the Goldengate Deployment Version resource.
- GoldengateDeploymentVersionProperties
- Properties of GoldengateDeploymentVersion.
- GoldengateElasticsearchConnectionProperties
- The properties of GoldengateElasticsearchConnection.
- GoldengateGenericConnectionProperties
- The properties of GoldengateGenericConnectionProperties.
- GoldengateGoldengateConnectionProperties
- The properties of GoldengateGoldengateConnectionProperties.
- GoldengateGoogleBigQueryConnectionProperties
- The properties of GoldengateGoogleBigQueryConnectionProperties.
- GoldengateGoogleCloudStorageConnectionProperties
- The properties of GoldengateGoogleCloudStorageConnectionProperties.
- GoldengateGooglePubsubConnectionProperties
- The properties of GoldengateGooglePubsubConnection.
- GoldengateGroupToRolesMapping
- The group to roles mapping of the GoldengateDeployment.
- GoldengateHdfsConnectionProperties
- The properties of GoldengateHdfsConnection.
- GoldengateIcebergConnectionProperties
- The properties of GoldengateIcebergConnection.
- GoldengateJavaMessageServiceConnectionProperties
- The properties of GoldengateJavaMessageServiceConnection.
- GoldengateKafkaConnectionProperties
- The properties of GoldengateKafkaConnection.
- GoldengateKafkaSchemaRegistryConnectionProperties
- The properties of GoldengateKafkaSchemaRegistryConnection.
- GoldengateMaintenanceConfig
- The maintenance configuration of the GoldengateDeployment.
- GoldengateMaintenanceWindow
- The maintenance window of the GoldengateDeployment.
- GoldengateMicrosoftFabricConnectionProperties
- The properties of GoldengateMicrosoftFabricConnection.
- GoldengateMicrosoftSqlserverConnectionProperties
- The properties of GoldengateMicrosoftSqlserverConnection.
- GoldengateMongodbConnectionProperties
- The properties of GoldengateMongodbConnection.
- GoldengateMysqlConnectionProperties
- Properties of GoldengateMysqlConnection.
- GoldengateOciObjectStorageConnectionProperties
- The properties of GoldengateOciObjectStorageConnection.
- GoldengateOggDeployment
- The Ogg data of the GoldengateDeployment.
- GoldengateOracleAIDataPlatformConnectionProperties
- The properties of GoldengateOracleAIDataPlatformConnection.
- GoldengateOracleConnectionProperties
- The properties of Goldengate Oracle Database Connection.
- GoldengateOracleNosqlConnectionProperties
- The properties of GoldengateOracleNosqlConnection.
- GoldengatePlacement
- The placement of the GoldengateDeployment.
- GoldengatePostgresqlConnectionProperties
- The properties of GoldengatePostgresqlConnection.
- GoldengateRedisConnectionProperties
- The properties of GoldengateRedisConnection.
- GoldengateSnowflakeConnectionProperties
- The properties of GoldengateSnowflakeConnection.
- GoogleCloudStorageIcebergStorage
- The Google Cloud Storage Iceberg storage.
- IcebergCatalog
- The Iceberg catalog details.
- IcebergStorage
- The Iceberg storage details.
- IdentityConnector
- The identity connector details which will allow OCI to securely access the resources in the customer project.
- IngressIp
- The ingress IPs of the GoldengateDeployment.
- KafkaBootstrapServer
- Represents a Kafka bootstrap server with host name, optional port defaults to 9092, and an optional private ip.
- ListAutonomousDatabaseBackupsResponse
-
The response for
AutonomousDatabaseBackup.List. - ListAutonomousDatabaseCharacterSetsResponse
-
The response for
AutonomousDatabaseCharacterSet.List. - ListAutonomousDatabasesResponse
-
The response for
AutonomousDatabase.List. - ListAutonomousDbVersionsResponse
-
The response for
AutonomousDbVersion.List. - ListCloudExadataInfrastructuresResponse
-
The response for
CloudExadataInfrastructures.list. - ListCloudVmClustersResponse
-
The response for
CloudVmCluster.List. - ListDatabaseCharacterSetsResponse
-
The response for
DatabaseCharacterSet.List. - ListDatabasesResponse
-
The response for
Database.List. - ListDbNodesResponse
-
The response for
DbNode.List. - ListDbServersResponse
-
The response for
DbServer.List. - ListDbSystemInitialStorageSizesResponse
-
The response for
DbSystemInitialStorageSizes.List. - ListDbSystemShapesResponse
-
The response for
DbSystemShape.List. - ListDbSystemsResponse
-
The response for
DbSystem.List. - ListDbVersionsResponse
-
The response for
DbVersions.List. - ListEntitlementsResponse
-
The response for
Entitlement.List. - ListExadbVmClustersResponse
-
The response for
ExadbVmCluster.List. - ListExascaleDbStorageVaultsResponse
-
The response for
ExascaleDbStorageVault.List. - ListGiVersionsResponse
-
The response for
GiVersion.List. - ListGoldengateConnectionAssignmentsResponse
- Response message for listing GoldengateConnectionAssignments.
- ListGoldengateConnectionsResponse
-
The response for
GoldengateConnection.List. - ListGoldengateConnectionTypesResponse
- Message for response to listing GoldengateConnectionTypes
- ListGoldengateDeploymentEnvironmentsResponse
- Message for response to listing GoldengateDeploymentEnvironments
- ListGoldengateDeploymentsResponse
-
The response for
GoldengateDeployment.List. - ListGoldengateDeploymentTypesResponse
- Message for response to listing GoldengateDeploymentTypes
- ListGoldengateDeploymentVersionsResponse
- Message for response to listing GoldengateDeploymentVersions
- ListLocationsResponse
- The response message for Locations.ListLocations.
- ListMinorVersionsResponse
-
The response for
MinorVersion.List. - ListOdbNetworksResponse
-
The response for
OdbNetwork.List. - ListOdbSubnetsResponse
-
The response for
OdbSubnet.List. - ListOperationsResponse
- The response message for Operations.ListOperations.
- ListPluggableDatabasesResponse
-
The response for
PluggableDatabase.List. - MaintenanceWindow
- Maintenance window as defined by Oracle.
- MinorVersion
- MinorVersion represents a minor version of a GI.
- NameValuePair
- A name-value pair representing an attribute entry usable in a list of attributes.
- NessieIcebergCatalog
- The Nessie Iceberg catalog.
- OdbNetwork
- Represents OdbNetwork resource.
- OdbSubnet
- Represents OdbSubnet resource.
- Operation
- This resource represents a long-running operation that is the result of a network API call.
- OracleDatabaseApi
- The Oracle Database@Google Cloud API provides a set of APIs to manage Oracle database services, such as Exadata and Autonomous Databases.
- PluggableDatabase
- The PluggableDatabase resource.
- PluggableDatabaseConnectionStrings
- The connection strings used to connect to the Oracle Database.
- PluggableDatabaseNodeLevelDetails
- The Pluggable Database Node Level Details.
- PluggableDatabaseProperties
- The properties of a PluggableDatabase.
- PolarisIcebergCatalog
- The Polaris Iceberg catalog.
- ProjectsLocationsAutonomousDatabaseBackupsResource
- ProjectsLocationsAutonomousDatabaseCharacterSetsResource
- ProjectsLocationsAutonomousDatabasesResource
- ProjectsLocationsAutonomousDbVersionsResource
- ProjectsLocationsCloudExadataInfrastructuresDbServersResource
- ProjectsLocationsCloudExadataInfrastructuresResource
- ProjectsLocationsCloudVmClustersDbNodesResource
- ProjectsLocationsCloudVmClustersResource
- ProjectsLocationsDatabaseCharacterSetsResource
- ProjectsLocationsDatabasesResource
- ProjectsLocationsDbSystemInitialStorageSizesResource
- ProjectsLocationsDbSystemShapesResource
- ProjectsLocationsDbSystemsResource
- ProjectsLocationsDbVersionsResource
- ProjectsLocationsEntitlementsResource
- ProjectsLocationsExadbVmClustersDbNodesResource
- ProjectsLocationsExadbVmClustersResource
- ProjectsLocationsExascaleDbStorageVaultsResource
- ProjectsLocationsGiVersionsMinorVersionsResource
- ProjectsLocationsGiVersionsResource
- ProjectsLocationsGoldengateConnectionAssignmentsResource
- ProjectsLocationsGoldengateConnectionsResource
- ProjectsLocationsGoldengateConnectionTypesResource
- ProjectsLocationsGoldengateDeploymentEnvironmentsResource
- ProjectsLocationsGoldengateDeploymentsResource
- ProjectsLocationsGoldengateDeploymentTypesResource
- ProjectsLocationsGoldengateDeploymentVersionsResource
- ProjectsLocationsOdbNetworksOdbSubnetsResource
- ProjectsLocationsOdbNetworksResource
- ProjectsLocationsOperationsResource
- ProjectsLocationsPluggableDatabasesResource
- ProjectsLocationsResource
- ProjectsResource
- RefreshAutonomousDatabaseRequest
- Request message for RefreshAutonomousDatabase method.
- RemoveVirtualMachineExadbVmClusterRequest
-
The request for
ExadbVmCluster.RemoveVirtualMachine. - RestIcebergCatalog
- The REST Iceberg catalog.
- RestoreAutonomousDatabaseRequest
-
The request for
AutonomousDatabase.Restore. - ScheduledOperationDetails
- Details of scheduled operation.
- SourceConfig
- The source configuration for the standby Autonomous Database.
- StorageSizeDetails
- The initial storage size, in gigabytes, that is applicable for virtual machine DBSystem.
- SwitchoverAutonomousDatabaseRequest
-
The request for
OracleDatabase.SwitchoverAutonomousDatabase. - TestConnectionAssignmentError
- Error details for TestGoldengateConnectionAssignment.
- TestGoldengateConnectionAssignmentRequest
- Request message for TestGoldengateConnectionAssignment.
- TestGoldengateConnectionAssignmentResponse
- The result of the connectivity test performed between the Goldengate deployment and the associated database / service.
Typedefs
- CancelOperationRequest = $Empty
- The request message for Operations.CancelOperation.
- Empty = $Empty
- A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
- Location = $Location00
- A resource that represents a Google Cloud location.
- RestartAutonomousDatabaseRequest = $Empty
-
The request for
AutonomousDatabase.Restart. - StartAutonomousDatabaseRequest = $Empty
-
The request for
AutonomousDatabase.Start. - StartGoldengateDeploymentRequest = $Empty
-
The request for
GoldengateDeployment.Start. - Status = $Status00
-
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. - StopAutonomousDatabaseRequest = $Empty
-
The request for
AutonomousDatabase.Stop. - StopGoldengateDeploymentRequest = $Empty
-
The request for
GoldengateDeployment.Stop. - TimeOfDay = $TimeOfDay
- Represents a time of day.
- TimeZone = $TimeZone
- Represents a time zone from the IANA Time Zone Database.
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.