AllConnectionStrings class

A list of all connection strings that can be used to connect to the Autonomous Database.

Constructors

AllConnectionStrings({String? high, String? low, String? medium})
AllConnectionStrings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
high ↔ String?
The database service provides the highest level of resources to each SQL statement.
getter/setter pair
low ↔ String?
The database service provides the least level of resources to each SQL statement.
getter/setter pair
medium ↔ String?
The database service provides a lower level of resources to each SQL statement.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited