AmazonS3IcebergStorage class
The Amazon S3 Iceberg storage.
Constructors
- AmazonS3IcebergStorage({String? accessKeyId, String? bucket, String? endpoint, String? region, String? schemeType, String? secretAccessKeySecret})
- AmazonS3IcebergStorage.fromJson(Map json_)
Properties
- accessKeyId ↔ String?
-
The access key ID of Amazon S3.
getter/setter pair
- bucket ↔ String?
-
The bucket of Amazon S3.
getter/setter pair
- endpoint ↔ String?
-
The endpoint of Amazon S3.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- region ↔ String?
-
The region of Amazon S3.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schemeType ↔ String?
-
The scheme type of Amazon S3.
getter/setter pair
- secretAccessKeySecret ↔ String?
-
The secret access key of Amazon S3.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited