AutonomousDatabaseApex class

Constructors

AutonomousDatabaseApex({String? apexVersion, String? ordsVersion})
AutonomousDatabaseApex.fromJson(Map json_)

Properties

apexVersion ↔ String?
The Oracle APEX Application Development version.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ordsVersion ↔ String?
The Oracle REST Data Services (ORDS) version.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited