AutonomousDatabaseBackup class

Constructors

AutonomousDatabaseBackup({String? autonomousDatabase, String? displayName, Map<String, String>? labels, String? name, AutonomousDatabaseBackupProperties? properties})
AutonomousDatabaseBackup.fromJson(Map json_)

Properties

autonomousDatabase ↔ String?
The name of the Autonomous Database resource for which the backup is being created.
getter/setter pair
displayName ↔ String?
User friendly name for the Backup.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
labels or tags associated with the resource.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
properties ↔ AutonomousDatabaseBackupProperties?
Various properties of the backup.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited