AutonomousDatabaseBackupProperties class

Properties of the Autonomous Database Backup resource.

Constructors

AutonomousDatabaseBackupProperties({String? availableTillTime, String? compartmentId, double? databaseSizeTb, String? dbVersion, String? endTime, bool? isAutomaticBackup, bool? isLongTermBackup, bool? isRestorable, String? keyStoreId, String? keyStoreWallet, String? kmsKeyId, String? kmsKeyVersionId, String? lifecycleDetails, String? lifecycleState, String? ocid, int? retentionPeriodDays, double? sizeTb, String? startTime, String? type, String? vaultId})
AutonomousDatabaseBackupProperties.fromJson(Map json_)

Properties

availableTillTime ↔ String?
Timestamp until when the backup will be available.
getter/setter pair
compartmentId ↔ String?
The OCID of the compartment.
getter/setter pair
databaseSizeTb ↔ double?
The quantity of data in the database, in terabytes.
getter/setter pair
dbVersion ↔ String?
A valid Oracle Database version for Autonomous Database.
getter/setter pair
endTime ↔ String?
The date and time the backup completed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAutomaticBackup ↔ bool?
Indicates if the backup is automatic or user initiated.
getter/setter pair
isLongTermBackup ↔ bool?
Indicates if the backup is long term backup.
getter/setter pair
isRestorable ↔ bool?
Indicates if the backup can be used to restore the Autonomous Database.
getter/setter pair
keyStoreId ↔ String?
The OCID of the key store of Oracle Vault.
getter/setter pair
keyStoreWallet ↔ String?
The wallet name for Oracle Key Vault.
getter/setter pair
kmsKeyId ↔ String?
The OCID of the key container that is used as the master encryption key in database transparent data encryption (TDE) operations.
getter/setter pair
kmsKeyVersionId ↔ String?
The OCID of the key container version that is used in database transparent data encryption (TDE) operations KMS Key can have multiple key versions.
getter/setter pair
lifecycleDetails ↔ String?
Additional information about the current lifecycle state.
getter/setter pair
lifecycleState ↔ String?
The lifecycle state of the backup.
getter/setter pair
ocid ↔ String?
OCID of the Autonomous Database backup.
getter/setter pair
retentionPeriodDays ↔ int?
Retention period in days for the backup.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeTb ↔ double?
The backup size in terabytes.
getter/setter pair
startTime ↔ String?
The date and time the backup started.
getter/setter pair
type ↔ String?
The type of the backup.
getter/setter pair
vaultId ↔ String?
The OCID of the vault.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited