AutonomousDatabaseConnectionStrings class

Properties

allConnectionStrings ↔ AllConnectionStrings?
Returns all connection strings that can be used to connect to the Autonomous Database.
getter/setter pair
dedicated ↔ String?
The database service provides the least level of resources to each SQL statement, but supports the most number of concurrent SQL statements.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
high ↔ String?
The database service provides the highest level of resources to each SQL statement.
getter/setter pair
low ↔ String?
The database service provides the least level of resources to each SQL statement.
getter/setter pair
medium ↔ String?
The database service provides a lower level of resources to each SQL statement.
getter/setter pair
profiles ↔ List<DatabaseConnectionStringProfile>?
A list of connection string profiles to allow clients to group, filter, and select values based on the structured metadata.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited