AutonomousDatabaseProperties class

The properties of an Autonomous Database.

Constructors

AutonomousDatabaseProperties({double? actualUsedDataStorageSizeTb, double? allocatedStorageSizeTb, List<String>? allowlistedIps, AutonomousDatabaseApex? apexDetails, bool? arePrimaryAllowlistedIpsUsed, String? autonomousContainerDatabaseId, List<String>? availableUpgradeVersions, int? backupRetentionPeriodDays, String? characterSet, double? computeCount, AutonomousDatabaseConnectionStrings? connectionStrings, AutonomousDatabaseConnectionUrls? connectionUrls, int? cpuCoreCount, List<CustomerContact>? customerContacts, String? dataGuardRoleChangedTime, String? dataSafeState, int? dataStorageSizeGb, int? dataStorageSizeTb, String? databaseManagementState, String? dbEdition, String? dbVersion, String? dbWorkload, String? disasterRecoveryRoleChangedTime, EncryptionKey? encryptionKey, List<EncryptionKeyHistoryEntry>? encryptionKeyHistoryEntries, String? failedDataRecoveryDuration, bool? isAutoScalingEnabled, bool? isLocalDataGuardEnabled, bool? isStorageAutoScalingEnabled, String? licenseType, String? lifecycleDetails, int? localAdgAutoFailoverMaxDataLossLimit, int? localAdgAutoFailoverMaxDataLossLimitDuration, bool? localDataGuardEnabled, String? localDisasterRecoveryType, AutonomousDatabaseStandbySummary? localStandbyDb, String? maintenanceBeginTime, String? maintenanceEndTime, String? maintenanceScheduleType, int? memoryPerOracleComputeUnitGbs, int? memoryTableGbs, bool? mtlsConnectionRequired, String? nCharacterSet, String? nextLongTermBackupTime, String? ociUrl, String? ocid, String? openMode, String? operationsInsightsState, List<String>? peerDbIds, String? permissionLevel, String? privateEndpoint, String? privateEndpointIp, String? privateEndpointLabel, bool? refreshableClone, String? refreshableMode, String? refreshableState, String? role, List<ScheduledOperationDetails>? scheduledOperationDetails, String? secretId, String? serviceAgentEmail, String? sqlWebDeveloperUrl, String? state, List<String>? supportedCloneRegions, double? totalAutoBackupStorageSizeGbs, int? usedDataStorageSizeTbs, String? vaultId})
AutonomousDatabaseProperties.fromJson(Map json_)

Properties

actualUsedDataStorageSizeTb ↔ double?
The amount of storage currently being used for user and system data, in terabytes.
getter/setter pair
allocatedStorageSizeTb ↔ double?
The amount of storage currently allocated for the database tables and billed for, rounded up in terabytes.
getter/setter pair
allowlistedIps ↔ List<String>?
The list of allowlisted IP addresses for the Autonomous Database.
getter/setter pair
apexDetails ↔ AutonomousDatabaseApex?
The details for the Oracle APEX Application Development.
getter/setter pair
arePrimaryAllowlistedIpsUsed ↔ bool?
This field indicates the status of Data Guard and Access control for the Autonomous Database.
getter/setter pair
autonomousContainerDatabaseId ↔ String?
The Autonomous Container Database OCID.
getter/setter pair
availableUpgradeVersions ↔ List<String>?
The list of available Oracle Database upgrade versions for an Autonomous Database.
getter/setter pair
backupRetentionPeriodDays ↔ int?
The retention period for the Autonomous Database.
getter/setter pair
characterSet ↔ String?
The character set for the Autonomous Database.
getter/setter pair
computeCount ↔ double?
The number of compute servers for the Autonomous Database.
getter/setter pair
connectionStrings ↔ AutonomousDatabaseConnectionStrings?
The connection strings used to connect to an Autonomous Database.
getter/setter pair
connectionUrls ↔ AutonomousDatabaseConnectionUrls?
The Oracle Connection URLs for an Autonomous Database.
getter/setter pair
cpuCoreCount ↔ int?
The number of CPU cores to be made available to the database.
getter/setter pair
customerContacts ↔ List<CustomerContact>?
The list of customer contacts.
getter/setter pair
databaseManagementState ↔ String?
The current state of database management for the Autonomous Database.
getter/setter pair
dataGuardRoleChangedTime ↔ String?
The date and time the Autonomous Data Guard role was changed for the standby Autonomous Database.
getter/setter pair
dataSafeState ↔ String?
The current state of the Data Safe registration for the Autonomous Database.
getter/setter pair
dataStorageSizeGb ↔ int?
The size of the data stored in the database, in gigabytes.
getter/setter pair
dataStorageSizeTb ↔ int?
The size of the data stored in the database, in terabytes.
getter/setter pair
dbEdition ↔ String?
The edition of the Autonomous Databases.
getter/setter pair
dbVersion ↔ String?
The Oracle Database version for the Autonomous Database.
getter/setter pair
dbWorkload ↔ String?
The workload type of the Autonomous Database.
getter/setter pair
disasterRecoveryRoleChangedTime ↔ String?
The date and time the Disaster Recovery role was changed for the standby Autonomous Database.
getter/setter pair
encryptionKey ↔ EncryptionKey?
The encryption key used to encrypt the Autonomous Database.
getter/setter pair
encryptionKeyHistoryEntries ↔ List<EncryptionKeyHistoryEntry>?
The history of the encryption keys used to encrypt the Autonomous Database.
getter/setter pair
failedDataRecoveryDuration ↔ String?
This field indicates the number of seconds of data loss during a Data Guard failover.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isAutoScalingEnabled ↔ bool?
This field indicates if auto scaling is enabled for the Autonomous Database CPU core count.
getter/setter pair
isLocalDataGuardEnabled ↔ bool?
Deprecated: Please use local_data_guard_enabled instead.
getter/setter pair
isStorageAutoScalingEnabled ↔ bool?
This field indicates if auto scaling is enabled for the Autonomous Database storage.
getter/setter pair
licenseType ↔ String?
The license type used for the Autonomous Database.
getter/setter pair
lifecycleDetails ↔ String?
The details of the current lifestyle state of the Autonomous Database.
getter/setter pair
localAdgAutoFailoverMaxDataLossLimit ↔ int?
Deprecated: Please use local_adg_auto_failover_max_data_loss_limit_duration instead.
getter/setter pair
localAdgAutoFailoverMaxDataLossLimitDuration ↔ int?
This field indicates the maximum data loss limit for an Autonomous Database, in seconds.
getter/setter pair
localDataGuardEnabled ↔ bool?
Indicates whether the Autonomous Database has a local (in-region) standby database.
getter/setter pair
localDisasterRecoveryType ↔ String?
This field indicates the local disaster recovery (DR) type of an Autonomous Database.
getter/setter pair
localStandbyDb ↔ AutonomousDatabaseStandbySummary?
The details of the Autonomous Data Guard standby database.
getter/setter pair
maintenanceBeginTime ↔ String?
The date and time when maintenance will begin.
getter/setter pair
maintenanceEndTime ↔ String?
The date and time when maintenance will end.
getter/setter pair
maintenanceScheduleType ↔ String?
The maintenance schedule of the Autonomous Database.
getter/setter pair
memoryPerOracleComputeUnitGbs ↔ int?
The amount of memory enabled per ECPU, in gigabytes.
getter/setter pair
memoryTableGbs ↔ int?
The memory assigned to in-memory tables in an Autonomous Database.
getter/setter pair
mtlsConnectionRequired ↔ bool?
This field specifies if the Autonomous Database requires mTLS connections.
getter/setter pair
nCharacterSet ↔ String?
The national character set for the Autonomous Database.
getter/setter pair
nextLongTermBackupTime ↔ String?
The long term backup schedule of the Autonomous Database.
getter/setter pair
ocid ↔ String?
OCID of the Autonomous Database.
getter/setter pair
ociUrl ↔ String?
The Oracle Cloud Infrastructure link for the Autonomous Database.
getter/setter pair
openMode ↔ String?
This field indicates the current mode of the Autonomous Database.
getter/setter pair
operationsInsightsState ↔ String?
This field indicates the state of Operations Insights for the Autonomous Database.
getter/setter pair
peerDbIds ↔ List<String>?
The list of OCIDs of standby databases located in Autonomous Data Guard remote regions that are associated with the source database.
getter/setter pair
permissionLevel ↔ String?
The permission level of the Autonomous Database.
getter/setter pair
privateEndpoint ↔ String?
The private endpoint for the Autonomous Database.
getter/setter pair
privateEndpointIp ↔ String?
The private endpoint IP address for the Autonomous Database.
getter/setter pair
privateEndpointLabel ↔ String?
The private endpoint label for the Autonomous Database.
getter/setter pair
refreshableClone ↔ bool?
Indicates if the Autonomous Database is a refreshable clone.
getter/setter pair
refreshableMode ↔ String?
The refresh mode of the cloned Autonomous Database.
getter/setter pair
refreshableState ↔ String?
The refresh State of the clone.
getter/setter pair
role ↔ String?
The Data Guard role of the Autonomous Database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduledOperationDetails ↔ List<ScheduledOperationDetails>?
The list and details of the scheduled operations of the Autonomous Database.
getter/setter pair
secretId ↔ String?
The ID of the Oracle Cloud Infrastructure vault secret.
getter/setter pair
serviceAgentEmail ↔ String?
An Oracle-managed Google Cloud service account on which customers can grant roles to access resources in the customer project.
getter/setter pair
sqlWebDeveloperUrl ↔ String?
The SQL Web Developer URL for the Autonomous Database.
getter/setter pair
state ↔ String?
The current lifecycle state of the Autonomous Database.
getter/setter pair
supportedCloneRegions ↔ List<String>?
The list of available regions that can be used to create a clone for the Autonomous Database.
getter/setter pair
totalAutoBackupStorageSizeGbs ↔ double?
The storage space used by automatic backups of Autonomous Database, in gigabytes.
getter/setter pair
usedDataStorageSizeTbs ↔ int?
The storage space used by Autonomous Database, in gigabytes.
getter/setter pair
vaultId ↔ String?
The ID of the Oracle Cloud Infrastructure vault.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited