AutonomousDatabaseRefreshableClones class
Response message for getting the Autonomous Database refreshable clones.
Constructors
-
AutonomousDatabaseRefreshableClones({List<
AutonomousDatabaseRefreshableClone> ? autonomousDatabaseRefreshableClones}) - AutonomousDatabaseRefreshableClones.fromJson(Map json_)
Properties
-
autonomousDatabaseRefreshableClones
↔ List<
AutonomousDatabaseRefreshableClone> ? -
The list of Autonomous Database refreshable clones.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited