AutonomousDatabaseStandbySummary class

Constructors

AutonomousDatabaseStandbySummary({String? dataGuardRoleChangedTime, String? disasterRecoveryRoleChangedTime, String? lagTimeDuration, String? lifecycleDetails, String? state})
AutonomousDatabaseStandbySummary.fromJson(Map json_)

Properties

dataGuardRoleChangedTime ↔ String?
The date and time the Autonomous Data Guard role was switched for the standby Autonomous Database.
getter/setter pair
disasterRecoveryRoleChangedTime ↔ String?
The date and time the Disaster Recovery role was switched for the standby Autonomous Database.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lagTimeDuration ↔ String?
The amount of time, in seconds, that the data of the standby database lags in comparison to the data of the primary database.
getter/setter pair
lifecycleDetails ↔ String?
The additional details about the current lifecycle state of the Autonomous Database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current lifecycle state of the Autonomous Database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited