AutonomousDbVersion class

Constructors

AutonomousDbVersion({String? dbWorkload, String? name, String? version, String? workloadUri})
AutonomousDbVersion.fromJson(Map json_)

Properties

dbWorkload ↔ String?
The Autonomous Database workload type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
An Oracle Database version for Autonomous Database.
getter/setter pair
workloadUri ↔ String?
A URL that points to a detailed description of the Autonomous Database version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited