ConfigureExascaleCloudExadataInfrastructureRequest class
The request for CloudExadataInfrastructure.ConfigureExascale.
Constructors
- ConfigureExascaleCloudExadataInfrastructureRequest({String? requestId, int? totalStorageSizeGb, int? totalVmStorageSizeGb})
- ConfigureExascaleCloudExadataInfrastructureRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId ↔ String?
-
An optional ID to identify the request.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalStorageSizeGb ↔ int?
-
The total storage to be allocated to Exascale in GBs.
getter/setter pair
- totalVmStorageSizeGb ↔ int?
-
Storage size needed for VM storage on Exascale in GBs.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited