Database class

Constructors

Database({String? adminPassword, String? adminPasswordSecretVersion, String? characterSet, String? createTime, String? databaseId, String? dbHomeName, String? dbName, String? dbUniqueName, String? gcpOracleZone, String? name, String? ncharacterSet, String? ociUrl, String? opsInsightsStatus, String? pluggableDatabaseId, String? pluggableDatabaseName, DatabaseProperties? properties, String? tdeWalletPassword, String? tdeWalletPasswordSecretVersion})
Database.fromJson(Map json_)

Properties

adminPassword ↔ String?
The password for the default ADMIN user.
getter/setter pair
adminPasswordSecretVersion ↔ String?
The resource name of a secret version in Secret Manager which contains the database admin user's password.
getter/setter pair
characterSet ↔ String?
The character set for the database.
getter/setter pair
createTime ↔ String?
The date and time that the Database was created.
getter/setter pair
databaseId ↔ String?
The database ID of the Database.
getter/setter pair
dbHomeName ↔ String?
The name of the DbHome resource associated with the Database.
getter/setter pair
dbName ↔ String?
The database name.
getter/setter pair
dbUniqueName ↔ String?
The DB_UNIQUE_NAME of the Oracle Database being backed up.
getter/setter pair
gcpOracleZone ↔ String?
The GCP Oracle zone where the Database is created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
ncharacterSet ↔ String?
The national character set for the database.
getter/setter pair
ociUrl ↔ String?
HTTPS link to OCI resources exposed to Customer via UI Interface.
getter/setter pair
opsInsightsStatus ↔ String?
The Status of Operations Insights for this Database.
getter/setter pair
pluggableDatabaseId ↔ String?
The ID of the pluggable database associated with the Database.
getter/setter pair
pluggableDatabaseName ↔ String?
The pluggable database associated with the Database.
getter/setter pair
properties ↔ DatabaseProperties?
The properties of the Database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tdeWalletPassword ↔ String?
The TDE wallet password for the database.
getter/setter pair
tdeWalletPasswordSecretVersion ↔ String?
The resource name of a secret version in Secret Manager which contains the TDE wallet password for the database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited