pluggableDatabaseId property

String? pluggableDatabaseId
getter/setter pair

The ID of the pluggable database associated with the Database.

The ID must be unique within the project and location.

Optional.

Implementation

core.String? pluggableDatabaseId;