pluggableDatabaseName property

String? pluggableDatabaseName
getter/setter pair

The pluggable database associated with the Database.

The name must begin with an alphabetic character and can contain a maximum of thirty alphanumeric characters.

Optional.

Implementation

core.String? pluggableDatabaseName;