DatabaseConnectionStringProfile class

Constructors

DatabaseConnectionStringProfile({String? consumerGroup, String? displayName, String? hostFormat, bool? isRegional, String? protocol, String? sessionMode, String? syntaxFormat, String? tlsAuthentication, String? value})
DatabaseConnectionStringProfile.fromJson(Map json_)

Properties

consumerGroup ↔ String?
The current consumer group being used by the connection.
getter/setter pair
displayName ↔ String?
The display name for the database connection.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostFormat ↔ String?
The host name format being currently used in connection string.
getter/setter pair
isRegional ↔ bool?
This field indicates if the connection string is regional and is only applicable for cross-region Data Guard.
getter/setter pair
protocol ↔ String?
The protocol being used by the connection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionMode ↔ String?
The current session mode of the connection.
getter/setter pair
syntaxFormat ↔ String?
The syntax of the connection string.
getter/setter pair
tlsAuthentication ↔ String?
This field indicates the TLS authentication type of the connection.
getter/setter pair
value ↔ String?
The value of the connection string.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited