DbBackupConfig class

Backup Options for the Database.

Constructors

DbBackupConfig({bool? autoBackupEnabled, String? autoFullBackupDay, String? autoFullBackupWindow, String? autoIncrementalBackupWindow, String? backupDeletionPolicy, List<BackupDestinationDetails>? backupDestinationDetails, int? retentionPeriodDays})
DbBackupConfig.fromJson(Map json_)

Properties

autoBackupEnabled ↔ bool?
If set to true, enables automatic backups on the database.
getter/setter pair
autoFullBackupDay ↔ String?
The day of the week on which the full backup should be performed on the database.
getter/setter pair
autoFullBackupWindow ↔ String?
The window in which the full backup should be performed on the database.
getter/setter pair
autoIncrementalBackupWindow ↔ String?
The window in which the incremental backup should be performed on the database.
getter/setter pair
backupDeletionPolicy ↔ String?
This defines when the backups will be deleted after Database termination.
getter/setter pair
backupDestinationDetails ↔ List<BackupDestinationDetails>?
Details of the database backup destinations.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
retentionPeriodDays ↔ int?
The number of days an automatic backup is retained before being automatically deleted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited