DbNodeProperties class

Various properties and settings associated with Db node.

Constructors

DbNodeProperties({String? createTime, int? dbNodeStorageSizeGb, String? dbServerOcid, String? hostname, int? memorySizeGb, String? ocid, int? ocpuCount, String? state, int? totalCpuCoreCount})
DbNodeProperties.fromJson(Map json_)

Properties

createTime ↔ String?
The date and time that the database node was created.
getter/setter pair
dbNodeStorageSizeGb ↔ int?
Local storage per database node.
getter/setter pair
dbServerOcid ↔ String?
Database server OCID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
DNS
getter/setter pair
memorySizeGb ↔ int?
Memory allocated in GBs.
getter/setter pair
ocid ↔ String?
OCID of database node.
getter/setter pair
ocpuCount ↔ int?
OCPU count per database node.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the database node.
getter/setter pair
totalCpuCoreCount ↔ int?
Total CPU core count of the database node.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited