DbServerProperties class

Various properties and settings associated with Exadata database server.

Constructors

DbServerProperties({List<String>? dbNodeIds, int? dbNodeStorageSizeGb, int? maxDbNodeStorageSizeGb, int? maxMemorySizeGb, int? maxOcpuCount, int? memorySizeGb, String? ocid, int? ocpuCount, String? state, int? vmCount})
DbServerProperties.fromJson(Map json_)

Properties

dbNodeIds ↔ List<String>?
OCID of database nodes associated with the database server.
getter/setter pair
dbNodeStorageSizeGb ↔ int?
Local storage per VM.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxDbNodeStorageSizeGb ↔ int?
Maximum local storage per VM.
getter/setter pair
maxMemorySizeGb ↔ int?
Maximum memory allocated in GBs.
getter/setter pair
maxOcpuCount ↔ int?
Maximum OCPU count per database.
getter/setter pair
memorySizeGb ↔ int?
Memory allocated in GBs.
getter/setter pair
ocid ↔ String?
OCID of database server.
getter/setter pair
ocpuCount ↔ int?
OCPU count per database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the database server.
getter/setter pair
vmCount ↔ int?
Vm count per database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited