DbSystemProperties class

The properties of a DbSystem.

Constructors

DbSystemProperties({int? computeCount, String? computeModel, DataCollectionOptionsDbSystem? dataCollectionOptions, int? dataStorageSizeGb, String? databaseEdition, DbHome? dbHome, DbSystemOptions? dbSystemOptions, String? domain, String? hostname, String? hostnamePrefix, int? initialDataStorageSizeGb, String? licenseModel, String? lifecycleState, int? memorySizeGb, int? nodeCount, String? ocid, String? privateIp, int? recoStorageSizeGb, String? shape, List<String>? sshPublicKeys, TimeZone? timeZone})
DbSystemProperties.fromJson(Map json_)

Properties

computeCount ↔ int?
The number of CPU cores to enable for the DbSystem.
getter/setter pair
computeModel ↔ String?
The compute model of the DbSystem.
getter/setter pair
databaseEdition ↔ String?
The database edition of the DbSystem.
getter/setter pair
dataCollectionOptions ↔ DataCollectionOptionsDbSystem?
Data collection options for diagnostics.
getter/setter pair
dataStorageSizeGb ↔ int?
The data storage size in GB that is currently available to DbSystems.
getter/setter pair
dbHome ↔ DbHome?
Details for creating a Database Home.
getter/setter pair
dbSystemOptions ↔ DbSystemOptions?
The options for the DbSystem.
getter/setter pair
domain ↔ String?
The host domain name of the DbSystem.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
The hostname of the DbSystem.
getter/setter pair
hostnamePrefix ↔ String?
Prefix for DB System host names.
getter/setter pair
initialDataStorageSizeGb ↔ int?
The initial data storage size in GB.
getter/setter pair
licenseModel ↔ String?
The license model of the DbSystem.
getter/setter pair
lifecycleState ↔ String?
State of the DbSystem.
getter/setter pair
memorySizeGb ↔ int?
The memory size in GB.
getter/setter pair
nodeCount ↔ int?
The number of nodes to launch for a virtual machine DbSystem.
getter/setter pair
ocid ↔ String?
OCID of the DbSystem.
getter/setter pair
privateIp ↔ String?
The private IP address of the DbSystem.
getter/setter pair
recoStorageSizeGb ↔ int?
The reco/redo storage size in GB.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shape ↔ String?
Shape of DB System.
getter/setter pair
sshPublicKeys ↔ List<String>?
SSH public keys to be stored with the DbSystem.
getter/setter pair
timeZone ↔ TimeZone?
Time zone of the DbSystem.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited