nodeCount property
The number of nodes to launch for a virtual machine DbSystem.
By default this will be set to 1.
Optional.
Implementation
core.int? nodeCount;
The number of nodes to launch for a virtual machine DbSystem.
By default this will be set to 1.
Optional.
core.int? nodeCount;