DbVersionProperties class

The properties of a DbVersion.

Constructors

DbVersionProperties({bool? isLatestForMajorVersion, bool? isPreviewDbVersion, bool? isUpgradeSupported, bool? supportsPdb, String? version})
DbVersionProperties.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isLatestForMajorVersion ↔ bool?
True if this version of the Oracle Database software is the latest version for a release.
getter/setter pair
isPreviewDbVersion ↔ bool?
True if this version of the Oracle Database software is the preview version.
getter/setter pair
isUpgradeSupported ↔ bool?
True if this version of the Oracle Database software is supported for Upgrade.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsPdb ↔ bool?
True if this version of the Oracle Database software supports pluggable databases.
getter/setter pair
version ↔ String?
A valid Oracle Database version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited