EncryptionKeyHistoryEntry class

The history of the encryption keys used to encrypt the Autonomous Database.

Constructors

EncryptionKeyHistoryEntry({String? activationTime, EncryptionKey? encryptionKey})
EncryptionKeyHistoryEntry.fromJson(Map json_)

Properties

activationTime ↔ String?
The date and time when the encryption key was activated on the Autonomous Database..
getter/setter pair
encryptionKey ↔ EncryptionKey?
The encryption key used to encrypt the Autonomous Database.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited