GiVersion class

Details of the Oracle Grid Infrastructure (GI) version resource.

https://docs.oracle.com/en-us/iaas/api/#/en/database/20160918/GiVersionSummary/

Constructors

GiVersion({String? name, String? version})
GiVersion.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
version
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited