GoldengateAmazonRedshiftConnectionProperties class

The properties of GoldengateAmazonRedshiftConnection.

Constructors

GoldengateAmazonRedshiftConnectionProperties({String? connectionUrl, String? password, String? passwordSecretVersion, String? technologyType, String? username})
GoldengateAmazonRedshiftConnectionProperties.fromJson(Map json_)

Properties

connectionUrl ↔ String?
Connection URL.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
password ↔ String?
Input only.
getter/setter pair
passwordSecretVersion ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
technologyType ↔ String?
The technology type of AmazonRedshiftConnection.
getter/setter pair
username ↔ String?
The username Oracle Goldengate uses to connect the associated system of the given technology.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited