GoldengateConnection class

Details of the GoldengateConnection resource.

Constructors

GoldengateConnection({String? createTime, String? entitlementId, String? gcpOracleZone, Map<String, String>? labels, String? name, String? ociUrl, String? odbNetwork, String? odbSubnet, GoldengateConnectionProperties? properties})
GoldengateConnection.fromJson(Map json_)

Properties

createTime String?
The date and time that the GoldengateConnection was created.
getter/setter pair
entitlementId String?
The ID of the subscription entitlement associated with the GoldengateConnection.
getter/setter pair
gcpOracleZone String?
The GCP Oracle zone where Oracle GoldengateConnection is hosted.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
The labels or tags associated with the GoldengateConnection.
getter/setter pair
name String?
Identifier.
getter/setter pair
ociUrl String?
HTTPS link to OCI resources exposed to Customer via UI Interface.
getter/setter pair
odbNetwork String?
The name of the OdbNetwork associated with the GoldengateConnection.
getter/setter pair
odbSubnet String?
The name of the OdbSubnet associated with the GoldengateConnection for IP allocation.
getter/setter pair
properties GoldengateConnectionProperties?
The properties of the GoldengateConnection.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited