GoldengateConnectionAssignment class

Represents the metadata of a Goldengate Connection Assignment.

Constructors

GoldengateConnectionAssignment({String? createTime, String? displayName, String? entitlementId, Map<String, String>? labels, String? name, GoldengateConnectionAssignmentProperties? properties})
GoldengateConnectionAssignment.fromJson(Map json_)

Properties

createTime String?
The time when the connection assignment was created.
getter/setter pair
displayName String?
The display name for the GoldengateConnectionAssignment.
getter/setter pair
entitlementId String?
The OCID of the entitlement linked to this resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
The labels or tags associated with the GoldengateConnectionAssignment.
getter/setter pair
name String?
Identifier.
getter/setter pair
properties GoldengateConnectionAssignmentProperties?
The properties of the GoldengateConnectionAssignment.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited