GoldengateConnectionAssignmentProperties class

The properties of a GoldengateConnectionAssignment.

Constructors

GoldengateConnectionAssignmentProperties({String? alias, String? goldengateConnection, String? goldengateDeployment, String? ocid, String? state})
GoldengateConnectionAssignmentProperties.fromJson(Map json_)

Properties

alias String?
Credential store alias.
getter/setter pair
goldengateConnection String?
The GoldengateConnection resource to be assigned.
getter/setter pair
goldengateDeployment String?
The GoldenGateDeployment to assign the connection to.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ocid String?
The OCID of the connection assignment being referenced.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The lifecycle state of the connection assignment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited