storageCredential property
External storage credential name to access files on object storage such as ADLS Gen2, S3 or Cloud Storage.
Optional.
Implementation
core.String? storageCredential;
External storage credential name to access files on object storage such as ADLS Gen2, S3 or Cloud Storage.
Optional.
core.String? storageCredential;