GoldengateDb2ConnectionProperties class

The properties of GoldengateDb2Connection.

Constructors

GoldengateDb2ConnectionProperties({List<NameValuePair>? additionalAttributes, String? database, String? host, String? password, String? passwordSecretVersion, int? port, String? securityProtocol, String? sslClientKeystashFile, String? sslClientKeystoredbFile, String? sslServerCertificateFile, String? technologyType, String? username})
GoldengateDb2ConnectionProperties.fromJson(Map json_)

Properties

additionalAttributes List<NameValuePair>?
An array of name-value pair attribute entries.
getter/setter pair
database String?
The name of the database.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
host String?
The name or address of a host.
getter/setter pair
password String?
Input only.
getter/setter pair
passwordSecretVersion String?
Input only.
getter/setter pair
port int?
The port of an endpoint usually specified for a connection.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityProtocol String?
Security protocol for the DB2 database.
getter/setter pair
sslClientKeystashFile String?
The keystash file which contains the encrypted password to the key database file.
getter/setter pair
sslClientKeystoredbFile String?
The keystore file created at the client containing the server certificate / CA root certificate.
getter/setter pair
sslServerCertificateFile String?
The file which contains the self-signed server certificate / Certificate Authority (CA) certificate.
getter/setter pair
technologyType String?
The technology type of Db2Connection.
getter/setter pair
username String?
The username Oracle Goldengate uses to connect to the DB2 database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited