sslClientKeystoredbFile property
The keystore file created at the client containing the server certificate / CA root certificate.
Not supported for IBM Db2 for i.
Optional.
Implementation
core.String? sslClientKeystoredbFile;
The keystore file created at the client containing the server certificate / CA root certificate.
Not supported for IBM Db2 for i.
Optional.
core.String? sslClientKeystoredbFile;