GoldengateDeployment class
GoldengateDeployment Goldengate Deployment resource model.
Constructors
-
GoldengateDeployment({String? createTime, String? displayName, String? entitlementId, String? gcpOracleZone, Map<
String, String> ? labels, String? name, String? ociUrl, String? odbNetwork, String? odbSubnet, GoldengateDeploymentProperties? properties}) - GoldengateDeployment.fromJson(Map json_)
Properties
- createTime ↔ String?
-
The date and time that the GoldengateDeployment was created.
getter/setter pair
- displayName ↔ String?
-
The display name for the GoldengateDeployment.
getter/setter pair
- entitlementId ↔ String?
-
The ID of the subscription entitlement associated with the
GoldengateDeployment
getter/setter pair
- gcpOracleZone ↔ String?
-
The GCP Oracle zone where Oracle GoldengateDeployment is hosted.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
The labels or tags associated with the GoldengateDeployment.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- ociUrl ↔ String?
-
HTTPS link to OCI resources exposed to Customer via UI Interface.
getter/setter pair
- odbNetwork ↔ String?
-
The name of the OdbNetwork associated with the GoldengateDeployment.
getter/setter pair
- odbSubnet ↔ String?
-
The name of the OdbSubnet associated with the GoldengateDeployment for IP
allocation.
getter/setter pair
- properties ↔ GoldengateDeploymentProperties?
-
The properties of the GoldengateDeployment.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited