defaultCpuCoreCount property
The default CPU core count of the Goldengate Deployment Environment resource.
Output only.
Implementation
core.int? defaultCpuCoreCount;
The default CPU core count of the Goldengate Deployment Environment resource.
Output only.
core.int? defaultCpuCoreCount;