maxCpuCoreCount property
The max CPU core count of the Goldengate Deployment Environment resource.
Output only.
Implementation
core.int? maxCpuCoreCount;
The max CPU core count of the Goldengate Deployment Environment resource.
Output only.
core.int? maxCpuCoreCount;