GoldengateDeploymentLock class

The lock of the GoldengateDeployment.

Constructors

GoldengateDeploymentLock({String? compartmentId, String? createTime, String? message, String? relatedResourceId, String? type})
GoldengateDeploymentLock.fromJson(Map json_)

Properties

compartmentId String?
The compartment id.
getter/setter pair
createTime String?
The time created.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
message String?
The message.
getter/setter pair
relatedResourceId String?
The related resource id.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of lock.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited