defaultUsername property
The default username of the Goldengate Deployment Type resource.
Output only.
Implementation
core.String? defaultUsername;
The default username of the Goldengate Deployment Type resource.
Output only.
core.String? defaultUsername;