GoldengateDeploymentVersion class
Details of the Goldengate Deployment Version resource.
Constructors
- GoldengateDeploymentVersion({String? name, String? ocid, GoldengateDeploymentVersionProperties? properties})
- GoldengateDeploymentVersion.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- ocid ↔ String?
-
The deployment version ocid of the Goldengate Deployment Version resource.
getter/setter pair
- properties ↔ GoldengateDeploymentVersionProperties?
-
The technology type of the Goldengate Deployment Version resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited