GoldengateDeploymentVersionProperties class

Properties of GoldengateDeploymentVersion.

Constructors

GoldengateDeploymentVersionProperties({String? deploymentType, String? oggVersion, String? releaseTime, String? releaseType, bool? securityFix, String? supportEndTime})
GoldengateDeploymentVersionProperties.fromJson(Map json_)

Properties

deploymentType String?
The deployment type of the Goldengate Deployment Version resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
oggVersion String?
The OGG version of the Goldengate Deployment Version resource.
getter/setter pair
releaseTime String?
The release time of the Goldengate Deployment Version resource.
getter/setter pair
releaseType String?
The release type of the Goldengate Deployment Version resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityFix bool?
Whether the Goldengate Deployment Version resource is a security fix.
getter/setter pair
supportEndTime String?
The support end time of the Goldengate Deployment Version resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited