serviceAccountKeyFile property
The base64 encoded content of the service account key file containing the credentials required to use Google Cloud Storage.
Optional.
Implementation
core.String? serviceAccountKeyFile;
The base64 encoded content of the service account key file containing the credentials required to use Google Cloud Storage.
Optional.
core.String? serviceAccountKeyFile;