GoldengateJavaMessageServiceConnectionProperties class

The properties of GoldengateJavaMessageServiceConnection.

Constructors

GoldengateJavaMessageServiceConnectionProperties({String? authenticationType, String? connectionFactory, String? connectionUrl, String? jndiConnectionFactory, String? jndiInitialContextFactory, String? jndiProviderUrl, String? jndiSecurityCredentialsSecret, String? jndiSecurityPrincipal, String? keyStoreFile, String? keyStorePassword, String? keyStorePasswordSecretVersion, String? password, String? passwordSecretVersion, String? securityProtocol, String? sslKeyPassword, String? sslKeyPasswordSecretVersion, String? technologyType, String? trustStoreFile, String? trustStorePassword, String? trustStorePasswordSecretVersion, bool? useJndi, String? username})
GoldengateJavaMessageServiceConnectionProperties.fromJson(Map json_)

Properties

authenticationType ↔ String?
Authentication type for Java Message Service.
getter/setter pair
connectionFactory ↔ String?
The Java class implementing javax.jms.ConnectionFactory interface supplied by the JMS provider.
getter/setter pair
connectionUrl ↔ String?
Connection URL of the Java Message Service, specifying the protocol, host, and port.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jndiConnectionFactory ↔ String?
The Connection Factory can be looked up using this name.
getter/setter pair
jndiInitialContextFactory ↔ String?
The implementation of javax.naming.spi.InitialContextFactory interface used to obtain initial naming context.
getter/setter pair
jndiProviderUrl ↔ String?
The URL that Java Message Service will use to contact the JNDI provider.
getter/setter pair
jndiSecurityCredentialsSecret ↔ String?
The password associated to the principal.
getter/setter pair
jndiSecurityPrincipal ↔ String?
Specifies the identity of the principal (user) to be authenticated.
getter/setter pair
keyStoreFile ↔ String?
The base64 encoded content of the KeyStore file.
getter/setter pair
keyStorePassword ↔ String?
Input only.
getter/setter pair
keyStorePasswordSecretVersion ↔ String?
Input only.
getter/setter pair
password ↔ String?
Input only.
getter/setter pair
passwordSecretVersion ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityProtocol ↔ String?
Security protocol for Java Message Service.
getter/setter pair
sslKeyPassword ↔ String?
Input only.
getter/setter pair
sslKeyPasswordSecretVersion ↔ String?
Input only.
getter/setter pair
technologyType ↔ String?
The technology type of JavaMessageServiceConnection.
getter/setter pair
trustStoreFile ↔ String?
The base64 encoded content of the TrustStore file.
getter/setter pair
trustStorePassword ↔ String?
Input only.
getter/setter pair
trustStorePasswordSecretVersion ↔ String?
Input only.
getter/setter pair
useJndi ↔ bool?
If set to true, Java Naming and Directory Interface (JNDI) properties should be provided.
getter/setter pair
username ↔ String?
The username Oracle Goldengate uses to connect to the Java Message Service.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited