connectionUrl property
Connection URL of the Java Message Service, specifying the protocol, host, and port.
e.g.: 'mq://myjms.host.domain:7676'
Optional.
Implementation
core.String? connectionUrl;
Connection URL of the Java Message Service, specifying the protocol, host, and port.
e.g.: 'mq://myjms.host.domain:7676'
Optional.
core.String? connectionUrl;