jndiProviderUrl property
The URL that Java Message Service will use to contact the JNDI provider.
e.g.: 'tcp://myjms.host.domain:61616?jms.prefetchPolicy.all=1000'
Optional.
Implementation
core.String? jndiProviderUrl;
The URL that Java Message Service will use to contact the JNDI provider.
e.g.: 'tcp://myjms.host.domain:61616?jms.prefetchPolicy.all=1000'
Optional.
core.String? jndiProviderUrl;