sslKeyPasswordSecretVersion property
Input only.
The resource name of a secret version in Secret Manager which contains the password for the cert inside of the KeyStore. Format: projects/{project}/secrets/{secret}/versions/{version}.
Optional.
Implementation
core.String? sslKeyPasswordSecretVersion;