useJndi property
If set to true, Java Naming and Directory Interface (JNDI) properties should be provided.
Optional.
Implementation
core.bool? useJndi;
If set to true, Java Naming and Directory Interface (JNDI) properties should be provided.
Optional.
core.bool? useJndi;