username property
The username Oracle Goldengate uses to connect to the Java Message Service.
Optional.
Implementation
core.String? username;
The username Oracle Goldengate uses to connect to the Java Message Service.
Optional.
core.String? username;