GoldengateMicrosoftSqlserverConnectionProperties class

The properties of GoldengateMicrosoftSqlserverConnection.

Constructors

GoldengateMicrosoftSqlserverConnectionProperties({List<NameValuePair>? additionalAttributes, String? database, String? host, String? password, String? passwordSecretVersion, int? port, String? securityProtocol, bool? serverCertificateValidationRequired, String? sslCaFile, String? technologyType, String? username})
GoldengateMicrosoftSqlserverConnectionProperties.fromJson(Map json_)

Properties

additionalAttributes List<NameValuePair>?
An array of name-value pair attribute entries.
getter/setter pair
database String?
The name of the database.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
host String?
The name or address of a host.
getter/setter pair
password String?
Input only.
getter/setter pair
passwordSecretVersion String?
Input only.
getter/setter pair
port int?
The port of an endpoint usually specified for a connection.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityProtocol String?
Security Type for Microsoft SQL Server.
getter/setter pair
serverCertificateValidationRequired bool?
If set to true, the driver validates the certificate that is sent by the database server.
getter/setter pair
sslCaFile String?
Database Certificate - The base64 encoded content of a .pem or .crt file containing the server public key (for 1-way SSL).
getter/setter pair
technologyType String?
The technology type of MicrosoftSqlserverConnection.
getter/setter pair
username String?
The username Oracle Goldengate uses to connect to the Microsoft SQL Server.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited