useResourcePrincipal property
Specifies that the user intends to authenticate to the instance using a resource principal.
Optional.
Implementation
core.bool? useResourcePrincipal;
Specifies that the user intends to authenticate to the instance using a resource principal.
Optional.
core.bool? useResourcePrincipal;