userId property
The OCID of the OCI user who will access the Object Storage.
The user must have write access to the bucket they want to connect to.
Optional.
Implementation
core.String? userId;
The OCID of the OCI user who will access the Object Storage.
The user must have write access to the bucket they want to connect to.
Optional.
core.String? userId;