GoldengateOracleAIDataPlatformConnectionProperties class

The properties of GoldengateOracleAIDataPlatformConnection.

Constructors

GoldengateOracleAIDataPlatformConnectionProperties({String? connectionUrl, String? privateKeyFile, String? privateKeyPassphraseSecret, String? publicKeyFingerprint, String? region, String? technologyType, String? tenancyId, bool? useResourcePrincipal, String? userId})
GoldengateOracleAIDataPlatformConnectionProperties.fromJson(Map json_)

Properties

connectionUrl String?
Connection URL.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
privateKeyFile String?
The content of the private key file (PEM file) corresponding to the API key of the fingerprint.
getter/setter pair
privateKeyPassphraseSecret String?
The passphrase of the private key.
getter/setter pair
publicKeyFingerprint String?
The fingerprint of the API Key of the user specified by the user_id.
getter/setter pair
region String?
The name of the region.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
technologyType String?
The technology type of OracleAiDataPlatformConnection.
getter/setter pair
tenancyId String?
The OCID of the related OCI tenancy.
getter/setter pair
useResourcePrincipal bool?
Specifies that the user intends to authenticate to the instance using a resource principal.
getter/setter pair
userId String?
The OCID of the OCI user who will access.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited