walletFile property
The wallet contents Oracle Goldengate uses to make connections to a database.
This attribute is expected to be base64 encoded.
Optional.
Implementation
core.String? walletFile;
The wallet contents Oracle Goldengate uses to make connections to a database.
This attribute is expected to be base64 encoded.
Optional.
core.String? walletFile;