GoldengateOracleNosqlConnectionProperties class

The properties of GoldengateOracleNosqlConnection.

Constructors

GoldengateOracleNosqlConnectionProperties({String? privateKeyFile, String? privateKeyPassphraseSecret, String? publicKeyFingerprint, String? region, String? technologyType, String? tenancyId, bool? useResourcePrincipal, String? userId})
GoldengateOracleNosqlConnectionProperties.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
privateKeyFile String?
The content of the private key file (PEM file) corresponding to the API key of the fingerprint.
getter/setter pair
privateKeyPassphraseSecret String?
The passphrase of the private key.
getter/setter pair
publicKeyFingerprint String?
The fingerprint of the API Key of the user specified by the userId.
getter/setter pair
region String?
The name of the region.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
technologyType String?
The technology type of OracleNosqlConnection.
getter/setter pair
tenancyId String?
The OCID of the OCI tenancy.
getter/setter pair
useResourcePrincipal bool?
Specifies that the user intends to authenticate to the instance using a resource principal.
getter/setter pair
userId String?
The OCID of the OCI user who will access the Oracle NoSQL database.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited