sslCrlFile property
The base64 encoded list of certificates revoked by the trusted certificate authorities (Trusted CA).
Optional.
Implementation
core.String? sslCrlFile;
The base64 encoded list of certificates revoked by the trusted certificate authorities (Trusted CA).
Optional.
core.String? sslCrlFile;