username property
The username Oracle Goldengate uses to connect the associated system of the given technology.
Optional.
Implementation
core.String? username;
The username Oracle Goldengate uses to connect the associated system of the given technology.
Optional.
core.String? username;