GoldengateRedisConnectionProperties class

The properties of GoldengateRedisConnection.

Constructors

GoldengateRedisConnectionProperties({String? authenticationType, String? keyStoreFile, String? keyStorePassword, String? keyStorePasswordSecretVersion, String? password, String? passwordSecretVersion, String? redisClusterId, String? securityProtocol, String? servers, String? technologyType, String? trustStoreFile, String? trustStorePassword, String? trustStorePasswordSecretVersion, String? username})
GoldengateRedisConnectionProperties.fromJson(Map json_)

Properties

authenticationType String?
Authentication type for Redis.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
keyStoreFile String?
The base64 encoded content of the KeyStore file.
getter/setter pair
keyStorePassword String?
Input only.
getter/setter pair
keyStorePasswordSecretVersion String?
Input only.
getter/setter pair
password String?
Input only.
getter/setter pair
passwordSecretVersion String?
Input only.
getter/setter pair
redisClusterId String?
The OCID of the Redis cluster.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
securityProtocol String?
Security protocol for Redis.
getter/setter pair
servers String?
Comma separated list of Redis server addresses, specified as host:port entries, where :port is optional.
getter/setter pair
technologyType String?
The technology type of RedisConnection.
getter/setter pair
trustStoreFile String?
The base64 encoded content of the TrustStore file.
getter/setter pair
trustStorePassword String?
Input only.
getter/setter pair
trustStorePasswordSecretVersion String?
Input only.
getter/setter pair
username String?
The username Oracle Goldengate uses to connect the associated system of the given technology.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited