GoogleCloudStorageIcebergStorage class
The Google Cloud Storage Iceberg storage.
Constructors
- GoogleCloudStorageIcebergStorage({String? bucket, String? projectId, String? serviceAccountKeyFile})
- GoogleCloudStorageIcebergStorage.fromJson(Map json_)
Properties
- bucket ↔ String?
-
The bucket of Google Cloud Storage.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectId ↔ String?
-
The project ID of Google Cloud Storage.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceAccountKeyFile ↔ String?
-
The base64 encoded content of the service account key file of Google Cloud
Storage.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited