serviceAccountKeyFile property
The base64 encoded content of the service account key file of Google Cloud Storage.
Optional.
Implementation
core.String? serviceAccountKeyFile;
The base64 encoded content of the service account key file of Google Cloud Storage.
Optional.
core.String? serviceAccountKeyFile;