KafkaBootstrapServer class

Represents a Kafka bootstrap server with host name, optional port defaults to 9092, and an optional private ip.

Constructors

KafkaBootstrapServer({String? host, int? port, String? privateIpAddress})
KafkaBootstrapServer.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
host String?
The name or address of a host.
getter/setter pair
port int?
The port of an endpoint usually specified for a connection.
getter/setter pair
privateIpAddress String?
The private IP address of the connection's endpoint in the customer's VCN, typically a database endpoint or a big data endpoint (e.g. Kafka bootstrap server).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited