ListAutonomousDatabasesResponse class

The response for AutonomousDatabase.List.

Constructors

ListAutonomousDatabasesResponse({List<AutonomousDatabase>? autonomousDatabases, String? nextPageToken, List<String>? unreachable})
ListAutonomousDatabasesResponse.fromJson(Map json_)

Properties

autonomousDatabases ↔ List<AutonomousDatabase>?
The list of Autonomous Databases.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token identifying a page of results the server should return.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unreachable locations when listing resources across all locations using wildcard location '-'.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited