NameValuePair class
A name-value pair representing an attribute entry usable in a list of attributes.
Constructors
- NameValuePair({String? key, String? value})
- NameValuePair.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited