PluggableDatabaseConnectionStrings class

The connection strings used to connect to the Oracle Database.

Constructors

PluggableDatabaseConnectionStrings({Map<String, String>? allConnectionStrings, String? pdbDefault, String? pdbIpDefault})
PluggableDatabaseConnectionStrings.fromJson(Map json_)

Properties

allConnectionStrings ↔ Map<String, String>?
All connection strings to use to connect to the pluggable database.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pdbDefault ↔ String?
The default connection string to use to connect to the pluggable database.
getter/setter pair
pdbIpDefault ↔ String?
The default connection string to use to connect to the pluggable database using IP.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited