PluggableDatabaseProperties class

The properties of a PluggableDatabase.

Constructors

PluggableDatabaseProperties({String? compartmentId, PluggableDatabaseConnectionStrings? connectionStrings, String? containerDatabaseOcid, DatabaseManagementConfig? databaseManagementConfig, Map<String, DefinedTagValue>? definedTags, Map<String, String>? freeformTags, bool? isRestricted, String? lifecycleDetails, String? lifecycleState, String? ocid, String? operationsInsightsState, String? pdbName, List<PluggableDatabaseNodeLevelDetails>? pdbNodeLevelDetails})
PluggableDatabaseProperties.fromJson(Map json_)

Properties

compartmentId ↔ String?
The OCID of the compartment.
getter/setter pair
connectionStrings ↔ PluggableDatabaseConnectionStrings?
The Connection strings used to connect to the Oracle Database.
getter/setter pair
containerDatabaseOcid ↔ String?
The OCID of the CDB.
getter/setter pair
databaseManagementConfig ↔ DatabaseManagementConfig?
The configuration of the Database Management service.
getter/setter pair
definedTags ↔ Map<String, DefinedTagValue>?
Defined tags for this resource.
getter/setter pair
freeformTags ↔ Map<String, String>?
Free-form tags for this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isRestricted ↔ bool?
The restricted mode of the pluggable database.
getter/setter pair
lifecycleDetails ↔ String?
Additional information about the current lifecycle state.
getter/setter pair
lifecycleState ↔ String?
The current state of the pluggable database.
getter/setter pair
ocid ↔ String?
The OCID of the pluggable database.
getter/setter pair
operationsInsightsState ↔ String?
The status of Operations Insights for this Database.
getter/setter pair
pdbName ↔ String?
The database name.
getter/setter pair
pdbNodeLevelDetails ↔ List<PluggableDatabaseNodeLevelDetails>?
Pluggable Database Node Level Details
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited