getRefreshableClones method
Gets the refreshable clones for a given Autonomous Database.
Request parameters:
name - Required. The Autonomous Database resource whose refreshable
clones are to be listed. Format:
projects/{project}/locations/{location}/autonomousDatabases/{autonomous_database}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/autonomousDatabases/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a AutonomousDatabaseRefreshableClones.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<AutonomousDatabaseRefreshableClones> getRefreshableClones(
core.String name, {
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':getRefreshableClones';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return AutonomousDatabaseRefreshableClones.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}