ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

autonomousDatabaseBackups → ProjectsLocationsAutonomousDatabaseBackupsResource
no setter
autonomousDatabaseCharacterSets → ProjectsLocationsAutonomousDatabaseCharacterSetsResource
no setter
autonomousDatabases → ProjectsLocationsAutonomousDatabasesResource
no setter
autonomousDbVersions → ProjectsLocationsAutonomousDbVersionsResource
no setter
cloudExadataInfrastructures → ProjectsLocationsCloudExadataInfrastructuresResource
no setter
cloudVmClusters → ProjectsLocationsCloudVmClustersResource
no setter
databaseCharacterSets → ProjectsLocationsDatabaseCharacterSetsResource
no setter
databases → ProjectsLocationsDatabasesResource
no setter
dbSystemInitialStorageSizes → ProjectsLocationsDbSystemInitialStorageSizesResource
no setter
dbSystems → ProjectsLocationsDbSystemsResource
no setter
dbSystemShapes → ProjectsLocationsDbSystemShapesResource
no setter
dbVersions → ProjectsLocationsDbVersionsResource
no setter
entitlements → ProjectsLocationsEntitlementsResource
no setter
exadbVmClusters → ProjectsLocationsExadbVmClustersResource
no setter
exascaleDbStorageVaults → ProjectsLocationsExascaleDbStorageVaultsResource
no setter
giVersions → ProjectsLocationsGiVersionsResource
no setter
goldengateConnectionAssignments → ProjectsLocationsGoldengateConnectionAssignmentsResource
no setter
goldengateConnections → ProjectsLocationsGoldengateConnectionsResource
no setter
goldengateConnectionTypes → ProjectsLocationsGoldengateConnectionTypesResource
no setter
goldengateDeploymentEnvironments → ProjectsLocationsGoldengateDeploymentEnvironmentsResource
no setter
goldengateDeployments → ProjectsLocationsGoldengateDeploymentsResource
no setter
goldengateDeploymentTypes → ProjectsLocationsGoldengateDeploymentTypesResource
no setter
goldengateDeploymentVersions → ProjectsLocationsGoldengateDeploymentVersionsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
odbNetworks → ProjectsLocationsOdbNetworksResource
no setter
operations → ProjectsLocationsOperationsResource
no setter
pluggableDatabases → ProjectsLocationsPluggableDatabasesResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) → Future<Location>
Gets information about a location.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited