refreshCutoffTime property

String? refreshCutoffTime
getter/setter pair

The timestamp to which the Autonomous Database refreshable clone will be refreshed.

Changes made in the primary database after this timestamp are not part of the data refresh.

Required.

Implementation

core.String? refreshCutoffTime;