autoRefreshPointLagSeconds property

int? autoRefreshPointLagSeconds
getter/setter pair

The time, in seconds, the data of the automatic refreshable clone lags the primary database at the point of refresh.

Optional.

Implementation

core.int? autoRefreshPointLagSeconds;