autoRefreshStartTime property

String? autoRefreshStartTime
getter/setter pair

The date and time that auto-refreshing will begin for an Autonomous Database refreshable clone.

This value controls only the start time for the first refresh operation.

Optional.

Implementation

core.String? autoRefreshStartTime;