sourceType property

String? sourceType
getter/setter pair

The source type of the Autonomous Database.

Optional. Possible string values are:

  • "SOURCE_TYPE_UNSPECIFIED" : Default unspecified value.
  • "CLONE_DATABASE" : Clone database from an existing database specified in autonomous_database field.
  • "CROSS_REGION_DISASTER_RECOVERY" : Create a cross-region disaster recovery peer adb from an existing adb.
  • "CLONE_TO_REFRESHABLE" : Create a refreshable clone from an existing database specified in autonomous_database field.
  • "BACKUP_FROM_ID" : Create clone from the backup resource.
  • "BACKUP_FROM_TIMESTAMP" : Create clone from backup specified by backup_time field, or use latest available backup if use_latest_available_backup is true. The autonomous_database field must specify the source database to clone from.

Implementation

core.String? sourceType;