useLatestAvailableBackup property
Clone from latest available backup timestamp.
This field is only applicable in case of BACKUP_FROM_TIMESTAMP source type.
Optional.
Implementation
core.bool? useLatestAvailableBackup;
Clone from latest available backup timestamp.
This field is only applicable in case of BACKUP_FROM_TIMESTAMP source type.
Optional.
core.bool? useLatestAvailableBackup;