TestGoldengateConnectionAssignmentResponse class

The result of the connectivity test performed between the Goldengate deployment and the associated database / service.

Properties

error ↔ TestConnectionAssignmentError?
Error details if test connection failed.
getter/setter pair
errors ↔ List<TestConnectionAssignmentError>?
List of test connection assignment error objects.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resultType ↔ String?
Type of the result i.e. Success, Failure or Timeout. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited