ExecStep class

A step that runs an executable for a PatchJob.

Constructors

ExecStep({ExecStepConfig? linuxExecStepConfig, ExecStepConfig? windowsExecStepConfig})
ExecStep.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
linuxExecStepConfig ↔ ExecStepConfig?
The ExecStepConfig for all Linux VMs targeted by the PatchJob.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
windowsExecStepConfig ↔ ExecStepConfig?
The ExecStepConfig for all Windows VMs targeted by the PatchJob.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited