ExecStepConfig class

Common configurations for an ExecStep.

Constructors

ExecStepConfig({List<int>? allowedSuccessCodes, GcsObject? gcsObject, String? interpreter, String? localPath})
ExecStepConfig.fromJson(Map json_)

Properties

allowedSuccessCodes ↔ List<int>?
Defaults to [0].
getter/setter pair
gcsObject ↔ GcsObject?
A Cloud Storage object containing the executable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interpreter ↔ String?
The script interpreter to use to run the script.
getter/setter pair
localPath ↔ String?
An absolute path to the executable on the VM.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited