ExecutePatchJobRequest class

A request message to initiate patching across Compute Engine instances.

Constructors

ExecutePatchJobRequest({String? description, String? displayName, bool? dryRun, String? duration, PatchInstanceFilter? instanceFilter, PatchConfig? patchConfig, PatchRollout? rollout})
ExecutePatchJobRequest.fromJson(Map json_)

Properties

description ↔ String?
Description of the patch job.
getter/setter pair
displayName ↔ String?
Display name for this patch job.
getter/setter pair
dryRun ↔ bool?
If this patch is a dry-run only, instances are contacted but will do nothing.
getter/setter pair
duration ↔ String?
Duration of the patch job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceFilter ↔ PatchInstanceFilter?
Instances to patch, either explicitly or filtered by some criteria such as zone or labels.
getter/setter pair
patchConfig ↔ PatchConfig?
Patch configuration being applied.
getter/setter pair
rollout ↔ PatchRollout?
Rollout strategy of the patch job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited