ListOSPolicyAssignmentReportsResponse class

A response message for listing OS Policy assignment reports including the page of results and page token.

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The pagination token to retrieve the next page of OS policy assignment report objects.
getter/setter pair
osPolicyAssignmentReports ↔ List<OSPolicyAssignmentReport>?
List of OS policy assignment reports.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited