OSPolicyAssignmentInstanceFilter class

Filters to select target VMs for an assignment.

If more than one filter criteria is specified below, a VM will be selected if and only if it satisfies all of them.

Properties

all ↔ bool?
Target all VMs in the project.
getter/setter pair
exclusionLabels ↔ List<OSPolicyAssignmentLabelSet>?
List of label sets used for VM exclusion.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inclusionLabels ↔ List<OSPolicyAssignmentLabelSet>?
List of label sets used for VM inclusion.
getter/setter pair
inventories ↔ List<OSPolicyAssignmentInstanceFilterInventory>?
List of inventories to select VMs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited