OSPolicyAssignmentReport class

A report of the OS policy assignment status for a given instance.

Constructors

OSPolicyAssignmentReport({String? instance, String? lastRunId, String? name, String? osPolicyAssignment, List<OSPolicyAssignmentReportOSPolicyCompliance>? osPolicyCompliances, String? updateTime})
OSPolicyAssignmentReport.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instance ↔ String?
The Compute Engine VM instance name.
getter/setter pair
lastRunId ↔ String?
Unique identifier of the last attempted run to apply the OS policies associated with this assignment on the VM.
getter/setter pair
name ↔ String?
The OSPolicyAssignmentReport API resource name.
getter/setter pair
osPolicyAssignment ↔ String?
Reference to the OSPolicyAssignment API resource that the OSPolicy belongs to.
getter/setter pair
osPolicyCompliances ↔ List<OSPolicyAssignmentReportOSPolicyCompliance>?
Compliance data for each OSPolicy that is applied to the VM.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Timestamp for when the report was last generated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited