OSPolicyAssignmentRollout class

Message to configure the rollout at the zonal level for the OS policy assignment.

Constructors

OSPolicyAssignmentRollout({FixedOrPercent? disruptionBudget, String? minWaitDuration})
OSPolicyAssignmentRollout.fromJson(Map json_)

Properties

disruptionBudget ↔ FixedOrPercent?
The maximum number (or percentage) of VMs per zone to disrupt at any given moment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minWaitDuration ↔ String?
This determines the minimum duration of time to wait after the configuration changes are applied through the current rollout.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited