OSPolicyResourceExecResourceExec class

A file or script to execute.

Constructors

OSPolicyResourceExecResourceExec({List<String>? args, OSPolicyResourceFile? file, String? interpreter, String? outputFilePath, String? script})
OSPolicyResourceExecResourceExec.fromJson(Map json_)

Properties

args ↔ List<String>?
Optional arguments to pass to the source during execution.
getter/setter pair
file ↔ OSPolicyResourceFile?
A remote or local file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interpreter ↔ String?
The script interpreter to use.
getter/setter pair
outputFilePath ↔ String?
Only recorded for enforce Exec.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
script ↔ String?
An inline script.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited