OSPolicyResourceFile class

A remote or local file.

Properties

allowInsecure ↔ bool?
Defaults to false.
getter/setter pair
gcs ↔ OSPolicyResourceFileGcs?
A Cloud Storage object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localPath ↔ String?
A local path within the VM to use.
getter/setter pair
remote ↔ OSPolicyResourceFileRemote?
A generic remote file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited