OSPolicyResourceRepositoryResource class

A resource that manages a package repository.

Properties

apt ↔ OSPolicyResourceRepositoryResourceAptRepository?
An Apt Repository.
getter/setter pair
goo ↔ OSPolicyResourceRepositoryResourceGooRepository?
A Goo Repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
yum ↔ OSPolicyResourceRepositoryResourceYumRepository?
A Yum Repository.
getter/setter pair
zypper ↔ OSPolicyResourceRepositoryResourceZypperRepository?
A Zypper Repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited