OneTimeSchedule class

Sets the time for a one time patch deployment.

Timestamp is in RFC3339 text format.

Constructors

OneTimeSchedule({String? executeTime})
OneTimeSchedule.fromJson(Map json_)

Properties

executeTime ↔ String?
The desired patch job execution time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited