PatchConfig class

Patch configuration specifications.

Contains details on how to apply the patch(es) to a VM instance.

Constructors

PatchConfig({AptSettings? apt, GooSettings? goo, bool? migInstancesAllowed, ExecStep? postStep, ExecStep? preStep, String? rebootConfig, bool? skipUnpatchableVms, WindowsUpdateSettings? windowsUpdate, YumSettings? yum, ZypperSettings? zypper})
PatchConfig.fromJson(Map json_)

Properties

apt ↔ AptSettings?
Apt update settings.
getter/setter pair
goo ↔ GooSettings?
Goo update settings.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
migInstancesAllowed ↔ bool?
Allows the patch job to run on Managed instance groups (MIGs).
getter/setter pair
postStep ↔ ExecStep?
The ExecStep to run after the patch update.
getter/setter pair
preStep ↔ ExecStep?
The ExecStep to run before the patch update.
getter/setter pair
rebootConfig ↔ String?
Post-patch reboot settings. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipUnpatchableVms ↔ bool?
Enables enhanced reporting for the patch job: 1.
getter/setter pair
windowsUpdate ↔ WindowsUpdateSettings?
Windows update settings.
getter/setter pair
yum ↔ YumSettings?
Yum update settings.
getter/setter pair
zypper ↔ ZypperSettings?
Zypper update settings.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited