skipUnpatchableVms property

bool? skipUnpatchableVms
getter/setter pair

Enables enhanced reporting for the patch job: 1.

The patch job skips instances that cannot be patched and reports them as SKIPPED. An instance cannot be patched for two reasons: 1. The instance runs Container-Optimized OS (COS), which cannot be patched. 2. The instance is part of a managed instance group (MIG), and patching MIG instances is disabled in the patch job's configuration (PatchConfig.migInstancesAllowed is false). 2. The patch job is reported as SUCCEEDED if it completes without errors, even if some instances are SKIPPED. 3. The patch job is reported as COMPLETED_WITH_INACTIVE_VMS if it completes without errors, but does not patch instances that are INACTIVE.

Optional.

Implementation

core.bool? skipUnpatchableVms;