PatchDeployment class

Patch deployments are configurations that individual patch jobs use to complete a patch.

These configurations include instance filter, package repository settings, and a schedule. For more information about creating and managing patch deployments, see Scheduling patch jobs.

Constructors

PatchDeployment({String? createTime, String? description, String? duration, PatchInstanceFilter? instanceFilter, String? lastExecuteTime, String? name, OneTimeSchedule? oneTimeSchedule, PatchConfig? patchConfig, RecurringSchedule? recurringSchedule, PatchRollout? rollout, String? state, String? updateTime})
PatchDeployment.fromJson(Map json_)

Properties

createTime ↔ String?
Time the patch deployment was created.
getter/setter pair
description ↔ String?
Description of the patch deployment.
getter/setter pair
duration ↔ String?
Duration of the patch.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceFilter ↔ PatchInstanceFilter?
VM instances to patch.
getter/setter pair
lastExecuteTime ↔ String?
The last time a patch job was started by this deployment.
getter/setter pair
name ↔ String?
Unique name for the patch deployment resource in a project.
getter/setter pair
oneTimeSchedule ↔ OneTimeSchedule?
Schedule a one-time execution.
getter/setter pair
patchConfig ↔ PatchConfig?
Patch configuration that is applied.
getter/setter pair
recurringSchedule ↔ RecurringSchedule?
Schedule recurring executions.
getter/setter pair
rollout ↔ PatchRollout?
Rollout strategy of the patch job.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Current state of the patch deployment.
getter/setter pair
updateTime ↔ String?
Time the patch deployment was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited