PatchJob class

A high level representation of a patch job that is either in progress or has completed.

Instance details are not included in the job. To paginate through instance details, use ListPatchJobInstanceDetails. For more information about patch jobs, see Creating patch jobs.

Constructors

PatchJob({String? createTime, String? description, String? displayName, bool? dryRun, String? duration, String? errorMessage, PatchJobInstanceDetailsSummary? instanceDetailsSummary, PatchInstanceFilter? instanceFilter, String? name, PatchConfig? patchConfig, String? patchDeployment, double? percentComplete, PatchRollout? rollout, String? state, String? updateTime})
PatchJob.fromJson(Map json_)

Properties

createTime ↔ String?
Time this patch job was created.
getter/setter pair
description ↔ String?
Description of the patch job.
getter/setter pair
displayName ↔ String?
Display name for this patch job.
getter/setter pair
dryRun ↔ bool?
If this patch job is a dry run, the agent reports that it has finished without running any updates on the VM instance.
getter/setter pair
duration ↔ String?
Duration of the patch job.
getter/setter pair
errorMessage ↔ String?
If this patch job failed, this message provides information about the failure.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceDetailsSummary ↔ PatchJobInstanceDetailsSummary?
Summary of instance details.
getter/setter pair
instanceFilter ↔ PatchInstanceFilter?
Instances to patch.
getter/setter pair
name ↔ String?
Unique identifier for this patch job in the form projects / * /patchJobs / *
getter/setter pair
patchConfig ↔ PatchConfig?
Patch configuration being applied.
getter/setter pair
patchDeployment ↔ String?
Name of the patch deployment that created this patch job.
getter/setter pair
percentComplete ↔ double?
Reflects the overall progress of the patch job in the range of 0.0 being no progress to 100.0 being complete.
getter/setter pair
rollout ↔ PatchRollout?
Rollout strategy being applied.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current state of the PatchJob. Possible string values are:
getter/setter pair
updateTime ↔ String?
Last time this patch job was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited