ProjectFeatureSettings class

ProjectFeatureSettings represents the VM Manager feature settings in a project.

For more information, see Enable full VM Manager functionality.

Constructors

ProjectFeatureSettings({String? name, String? patchAndConfigFeatureSet})
ProjectFeatureSettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name specifies the URL for the ProjectFeatureSettings resource: projects/project_id/locations/global/projectFeatureSettings.
getter/setter pair
patchAndConfigFeatureSet ↔ String?
Set PatchAndConfigFeatureSet for the project. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited