RecurringSchedule class

Sets the time for recurring patch deployments.

Constructors

RecurringSchedule({String? endTime, String? frequency, String? lastExecuteTime, MonthlySchedule? monthly, String? nextExecuteTime, String? startTime, TimeOfDay? timeOfDay, TimeZone? timeZone, WeeklySchedule? weekly})
RecurringSchedule.fromJson(Map json_)

Properties

endTime ↔ String?
The end time at which a recurring patch deployment schedule is no longer active.
getter/setter pair
frequency ↔ String?
The frequency unit of this recurring schedule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastExecuteTime ↔ String?
The time the last patch job ran successfully.
getter/setter pair
monthly ↔ MonthlySchedule?
Schedule with monthly executions.
getter/setter pair
nextExecuteTime ↔ String?
The time the next patch job is scheduled to run.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time that the recurring schedule becomes effective.
getter/setter pair
timeOfDay ↔ TimeOfDay?
Time of the day to run a recurring deployment.
getter/setter pair
timeZone ↔ TimeZone?
Defines the time zone that time_of_day is relative to.
getter/setter pair
weekly ↔ WeeklySchedule?
Schedule with weekly executions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited