VulnerabilityReport class

This API resource represents the vulnerability report for a specified Compute Engine virtual machine (VM) instance at a given point in time.

For more information, see Vulnerability reports.

Constructors

VulnerabilityReport({String? highestUpgradableCveSeverity, String? name, String? updateTime, List<VulnerabilityReportVulnerability>? vulnerabilities})
VulnerabilityReport.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
highestUpgradableCveSeverity ↔ String?
Highest level of severity among all the upgradable vulnerabilities with CVEs attached.
getter/setter pair
name ↔ String?
The vulnerabilityReport API resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The timestamp for when the last vulnerability report was generated for the VM.
getter/setter pair
vulnerabilities ↔ List<VulnerabilityReportVulnerability>?
List of vulnerabilities affecting the VM.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited