WeekDayOfMonth class

Represents one week day in a month.

An example is "the 4th Sunday".

Constructors

WeekDayOfMonth({String? dayOfWeek, int? dayOffset, int? weekOrdinal})
WeekDayOfMonth.fromJson(Map json_)

Properties

dayOffset ↔ int?
Represents the number of days before or after the given week day of month that the patch deployment is scheduled for.
getter/setter pair
dayOfWeek ↔ String?
A day of the week.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weekOrdinal ↔ int?
Week number in a month.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited