WindowsUpdateSettings class

Windows patching is performed using the Windows Update Agent.

Constructors

WindowsUpdateSettings({List<String>? classifications, List<String>? excludes, List<String>? exclusivePatches})
WindowsUpdateSettings.fromJson(Map json_)

Properties

classifications ↔ List<String>?
Only apply updates of these windows update classifications.
getter/setter pair
excludes ↔ List<String>?
List of KBs to exclude from update.
getter/setter pair
exclusivePatches ↔ List<String>?
An exclusive list of kbs to be updated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited