OSPolicyResource class

An OS policy resource is used to define the desired state configuration and provides a specific functionality like installing/removing packages, executing a script etc.

The system ensures that resources are always in their desired state by taking necessary actions if they have drifted from their desired state.

Properties

exec ↔ OSPolicyResourceExecResource?
Exec resource
getter/setter pair
file ↔ OSPolicyResourceFileResource?
File resource
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The id of the resource with the following restrictions: * Must contain only lowercase letters, numbers, and hyphens.
getter/setter pair
pkg ↔ OSPolicyResourcePackageResource?
Package resource
getter/setter pair
repository ↔ OSPolicyResourceRepositoryResource?
Package repository resource
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited