OSPolicyResourceGroup class

Resource groups provide a mechanism to group OS policy resources.

Resource groups enable OS policy authors to create a single OS policy to be applied to VMs running different operating Systems. When the OS policy is applied to a target VM, the appropriate resource group within the OS policy is selected based on the OSFilter specified within the resource group.

Properties

hashCode → int
The hash code for this object.
no setterinherited
inventoryFilters ↔ List<OSPolicyAssignmentInstanceFilterInventory>?
List of inventory filters for the resource group.
getter/setter pair
resources ↔ List<OSPolicyResource>?
List of resources configured for this resource group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited