OSPolicyResourcePackageResource class

A resource that manages a system package.

Properties

apt ↔ OSPolicyResourcePackageResourceAPT?
A package managed by Apt.
getter/setter pair
deb ↔ OSPolicyResourcePackageResourceDeb?
A deb package file.
getter/setter pair
desiredState ↔ String?
The desired state the agent should maintain for this package.
getter/setter pair
googet ↔ OSPolicyResourcePackageResourceAPT?
A package managed by GooGet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
msi ↔ OSPolicyResourcePackageResourceMSI?
An MSI package.
getter/setter pair
rpm ↔ OSPolicyResourcePackageResourceRPM?
An rpm package file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
yum ↔ OSPolicyResourcePackageResourceAPT?
A package managed by YUM.
getter/setter pair
zypper ↔ OSPolicyResourcePackageResourceAPT?
A package managed by Zypper.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited