UsersResource class

Constructors

UsersResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
projects → UsersProjectsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sshPublicKeys → UsersSshPublicKeysResource
no setter

Methods

getLoginProfile(String name, {String? projectId, String? systemId, String? $fields}) → Future<LoginProfile>
Retrieves the profile information used for logging in to a virtual machine on Google Compute Engine.
importSshPublicKey(SshPublicKey request, String parent, {String? projectId, List<String>? regions, String? $fields}) → Future<ImportSshPublicKeyResponse>
Adds an SSH public key and returns the profile information.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited