Bucket class

A proportion of data in the total distribution, bucketed by a min/max percentage.

Each bucket's range is bounded by min <= x < max, In millisecond.

Constructors

Bucket({int? max, int? min, double? proportion})
Bucket.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
max ↔ int?
Upper bound for a bucket's range.
getter/setter pair
min ↔ int?
Lower bound for a bucket's range.
getter/setter pair
proportion ↔ double?
The proportion of data in this bucket.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited