ConfigSettings class

Message containing the configuration settings for the Lighthouse run.

Constructors

ConfigSettings({String? channel, String? emulatedFormFactor, String? formFactor, String? locale, Object? onlyCategories})
ConfigSettings.fromJson(Map json_)

Properties

channel ↔ String?
How Lighthouse was run, e.g. from the Chrome extension or from the npm module.
getter/setter pair
emulatedFormFactor ↔ String?
The form factor the emulation should use.
getter/setter pair
formFactor ↔ String?
How Lighthouse should interpret this run in regards to scoring performance metrics and skipping mobile-only tests in desktop.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locale ↔ String?
The locale setting.
getter/setter pair
onlyCategories ↔ Object?
List of categories of audits the run should conduct.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited