StackPack class

Message containing Stack Pack information.

Constructors

StackPack({Map<String, String>? descriptions, String? iconDataURL, String? id, String? title})
StackPack.fromJson(Map json_)

Properties

descriptions ↔ Map<String, String>?
The stack pack advice strings.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconDataURL ↔ String?
The stack pack icon data uri.
getter/setter pair
id ↔ String?
The stack pack id.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The stack pack title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited