UserPageLoadMetricV5 class

A CrUX metric object for a single metric and form factor.

Constructors

UserPageLoadMetricV5({String? category, List<Bucket>? distributions, String? formFactor, int? median, String? metricId, int? percentile})
UserPageLoadMetricV5.fromJson(Map json_)

Properties

category ↔ String?
The category of the specific time metric.
getter/setter pair
distributions ↔ List<Bucket>?
Metric distributions.
getter/setter pair
formFactor ↔ String?
Identifies the form factor of the metric being collected.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
median ↔ int?
The median number of the metric, in millisecond.
getter/setter pair
metricId ↔ String?
Identifies the type of the metric.
getter/setter pair
percentile ↔ int?
We use this field to store certain percentile value for this metric.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited