parametermanager/v1 library

Parameter Manager API - v1

Parameter Manager is a single source of truth to store, access and manage the lifecycle of your workload parameters. Parameter Manager aims to make management of sensitive application parameters effortless for customers without diminishing focus on security.

For more information, see cloud.google.com/secret-manager/parameter-manager/docs/overview

Create an instance of ParameterManagerApi to access these resources:

Classes

ListLocationsResponse
The response message for Locations.ListLocations.
ListParametersResponse
Message for response to listing Parameters
ListParameterVersionsResponse
Message for response to listing ParameterVersions
ListTemplatesResponse
Message for response to listing Templates
ListTemplateVersionsResponse
Message for response to listing TemplateVersions
Parameter
Message describing Parameter resource
ParameterManagerApi
Parameter Manager is a single source of truth to store, access and manage the lifecycle of your workload parameters.
ParameterVersion
Message describing ParameterVersion resource
ProjectsLocationsParametersResource
ProjectsLocationsParametersVersionsResource
ProjectsLocationsResource
ProjectsLocationsTemplatesResource
ProjectsLocationsTemplatesVersionsResource
ProjectsResource
RenderParameterVersionResponse
Message describing RenderParameterVersionResponse resource
RenderTemplateVersionResponse
Message describing RenderTemplateVersionResponse resource
Template
Message describing Template resource
TemplateVersion
Message describing TemplateVersion resource

Typedefs

Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Location = $Location00
A resource that represents a Google Cloud location.
ParameterVersionPayload = $VersionPayload
Message for storing a ParameterVersion resource's payload data
ResourcePolicyMember = $ResourcePolicyMember
Output-only policy member strings of a Google Cloud resource's built-in identity.
TemplateVersionPayload = $VersionPayload
Message for storing a TemplateVersion resource's payload data

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.