ProjectsLocationsTemplatesResource class

Constructors

ProjectsLocationsTemplatesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versions ProjectsLocationsTemplatesVersionsResource
no setter

Methods

create(Template request, String parent, {String? requestId, String? templateId, String? $fields}) Future<Template>
Creates a new Template in a given project and location.
delete(String name, {String? requestId, String? $fields}) Future<Empty>
Deletes a single Template.
get(String name, {String? $fields}) Future<Template>
Gets details of a single Template.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListTemplatesResponse>
Lists Templates in a given project and location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Template request, String name, {String? requestId, String? updateMask, String? $fields}) Future<Template>
Updates a single Template.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited