ProjectsLocationsTemplatesVersionsResource class

Constructors

ProjectsLocationsTemplatesVersionsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(TemplateVersion request, String parent, {String? requestId, String? templateVersionId, String? $fields}) Future<TemplateVersion>
Creates a new TemplateVersion in a given project, location, and template.
delete(String name, {String? requestId, String? $fields}) Future<Empty>
Deletes a single TemplateVersion.
get(String name, {String? view, String? $fields}) Future<TemplateVersion>
Gets details of a single TemplateVersion.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields}) Future<ListTemplateVersionsResponse>
Lists TemplateVersions in a given project, location, and template.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(TemplateVersion request, String name, {String? requestId, String? updateMask, String? $fields}) Future<TemplateVersion>
Updates a single TemplateVersion.
render(String name, {String? parameterVersion, String? $fields}) Future<RenderTemplateVersionResponse>
Gets rendered version of a TemplateVersion.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited