get method
Gets details of a single TemplateVersion.
Request parameters:
name - Required. Name of the resource in the format projects / * /locations / * /templates / * /versions / * .
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/templates/\[^/\]+/versions/\[^/\]+$.
view - Optional. Specifies the view of the TemplateVersion to return. In
the default FULL view, all metadata & payload associated with the
TemplateVersion will be returned.
Possible string values are:
- "VIEW_UNSPECIFIED" : The default / unset value. The API will default to the FULL view.
- "BASIC" : Include only the metadata for the resource.
- "FULL" : Include metadata & other relevant payload data as well. This is the default view.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a TemplateVersion.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<TemplateVersion> get(
core.String name, {
core.String? view,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'view': ?view == null ? null : [view],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return TemplateVersion.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}