RenderTemplateVersionResponse class
Message describing RenderTemplateVersionResponse resource
Constructors
- RenderTemplateVersionResponse({String? parameterVersion, TemplateVersionPayload? payload, String? renderedPayload, String? templateFormat, String? templateVersion})
- RenderTemplateVersionResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- parameterVersion ↔ String?
-
The resource name of the ParameterVersion used to render the template
version in the format
projects / * /locations / * /parameters / * /versions / *.getter/setter pair - payload ↔ ParameterVersionPayload?
-
Payload content of a TemplateVersion resource.
getter/setter pair
- renderedPayload ↔ String?
-
Server generated rendered version of the user provided payload data
(TemplateVersionPayload) which has all the variables resolved using the
provided parameter version.
getter/setter pair
-
renderedPayloadAsBytes
↔ List<
int> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- templateFormat ↔ String?
-
Format of the template version.
getter/setter pair
- templateVersion ↔ String?
-
Resource identifier of a TemplateVersion in the format
projects / * /locations / * /templates / * /versions / *.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited