name property
Identifier.
The resource name of the Template in the format `projects / * /locations /
- /templates / * `.
Implementation
core.String? name;
Identifier.
The resource name of the Template in the format `projects / * /locations /
core.String? name;