Address class

A person's physical address.

May be a P.O. box or street address. All fields are optional.

Constructors

Address({String? city, String? country, String? countryCode, String? extendedAddress, String? formattedType, String? formattedValue, FieldMetadata? metadata, String? poBox, String? postalCode, String? region, String? streetAddress, String? type})
Address.fromJson(Map json_)

Properties

city ↔ String?
The city of the address.
getter/setter pair
country ↔ String?
The country of the address.
getter/setter pair
countryCode ↔ String?
The [ISO 3166-1 alpha-2](http://www.iso.org/iso/country_codes.htm) country code of the address.
getter/setter pair
extendedAddress ↔ String?
The extended address of the address; for example, the apartment number.
getter/setter pair
formattedType ↔ String?
The type of the address translated and formatted in the viewer's account locale or the Accept-Language HTTP header locale.
getter/setter pair
formattedValue ↔ String?
The unstructured value of the address.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FieldMetadata?
Metadata about the address.
getter/setter pair
poBox ↔ String?
The P.O. box of the address.
getter/setter pair
postalCode ↔ String?
The postal code of the address.
getter/setter pair
region ↔ String?
The region of the address; for example, the state or province.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
streetAddress ↔ String?
The street address.
getter/setter pair
type ↔ String?
The type of the address.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited