AgeRangeType class

A person's age range.

Constructors

AgeRangeType({String? ageRange, FieldMetadata? metadata})
AgeRangeType.fromJson(Map json_)

Properties

ageRange ↔ String?
The age range. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FieldMetadata?
Metadata about the age range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited