BatchUpdateContactsResponse class

If not successful, returns BatchUpdateContactsErrorDetails, a list of errors corresponding to each contact.

The response to a request to update a batch of contacts.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateResult ↔ Map<String, PersonResponse>?
A map of resource names to the contacts that were updated, unless the request read_mask is empty.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited