ContactToCreate class

A wrapper that contains the person data to populate a newly created source.

Constructors

ContactToCreate({Person? contactPerson})
ContactToCreate.fromJson(Map json_)

Properties

contactPerson ↔ Person?
The person data to populate a newly created source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited