CoverPhoto class

A person's cover photo.

A large image shown on the person's profile page that represents who they are or what they care about.

Constructors

CoverPhoto({bool? default_, FieldMetadata? metadata, String? url})
CoverPhoto.fromJson(Map json_)

Properties

default_ ↔ bool?
True if the cover photo is the default cover photo; false if the cover photo is a user-provided cover photo.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FieldMetadata?
Metadata about the cover photo.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The URL of the cover photo.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited