EmailAddress class

A person's email address.

Constructors

EmailAddress({String? displayName, String? formattedType, FieldMetadata? metadata, String? type, String? value})
EmailAddress.fromJson(Map json_)

Properties

displayName ↔ String?
The display name of the email.
getter/setter pair
formattedType ↔ String?
The type of the email address translated and formatted in the viewer's account locale or the Accept-Language HTTP header locale.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FieldMetadata?
Metadata about the email address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the email address.
getter/setter pair
value ↔ String?
The email address.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited