Event class

An event related to the person.

Constructors

Event({Date? date, String? formattedType, FieldMetadata? metadata, String? type})
Event.fromJson(Map json_)

Properties

date ↔ Date?
The date of the event.
getter/setter pair
formattedType ↔ String?
The type of the event translated and formatted in the viewer's account locale or the Accept-Language HTTP header locale.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FieldMetadata?
Metadata about the event.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the event.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited