FieldMetadata class

Metadata about a field.

Constructors

FieldMetadata({bool? primary, Source? source, bool? sourcePrimary, bool? verified})
FieldMetadata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
primary ↔ bool?
True if the field is the primary field for all sources in the person.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ Source?
The source of the field.
getter/setter pair
sourcePrimary ↔ bool?
True if the field is the primary field for the source.
getter/setter pair
verified ↔ bool?
True if the field is verified; false if the field is unverified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited