ImClient class

A person's instant messaging client.

Constructors

ImClient({String? formattedProtocol, String? formattedType, FieldMetadata? metadata, String? protocol, String? type, String? username})
ImClient.fromJson(Map json_)

Properties

formattedProtocol ↔ String?
The protocol of the IM client formatted in the viewer's account locale or the Accept-Language HTTP header locale.
getter/setter pair
formattedType ↔ String?
The type of the IM client translated and formatted in the viewer's account locale or the Accept-Language HTTP header locale.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FieldMetadata?
Metadata about the IM client.
getter/setter pair
protocol ↔ String?
The protocol of the IM client.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the IM client.
getter/setter pair
username ↔ String?
The user name used in the IM client.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited