Interest class

One of the person's interests.

Constructors

Interest({FieldMetadata? metadata, String? value})
Interest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FieldMetadata?
Metadata about the interest.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The interest; for example, stargazing.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited