ModifyContactGroupMembersRequest class

A request to modify an existing contact group's members.

Contacts can be removed from any group but they can only be added to a user group or "myContacts" or "starred" system groups.

Constructors

ModifyContactGroupMembersRequest({List<String>? resourceNamesToAdd, List<String>? resourceNamesToRemove})
ModifyContactGroupMembersRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourceNamesToAdd ↔ List<String>?
The resource names of the contact people to add in the form of people/{person_id}.
getter/setter pair
resourceNamesToRemove ↔ List<String>?
The resource names of the contact people to remove in the form of people/{person_id}.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited