ModifyContactGroupMembersResponse class

The response to a modify contact group members request.

Constructors

ModifyContactGroupMembersResponse({List<String>? canNotRemoveLastContactGroupResourceNames, List<String>? notFoundResourceNames})
ModifyContactGroupMembersResponse.fromJson(Map json_)

Properties

canNotRemoveLastContactGroupResourceNames ↔ List<String>?
The contact people resource names that cannot be removed from their last contact group.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
notFoundResourceNames ↔ List<String>?
The contact people resource names that were not found.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited