PersonMetadata class

The metadata about a person.

Constructors

PersonMetadata({bool? deleted, List<String>? linkedPeopleResourceNames, String? objectType, List<String>? previousResourceNames, List<Source>? sources})
PersonMetadata.fromJson(Map json_)

Properties

deleted ↔ bool?
True if the person resource has been deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
linkedPeopleResourceNames ↔ List<String>?
Resource names of people linked to this resource.
getter/setter pair
objectType ↔ String?
DEPRECATED (Please use person.metadata.sources.profileMetadata.objectType instead) The type of the person object.
getter/setter pair
previousResourceNames ↔ List<String>?
Any former resource names this person has had.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources ↔ List<Source>?
The sources of data for the person.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited