Residence class

DEPRECATED: Please use person.locations instead.

A person's past or current residence.

Constructors

Residence({bool? current, FieldMetadata? metadata, String? value})
Residence.fromJson(Map json_)

Properties

current ↔ bool?
True if the residence is the person's current residence; false if the residence is a past residence.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ FieldMetadata?
Metadata about the residence.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The address of the residence.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited