Source class

The source of a field.

Constructors

Source({String? etag, String? id, ProfileMetadata? profileMetadata, String? type, String? updateTime})
Source.fromJson(Map json_)

Properties

etag ↔ String?
Only populated in person.metadata.sources. The HTTP entity tag of the source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier within the source type generated by the server.
getter/setter pair
profileMetadata ↔ ProfileMetadata?
Only populated in person.metadata.sources. Metadata about a source of type PROFILE.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The source type. Possible string values are:
getter/setter pair
updateTime ↔ String?
Only populated in person.metadata.sources. Last update timestamp of this source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited