UpdateContactGroupRequest class

A request to update an existing user contact group.

All updated fields will be replaced.

Constructors

UpdateContactGroupRequest({ContactGroup? contactGroup, String? readGroupFields, String? updateGroupFields})
UpdateContactGroupRequest.fromJson(Map json_)

Properties

contactGroup ↔ ContactGroup?
The contact group to update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readGroupFields ↔ String?
A field mask to restrict which fields on the group are returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateGroupFields ↔ String?
A field mask to restrict which fields on the group are updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited