GoogleMapsPlacesV1PlaceAddressComponent class

The structured components that form the formatted address, if this information is available.

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The language used to format this components, in CLDR notation.
getter/setter pair
longText ↔ String?
The full text description or name of the address component.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortText ↔ String?
An abbreviated textual name for the address component, if available.
getter/setter pair
types ↔ List<String>?
An array indicating the type(s) of the address component.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited