GoogleMapsPlacesV1PlaceNavigationPoint class
A navigation point is a location next to a road where navigation can end.
Constructors
Properties
- displayName ↔ GoogleTypeLocalizedText?
-
The display name of this navigation point.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- location ↔ GoogleTypeLatLng?
-
A point next to the road segment where navigation should end.
getter/setter pair
-
A token that can be used to identify this navigation point.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
travelModes
↔ List<
String> ? -
Travel modes that are appropriate for this navigation point.
getter/setter pair
-
usages
↔ List<
String> ? -
Lists
usagessupported by this navigation point.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited