GoogleMapsPlacesV1RouteModifiers class

Encapsulates a set of optional conditions to satisfy when calculating the routes.

Constructors

GoogleMapsPlacesV1RouteModifiers({bool? avoidFerries, bool? avoidHighways, bool? avoidIndoor, bool? avoidTolls})
GoogleMapsPlacesV1RouteModifiers.fromJson(Map json_)

Properties

avoidFerries ↔ bool?
When set to true, avoids ferries where reasonable, giving preference to routes not containing ferries.
getter/setter pair
avoidHighways ↔ bool?
When set to true, avoids highways where reasonable, giving preference to routes not containing highways.
getter/setter pair
avoidIndoor ↔ bool?
When set to true, avoids navigating indoors where reasonable, giving preference to routes not containing indoor navigation.
getter/setter pair
avoidTolls ↔ bool?
When set to true, avoids toll roads where reasonable, giving preference to routes not containing toll roads.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited