GoogleMapsPlacesV1TransitIcon class

Icon for a transit line, vehicle, or agency.

Properties

hashCode → int
The hash code for this object.
no setterinherited
nameIncluded ↔ bool?
Whether the name is contained in the icon and there is no need to display it next to the icon.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The URL of the icon.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited