nameIncluded property
Whether the name is contained in the icon and there is no need to display it next to the icon.
Implementation
core.bool? nameIncluded;
Whether the name is contained in the icon and there is no need to display it next to the icon.
core.bool? nameIncluded;