backgroundColor property

String? backgroundColor
getter/setter pair

The background color of the labels for this transit line in #RRGGBB hex format, e.g. #909CE1.

This color can also be used for drawing shapes for this transit line.

Implementation

core.String? backgroundColor;