id property
The id of the transit line that can be used to uniquely identify the line among other transit lines in the same transit station.
This identifier is not guaranteed to be stable across different responses.
Implementation
core.String? id;
The id of the transit line that can be used to uniquely identify the line among other transit lines in the same transit station.
This identifier is not guaranteed to be stable across different responses.
core.String? id;