textColor property
The text color of labels for this transit line in #RRGGBB hex format, e.g. #909CE1.
Implementation
core.String? textColor;
The text color of labels for this transit line in #RRGGBB hex format, e.g. #909CE1.
core.String? textColor;