stopCode property

GoogleTypeLocalizedText? stopCode
getter/setter pair

Human readable identifier of the stop, used by transit agencies to distinguish stops with the same name.

Implementation

GoogleTypeLocalizedText? stopCode;