CustomApp class

This resource represents a custom app.

Constructors

CustomApp({String? languageCode, List<Organization>? organizations, String? packageName, String? title})
CustomApp.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
Default listing language in BCP 47 format.
getter/setter pair
organizations ↔ List<Organization>?
Organizations to which the custom app should be made available.
getter/setter pair
packageName ↔ String?
Package name of the created Android app.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title for the Android app.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited