Organization class

Represents an organization that can access a custom app.

Constructors

Organization({String? organizationId, String? organizationName})
Organization.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
organizationId ↔ String?
ID of the organization.
getter/setter pair
organizationName ↔ String?
A human-readable name of the organization, to help recognize the organization.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited