AccountActivity class

(Restricted Access) Contains a signal helping apps differentiating between likely genuine and likely non-genuine user traffic.

Constructors

AccountActivity({String? activityLevel})
AccountActivity.fromJson(Map json_)

Properties

activityLevel ↔ String?
Indicates the activity level of the account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited