AppIntegrity class

Contains the application integrity information.

Constructors

AppIntegrity({String? appRecognitionVerdict, List<String>? certificateSha256Digest, String? packageName, String? versionCode})
AppIntegrity.fromJson(Map json_)

Properties

appRecognitionVerdict ↔ String?
Details about the app recognition verdict
getter/setter pair
certificateSha256Digest ↔ List<String>?
The SHA256 hash of the requesting app's signing certificates (base64 web-safe encoded).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
packageName ↔ String?
Package name of the application under attestation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionCode ↔ String?
Version code of the application.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited