DeviceRecall class

Contains the recall bits per device set by the developer.

Constructors

DeviceRecall({Values? values, WriteDates? writeDates})
DeviceRecall.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ Values?
Contains the recall bits values.
getter/setter pair
writeDates ↔ WriteDates?
Contains the recall bits write dates.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited