PcTokenPayloadExternal class

Contains PC device attestation details.

Constructors

PcTokenPayloadExternal({PcAccountDetails? accountDetails, PcDeviceIntegrity? deviceIntegrity, PcRequestDetails? requestDetails, PcTestingDetails? testingDetails})
PcTokenPayloadExternal.fromJson(Map json_)

Properties

accountDetails ↔ PcAccountDetails?
Details about the account information such as the licensing status.
getter/setter pair
deviceIntegrity ↔ PcDeviceIntegrity?
Details about the device integrity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestDetails ↔ PcRequestDetails?
Details about the integrity request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testingDetails ↔ PcTestingDetails?
Indicates that this payload is generated for testing purposes and contains any additional data that is linked with testing status.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited