TokenPayloadExternal class

Contains basic app information and integrity signals like device attestation and licensing details.

Constructors

TokenPayloadExternal({AccountDetails? accountDetails, AppIntegrity? appIntegrity, DeviceIntegrity? deviceIntegrity, EnvironmentDetails? environmentDetails, RequestDetails? requestDetails, TestingDetails? testingDetails})
TokenPayloadExternal.fromJson(Map json_)

Properties

accountDetails ↔ AccountDetails?
Details about the Play Store account.
getter/setter pair
appIntegrity ↔ AppIntegrity?
Details about the application integrity.
getter/setter pair
deviceIntegrity ↔ DeviceIntegrity?
Details about the device integrity.
getter/setter pair
environmentDetails ↔ EnvironmentDetails?
Details of the environment Play Integrity API runs in.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestDetails ↔ RequestDetails?
Details about the integrity request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
testingDetails ↔ TestingDetails?
Indicates that this payload is generated for testing purposes and contains any additional data that is linked with testing status.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited