WriteDates class

Contains the recall bits write dates.

Constructors

WriteDates({int? yyyymmFirst, int? yyyymmSecond, int? yyyymmThird})
WriteDates.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
yyyymmFirst ↔ int?
Write time in YYYYMM format (in UTC, e.g. 202402) for the first bit.
getter/setter pair
yyyymmSecond ↔ int?
Write time in YYYYMM format (in UTC, e.g. 202402) for the second bit.
getter/setter pair
yyyymmThird ↔ int?
Write time in YYYYMM format (in UTC, e.g. 202402) for the third bit.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited