WriteDeviceRecallRequest class

Request to write device recall bits.

Constructors

WriteDeviceRecallRequest({String? integrityToken, Values? newValues})
WriteDeviceRecallRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
integrityToken ↔ String?
Integrity token obtained from calling Play Integrity API.
getter/setter pair
newValues ↔ Values?
The new values for the device recall bits to be written.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited