CaPool class

A CaPool represents a group of CertificateAuthorities that form a trust anchor.

A CaPool can be used to manage issuance policies for one or more CertificateAuthority resources and to rotate CA certificates in and out of the trust anchor.

Constructors

CaPool({EncryptionSpec? encryptionSpec, IssuancePolicy? issuancePolicy, Map<String, String>? labels, String? name, PublishingOptions? publishingOptions, String? tier})
CaPool.fromJson(Map json_)

Properties

encryptionSpec ↔ EncryptionSpec?
When EncryptionSpec is provided, the Subject, SubjectAltNames, and the PEM-encoded certificate fields will be encrypted at rest.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuancePolicy ↔ IssuancePolicy?
The IssuancePolicy to control how Certificates will be issued from this CaPool.
getter/setter pair
labels ↔ Map<String, String>?
Labels with user-defined metadata.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
publishingOptions ↔ PublishingOptions?
The PublishingOptions to follow when issuing Certificates from any CertificateAuthority in this CaPool.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tier ↔ String?
The Tier of this CaPool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited