requestedNotBeforeTime property

String? requestedNotBeforeTime
getter/setter pair

The requested not_before_time of this Certificate.

This field may only be set if the CaPool.IssuancePolicy.allow_requester_specified_not_before_time field is set to true for the issuing CaPool. If this field is specified, the certificate will be issued with this 'not_before_time'. If this is not specified, the 'not_before_time' will be set to the issuance time or issuance time minus backdate_duration depending on the CaPool configuration.

Optional.

Implementation

core.String? requestedNotBeforeTime;