ExtendedKeyUsageOptions class

KeyUsage.ExtendedKeyUsageOptions has fields that correspond to certain common OIDs that could be specified as an extended key usage value.

Constructors

ExtendedKeyUsageOptions({bool? clientAuth, bool? codeSigning, bool? emailProtection, bool? ocspSigning, bool? serverAuth, bool? timeStamping})
ExtendedKeyUsageOptions.fromJson(Map json_)

Properties

clientAuth ↔ bool?
Corresponds to OID 1.3.6.1.5.5.7.3.2.
getter/setter pair
codeSigning ↔ bool?
Corresponds to OID 1.3.6.1.5.5.7.3.3.
getter/setter pair
emailProtection ↔ bool?
Corresponds to OID 1.3.6.1.5.5.7.3.4.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ocspSigning ↔ bool?
Corresponds to OID 1.3.6.1.5.5.7.3.9.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serverAuth ↔ bool?
Corresponds to OID 1.3.6.1.5.5.7.3.1.
getter/setter pair
timeStamping ↔ bool?
Corresponds to OID 1.3.6.1.5.5.7.3.8.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited