KeyId class

A KeyId identifies a specific public key, usually by hashing the public key.

Constructors

KeyId({String? keyId})
KeyId.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
keyId ↔ String?
The value of this KeyId encoded in lowercase hexadecimal.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited