KeyUsage class

A KeyUsage describes key usage values that may appear in an X.509 certificate.

Constructors

KeyUsage({KeyUsageOptions? baseKeyUsage, ExtendedKeyUsageOptions? extendedKeyUsage, List<ObjectId>? unknownExtendedKeyUsages})
KeyUsage.fromJson(Map json_)

Properties

baseKeyUsage ↔ KeyUsageOptions?
Describes high-level ways in which a key may be used.
getter/setter pair
extendedKeyUsage ↔ ExtendedKeyUsageOptions?
Detailed scenarios in which a key may be used.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknownExtendedKeyUsages ↔ List<ObjectId>?
Used to describe extended key usages that are not listed in the KeyUsage.ExtendedKeyUsageOptions message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited