RelativeDistinguishedName class

RelativeDistinguishedName specifies a relative distinguished name which will be used to build a distinguished name.

Properties

attributes ↔ List<AttributeTypeAndValue>?
Attributes describes the attribute value assertions in the RDN.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited