SubordinateConfig class

Describes a subordinate CA's issuers.

This is either a resource name to a known issuing CertificateAuthority, or a PEM issuer certificate chain.

Constructors

SubordinateConfig({String? certificateAuthority, SubordinateConfigChain? pemIssuerChain})
SubordinateConfig.fromJson(Map json_)

Properties

certificateAuthority ↔ String?
This can refer to a CertificateAuthority that was used to create a subordinate CertificateAuthority.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pemIssuerChain ↔ SubordinateConfigChain?
Contains the PEM certificate chain for the issuers of this CertificateAuthority, but not pem certificate for this CA itself.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited