UserDefinedAccessUrls class

User-defined URLs for accessing content published by this CertificateAuthority.

Constructors

UserDefinedAccessUrls({List<String>? aiaIssuingCertificateUrls, List<String>? crlAccessUrls})
UserDefinedAccessUrls.fromJson(Map json_)

Properties

aiaIssuingCertificateUrls ↔ List<String>?
A list of URLs where the issuer CA certificate may be downloaded, which appears in the "Authority Information Access" extension in the certificate.
getter/setter pair
crlAccessUrls ↔ List<String>?
A list of URLs where to obtain CRL information, i.e. the DistributionPoint.fullName described by https://tools.ietf.org/html/rfc5280#section-4.2.1.13.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited