ExternalAccountKey class

A representation of an ExternalAccountKey used for external account binding within ACME.

Constructors

ExternalAccountKey({String? b64MacKey, String? keyId, String? name})
ExternalAccountKey.fromJson(Map json_)

Properties

b64MacKey ↔ String?
Base64-URL-encoded HS256 key.
getter/setter pair
b64MacKeyAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyId ↔ String?
Key ID.
getter/setter pair
name ↔ String?
Resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited