AzureEventHubs class

Ingestion settings for Azure Event Hubs.

Constructors

AzureEventHubs({String? clientId, String? eventHub, String? gcpServiceAccount, String? namespace, String? resourceGroup, String? state, String? subscriptionId, String? tenantId})
AzureEventHubs.fromJson(Map json_)

Properties

clientId ↔ String?
The client id of the Azure application that is being used to authenticate Pub/Sub.
getter/setter pair
eventHub ↔ String?
The name of the Event Hub.
getter/setter pair
gcpServiceAccount ↔ String?
The GCP service account to be used for Federated Identity authentication.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
namespace ↔ String?
The name of the Event Hubs namespace.
getter/setter pair
resourceGroup ↔ String?
Name of the resource group within the azure subscription.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
An output-only field that indicates the state of the Event Hubs ingestion source.
getter/setter pair
subscriptionId ↔ String?
The Azure subscription id.
getter/setter pair
tenantId ↔ String?
The tenant id of the Azure application that is being used to authenticate Pub/Sub.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited