BigtableConfig class
Configuration for a Bigtable subscription.
The Pub/Sub message will be written to a Bigtable row as follows: - row key:
subscription name, message ID hash, and message ID delimited by #. -
columns: message bytes written to a single column family data with an
empty-string column qualifier. - cell timestamp: the message publish
timestamp.
Constructors
- BigtableConfig({String? appProfileId, String? serviceAccountEmail, String? state, String? table, bool? writeMetadata})
- BigtableConfig.fromJson(Map json_)
Properties
- appProfileId ↔ String?
-
The app profile to use for the Bigtable writes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceAccountEmail ↔ String?
-
The service account to use to write to Bigtable.
getter/setter pair
- state ↔ String?
-
An output-only field that indicates whether or not the subscription can
receive messages.
getter/setter pair
- table ↔ String?
-
The unique name of the table to write messages to.
getter/setter pair
- writeMetadata ↔ bool?
-
When true, write the subscription name, message_id, publish_time,
attributes, and ordering_key to additional columns in the table under the
pubsub_metadata column family.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited