appProfileId property
The app profile to use for the Bigtable writes.
If not specified, the "default" application profile will be used. The app profile must use single-cluster routing.
Optional.
Implementation
core.String? appProfileId;
The app profile to use for the Bigtable writes.
If not specified, the "default" application profile will be used. The app profile must use single-cluster routing.
Optional.
core.String? appProfileId;