state property

String? state
getter/setter pair

An output-only field that indicates whether or not the subscription can receive messages.

Output only. Possible string values are:

  • "STATE_UNSPECIFIED" : Default value. This value is unused.
  • "ACTIVE" : The subscription can actively send messages to Bigtable.
  • "NOT_FOUND" : Unused in the current implementation. Placeholder for future use.
  • "APP_PROFILE_MISCONFIGURED" : Unused in the current implementation. Placeholder for future use.
  • "PERMISSION_DENIED" : Cannot write to Bigtable because of permission denied errors. This can happen if: - The Bigtable instance, table, or app profile does not exist. - The Pub/Sub service agent has not been granted the [appropriate Bigtable IAM permission bigtable.tables.mutateRows]({$universe.dns_names.final_documentation_domain}/bigtable/docs/access-control#permissions)
  • The bigtable.googleapis.com API is not enabled for the project ([instructions]({$universe.dns_names.final_documentation_domain}/service-usage/docs/enable-disable))
  • "SCHEMA_MISMATCH" : Cannot write to Bigtable because of a missing column family (data), or if there is no structured row key for the subscription name + message ID, if because the app profile is not configured for single-cluster routing.
  • "IN_TRANSIT_LOCATION_RESTRICTION" : Cannot write to the destination because enforce_in_transit is set to true and the destination locations are not in the allowed regions.
  • "VERTEX_AI_LOCATION_RESTRICTION" : Cannot write to Bigtable because the table is not in the same location as where Vertex AI models used in message_transforms are deployed.

Implementation

core.String? state;