state property
An output-only field that indicates the state of the Cloud Storage ingestion source.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : Default value. This value is unused.
- "ACTIVE" : Ingestion is active.
- "CLOUD_STORAGE_PERMISSION_DENIED" : Permission denied encountered while calling the Cloud Storage API. This can happen if the Pub/Sub SA has not been granted the appropriate permissions:
- storage.objects.list: to list the objects in a bucket. - storage.objects.get: to read the objects in a bucket. - storage.buckets.get: to verify the bucket exists.
- "PUBLISH_PERMISSION_DENIED" : Permission denied encountered while publishing to the topic. This can happen if the Pub/Sub SA has not been granted the appropriate publish permissions
- "BUCKET_NOT_FOUND" : The provided Cloud Storage bucket doesn't exist.
- "TOO_MANY_OBJECTS" : The Cloud Storage bucket has too many objects, ingestion will be paused.
- "CONFLICTING_REGION_CONSTRAINTS" : Indicates an error state where the ingestion source cannot be processed because the selected ingestion region is not permitted by the Regional Access Boundary (RAB) restrictions on the project's service account.
Implementation
core.String? state;