ConfluentCloud class

Ingestion settings for Confluent Cloud.

Constructors

ConfluentCloud({String? bootstrapServer, String? clusterId, String? gcpServiceAccount, String? identityPoolId, String? state, String? topic})
ConfluentCloud.fromJson(Map json_)

Properties

bootstrapServer ↔ String?
The address of the bootstrap server.
getter/setter pair
clusterId ↔ String?
The id of the cluster.
getter/setter pair
gcpServiceAccount ↔ String?
The GCP service account to be used for Federated Identity authentication with identity_pool_id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identityPoolId ↔ String?
The id of the identity pool to be used for Federated Identity authentication with Confluent Cloud.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
An output-only field that indicates the state of the Confluent Cloud ingestion source.
getter/setter pair
topic ↔ String?
The name of the topic in the Confluent Cloud cluster that Pub/Sub will import from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited