state property
An output-only field that indicates the state of the Confluent Cloud ingestion source.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : Default value. This value is unused.
- "ACTIVE" : Ingestion is active.
- "CONFLUENT_CLOUD_PERMISSION_DENIED" : Permission denied encountered while consuming data from Confluent Cloud.
- "PUBLISH_PERMISSION_DENIED" : Permission denied encountered while publishing to the topic.
- "UNREACHABLE_BOOTSTRAP_SERVER" : The provided bootstrap server address is unreachable.
- "CLUSTER_NOT_FOUND" : The provided cluster wasn't found.
- "TOPIC_NOT_FOUND" : The provided topic wasn't found.
- "CONFLICTING_REGION_CONSTRAINTS" : Indicates an error state where the ingestion source cannot be processed because the selected ingestion region is not permitted by the Regional Access Boundary (RAB) restrictions on the project's service account.
Implementation
core.String? state;