CreateSnapshotRequest class

Request for the CreateSnapshot method.

Constructors

CreateSnapshotRequest({Map<String, String>? labels, String? subscription})
CreateSnapshotRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
See Creating and managing labels.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription ↔ String?
The subscription whose backlog the snapshot retains.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited