IngestionDataSourceSettings class

Settings for an ingestion data source on a topic.

Constructors

IngestionDataSourceSettings({AwsKinesis? awsKinesis, AwsMsk? awsMsk, AzureEventHubs? azureEventHubs, CloudStorage? cloudStorage, ConfluentCloud? confluentCloud, PlatformLogsSettings? platformLogsSettings})
IngestionDataSourceSettings.fromJson(Map json_)

Properties

awsKinesis ↔ AwsKinesis?
Amazon Kinesis Data Streams.
getter/setter pair
awsMsk ↔ AwsMsk?
Amazon MSK.
getter/setter pair
azureEventHubs ↔ AzureEventHubs?
Azure Event Hubs.
getter/setter pair
cloudStorage ↔ CloudStorage?
Cloud Storage.
getter/setter pair
confluentCloud ↔ ConfluentCloud?
Confluent Cloud.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
platformLogsSettings ↔ PlatformLogsSettings?
Platform Logs settings.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited