ListTopicSubscriptionsResponse class

Response for the ListTopicSubscriptions method.

Constructors

ListTopicSubscriptionsResponse({String? nextPageToken, List<String>? subscriptions})
ListTopicSubscriptionsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If not empty, indicates that there may be more subscriptions that match the request; this value should be passed in a new ListTopicSubscriptionsRequest to get more subscriptions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptions ↔ List<String>?
The names of subscriptions attached to the topic specified in the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited