ListTopicsResponse class

Response for the ListTopics method.

Constructors

ListTopicsResponse({String? nextPageToken, List<Topic>? topics})
ListTopicsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If not empty, indicates that there may be more topics that match the request; this value should be passed in a new ListTopicsRequest.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topics ↔ List<Topic>?
The resulting topics.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited