MessageStoragePolicy class

A policy constraining the storage of messages published to the topic.

Constructors

MessageStoragePolicy({List<String>? allowedPersistenceRegions, bool? enforceInTransit})
MessageStoragePolicy.fromJson(Map json_)

Properties

allowedPersistenceRegions ↔ List<String>?
A list of IDs of Google Cloud regions where messages that are published to the topic may be persisted in storage.
getter/setter pair
enforceInTransit ↔ bool?
If true, allowed_persistence_regions is also used to enforce in-transit guarantees for messages.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited