MessageTransform class

All supported message transforms types.

Constructors

MessageTransform({AIInference? aiInference, Compression? compression, bool? disabled, bool? enabled, JavaScriptUDF? javascriptUdf})
MessageTransform.fromJson(Map json_)

Properties

aiInference ↔ AIInference?
AI Inference.
getter/setter pair
compression ↔ Compression?
Compression/Decompression.
getter/setter pair
disabled ↔ bool?
If true, the transform is disabled and will not be applied to messages.
getter/setter pair
enabled ↔ bool?
This field is deprecated, use the disabled field to disable transforms.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
javascriptUdf ↔ JavaScriptUDF?
JavaScript User Defined Function.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited