Schema class

A schema resource.

Constructors

Schema({String? definition, String? name, String? revisionCreateTime, String? revisionId, String? type})
Schema.fromJson(Map json_)

Properties

definition ↔ String?
The definition of the schema.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the schema.
getter/setter pair
revisionCreateTime ↔ String?
The timestamp that the revision was created.
getter/setter pair
revisionId ↔ String?
The revision ID of the schema.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the schema definition. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited