Snapshot class

A snapshot resource.

Snapshots are used in Seek operations, which allow you to manage message acknowledgments in bulk. That is, you can set the acknowledgment state of messages in an existing subscription to the state captured by a snapshot.

Constructors

Snapshot({String? expireTime, Map<String, String>? labels, String? name, String? topic})
Snapshot.fromJson(Map json_)

Properties

expireTime ↔ String?
The snapshot is guaranteed to exist up until this time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
See Creating and managing labels.
getter/setter pair
name ↔ String?
The name of the snapshot.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
topic ↔ String?
The name of the topic from which this snapshot is retaining messages.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited