Subscription class

A subscription resource.

If none of push_config, bigquery_config, cloud_storage_config, or bigtable_config is set, then the subscriber will pull and ack messages using API methods. At most one of these fields may be set.

Constructors

Subscription({int? ackDeadlineSeconds, AnalyticsHubSubscriptionInfo? analyticsHubSubscriptionInfo, BigQueryConfig? bigqueryConfig, BigtableConfig? bigtableConfig, CloudStorageConfig? cloudStorageConfig, DeadLetterPolicy? deadLetterPolicy, bool? detached, bool? enableExactlyOnceDelivery, bool? enableMessageOrdering, ExpirationPolicy? expirationPolicy, String? filter, Map<String, String>? labels, String? messageRetentionDuration, List<MessageTransform>? messageTransforms, String? name, PushConfig? pushConfig, bool? retainAckedMessages, RetryPolicy? retryPolicy, String? state, Map<String, String>? tags, String? topic, String? topicMessageRetentionDuration})
Subscription.fromJson(Map json_)

Properties

ackDeadlineSeconds ↔ int?
The approximate amount of time (on a best-effort basis) Pub/Sub waits for the subscriber to acknowledge receipt before resending the message.
getter/setter pair
analyticsHubSubscriptionInfo ↔ AnalyticsHubSubscriptionInfo?
Information about the associated Analytics Hub subscription.
getter/setter pair
bigqueryConfig ↔ BigQueryConfig?
If delivery to BigQuery is used with this subscription, this field is used to configure it.
getter/setter pair
bigtableConfig ↔ BigtableConfig?
If delivery to Bigtable is used with this subscription, this field is used to configure it.
getter/setter pair
cloudStorageConfig ↔ CloudStorageConfig?
If delivery to Google Cloud Storage is used with this subscription, this field is used to configure it.
getter/setter pair
deadLetterPolicy ↔ DeadLetterPolicy?
A policy that specifies the conditions for dead lettering messages in this subscription.
getter/setter pair
detached ↔ bool?
Indicates whether the subscription is detached from its topic.
getter/setter pair
enableExactlyOnceDelivery ↔ bool?
If true, Pub/Sub provides the following guarantees for the delivery of a message with a given value of message_id on this subscription: * The message sent to a subscriber is guaranteed not to be resent before the message's acknowledgment deadline expires.
getter/setter pair
enableMessageOrdering ↔ bool?
If true, messages published with the same ordering_key in PubsubMessage will be delivered to the subscribers in the order in which they are received by the Pub/Sub system.
getter/setter pair
expirationPolicy ↔ ExpirationPolicy?
A policy that specifies the conditions for this subscription's expiration.
getter/setter pair
filter ↔ String?
An expression written in the Pub/Sub filter language.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
See Creating and managing labels.
getter/setter pair
messageRetentionDuration ↔ String?
How long to retain unacknowledged messages in the subscription's backlog, from the moment a message is published.
getter/setter pair
messageTransforms ↔ List<MessageTransform>?
Transforms to be applied to messages before they are delivered to subscribers.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
pushConfig ↔ PushConfig?
If push delivery is used with this subscription, this field is used to configure it.
getter/setter pair
retainAckedMessages ↔ bool?
Indicates whether to retain acknowledged messages.
getter/setter pair
retryPolicy ↔ RetryPolicy?
A policy that specifies how Pub/Sub retries message delivery for this subscription.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
An output-only field indicating whether or not the subscription can receive messages.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
topic ↔ String?
The name of the topic from which this subscription is receiving messages.
getter/setter pair
topicMessageRetentionDuration ↔ String?
Indicates the minimum duration for which a message is retained after it is published to the subscription's topic.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited