Topic class

A topic resource.

Constructors

Topic({IngestionDataSourceSettings? ingestionDataSourceSettings, String? kmsKeyName, Map<String, String>? labels, String? messageRetentionDuration, MessageStoragePolicy? messageStoragePolicy, List<MessageTransform>? messageTransforms, String? name, bool? satisfiesPzs, SchemaSettings? schemaSettings, String? state, Map<String, String>? tags})
Topic.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ingestionDataSourceSettings ↔ IngestionDataSourceSettings?
Settings for ingestion from a data source into this topic.
getter/setter pair
kmsKeyName ↔ String?
The resource name of the Cloud KMS CryptoKey to be used to protect access to messages published on this topic.
getter/setter pair
labels ↔ Map<String, String>?
See Creating and managing labels.
getter/setter pair
messageRetentionDuration ↔ String?
Indicates the minimum duration to retain a message after it is published to the topic.
getter/setter pair
messageStoragePolicy ↔ MessageStoragePolicy?
Policy constraining the set of Google Cloud Platform regions where messages published to the topic may be stored.
getter/setter pair
messageTransforms ↔ List<MessageTransform>?
Transforms to be applied to messages published to the topic.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
schemaSettings ↔ SchemaSettings?
Settings for validating messages published against a schema.
getter/setter pair
state ↔ String?
An output-only field indicating the state of the topic.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited