UpdateSnapshotRequest class

Request for the UpdateSnapshot method.

Constructors

UpdateSnapshotRequest({Snapshot? snapshot, String? updateMask})
UpdateSnapshotRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot ↔ Snapshot?
The updated snapshot object.
getter/setter pair
updateMask ↔ String?
Indicates which fields in the provided snapshot to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited