UpdateSubscriptionRequest class

Request for the UpdateSubscription method.

Constructors

UpdateSubscriptionRequest({Subscription? subscription, String? updateMask})
UpdateSubscriptionRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription ↔ Subscription?
The updated subscription object.
getter/setter pair
updateMask ↔ String?
Indicates which fields in the provided subscription to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited