Capacity class

The throughput capacity configuration for each partition.

Constructors

Capacity({int? publishMibPerSec, int? subscribeMibPerSec})
Capacity.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
publishMibPerSec ↔ int?
Publish throughput capacity per partition in MiB/s.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscribeMibPerSec ↔ int?
Subscribe throughput capacity per partition in MiB/s.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited