ComputeHeadCursorResponse class

Response containing the head cursor for the requested topic and partition.

Properties

hashCode → int
The hash code for this object.
no setterinherited
headCursor ↔ Cursor?
The head cursor.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited