ComputeMessageStatsRequest class

Compute statistics about a range of messages in a given topic and partition.

Constructors

ComputeMessageStatsRequest({Cursor? endCursor, String? partition, Cursor? startCursor})
ComputeMessageStatsRequest.fromJson(Map json_)

Properties

endCursor ↔ Cursor?
The exclusive end of the range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partition ↔ String?
The partition for which we should compute message stats.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startCursor ↔ Cursor?
The inclusive start of the range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited