ComputeTimeCursorResponse class

Response containing the cursor corresponding to a publish or event time in a topic partition.

Properties

cursor ↔ Cursor?
If present, the cursor references the first message with time greater than or equal to the specified target time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited