ExportConfig class

Configuration for a Pub/Sub Lite subscription that writes messages to a destination.

User subscriber clients must not connect to this subscription.

Constructors

ExportConfig({String? currentState, String? deadLetterTopic, String? desiredState, PubSubConfig? pubsubConfig})
ExportConfig.fromJson(Map json_)

Properties

currentState ↔ String?
The current state of the export, which may be different to the desired state due to errors.
getter/setter pair
deadLetterTopic ↔ String?
The name of an optional Pub/Sub Lite topic to publish messages that can not be exported to the destination.
getter/setter pair
desiredState ↔ String?
The desired state of this export.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pubsubConfig ↔ PubSubConfig?
Messages are automatically written from the Pub/Sub Lite topic associated with this subscription to a Pub/Sub topic.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited