PartitionConfig class

The settings for a topic's partitions.

Constructors

PartitionConfig({Capacity? capacity, String? count, int? scale})
PartitionConfig.fromJson(Map json_)

Properties

capacity ↔ Capacity?
The capacity configuration.
getter/setter pair
count ↔ String?
The number of partitions in the topic.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale ↔ int?
DEPRECATED: Use capacity instead which can express a superset of configurations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited