RetentionConfig class

The settings for a topic's message retention.

Constructors

RetentionConfig({String? perPartitionBytes, String? period})
RetentionConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
period ↔ String?
How long a published message is retained.
getter/setter pair
perPartitionBytes ↔ String?
The provisioned storage, in bytes, per partition.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited