Topic class

Metadata about a topic resource.

Constructors

Topic({String? name, PartitionConfig? partitionConfig, ReservationConfig? reservationConfig, RetentionConfig? retentionConfig})
Topic.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the topic.
getter/setter pair
partitionConfig ↔ PartitionConfig?
The settings for this topic's partitions.
getter/setter pair
reservationConfig ↔ ReservationConfig?
The settings for this topic's Reservation usage.
getter/setter pair
retentionConfig ↔ RetentionConfig?
The settings for this topic's message retention.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited