Reader class

A reader of a publication.

Constructors

Reader({String? createTime, String? name, String? originatingPublicationId, String? ppid, String? publicationId})
Reader.fromJson(Map json_)

Properties

createTime ↔ String?
Time the publication reader was created and associated with a Google user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the reader.
getter/setter pair
originatingPublicationId ↔ String?
The SwG publication id that the reader's subscription linking was originating from.
getter/setter pair
ppid ↔ String?
The publisher provided id of the reader.
getter/setter pair
publicationId ↔ String?
The SwG publication id that the reader has linked their subscription to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited