GoogleCloudRecommenderV1Insight class

An insight along with the information used to derive the insight.

The insight may have associated recommendations as well.

Constructors

GoogleCloudRecommenderV1Insight({List<GoogleCloudRecommenderV1InsightRecommendationReference>? associatedRecommendations, String? category, Map<String, Object?>? content, String? description, String? etag, String? insightSubtype, String? lastRefreshTime, String? name, String? observationPeriod, String? severity, GoogleCloudRecommenderV1InsightStateInfo? stateInfo, List<String>? targetResources})
GoogleCloudRecommenderV1Insight.fromJson(Map json_)

Properties

associatedRecommendations ↔ List<GoogleCloudRecommenderV1InsightRecommendationReference>?
Recommendations derived from this insight.
getter/setter pair
category ↔ String?
Category being targeted by the insight. Possible string values are:
getter/setter pair
content ↔ Map<String, Object?>?
A struct of custom fields to explain the insight.
getter/setter pair
description ↔ String?
Free-form human readable summary in English.
getter/setter pair
etag ↔ String?
Fingerprint of the Insight.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
insightSubtype ↔ String?
Insight subtype.
getter/setter pair
lastRefreshTime ↔ String?
Timestamp of the latest data used to generate the insight.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
observationPeriod ↔ String?
Observation period that led to the insight.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Insight's severity. Possible string values are:
getter/setter pair
stateInfo ↔ GoogleCloudRecommenderV1InsightStateInfo?
Information state and metadata.
getter/setter pair
targetResources ↔ List<String>?
Fully qualified resource names that this insight is targeting.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited