AclRule class

A single ACL rule which defines the policy for a user.

Constructors

AclRule({String? rule, String? username})
AclRule.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
rule ↔ String?
The rule to be applied to the username.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String?
Specifies the IAM user or service account to be added to the ACL policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited