username property

String? username
getter/setter pair

Specifies the IAM user or service account to be added to the ACL policy.

This username will be directly set on the Redis OSS.

Required.

Implementation

core.String? username;