AuthToken class

Auth token for the cluster.

Constructors

AuthToken({String? createTime, String? name, String? state, String? token})
AuthToken.fromJson(Map json_)

Properties

createTime String?
Create time of the auth token.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
State of the auth token.
getter/setter pair
token String?
The service generated authentication token used to connect to the Redis cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited