Backup class

Backup of a cluster.

Constructors

Backup({List<BackupFile>? backupFiles, String? backupType, String? cluster, String? clusterUid, String? createTime, EncryptionInfo? encryptionInfo, String? engineVersion, String? expireTime, String? name, String? nodeType, int? replicaCount, int? shardCount, String? state, String? totalSizeBytes, String? uid})
Backup.fromJson(Map json_)

Properties

backupFiles ↔ List<BackupFile>?
List of backup files of the backup.
getter/setter pair
backupType ↔ String?
Type of the backup.
getter/setter pair
cluster ↔ String?
Cluster resource path of this backup.
getter/setter pair
clusterUid ↔ String?
Cluster uid of this backup.
getter/setter pair
createTime ↔ String?
The time when the backup was created.
getter/setter pair
encryptionInfo ↔ EncryptionInfo?
Encryption information of the backup.
getter/setter pair
engineVersion ↔ String?
redis-7.2, valkey-7.5
getter/setter pair
expireTime ↔ String?
The time when the backup will expire.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
nodeType ↔ String?
Node type of the cluster.
getter/setter pair
replicaCount ↔ int?
Number of replicas for the cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shardCount ↔ int?
Number of shards for the cluster.
getter/setter pair
state ↔ String?
State of the backup.
getter/setter pair
totalSizeBytes ↔ String?
Total size of the backup in bytes.
getter/setter pair
uid ↔ String?
System assigned unique identifier of the backup.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited