BackupFile class

Backup is consisted of multiple backup files.

Constructors

BackupFile({String? createTime, String? fileName, String? sizeBytes})
BackupFile.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the backup file was created.
getter/setter pair
fileName ↔ String?
e.g: .rdb
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes ↔ String?
Size of the backup file in bytes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited