ClusterEndpoint class

ClusterEndpoint consists of PSC connections that are created as a group in each VPC network for accessing the cluster.

In each group, there shall be one connection for each service attachment in the cluster.

Constructors

ClusterEndpoint({List<ConnectionDetail>? connections})
ClusterEndpoint.fromJson(Map json_)

Properties

connections ↔ List<ConnectionDetail>?
A group of PSC connections.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited