ClusterMaintenancePolicy class

Maintenance policy per cluster.

Constructors

ClusterMaintenancePolicy({String? createTime, String? updateTime, List<ClusterWeeklyMaintenanceWindow>? weeklyMaintenanceWindow})
ClusterMaintenancePolicy.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the policy was created i.e. Maintenance Window or Deny Period was assigned.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The time when the policy was updated i.e. Maintenance Window or Deny Period was updated.
getter/setter pair
weeklyMaintenanceWindow ↔ List<ClusterWeeklyMaintenanceWindow>?
Maintenance window that is applied to resources covered by this policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited