ClusterPersistenceConfig class

Configuration of the persistence functionality.

Constructors

ClusterPersistenceConfig({AOFConfig? aofConfig, String? mode, RDBConfig? rdbConfig})
ClusterPersistenceConfig.fromJson(Map json_)

Properties

aofConfig ↔ AOFConfig?
AOF configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?
The mode of persistence.
getter/setter pair
rdbConfig ↔ RDBConfig?
RDB configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited