ConnectionDetail class

Detailed information of each PSC connection.

Constructors

ConnectionDetail({PscAutoConnection? pscAutoConnection, PscConnection? pscConnection})
ConnectionDetail.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pscAutoConnection ↔ PscAutoConnection?
Detailed information of a PSC connection that is created through service connectivity automation.
getter/setter pair
pscConnection ↔ PscConnection?
Detailed information of a PSC connection that is created by the customer who owns the cluster.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited