Instance class

A Memorystore for Redis instance.

Constructors

Instance({String? alternativeLocationId, bool? authEnabled, String? authorizedNetwork, List<String>? availableMaintenanceVersions, String? connectMode, String? createTime, String? currentLocationId, String? customerManagedKey, String? displayName, String? host, Map<String, String>? labels, String? locationId, MaintenancePolicy? maintenancePolicy, MaintenanceSchedule? maintenanceSchedule, String? maintenanceVersion, int? memorySizeGb, String? name, List<NodeInfo>? nodes, PersistenceConfig? persistenceConfig, String? persistenceIamIdentity, int? port, String? readEndpoint, int? readEndpointPort, String? readReplicasMode, Map<String, String>? redisConfigs, String? redisVersion, int? replicaCount, String? reservedIpRange, bool? satisfiesPzi, bool? satisfiesPzs, String? secondaryIpRange, List<TlsCertificate>? serverCaCerts, String? state, String? statusMessage, List<String>? suspensionReasons, Map<String, String>? tags, String? tier, String? transitEncryptionMode})
Instance.fromJson(Map json_)

Properties

alternativeLocationId ↔ String?
If specified, at least one node will be provisioned in this zone in addition to the zone specified in location_id.
getter/setter pair
authEnabled ↔ bool?
Indicates whether OSS Redis AUTH is enabled for the instance.
getter/setter pair
authorizedNetwork ↔ String?
The full name of the Google Compute Engine network to which the instance is connected.
getter/setter pair
availableMaintenanceVersions ↔ List<String>?
The available maintenance versions that an instance could update to.
getter/setter pair
connectMode ↔ String?
The network connect mode of the Redis instance.
getter/setter pair
createTime ↔ String?
The time the instance was created.
getter/setter pair
currentLocationId ↔ String?
The current zone where the Redis primary node is located.
getter/setter pair
customerManagedKey ↔ String?
The KMS key reference that the customer provides when trying to create the instance.
getter/setter pair
displayName ↔ String?
An arbitrary and optional user-provided name for the instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
Hostname or IP address of the exposed Redis endpoint used by clients to connect to the service.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user provided metadata
getter/setter pair
locationId ↔ String?
The zone where the instance will be provisioned.
getter/setter pair
maintenancePolicy ↔ MaintenancePolicy?
The maintenance policy for the instance.
getter/setter pair
maintenanceSchedule ↔ MaintenanceSchedule?
Date and time of upcoming maintenance events which have been scheduled.
getter/setter pair
maintenanceVersion ↔ String?
The self service update maintenance version.
getter/setter pair
memorySizeGb ↔ int?
Redis memory size in GiB.
getter/setter pair
name ↔ String?
Unique name of the resource in this scope including project and location using the form: projects/{project_id}/locations/{location_id}/instances/{instance_id} Note: Redis instances are managed and addressed at regional level so location_id here refers to a GCP region; however, users may choose which specific zone (or collection of zones for cross-zone instances) an instance should be provisioned in.
getter/setter pair
nodes ↔ List<NodeInfo>?
Info per node.
getter/setter pair
persistenceConfig ↔ PersistenceConfig?
Persistence configuration parameters
getter/setter pair
persistenceIamIdentity ↔ String?
Cloud IAM identity used by import / export operations to transfer data to/from Cloud Storage.
getter/setter pair
port ↔ int?
The port number of the exposed Redis endpoint.
getter/setter pair
readEndpoint ↔ String?
Hostname or IP address of the exposed readonly Redis endpoint.
getter/setter pair
readEndpointPort ↔ int?
The port number of the exposed readonly redis endpoint.
getter/setter pair
readReplicasMode ↔ String?
Read replicas mode for the instance.
getter/setter pair
redisConfigs ↔ Map<String, String>?
Redis configuration parameters, according to Redis configuration.
getter/setter pair
redisVersion ↔ String?
The version of Redis software.
getter/setter pair
replicaCount ↔ int?
The number of replica nodes.
getter/setter pair
reservedIpRange ↔ String?
For DIRECT_PEERING mode, the CIDR range of internal addresses that are reserved for this instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzi ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
secondaryIpRange ↔ String?
Additional IP range for node placement.
getter/setter pair
serverCaCerts ↔ List<TlsCertificate>?
List of server CA certificates for the instance.
getter/setter pair
state ↔ String?
The current state of this instance.
getter/setter pair
statusMessage ↔ String?
Additional information about the current status of this instance, if available.
getter/setter pair
suspensionReasons ↔ List<String>?
reasons that causes instance in "SUSPENDED" state.
getter/setter pair
tags ↔ Map<String, String>?
Input only.
getter/setter pair
tier ↔ String?
The service tier of the instance.
getter/setter pair
transitEncryptionMode ↔ String?
The TLS mode of the Redis instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited