MaintenancePolicy class

Maintenance policy for an instance.

Constructors

MaintenancePolicy({String? createTime, String? description, String? updateTime, List<WeeklyMaintenanceWindow>? weeklyMaintenanceWindow})
MaintenancePolicy.fromJson(Map json_)

Properties

createTime ↔ String?
The time when the policy was created.
getter/setter pair
description ↔ String?
Description of what this policy is for.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The time when the policy was last updated.
getter/setter pair
weeklyMaintenanceWindow ↔ List<WeeklyMaintenanceWindow>?
Maintenance window that is applied to resources covered by this policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited