PersistenceConfig class

Configuration of the persistence functionality.

Constructors

PersistenceConfig({String? persistenceMode, String? rdbNextSnapshotTime, String? rdbSnapshotPeriod, String? rdbSnapshotStartTime})
PersistenceConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
persistenceMode ↔ String?
Controls whether Persistence features are enabled.
getter/setter pair
rdbNextSnapshotTime ↔ String?
The next time that a snapshot attempt is scheduled to occur.
getter/setter pair
rdbSnapshotPeriod ↔ String?
Period between RDB snapshots.
getter/setter pair
rdbSnapshotStartTime ↔ String?
Date and time that the first snapshot was/will be attempted, and to which future snapshots will be aligned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited