ProjectsLocationsAclPoliciesResource class

Constructors

ProjectsLocationsAclPoliciesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
revisions ProjectsLocationsAclPoliciesRevisionsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(AclPolicy request, String parent, {String? aclPolicyId, String? requestId, String? $fields}) Future<AclPolicy>
Creates an ACL policy.
delete(String name, {String? etag, String? requestId, String? $fields}) Future<Operation>
Deletes a specific ACL policy.
get(String name, {String? $fields}) Future<AclPolicy>
Gets the details of a specific Redis Cluster ACL policy.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<ListAclPoliciesResponse>
Lists all ACL policies owned by a project in either the specified location (region) or all locations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(AclPolicy request, String name, {String? requestId, String? updateMask, String? $fields}) Future<Operation>
Updates the ACL policy.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited