addAuthToken method
Future<Operation>
addAuthToken(
- AddAuthTokenRequest request,
- String tokenAuthUser, {
- String? $fields,
Adds a auth token for a user of a token based auth enabled cluster.
request - The metadata request object.
Request parameters:
tokenAuthUser - Required. The name of the token auth user resource that
this auth token will be added for. Format:
projects/{project}/locations/{location}/clusters/{cluster}/tokenAuthUsers/{token_auth_user}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/clusters/\[^/\]+/tokenAuthUsers/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Operation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Operation> addAuthToken(
AddAuthTokenRequest request,
core.String tokenAuthUser, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v1/' + core.Uri.encodeFull('$tokenAuthUser') + ':addAuthToken';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}