list method

Future<ListTokenAuthUsersResponse> list(
  1. String parent, {
  2. String? filter,
  3. String? orderBy,
  4. int? pageSize,
  5. String? pageToken,
  6. String? $fields,
})

Lists all the token auth users for a token based auth enabled cluster.

Request parameters:

parent - Required. The parent resource that this token based auth user will be listed for. Format: projects/{project}/locations/{location}/clusters/{cluster} Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+/clusters/\[^/\]+$.

filter - Optional. Expression for filtering results.

orderBy - Optional. Sort results by a defined order.

pageSize - Optional. The maximum number of items to return. If not specified, a default value of 1000 will be used by the service. Regardless of the page_size value, the response may include a partial list and a caller should only rely on response's The maximum value is 1000; values above 1000 will be coerced to 1000. next_page_token to determine if there are more clusters left to be queried.

pageToken - Optional. The next_page_token value returned from a previous [ListTokenAuthUsers] request, if any.

$fields - Selector specifying which fields to include in a partial response.

Completes with a ListTokenAuthUsersResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<ListTokenAuthUsersResponse> list(
  core.String parent, {
  core.String? filter,
  core.String? orderBy,
  core.int? pageSize,
  core.String? pageToken,
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'filter': ?filter == null ? null : [filter],
    'orderBy': ?orderBy == null ? null : [orderBy],
    'pageSize': ?pageSize == null ? null : ['${pageSize}'],
    'pageToken': ?pageToken == null ? null : [pageToken],
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/tokenAuthUsers';

  final response_ = await _requester.request(
    url_,
    'GET',
    queryParams: queryParams_,
  );
  return ListTokenAuthUsersResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}