UpdateInfo class

Represents information about an updating cluster.

Constructors

UpdateInfo({String? targetNodeType, int? targetReplicaCount, int? targetShardCount})
UpdateInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetNodeType ↔ String?
Target node type for redis cluster. Possible string values are:
getter/setter pair
targetReplicaCount ↔ int?
Target number of replica nodes per shard.
getter/setter pair
targetShardCount ↔ int?
Target number of shards for redis cluster
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited