ZoneDistributionConfig class

Zone distribution config for allocation of cluster resources.

Constructors

ZoneDistributionConfig({String? mode, String? zone, List<String>? zones})
ZoneDistributionConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?
The mode of zone distribution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zone ↔ String?
When SINGLE ZONE distribution is selected, zone field would be used to allocate all resources in that zone.
getter/setter pair
zones ↔ List<String>?
Specify the zones of a multi-zone cluster where Redis Cluster allocates resources.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited