GoogleCloudRetailV2AddLocalInventoriesRequest class

Request message for ProductService.AddLocalInventories method.

Properties

addMask ↔ String?
Indicates which inventory fields in the provided list of LocalInventory to update.
getter/setter pair
addTime ↔ String?
The time when the inventory updates are issued.
getter/setter pair
allowMissing ↔ bool?
If set to true, and the Product is not found, the local inventory will still be processed and retained for at most 1 day and processed once the Product is created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
localInventories ↔ List<GoogleCloudRetailV2LocalInventory>?
A list of inventory information at difference places.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited