GoogleCloudRetailV2AttributesConfig class

Catalog level attribute config.

Properties

attributeConfigLevel ↔ String?
The AttributeConfigLevel used for this catalog.
getter/setter pair
catalogAttributes ↔ Map<String, GoogleCloudRetailV2CatalogAttribute>?
Enable attribute(s) config at catalog level.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The fully qualified resource name of the attribute config.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited