GoogleCloudRetailV2BigQuerySource class

BigQuery source import data from.

Constructors

GoogleCloudRetailV2BigQuerySource({String? dataSchema, String? datasetId, String? gcsStagingDir, GoogleTypeDate? partitionDate, String? projectId, String? tableId})
GoogleCloudRetailV2BigQuerySource.fromJson(Map json_)

Properties

dataSchema ↔ String?
The schema to use when parsing the data from the source.
getter/setter pair
datasetId ↔ String?
The BigQuery data set to copy the data from with a length limit of 1,024 characters.
getter/setter pair
gcsStagingDir ↔ String?
Intermediate Cloud Storage directory used for the import with a length limit of 2,000 characters.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partitionDate ↔ GoogleTypeDate?
BigQuery time partitioned table's _PARTITIONDATE in YYYY-MM-DD format.
getter/setter pair
projectId ↔ String?
The project ID (can be project # or ID) that the BigQuery source is in with a length limit of 128 characters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableId ↔ String?
The BigQuery table to copy the data from with a length limit of 1,024 characters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited