GoogleCloudRetailV2CompletionConfig class

Catalog level autocomplete config for customers to customize autocomplete feature's settings.

Constructors

GoogleCloudRetailV2CompletionConfig({GoogleCloudRetailV2CompletionDataInputConfig? allowlistInputConfig, bool? autoLearning, GoogleCloudRetailV2CompletionDataInputConfig? denylistInputConfig, String? lastAllowlistImportOperation, String? lastDenylistImportOperation, String? lastSuggestionsImportOperation, String? matchingOrder, int? maxSuggestions, int? minPrefixLength, String? name, GoogleCloudRetailV2CompletionDataInputConfig? suggestionsInputConfig})
GoogleCloudRetailV2CompletionConfig.fromJson(Map json_)

Properties

allowlistInputConfig ↔ GoogleCloudRetailV2CompletionDataInputConfig?
The source data for the latest import of the autocomplete allowlist phrases.
getter/setter pair
autoLearning ↔ bool?
If set to true, the auto learning function is enabled.
getter/setter pair
denylistInputConfig ↔ GoogleCloudRetailV2CompletionDataInputConfig?
The source data for the latest import of the autocomplete denylist phrases.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastAllowlistImportOperation ↔ String?
Name of the LRO corresponding to the latest allowlist import.
getter/setter pair
lastDenylistImportOperation ↔ String?
Name of the LRO corresponding to the latest denylist import.
getter/setter pair
lastSuggestionsImportOperation ↔ String?
Name of the LRO corresponding to the latest suggestion terms list import.
getter/setter pair
matchingOrder ↔ String?
Specifies the matching order for autocomplete suggestions, e.g., a query consisting of 'sh' with 'out-of-order' specified would suggest "women's shoes", whereas a query of 'red s' with 'exact-prefix' specified would suggest "red shoes".
getter/setter pair
maxSuggestions ↔ int?
The maximum number of autocomplete suggestions returned per term.
getter/setter pair
minPrefixLength ↔ int?
The minimum number of characters needed to be typed in order to get suggestions.
getter/setter pair
name ↔ String?
Fully qualified name projects / * /locations / * /catalogs / * /completionConfig
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestionsInputConfig ↔ GoogleCloudRetailV2CompletionDataInputConfig?
The source data for the latest import of the autocomplete suggestion phrases.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited