GoogleCloudRetailV2ConversationalSearchRequestConversationalFilteringSpec class

This field specifies all conversational filtering related parameters addition to conversational retail search.

Properties

conversationalFilteringMode ↔ String?
Mode to control Conversational Filtering.
getter/setter pair
enableConversationalFiltering ↔ bool?
This field is deprecated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAnswer ↔ GoogleCloudRetailV2ConversationalSearchRequestUserAnswer?
This field specifies the current user answer during the conversational filtering search.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited