GoogleCloudRetailV2ConversationalSearchRequestUserAnswer class

This field specifies the current user answer during the conversational filtering search.

This can be either user selected from suggested answers or user input plain text.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedAnswer ↔ GoogleCloudRetailV2ConversationalSearchRequestUserAnswerSelectedAnswer?
This field specifies the selected answer during the conversational search.
getter/setter pair
textAnswer ↔ String?
This field specifies the incremental input text from the user during the conversational search.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited