GoogleCloudRetailV2GenerativeQuestionConfig class

Configuration for a single generated question.

Constructors

GoogleCloudRetailV2GenerativeQuestionConfig({bool? allowedInConversation, String? catalog, List<String>? exampleValues, String? facet, String? finalQuestion, double? frequency, String? generatedQuestion})
GoogleCloudRetailV2GenerativeQuestionConfig.fromJson(Map json_)

Properties

allowedInConversation ↔ bool?
Whether the question is asked at serving time.
getter/setter pair
catalog ↔ String?
Resource name of the catalog.
getter/setter pair
exampleValues ↔ List<String>?
Values that can be used to answer the question.
getter/setter pair
facet ↔ String?
The facet to which the question is associated.
getter/setter pair
finalQuestion ↔ String?
The question that will be used at serving time.
getter/setter pair
frequency ↔ double?
The ratio of how often a question was asked.
getter/setter pair
generatedQuestion ↔ String?
The LLM generated question.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited