GoogleCloudRetailV2GenerativeQuestionsFeatureConfig class

Configuration for overall generative question feature state.

Properties

catalog ↔ String?
Resource name of the affected catalog.
getter/setter pair
featureEnabled ↔ bool?
Determines whether questions will be used at serving time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
minimumProducts ↔ int?
Minimum number of products in the response to trigger follow-up questions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited