GoogleCloudRetailV2ImportUserEventsRequest class

Request message for the ImportUserEvents request.

Properties

errorsConfig ↔ GoogleCloudRetailV2ImportErrorsConfig?
The desired location of errors incurred during the Import.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputConfig ↔ GoogleCloudRetailV2UserEventInputConfig?
The desired input location of the data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited