GoogleCloudRetailV2IntentClassificationConfig class

The public proto to represent the intent classification config.

It will be converted to the internal proto in the backend.

Properties

blocklistKeywords ↔ List<String>?
A list of keywords that will be used to classify the query to the "BLOCKLISTED" intent type.
getter/setter pair
disabledIntentTypes ↔ List<String>?
A list of intent types that will be disabled for this customer.
getter/setter pair
example ↔ List<GoogleCloudRetailV2IntentClassificationConfigExample>?
A list of examples for intent classification.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inlineSource ↔ GoogleCloudRetailV2IntentClassificationConfigInlineSource?
Inline source for intent classifications.
getter/setter pair
modelPreamble ↔ String?
Customers can use the preamble to specify any requirements for blocklisting intent classification.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited