GoogleCloudRetailV2IntentClassificationConfigInlineForceIntent class

An inline force intent classification configuration.

Properties

hashCode → int
The hash code for this object.
no setterinherited
intentType ↔ String?
The intent_type must match one of the predefined intent types defined at https://cloud.google.com/retail/docs/reference/rpc/google.cloud.retail.v2alpha#querytype
getter/setter pair
operation ↔ String?
The operation to perform for the query.
getter/setter pair
query ↔ String?
A example query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited