GoogleCloudRetailV2LocalInventory class

The inventory information at a place (e.g. a store) identified by a place ID.

Properties

attributes ↔ Map<String, GoogleCloudRetailV2CustomAttribute>?
Additional local inventory attributes, for example, store name, promotion tags, etc.
getter/setter pair
fulfillmentTypes ↔ List<String>?
Supported fulfillment types.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
placeId ↔ String?
The place ID for the current set of inventory information.
getter/setter pair
priceInfo ↔ GoogleCloudRetailV2PriceInfo?
Product price and cost information.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited