GoogleCloudRetailV2OutputConfigBigQueryDestination class

The BigQuery output destination configuration.

Properties

datasetId ↔ String?
The ID of a BigQuery Dataset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableIdPrefix ↔ String?
The prefix of exported BigQuery tables.
getter/setter pair
tableType ↔ String?
Describes the table type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited