GoogleCloudRetailV2PinControlMetadata class

Metadata for pinning to be returned in the response.

This is used for distinguishing between applied vs dropped pins.

Properties

allMatchedPins ↔ Map<String, GoogleCloudRetailV2PinControlMetadataProductPins>?
Map of all matched pins, keyed by pin position.
getter/setter pair
droppedPins ↔ Map<String, GoogleCloudRetailV2PinControlMetadataProductPins>?
Map of pins that were dropped due to overlap with other matching pins, keyed by pin position.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited