GoogleCloudRetailV2PredictRequest class

Request message for Predict method.

Constructors

GoogleCloudRetailV2PredictRequest({String? filter, Map<String, String>? labels, int? pageSize, String? pageToken, Map<String, Object?>? params, GoogleCloudRetailV2UserEvent? userEvent, bool? validateOnly})
GoogleCloudRetailV2PredictRequest.fromJson(Map json_)

Properties

filter ↔ String?
Filter for restricting prediction results with a length limit of 5,000 characters.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels applied to a resource must meet the following requirements: * Each resource can have multiple labels, up to a maximum of 64.
getter/setter pair
pageSize ↔ int?
Maximum number of results to return.
getter/setter pair
pageToken ↔ String?
This field is not used; leave it unset.
getter/setter pair
params ↔ Map<String, Object?>?
Additional domain specific parameters for the predictions.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userEvent ↔ GoogleCloudRetailV2UserEvent?
Context about the user, what they are looking at and what action they took to trigger the predict request.
getter/setter pair
validateOnly ↔ bool?
Use validate only mode for this prediction query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited