GoogleCloudRetailV2PredictResponse class

Response message for predict method.

Properties

attributionToken ↔ String?
A unique attribution token.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
missingIds ↔ List<String>?
IDs of products in the request that were missing from the inventory.
getter/setter pair
results ↔ List<GoogleCloudRetailV2PredictResponsePredictionResult>?
A list of recommended products.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
True if the validateOnly property was set in the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited