GoogleCloudRetailV2RuleDoNotAssociateAction class

Prevents query_term from being associated with specified terms during search.

Example: Don't associate "gShoe" and "cheap".

Properties

doNotAssociateTerms ↔ List<String>?
Cannot contain duplicates or the query term.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
queryTerms ↔ List<String>?
Terms from the search query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terms ↔ List<String>?
Will be [deprecated = true] post migration;
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited