GoogleCloudRetailV2SearchRequestConversationalSearchSpecUserAnswerSelectedAnswer class

This field specifies the selected answers during the conversational search.

Properties

hashCode → int
The hash code for this object.
no setterinherited
productAttributeValue ↔ GoogleCloudRetailV2ProductAttributeValue?
This field specifies the selected answer which is a attribute key-value.
getter/setter pair
productAttributeValues ↔ List<GoogleCloudRetailV2ProductAttributeValue>?
This field is deprecated and should not be set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited