GoogleCloudRetailV2SetInventoryRequest class

Request message for ProductService.SetInventory method.

Properties

allowMissing ↔ bool?
If set to true, and the Product with name Product.name is not found, the inventory update will still be processed and retained for at most 1 day until the Product is created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inventory ↔ GoogleCloudRetailV2Product?
The inventory information to update.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
setMask ↔ String?
Indicates which inventory fields in the provided Product to update.
getter/setter pair
setTime ↔ String?
The time when the request is issued, used to prevent out-of-order updates on inventory fields with the last update time recorded.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited