GoogleCloudRetailV2UpdateGenerativeQuestionConfigRequest class

Request for UpdateGenerativeQuestionConfig method.

Properties

generativeQuestionConfig ↔ GoogleCloudRetailV2GenerativeQuestionConfig?
The question to update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateMask ↔ String?
Indicates which fields in the provided GenerativeQuestionConfig to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited