GoogleCloudRetailV2UserEventInputConfig class

The input config source for user events.

Properties

bigQuerySource ↔ GoogleCloudRetailV2BigQuerySource?
BigQuery input source.
getter/setter pair
gcsSource ↔ GoogleCloudRetailV2GcsSource?
Google Cloud Storage location for the input content.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userEventInlineSource ↔ GoogleCloudRetailV2UserEventInlineSource?
The Inline source for the input content for UserEvents.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited