CSIVolumeSource class

Storage volume source using the Container Storage Interface.

Constructors

CSIVolumeSource({String? driver, bool? readOnly, Map<String, String>? volumeAttributes})
CSIVolumeSource.fromJson(Map json_)

Properties

driver ↔ String?
name of the CSI driver for the requested storage system.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readOnly ↔ bool?
If true, mount the volume as read only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volumeAttributes ↔ Map<String, String>?
stores driver specific attributes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited