ConfigMapEnvSource class

Not supported by Cloud Run.

ConfigMapEnvSource selects a ConfigMap to populate the environment variables with. The contents of the target ConfigMap's Data field will represent the key-value pairs as environment variables.

Constructors

ConfigMapEnvSource({LocalObjectReference? localObjectReference, String? name, bool? optional})
ConfigMapEnvSource.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
localObjectReference ↔ LocalObjectReference?
This field should not be used directly as it is meant to be inlined directly into the message.
getter/setter pair
name ↔ String?
The ConfigMap to select from.
getter/setter pair
optional ↔ bool?
Specify whether the ConfigMap must be defined.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited