Configuration class

Configuration represents the "floating HEAD" of a linear history of Revisions, and optionally how the containers those revisions reference are built.

Users create new Revisions by updating the Configuration's spec. The "latest created" revision's name is available under status, as is the "latest ready" revision's name.

Constructors

Configuration({String? apiVersion, String? kind, ObjectMeta? metadata, ConfigurationSpec? spec, ConfigurationStatus? status})
Configuration.fromJson(Map json_)

Properties

apiVersion ↔ String?
The API version for this call such as "serving.knative.dev/v1".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of resource, in this case always "Configuration".
getter/setter pair
metadata ↔ ObjectMeta?
Metadata associated with this Configuration, including name, namespace, labels, and annotations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ ConfigurationSpec?
Spec holds the desired state of the Configuration (from the client).
getter/setter pair
status ↔ ConfigurationStatus?
Status communicates the observed state of the Configuration (from the controller).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited