sandboxLauncher property
Indicates that this container can act as a sandbox supervisor and launch sandboxes.
Optional.
Implementation
core.bool? sandboxLauncher;
Indicates that this container can act as a sandbox supervisor and launch sandboxes.
Optional.
core.bool? sandboxLauncher;