DomainMapping class

Resource to hold the state and status of a user's domain mapping.

NOTE: This resource is currently in Beta.

Constructors

DomainMapping({String? apiVersion, String? kind, ObjectMeta? metadata, DomainMappingSpec? spec, DomainMappingStatus? status})
DomainMapping.fromJson(Map json_)

Properties

apiVersion ↔ String?
The API version for this call such as "domains.cloudrun.com/v1".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of resource, in this case "DomainMapping".
getter/setter pair
metadata ↔ ObjectMeta?
Metadata associated with this BuildTemplate.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ DomainMappingSpec?
The spec for this DomainMapping.
getter/setter pair
status ↔ DomainMappingStatus?
The current status of the DomainMapping.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited