EnvVar class

EnvVar represents an environment variable present in a Container.

Constructors

EnvVar({String? name, String? value, EnvVarSource? valueFrom})
EnvVar.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the environment variable.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
Value of the environment variable.
getter/setter pair
valueFrom ↔ EnvVarSource?
Source for the environment variable's value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited