Execution class

Execution represents the configuration of a single execution.

An execution is an immutable resource that references a container image which is run to completion.

Constructors

Execution({String? apiVersion, String? kind, ObjectMeta? metadata, ExecutionSpec? spec, ExecutionStatus? status})
Execution.fromJson(Map json_)

Properties

apiVersion ↔ String?
APIVersion defines the versioned schema of this representation of an object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Kind is a string value representing the REST resource this object represents.
getter/setter pair
metadata ↔ ObjectMeta?
Standard object's metadata.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ ExecutionSpec?
Specification of the desired behavior of an execution.
getter/setter pair
status ↔ ExecutionStatus?
Current status of an execution.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited