ExecutionTemplateSpec class

ExecutionTemplateSpec describes the metadata and spec an Execution should have when created from a job.

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ ObjectMeta?
Optional metadata for this Execution, including labels and annotations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ ExecutionSpec?
ExecutionSpec holds the desired configuration for executions of this job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited