GRPCAction class

GRPCAction describes an action involving a GRPC port.

Constructors

GRPCAction({int? port, String? service})
GRPCAction.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
port ↔ int?
Port number of the gRPC service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
Service is the name of the service to place in the gRPC HealthCheckRequest.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited