HTTPGetAction class

HTTPGetAction describes an action based on HTTP Get requests.

Constructors

HTTPGetAction({String? host, List<HTTPHeader>? httpHeaders, String? path, int? port, String? scheme})
HTTPGetAction.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
Not supported by Cloud Run.
getter/setter pair
httpHeaders ↔ List<HTTPHeader>?
Custom headers to set in the request.
getter/setter pair
path ↔ String?
Path to access on the HTTP server.
getter/setter pair
port ↔ int?
Port number to access on the container.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheme ↔ String?
Not supported by Cloud Run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited