InstanceSplit class

Holds a single instance split entry for the Worker.

Allocations can be done to a specific Revision name, or pointing to the latest Ready Revision.

Constructors

InstanceSplit({bool? latestRevision, int? percent, String? revisionName})
InstanceSplit.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
latestRevision ↔ bool?
Uses the "status.latestReadyRevisionName" to determine the instance split target.
getter/setter pair
percent ↔ int?
Specifies percent of the instance split to this Revision.
getter/setter pair
revisionName ↔ String?
Revision to which to assign this portion of instances.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited