InstanceStatus class

InstanceStatus represents the current state of a Instance.

Constructors

InstanceStatus({List<GoogleCloudRunV1Condition>? conditions, String? logUri, int? observedGeneration})
InstanceStatus.fromJson(Map json_)

Properties

conditions ↔ List<GoogleCloudRunV1Condition>?
Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
logUri ↔ String?
URI where logs for this execution can be found in Cloud Console.
getter/setter pair
observedGeneration ↔ int?
The 'generation' of the Instance that was last processed by the controller.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited