JobStatus class

JobStatus represents the current state of a Job.

Constructors

JobStatus({List<GoogleCloudRunV1Condition>? conditions, int? executionCount, ExecutionReference? latestCreatedExecution, int? observedGeneration})
JobStatus.fromJson(Map json_)

Properties

conditions ↔ List<GoogleCloudRunV1Condition>?
Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world.
getter/setter pair
executionCount ↔ int?
Number of executions created for this job.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latestCreatedExecution ↔ ExecutionReference?
A pointer to the most recently created execution for this job.
getter/setter pair
observedGeneration ↔ int?
The 'generation' of the job that was last processed by the controller.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited