KeyToPath class

Maps a string key to a path within a volume.

Constructors

KeyToPath({String? key, int? mode, String? path})
KeyToPath.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The Cloud Secret Manager secret version.
getter/setter pair
mode ↔ int?
(Optional) Mode bits to use on this file, must be a value between 01 and 0777 (octal).
getter/setter pair
path ↔ String?
The relative path of the file to map the key to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited