NamespacesDomainmappingsResource class

Constructors

NamespacesDomainmappingsResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(DomainMapping request, String parent, {String? dryRun, String? $fields}) → Future<DomainMapping>
Create a new domain mapping.
delete(String name, {String? apiVersion, String? dryRun, String? kind, String? propagationPolicy, String? $fields}) → Future<Status>
Delete a domain mapping.
get(String name, {String? $fields}) → Future<DomainMapping>
Get information about a domain mapping.
list(String parent, {String? continue_, String? fieldSelector, bool? includeUninitialized, String? labelSelector, int? limit, String? resourceVersion, bool? watch, String? $fields}) → Future<ListDomainMappingsResponse>
List all domain mappings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited