NamespacesInstancesResource class

Constructors

NamespacesInstancesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Instance request, String parent, {String? dryRun, String? $fields}) Future<Instance>
Create an Instance.
delete(String name, {String? apiVersion, String? dryRun, String? kind, String? propagationPolicy, String? $fields}) Future<Status>
Delete an Instance.
get(String name, {String? $fields}) Future<Instance>
Get an Instance.
list(String parent, {String? continue_, String? fieldSelector, bool? includeUninitialized, String? labelSelector, int? limit, String? resourceVersion, bool? watch, String? $fields}) Future<ListInstancesResponse>
List Instances.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replaceInstance(Instance request, String name, {String? dryRun, String? $fields}) Future<Instance>
Replace an Instance.
start(StartInstanceRequest request, String name, {String? $fields}) Future<Instance>
Start an Instance which has been stopped.
stop(StopInstanceRequest request, String name, {String? $fields}) Future<Instance>
Stop an Instance that is running.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited