NamespacesResource class

Constructors

NamespacesResource(ApiRequester client)

Properties

authorizeddomains → NamespacesAuthorizeddomainsResource
no setter
configurations → NamespacesConfigurationsResource
no setter
domainmappings → NamespacesDomainmappingsResource
no setter
executions → NamespacesExecutionsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
instances → NamespacesInstancesResource
no setter
jobs → NamespacesJobsResource
no setter
revisions → NamespacesRevisionsResource
no setter
routes → NamespacesRoutesResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services → NamespacesServicesResource
no setter
tasks → NamespacesTasksResource
no setter
workerpools → NamespacesWorkerpoolsResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited