NamespacesTasksResource class

Constructors

NamespacesTasksResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) → Future<Task>
Get information about a task.
list(String parent, {String? continue_, String? fieldSelector, bool? includeUninitialized, String? labelSelector, int? limit, String? resourceVersion, bool? watch, String? $fields}) → Future<ListTasksResponse>
List tasks.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited