ObjectMeta class

google.cloud.run.meta.v1.ObjectMeta is metadata that all persisted resources must have, which includes all objects users must create.

Constructors

ObjectMeta({Map<String, String>? annotations, String? clusterName, String? creationTimestamp, int? deletionGracePeriodSeconds, String? deletionTimestamp, List<String>? finalizers, String? generateName, int? generation, Map<String, String>? labels, String? name, String? namespace, List<OwnerReference>? ownerReferences, String? resourceVersion, String? selfLink, String? uid})
ObjectMeta.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Unstructured key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
getter/setter pair
clusterName ↔ String?
Not supported by Cloud Run
getter/setter pair
creationTimestamp ↔ String?
UTC timestamp representing the server time when this object was created.
getter/setter pair
deletionGracePeriodSeconds ↔ int?
Not supported by Cloud Run
getter/setter pair
deletionTimestamp ↔ String?
The read-only soft deletion timestamp for this resource.
getter/setter pair
finalizers ↔ List<String>?
Not supported by Cloud Run
getter/setter pair
generateName ↔ String?
Not supported by Cloud Run
getter/setter pair
generation ↔ int?
A system-provided sequence number representing a specific generation of the desired state.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Map of string keys and values that can be used to organize and categorize (scope and select) objects.
getter/setter pair
name ↔ String?
The name of the resource.
getter/setter pair
namespace ↔ String?
Defines the space within each name must be unique within a Cloud Run region.
getter/setter pair
ownerReferences ↔ List<OwnerReference>?
Not supported by Cloud Run
getter/setter pair
resourceVersion ↔ String?
Opaque, system-generated value that represents the internal version of this object that can be used by clients to determine when objects have changed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
URL representing this object.
getter/setter pair
uid ↔ String?
Unique, system-generated identifier for this resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited