generateName property
A prefix for the resource name if not provided in the create request.
Must be less than 31 characters to allow for a random suffix.
Optional.
Implementation
core.String? generateName;
A prefix for the resource name if not provided in the create request.
Must be less than 31 characters to allow for a random suffix.
Optional.
core.String? generateName;