OwnerReference class

This is not supported or used by Cloud Run.

Constructors

OwnerReference({String? apiVersion, bool? blockOwnerDeletion, bool? controller, String? kind, String? name, String? uid})
OwnerReference.fromJson(Map json_)

Properties

apiVersion ↔ String?
This is not supported or used by Cloud Run.
getter/setter pair
blockOwnerDeletion ↔ bool?
This is not supported or used by Cloud Run.
getter/setter pair
controller ↔ bool?
This is not supported or used by Cloud Run.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
This is not supported or used by Cloud Run.
getter/setter pair
name ↔ String?
This is not supported or used by Cloud Run.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String?
This is not supported or used by Cloud Run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited