ResourceRequirements class

ResourceRequirements describes the compute resource requirements.

Constructors

ResourceRequirements({Map<String, String>? limits, Map<String, String>? requests})
ResourceRequirements.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
limits ↔ Map<String, String>?
Limits describes the maximum amount of compute resources allowed.
getter/setter pair
requests ↔ Map<String, String>?
Requests describes the minimum amount of compute resources required.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited