RevisionStatus class

RevisionStatus communicates the observed state of the Revision (from the controller).

Constructors

RevisionStatus({List<GoogleCloudRunV1Condition>? conditions, int? desiredReplicas, String? imageDigest, String? logUrl, int? observedGeneration, String? serviceName})
RevisionStatus.fromJson(Map json_)

Properties

conditions ↔ List<GoogleCloudRunV1Condition>?
Conditions communicate information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world.
getter/setter pair
desiredReplicas ↔ int?
The configured number of instances running this revision.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageDigest ↔ String?
ImageDigest holds the resolved digest for the image specified within .Spec.Container.Image.
getter/setter pair
logUrl ↔ String?
Specifies the generated logging url for this particular revision based on the revision url template specified in the controller's config.
getter/setter pair
observedGeneration ↔ int?
ObservedGeneration is the 'Generation' of the Revision that was last processed by the controller.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceName ↔ String?
Not currently used by Cloud Run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited