Route class

Route is responsible for configuring ingress over a collection of Revisions.

Some of the Revisions a Route distributes traffic over may be specified by referencing the Configuration responsible for creating them; in these cases the Route is additionally responsible for monitoring the Configuration for "latest ready" revision changes, and smoothly rolling out latest revisions. Cloud Run currently supports referencing a single Configuration to automatically deploy the "latest ready" Revision from that Configuration.

Constructors

Route({String? apiVersion, String? kind, ObjectMeta? metadata, RouteSpec? spec, RouteStatus? status})
Route.fromJson(Map json_)

Properties

apiVersion ↔ String?
The API version for this call such as "serving.knative.dev/v1".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of this resource, in this case always "Route".
getter/setter pair
metadata ↔ ObjectMeta?
Metadata associated with this Route, including name, namespace, labels, and annotations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ RouteSpec?
Spec holds the desired state of the Route (from the client).
getter/setter pair
status ↔ RouteStatus?
Status communicates the observed state of the Route (from the controller).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited