RouteSpec class

RouteSpec holds the desired state of the Route (from the client).

Constructors

RouteSpec({List<TrafficTarget>? traffic})
RouteSpec.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traffic ↔ List<TrafficTarget>?
Traffic specifies how to distribute traffic over a collection of Knative Revisions and Configurations.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited