RouteStatus class

RouteStatus communicates the observed state of the Route (from the controller).

Constructors

RouteStatus({Addressable? address, List<GoogleCloudRunV1Condition>? conditions, int? observedGeneration, List<TrafficTarget>? traffic, String? url})
RouteStatus.fromJson(Map json_)

Properties

address ↔ Addressable?
Similar to url, information on where the service is available on HTTP.
getter/setter pair
conditions ↔ List<GoogleCloudRunV1Condition>?
Conditions communicates information about ongoing/complete reconciliation processes that bring the "spec" inline with the observed state of the world.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
observedGeneration ↔ int?
ObservedGeneration is the 'Generation' of the Route that was last processed by the controller.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
traffic ↔ List<TrafficTarget>?
Traffic holds the configured traffic distribution.
getter/setter pair
url ↔ String?
URL holds the url that will distribute traffic over the provided traffic targets.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited