RunJobRequest class

Request message for creating a new execution of a job.

Constructors

RunJobRequest({Overrides? overrides})
RunJobRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
overrides ↔ Overrides?
Overrides existing job configuration for one specific new job execution only, using the specified values to update the job configuration for the new execution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited