ServiceSpec class

ServiceSpec holds the desired state of the Route (from the client), which is used to manipulate the underlying Route and Configuration(s).

Constructors

ServiceSpec({RevisionTemplate? template, List<TrafficTarget>? traffic})
ServiceSpec.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template ↔ RevisionTemplate?
Holds the latest specification for the Revision to be stamped out.
getter/setter pair
traffic ↔ List<TrafficTarget>?
Specifies how to distribute traffic over a collection of Knative Revisions and Configurations to the Service's main URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited