StatusDetails class

StatusDetails is a set of additional properties that MAY be set by the server to provide additional information about a response.

The Reason field of a Status object defines what attributes will be set. Clients must ignore fields that do not match the defined type of each attribute, and should assume that any attribute may be empty, invalid, or under defined.

Constructors

StatusDetails({List<StatusCause>? causes, String? group, String? kind, String? name, int? retryAfterSeconds, String? uid})
StatusDetails.fromJson(Map json_)

Properties

causes ↔ List<StatusCause>?
The Causes array includes more details associated with the StatusReason failure.
getter/setter pair
group ↔ String?
The group attribute of the resource associated with the status StatusReason.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind attribute of the resource associated with the status StatusReason.
getter/setter pair
name ↔ String?
The name attribute of the resource associated with the status StatusReason (when there is a single name which can be described).
getter/setter pair
retryAfterSeconds ↔ int?
If specified, the time in seconds before the operation should be retried.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String?
UID of the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited