TaskSpec class

TaskSpec is a description of a task.

Constructors

TaskSpec({List<Container>? containers, int? maxRetries, Map<String, String>? nodeSelector, String? serviceAccountName, String? timeoutSeconds, List<Volume>? volumes})
TaskSpec.fromJson(Map json_)

Properties

containers ↔ List<Container>?
List of containers belonging to the task.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxRetries ↔ int?
Number of retries allowed per task, before marking this job failed.
getter/setter pair
nodeSelector ↔ Map<String, String>?
The Node Selector configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountName ↔ String?
Email address of the IAM service account associated with the task of a job execution.
getter/setter pair
timeoutSeconds ↔ String?
Duration in seconds the task may be active before the system will actively try to mark it failed and kill associated containers.
getter/setter pair
volumes ↔ List<Volume>?
List of volumes that can be mounted by containers belonging to the task.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited