VolumeMount class

VolumeMount describes a mounting of a Volume within a container.

Constructors

VolumeMount({String? mountPath, String? name, bool? readOnly, String? subPath})
VolumeMount.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mountPath ↔ String?
Path within the container at which the volume should be mounted.
getter/setter pair
name ↔ String?
The name of the volume.
getter/setter pair
readOnly ↔ bool?
Sets the mount to be read-only or read-write.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subPath ↔ String?
Path within the volume from which the container's volume should be mounted.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited