WorkerPool class

WorkerPool acts as a top-level container that manages a set instance splits among a set of Revisions and a template for creating new Revisions.

Constructors

WorkerPool({String? apiVersion, String? kind, ObjectMeta? metadata, WorkerPoolSpec? spec, WorkerPoolStatus? status})
WorkerPool.fromJson(Map json_)

Properties

apiVersion ↔ String?
The API version for this call.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of resource.
getter/setter pair
metadata ↔ ObjectMeta?
Metadata associated with this WorkerPool, including name, namespace, labels, and annotations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ WorkerPoolSpec?
Holds the desired state of the WorkerPool (from the client).
getter/setter pair
status ↔ WorkerPoolStatus?
Communicates the system-controlled state of the WorkerPool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited