GoogleCloudRunV2BinaryAuthorization class

Settings for Binary Authorization feature.

Constructors

GoogleCloudRunV2BinaryAuthorization({String? breakglassJustification, String? policy, bool? useDefault})
GoogleCloudRunV2BinaryAuthorization.fromJson(Map json_)

Properties

breakglassJustification ↔ String?
If present, indicates to use Breakglass using this justification.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
policy ↔ String?
The path to a binary authorization policy.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useDefault ↔ bool?
If True, indicates to use the default project's binary authorization policy.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited