GoogleCloudRunV2BuildConfig class

Describes the Build step of the function that builds a container from the given source.

Constructors

GoogleCloudRunV2BuildConfig({String? baseImage, bool? enableAutomaticUpdates, Map<String, String>? environmentVariables, String? functionTarget, String? imageUri, String? name, String? serviceAccount, String? sourceLocation, String? workerPool})
GoogleCloudRunV2BuildConfig.fromJson(Map json_)

Properties

baseImage ↔ String?
The base image used to build the function.
getter/setter pair
enableAutomaticUpdates ↔ bool?
Sets whether the function will receive automatic base image updates.
getter/setter pair
environmentVariables ↔ Map<String, String>?
User-provided build-time environment variables for the function
getter/setter pair
functionTarget ↔ String?
The name of the function (as defined in source code) that will be executed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageUri ↔ String?
Artifact Registry URI to store the built image.
getter/setter pair
name ↔ String?
The Cloud Build name of the latest successful deployment of the function.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
Service account to be used for building the container.
getter/setter pair
sourceLocation ↔ String?
The Cloud Storage bucket URI where the function source code is located.
getter/setter pair
workerPool ↔ String?
Name of the Cloud Build Custom Worker Pool that should be used to build the Cloud Run function.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited