GoogleCloudRunV2BuildpacksBuild class

Build the source using Buildpacks.

Constructors

GoogleCloudRunV2BuildpacksBuild({String? baseImage, String? cacheImageUri, bool? enableAutomaticUpdates, Map<String, String>? environmentVariables, String? functionTarget, String? projectDescriptor, String? runtime})
GoogleCloudRunV2BuildpacksBuild.fromJson(Map json_)

Properties

baseImage ↔ String?
The base image to use for the build.
getter/setter pair
cacheImageUri ↔ String?
cache_image_uri is the GCR/AR URL where the cache image will be stored.
getter/setter pair
enableAutomaticUpdates ↔ bool?
Whether or not the application container will be enrolled in automatic base image updates.
getter/setter pair
environmentVariables ↔ Map<String, String>?
User-provided build-time environment variables.
getter/setter pair
functionTarget ↔ String?
Name of the function target if the source is a function source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
projectDescriptor ↔ String?
project_descriptor stores the path to the project descriptor file.
getter/setter pair
runtime ↔ String?
The runtime name, e.g. 'go113'.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited