GoogleCloudRunV2CloudSqlInstance class
Represents a set of Cloud SQL instances.
Each one will be available under /cloudsql/[instance]. Visit https://cloud.google.com/sql/docs/mysql/connect-run for more information on how to connect Cloud SQL and Cloud Run.
Constructors
-
GoogleCloudRunV2CloudSqlInstance({List<
String> ? instances}) - GoogleCloudRunV2CloudSqlInstance.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited