GoogleCloudRunV2Execution class

Execution represents the configuration of a single execution.

A execution an immutable resource that references a container image which is run to completion.

Constructors

GoogleCloudRunV2Execution({Map<String, String>? annotations, int? cancelledCount, String? client, String? clientVersion, String? completionTime, List<GoogleCloudRunV2Condition>? conditions, String? createTime, String? creator, String? deleteTime, String? etag, String? expireTime, int? failedCount, String? generation, String? job, Map<String, String>? labels, String? launchStage, String? logUri, String? name, String? observedGeneration, int? parallelism, bool? reconciling, int? retriedCount, int? runningCount, bool? satisfiesPzs, String? startTime, int? succeededCount, int? taskCount, GoogleCloudRunV2TaskTemplate? template, String? uid, String? updateTime})
GoogleCloudRunV2Execution.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Unstructured key value map that may be set by external tools to store and arbitrary metadata.
getter/setter pair
cancelledCount ↔ int?
The number of tasks which reached phase Cancelled.
getter/setter pair
client ↔ String?
Arbitrary identifier for the API client.
getter/setter pair
clientVersion ↔ String?
Arbitrary version identifier for the API client.
getter/setter pair
completionTime ↔ String?
Represents time when the execution was completed.
getter/setter pair
conditions ↔ List<GoogleCloudRunV2Condition>?
The Condition of this Execution, containing its readiness status, and detailed error information in case it did not reach the desired state.
getter/setter pair
createTime ↔ String?
Represents time when the execution was acknowledged by the execution controller.
getter/setter pair
creator ↔ String?
Email address of the authenticated creator.
getter/setter pair
deleteTime ↔ String?
For a deleted resource, the deletion time.
getter/setter pair
etag ↔ String?
A system-generated fingerprint for this version of the resource.
getter/setter pair
expireTime ↔ String?
For a deleted resource, the time after which it will be permamently deleted.
getter/setter pair
failedCount ↔ int?
The number of tasks which reached phase Failed.
getter/setter pair
generation ↔ String?
A number that monotonically increases every time the user modifies the desired state.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
job ↔ String?
The name of the parent Job.
getter/setter pair
labels ↔ Map<String, String>?
Unstructured key value map that can be used to organize and categorize objects.
getter/setter pair
launchStage ↔ String?
The least stable launch stage needed to create this resource, as defined by Google Cloud Platform Launch Stages.
getter/setter pair
logUri ↔ String?
URI where logs for this execution can be found in Cloud Console.
getter/setter pair
name ↔ String?
The unique name of this Execution.
getter/setter pair
observedGeneration ↔ String?
The generation of this Execution.
getter/setter pair
parallelism ↔ int?
Specifies the maximum desired number of tasks the execution should run at any given time.
getter/setter pair
reconciling ↔ bool?
Indicates whether the resource's reconciliation is still in progress.
getter/setter pair
retriedCount ↔ int?
The number of tasks which have retried at least once.
getter/setter pair
runningCount ↔ int?
The number of actively running tasks.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
startTime ↔ String?
Represents time when the execution started to run.
getter/setter pair
succeededCount ↔ int?
The number of tasks which reached phase Succeeded.
getter/setter pair
taskCount ↔ int?
Specifies the desired number of tasks the execution should run.
getter/setter pair
template ↔ GoogleCloudRunV2TaskTemplate?
The template used to create tasks for this execution.
getter/setter pair
uid ↔ String?
Server assigned unique identifier for the Execution.
getter/setter pair
updateTime ↔ String?
The last-modified time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited