GoogleCloudRunV2ExportStatusResponse class

ExportStatusResponse contains the status of image export operation, with the status of each image export job.

Properties

hashCode → int
The hash code for this object.
no setterinherited
imageExportStatuses ↔ List<GoogleCloudRunV2ImageExportStatus>?
The status of each image export job.
getter/setter pair
operationId ↔ String?
The operation id.
getter/setter pair
operationState ↔ String?
The state of the overall export operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited