GoogleCloudRunV2GCSVolumeSource class

Represents a volume backed by a Cloud Storage bucket using Cloud Storage FUSE.

Constructors

GoogleCloudRunV2GCSVolumeSource({String? bucket, List<String>? mountOptions, bool? readOnly})
GoogleCloudRunV2GCSVolumeSource.fromJson(Map json_)

Properties

bucket ↔ String?
Cloud Storage Bucket name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mountOptions ↔ List<String>?
A list of additional flags to pass to the gcsfuse CLI.
getter/setter pair
readOnly ↔ bool?
If true, the volume will be mounted as read only for all mounts.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited