GoogleCloudRunV2HTTPHeader class

HTTPHeader describes a custom header to be used in HTTP probes

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The header field name
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The header field value
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited