reconciling property

bool? reconciling
getter/setter pair

Returns true if the Instance is currently being acted upon by the system to bring it into the desired state.

When a new Instance is created, or an existing one is updated, Cloud Run will asynchronously perform all necessary steps to bring the Instance to the desired serving state. This process is called reconciliation. While reconciliation is in process, observed_generation will have a transient value that might mismatch the intended state. Once reconciliation is over (and this field is false), there are two possible outcomes: reconciliation succeeded and the serving state matches the Instance, or there was an error, and reconciliation failed. This state can be found in terminal_condition.state.

Output only.

Implementation

core.bool? reconciling;