GoogleCloudRunV2InstanceSplitStatus class

Represents the observed state of a single InstanceSplit entry.

Properties

hashCode → int
The hash code for this object.
no setterinherited
percent ↔ int?
Specifies percent of the instance split to this Revision.
getter/setter pair
revision ↔ String?
Revision to which this instance split is assigned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The allocation type for this instance split. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited