GoogleCloudRunV2Job class

Job represents the configuration of a single job, which references a container image that is run to completion.

Constructors

GoogleCloudRunV2Job({Map<String, String>? annotations, GoogleCloudRunV2BinaryAuthorization? binaryAuthorization, String? client, String? clientVersion, List<GoogleCloudRunV2Condition>? conditions, String? createTime, String? creator, String? deleteTime, String? etag, int? executionCount, String? expireTime, String? generation, Map<String, String>? labels, String? lastModifier, GoogleCloudRunV2ExecutionReference? latestCreatedExecution, String? launchStage, String? name, String? observedGeneration, bool? reconciling, String? runExecutionToken, bool? satisfiesPzs, String? startExecutionToken, GoogleCloudRunV2ExecutionTemplate? template, GoogleCloudRunV2Condition? terminalCondition, String? uid, String? updateTime})
GoogleCloudRunV2Job.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Unstructured key value map that may be set by external tools to store and arbitrary metadata.
getter/setter pair
binaryAuthorization ↔ GoogleCloudRunV2BinaryAuthorization?
Settings for the Binary Authorization feature.
getter/setter pair
client ↔ String?
Arbitrary identifier for the API client.
getter/setter pair
clientVersion ↔ String?
Arbitrary version identifier for the API client.
getter/setter pair
conditions ↔ List<GoogleCloudRunV2Condition>?
The Conditions of all other associated sub-resources.
getter/setter pair
createTime ↔ String?
The creation time.
getter/setter pair
creator ↔ String?
Email address of the authenticated creator.
getter/setter pair
deleteTime ↔ String?
The deletion time.
getter/setter pair
etag ↔ String?
A system-generated fingerprint for this version of the resource.
getter/setter pair
executionCount ↔ int?
Number of executions created for this job.
getter/setter pair
expireTime ↔ String?
For a deleted resource, the time after which it will be permamently deleted.
getter/setter pair
generation ↔ String?
A number that monotonically increases every time the user modifies the desired state.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Unstructured key value map that can be used to organize and categorize objects.
getter/setter pair
lastModifier ↔ String?
Email address of the last authenticated modifier.
getter/setter pair
latestCreatedExecution ↔ GoogleCloudRunV2ExecutionReference?
Name of the last created execution.
getter/setter pair
launchStage ↔ String?
The launch stage as defined by Google Cloud Platform Launch Stages.
getter/setter pair
name ↔ String?
The fully qualified name of this Job.
getter/setter pair
observedGeneration ↔ String?
The generation of this Job.
getter/setter pair
reconciling ↔ bool?
Returns true if the Job is currently being acted upon by the system to bring it into the desired state.
getter/setter pair
runExecutionToken ↔ String?
A unique string used as a suffix for creating a new execution.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
startExecutionToken ↔ String?
A unique string used as a suffix creating a new execution.
getter/setter pair
template ↔ GoogleCloudRunV2ExecutionTemplate?
The template used to create executions for this Job.
getter/setter pair
terminalCondition ↔ GoogleCloudRunV2Condition?
The Condition of this Job, containing its readiness status, and detailed error information in case it did not reach the desired state.
getter/setter pair
uid ↔ String?
Server assigned unique identifier for the Execution.
getter/setter pair
updateTime ↔ String?
The last-modified time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited