GoogleCloudRunV2Probe class

Probe describes a health check to be performed against a container to determine whether it is alive or ready to receive traffic.

Constructors

GoogleCloudRunV2Probe({int? failureThreshold, GoogleCloudRunV2GRPCAction? grpc, GoogleCloudRunV2HTTPGetAction? httpGet, int? initialDelaySeconds, int? periodSeconds, GoogleCloudRunV2TCPSocketAction? tcpSocket, int? timeoutSeconds})
GoogleCloudRunV2Probe.fromJson(Map json_)

Properties

failureThreshold ↔ int?
Minimum consecutive failures for the probe to be considered failed after having succeeded.
getter/setter pair
grpc ↔ GoogleCloudRunV2GRPCAction?
GRPC specifies an action involving a gRPC port.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpGet ↔ GoogleCloudRunV2HTTPGetAction?
HTTPGet specifies the http request to perform.
getter/setter pair
initialDelaySeconds ↔ int?
Number of seconds after the container has started before the probe is initiated.
getter/setter pair
periodSeconds ↔ int?
How often (in seconds) to perform the probe.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tcpSocket ↔ GoogleCloudRunV2TCPSocketAction?
TCPSocket specifies an action involving a TCP port.
getter/setter pair
timeoutSeconds ↔ int?
Number of seconds after which the probe times out.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited