GoogleCloudRunV2SecretKeySelector class

SecretEnvVarSource represents a source for the value of an EnvVar.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret ↔ String?
The name of the secret in Cloud Secret Manager.
getter/setter pair
version ↔ String?
The Cloud Secret Manager secret version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited