durableExecution property
Indicates whether the Service has durable execution enabled.
This field is immutable once the Service is created.
Optional. Immutable.
Implementation
core.bool? durableExecution;
Indicates whether the Service has durable execution enabled.
This field is immutable once the Service is created.
Optional. Immutable.
core.bool? durableExecution;