GoogleCloudRunV2ServiceMesh class

Settings for Cloud Service Mesh.

For more information see https://cloud.google.com/service-mesh/docs/overview.

Properties

hashCode → int
The hash code for this object.
no setterinherited
mesh ↔ String?
The Mesh resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited