inlinedSource property
Input only.
Source code inlined in the request. Cloud Run will store the inlined_source to Cloud Storage and replace the field with cloud_storage_source.
Optional.
Implementation
GoogleCloudRunV2InlinedSource? inlinedSource;
Input only.
Source code inlined in the request. Cloud Run will store the inlined_source to Cloud Storage and replace the field with cloud_storage_source.
Optional.
GoogleCloudRunV2InlinedSource? inlinedSource;