GoogleCloudRunV2Task class

Task represents a single run of a container to completion.

Constructors

GoogleCloudRunV2Task({Map<String, String>? annotations, String? completionTime, List<GoogleCloudRunV2Condition>? conditions, List<GoogleCloudRunV2Container>? containers, String? createTime, String? deleteTime, String? encryptionKey, String? etag, String? execution, String? executionEnvironment, String? expireTime, String? generation, bool? gpuZonalRedundancyDisabled, int? index, String? job, Map<String, String>? labels, GoogleCloudRunV2TaskAttemptResult? lastAttemptResult, String? logUri, int? maxRetries, String? name, GoogleCloudRunV2NodeSelector? nodeSelector, String? observedGeneration, bool? reconciling, int? retried, bool? satisfiesPzs, String? scheduledTime, String? serviceAccount, String? startTime, String? timeout, String? uid, String? updateTime, List<GoogleCloudRunV2Volume>? volumes, GoogleCloudRunV2VpcAccess? vpcAccess})
GoogleCloudRunV2Task.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Unstructured key value map that may be set by external tools to store and arbitrary metadata.
getter/setter pair
completionTime ↔ String?
Represents time when the Task was completed.
getter/setter pair
conditions ↔ List<GoogleCloudRunV2Condition>?
The Condition of this Task, containing its readiness status, and detailed error information in case it did not reach the desired state.
getter/setter pair
containers ↔ List<GoogleCloudRunV2Container>?
Holds the single container that defines the unit of execution for this task.
getter/setter pair
createTime ↔ String?
Represents time when the task was created by the system.
getter/setter pair
deleteTime ↔ String?
For a deleted resource, the deletion time.
getter/setter pair
encryptionKey ↔ String?
A reference to a customer managed encryption key (CMEK) to use to encrypt this container image.
getter/setter pair
etag ↔ String?
A system-generated fingerprint for this version of the resource.
getter/setter pair
execution ↔ String?
The name of the parent Execution.
getter/setter pair
executionEnvironment ↔ String?
The execution environment being used to host this Task. Possible string values are:
getter/setter pair
expireTime ↔ String?
For a deleted resource, the time after which it will be permamently deleted.
getter/setter pair
generation ↔ String?
A number that monotonically increases every time the user modifies the desired state.
getter/setter pair
gpuZonalRedundancyDisabled ↔ bool?
True if GPU zonal redundancy is disabled on this task.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int?
Index of the Task, unique per execution, and beginning at 0.
getter/setter pair
job ↔ String?
The name of the parent Job.
getter/setter pair
labels ↔ Map<String, String>?
Unstructured key value map that can be used to organize and categorize objects.
getter/setter pair
lastAttemptResult ↔ GoogleCloudRunV2TaskAttemptResult?
Result of the last attempt of this Task.
getter/setter pair
logUri ↔ String?
URI where logs for this execution can be found in Cloud Console.
getter/setter pair
maxRetries ↔ int?
Number of retries allowed per Task, before marking this Task failed.
getter/setter pair
name ↔ String?
The unique name of this Task.
getter/setter pair
nodeSelector ↔ GoogleCloudRunV2NodeSelector?
The node selector for the task.
getter/setter pair
observedGeneration ↔ String?
The generation of this Task.
getter/setter pair
reconciling ↔ bool?
Indicates whether the resource's reconciliation is still in progress.
getter/setter pair
retried ↔ int?
The number of times this Task was retried.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPzs ↔ bool?
Reserved for future use.
getter/setter pair
scheduledTime ↔ String?
Represents time when the task was scheduled to run by the system.
getter/setter pair
serviceAccount ↔ String?
Email address of the IAM service account associated with the Task of a Job.
getter/setter pair
startTime ↔ String?
Represents time when the task started to run.
getter/setter pair
timeout ↔ String?
Max allowed time duration the Task may be active before the system will actively try to mark it failed and kill associated containers.
getter/setter pair
uid ↔ String?
Server assigned unique identifier for the Task.
getter/setter pair
updateTime ↔ String?
The last-modified time.
getter/setter pair
volumes ↔ List<GoogleCloudRunV2Volume>?
A list of Volumes to make available to containers.
getter/setter pair
vpcAccess ↔ GoogleCloudRunV2VpcAccess?
VPC Access configuration to use for this Task.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited