cloudStorageSource property
The Cloud Storage object path the source archive is uploaded to.
Implementation
GoogleCloudRunV2CloudStorageSource? cloudStorageSource;
The Cloud Storage object path the source archive is uploaded to.
GoogleCloudRunV2CloudStorageSource? cloudStorageSource;