subPath property
Path within the volume from which the container's volume should be mounted.
Defaults to "" (volume's root). This field is currently rejected in Secret volume mounts.
Optional.
Implementation
core.String? subPath;
Path within the volume from which the container's volume should be mounted.
Defaults to "" (volume's root). This field is currently rejected in Secret volume mounts.
Optional.
core.String? subPath;