ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

builds ProjectsLocationsBuildsResource
no setter
hashCode int
The hash code for this object.
no setterinherited
instances ProjectsLocationsInstancesResource
no setter
jobs ProjectsLocationsJobsResource
no setter
operations ProjectsLocationsOperationsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
services ProjectsLocationsServicesResource
no setter
workerPools ProjectsLocationsWorkerPoolsResource
no setter

Methods

exportImage(GoogleCloudRunV2ExportImageRequest request, String name, {String? $fields}) Future<GoogleCloudRunV2ExportImageResponse>
Export image for a given resource.
exportImageMetadata(String name, {String? $fields}) Future<GoogleCloudRunV2Metadata>
Export image metadata for a given resource.
exportMetadata(String name, {String? $fields}) Future<GoogleCloudRunV2Metadata>
Export generated customer metadata for a given resource.
exportProjectMetadata(String name, {String? $fields}) Future<GoogleCloudRunV2Metadata>
Export generated customer metadata for a given project.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited