UtilStatusProto class

Wire-format for a Status object

Constructors

UtilStatusProto({int? canonicalCode, int? code, String? message, Proto2BridgeMessageSet? messageSet, String? space})
UtilStatusProto.fromJson(Map json_)

Properties

canonicalCode ↔ int?
copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional int32 canonical_code = 6;
getter/setter pair
code ↔ int?
Numeric code drawn from the space specified below.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ String?
Detail message copybara:strip_begin(b/383363683) copybara:strip_end_and_replace optional string message = 3;
getter/setter pair
messageSet ↔ Proto2BridgeMessageSet?
message_set associates an arbitrary proto message with the status.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space ↔ String?
copybara:strip_begin(b/383363683) Space to which this status belongs copybara:strip_end_and_replace optional string space = 2; // Space to which this status belongs
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited