Aggregate class
Represents the aggregation of a set of population of like records by a certain group.
For example, a collection of unit counts can be aggregated and grouped by their state.
Constructors
- Aggregate({int? count, String? group})
- Aggregate.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited