FromMapping class
Output variables whose values will be passed on to dependencies
Constructors
- FromMapping({String? dependency, String? outputVariable})
- FromMapping.fromJson(Map json_)
Properties
- dependency ↔ String?
-
Alias of the dependency that the outputVariable will pass its value to
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputVariable ↔ String?
-
Name of the outputVariable on the dependency
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited