ListUnitOperationsResponse class

The response structure for the ListUnitOperations method.

Constructors

ListUnitOperationsResponse({String? nextPageToken, List<UnitOperation>? unitOperations, List<String>? unreachable})
ListUnitOperationsResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
nextPageToken String?
If present, the next page token can be provided to a subsequent ListUnitOperations call to list the next page.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unitOperations List<UnitOperation>?
The resulting unit operations.
getter/setter pair
unreachable List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited