systemCleanupAt property
If set, indicates the time when the system will start removing the unit.
Optional. Output only.
Implementation
core.String? systemCleanupAt;
If set, indicates the time when the system will start removing the unit.
Optional. Output only.
core.String? systemCleanupAt;