UnitOperation class
UnitOperation encapsulates the intent of changing/interacting with the service component represented by the specific Unit.
Multiple UnitOperations can be created (requested) and scheduled in the future, however only one will be allowed to execute at a time (that can change in the future for non-mutating operations). UnitOperations allow different actors interacting with the same unit to focus only on the change they have requested. This is a base object that contains the common fields in all unit operations. Next: 22
Constructors
-
UnitOperation({Map<
String, String> ? annotations, bool? cancel, List<UnitOperationCondition> ? conditions, String? createTime, String? deleteTime, Deprovision? deprovision, String? engineState, String? errorCategory, String? etag, FlagUpdate? flagUpdate, Map<String, String> ? labels, String? name, String? parentUnitOperation, Provision? provision, String? rollout, Schedule? schedule, String? state, String? uid, String? unit, String? updateTime, Upgrade? upgrade}) - UnitOperation.fromJson(Map json_)
Properties
-
annotations
↔ Map<
String, String> ? -
Annotations is an unstructured key-value map stored with a resource that
may be set by external tools to store and retrieve arbitrary metadata.
getter/setter pair
- cancel ↔ bool?
-
When true, attempt to cancel the operation.
getter/setter pair
-
conditions
↔ List<
UnitOperationCondition> ? -
A set of conditions which indicate the various conditions this resource
can have.
getter/setter pair
- createTime ↔ String?
-
The timestamp when the resource was created.
getter/setter pair
- deleteTime ↔ String?
-
The timestamp when the resource was marked for deletion (deletion is an
asynchronous operation).
getter/setter pair
- deprovision ↔ Deprovision?
-
Deprovision operation.
getter/setter pair
- engineState ↔ String?
-
The engine state for on-going deployment engine operation(s).
getter/setter pair
- errorCategory ↔ String?
-
UnitOperationErrorCategory describe the error category.
getter/setter pair
- etag ↔ String?
-
An opaque value that uniquely identifies a version or generation of a
resource.
getter/setter pair
- flagUpdate ↔ FlagUpdate?
-
Flag update operation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
The labels on the resource, which can be used for categorization.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- parentUnitOperation ↔ String?
-
Reference to parent resource: UnitOperation.
getter/setter pair
- provision ↔ Provision?
-
Provision operation.
getter/setter pair
- rollout ↔ String?
-
Specifies which rollout created this Unit Operation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schedule ↔ Schedule?
-
When to schedule this operation.
getter/setter pair
- state ↔ String?
-
UnitOperationState describes the current state of the unit operation.
getter/setter pair
- uid ↔ String?
-
The unique identifier of the resource.
getter/setter pair
- unit ↔ String?
-
The Unit a given UnitOperation will act upon.
getter/setter pair
- updateTime ↔ String?
-
The timestamp when the resource was last updated.
getter/setter pair
- upgrade ↔ Upgrade?
-
Upgrade operation.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited