deleteTime property
The timestamp when the resource was marked for deletion (deletion is an asynchronous operation).
Output only.
Implementation
core.String? deleteTime;
The timestamp when the resource was marked for deletion (deletion is an asynchronous operation).
Output only.
core.String? deleteTime;