type property

String? type
getter/setter pair

Type of the condition.

Required. Possible string values are:

  • "TYPE_UNSPECIFIED" : Condition type is unspecified.
  • "TYPE_SCHEDULED" : Condition type is scheduled.
  • "TYPE_RUNNING" : Condition type is running.
  • "TYPE_SUCCEEDED" : Condition type is succeeded.
  • "TYPE_CANCELLED" : Condition type is cancelled.
  • "TYPE_APP_CREATED" : Indicates if AppHub app has been created.
  • "TYPE_APP_COMPONENTS_REGISTERED" : Indicates if services and workloads have been registered with AppHub.
  • "TYPE_WORKLOAD_SUCCEEDED" : Indicates if the UnitOperation's core workload execution completed successfully. The workload is the core execution operation performed for a UnitOperation (e.g., provisioning, updating, or deprovisioning resources) excluding post-operation checks.

Implementation

core.String? type;