maxConcurrentOperationsCount property
An absolute cap on concurrent units operations.
If both percent and count are provided, the system uses the MINIMUM (most restrictive).
Optional.
Implementation
core.int? maxConcurrentOperationsCount;
An absolute cap on concurrent units operations.
If both percent and count are provided, the system uses the MINIMUM (most restrictive).
Optional.
core.int? maxConcurrentOperationsCount;