mutate method
- GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifiersRequest request,
- String customerId, {
- String? $fields,
Creates, updates, or removes ad group bid modifiers.
Operation statuses are returned. List of thrown errors: [AdGroupBidModifierError]() [AuthenticationError]() [AuthorizationError]() [ContextError]() [CriterionError]() [DatabaseError]() [DistinctError]() [FieldError]() [FieldMaskError]() [HeaderError]() [IdError]() [InternalError]() [MutateError]() [NewResourceCreationError]() [NotEmptyError]() [OperatorError]() [QuotaError]() [RangeError]() [RequestError]() [ResourceCountLimitExceededError]() [SizeLimitError]() [StringFormatError]() [StringLengthError]()
request - The metadata request object.
Request parameters:
customerId - Required. ID of the customer whose ad group bid modifiers
are being modified.
Value must have pattern ^\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifiersResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<
GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifiersResponse
>
mutate(
GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifiersRequest request,
core.String customerId, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v23/customers/' +
core.Uri.encodeFull('$customerId') +
'/adGroupBidModifiers:mutate';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleAdsSearchads360V23ServicesMutateAdGroupBidModifiersResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}