mutate method

Creates and removes ad group labels.

Operation statuses are returned. List of thrown errors: [AuthenticationError]() [AuthorizationError]() [DatabaseError]() [FieldError]() [HeaderError]() [InternalError]() [LabelError]() [MutateError]() [NewResourceCreationError]() [QuotaError]() [RequestError]()

request - The metadata request object.

Request parameters:

customerId - Required. ID of the customer whose ad group labels are being modified. Value must have pattern ^\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsResponse>
mutate(
  GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsRequest request,
  core.String customerId, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'v23/customers/' +
      core.Uri.encodeFull('$customerId') +
      '/adGroupLabels:mutate';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return GoogleAdsSearchads360V23ServicesMutateAdGroupLabelsResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}