CustomersCustomerLifecycleGoalResource class

Constructors

CustomersCustomerLifecycleGoalResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

configureCustomerLifecycleGoals(GoogleAdsSearchads360V23ServicesConfigureCustomerLifecycleGoalsRequest request, String customerId, {String? $fields}) Future<GoogleAdsSearchads360V23ServicesConfigureCustomerLifecycleGoalsResponse>
Process the given customer lifecycle configurations.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited