CustomersExperimentsResource class

Constructors

CustomersExperimentsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

endExperiment(GoogleAdsSearchads360V23ServicesEndExperimentRequest request, String experiment, {String? $fields}) Future<GoogleProtobufEmpty>
Immediately ends an experiment, changing the experiment's scheduled end date and without waiting for end of day.
graduateExperiment(GoogleAdsSearchads360V23ServicesGraduateExperimentRequest request, String experiment, {String? $fields}) Future<GoogleProtobufEmpty>
Graduates an experiment to a full campaign.
listExperimentAsyncErrors(String resourceName, {int? pageSize, String? pageToken, String? $fields}) Future<GoogleAdsSearchads360V23ServicesListExperimentAsyncErrorsResponse>
Returns all errors that occurred during the last Experiment update (either scheduling or promotion).
mutate(GoogleAdsSearchads360V23ServicesMutateExperimentsRequest request, String customerId, {String? $fields}) Future<GoogleAdsSearchads360V23ServicesMutateExperimentsResponse>
Creates, updates, or removes experiments.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promoteExperiment(GoogleAdsSearchads360V23ServicesPromoteExperimentRequest request, String resourceName, {String? $fields}) Future<GoogleLongrunningOperation>
Promotes the trial campaign thus applying changes in the trial campaign to the base campaign.
scheduleExperiment(GoogleAdsSearchads360V23ServicesScheduleExperimentRequest request, String resourceName, {String? $fields}) Future<GoogleLongrunningOperation>
Schedule an experiment.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited