CustomersIncentivesResource class

Constructors

CustomersIncentivesResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

applyIncentive(GoogleAdsSearchads360V23ServicesApplyIncentiveRequest request, String customerId, String selectedIncentiveId, {String? $fields}) Future<GoogleAdsSearchads360V23ServicesApplyIncentiveResponse>
Applies the incentive for the ads customer.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited