CustomersResource class
Methods
createCustomerClient (GoogleAdsSearchads360V23ServicesCreateCustomerClientRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse >
Creates a new client under manager.
generateAdGroupThemes (GoogleAdsSearchads360V23ServicesGenerateAdGroupThemesRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateAdGroupThemesResponse >
Returns a list of suggested AdGroups and suggested modifications (text,
match type) for the given keywords.
generateAudienceCompositionInsights (GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateAudienceCompositionInsightsResponse >
Returns a collection of attributes that are represented in an audience of
interest, with metrics that compare each attribute's share of the audience
with its share of a baseline audience.
generateAudienceDefinition (GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateAudienceDefinitionResponse >
Returns a collection of audience attributes using generative AI based on
the provided audience description.
generateAudienceOverlapInsights (GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateAudienceOverlapInsightsResponse >
Returns a collection of audience attributes along with estimates of the
overlap between their potential YouTube reach and that of a given input
attribute.
generateBenchmarksMetrics (GoogleAdsSearchads360V23ServicesGenerateBenchmarksMetricsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateBenchmarksMetricsResponse >
Returns YouTube advertisement metrics for the given client against
industry benchmarks.
generateInsightsFinderReport (GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateInsightsFinderReportResponse >
Creates a saved report that can be viewed in the Insights Finder tool.
generateKeywordForecastMetrics (GoogleAdsSearchads360V23ServicesGenerateKeywordForecastMetricsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateKeywordForecastMetricsResponse >
Returns metrics (such as impressions, clicks, total cost) of a keyword
forecast for the given campaign.
generateKeywordHistoricalMetrics (GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateKeywordHistoricalMetricsResponse >
Returns a list of keyword historical metrics.
generateKeywordIdeas (GoogleAdsSearchads360V23ServicesGenerateKeywordIdeasRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateKeywordIdeaResponse >
Returns a list of keyword ideas.
generateReachForecast (GoogleAdsSearchads360V23ServicesGenerateReachForecastRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateReachForecastResponse >
Generates a reach forecast for a given targeting / product mix.
generateSuggestedTargetingInsights (GoogleAdsSearchads360V23ServicesGenerateSuggestedTargetingInsightsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateSuggestedTargetingInsightsResponse >
Returns a collection of targeting insights (e.g. targetable audiences)
that are relevant to the requested audience.
generateTargetingSuggestionMetrics (GoogleAdsSearchads360V23ServicesGenerateTargetingSuggestionMetricsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGenerateTargetingSuggestionMetricsResponse >
Returns potential reach metrics for targetable audiences.
getIdentityVerification (String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesGetIdentityVerificationResponse >
Returns Identity Verification information.
listAccessibleCustomers ({String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesListAccessibleCustomersResponse >
Returns resource names of customers directly accessible by the user
authenticating the call.
mutate (GoogleAdsSearchads360V23ServicesMutateCustomerRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesMutateCustomerResponse >
Updates a customer.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCampaignAutomaticallyCreatedAsset (GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesRemoveCampaignAutomaticallyCreatedAssetResponse >
Removes automatically created assets from a campaign.
searchAudienceInsightsAttributes (GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesListAudienceInsightsAttributesResponse >
Searches for audience attributes that can be used to generate insights.
startIdentityVerification (GoogleAdsSearchads360V23ServicesStartIdentityVerificationRequest request , String customerId , {String ? $fields })
→ Future <GoogleProtobufEmpty >
Starts Identity Verification for a given verification program type.
suggestKeywordThemes (GoogleAdsSearchads360V23ServicesSuggestKeywordThemesRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesSuggestKeywordThemesResponse >
Suggests keyword themes to advertise on.
suggestSmartCampaignAd (GoogleAdsSearchads360V23ServicesSuggestSmartCampaignAdRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesSuggestSmartCampaignAdResponse >
Suggests a Smart campaign ad compatible with the Ad family of resources,
based on data points such as targeting and the business to advertise.
suggestSmartCampaignBudgetOptions (GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesSuggestSmartCampaignBudgetOptionsResponse >
Returns BudgetOption suggestions.
suggestTravelAssets (GoogleAdsSearchads360V23ServicesSuggestTravelAssetsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesSuggestTravelAssetsResponse >
Returns Travel Asset suggestions.
toString ()
→ String
A string representation of this object.
inherited
uploadCallConversions (GoogleAdsSearchads360V23ServicesUploadCallConversionsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesUploadCallConversionsResponse >
Processes the given call conversions.
uploadClickConversions (GoogleAdsSearchads360V23ServicesUploadClickConversionsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesUploadClickConversionsResponse >
Processes the given click conversions.
uploadConversionAdjustments (GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesUploadConversionAdjustmentsResponse >
Processes the given conversion adjustments.
uploadUserData (GoogleAdsSearchads360V23ServicesUploadUserDataRequest request , String customerId , {String ? $fields })
→ Future <GoogleAdsSearchads360V23ServicesUploadUserDataResponse >
Uploads the given user data.