createCustomerClient method
- GoogleAdsSearchads360V23ServicesCreateCustomerClientRequest request,
- String customerId, {
- String? $fields,
Creates a new client under manager.
The new client customer is returned. List of thrown errors: [AccessInvitationError]() [AuthenticationError]() [AuthorizationError]() [CurrencyCodeError]() [HeaderError]() [InternalError]() [ManagerLinkError]() [QuotaError]() [RequestError]() [StringLengthError]() [TimeZoneError]()
request - The metadata request object.
Request parameters:
customerId - Required. The ID of the Manager under whom client customer
is being created.
Value must have pattern ^\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse>
createCustomerClient(
GoogleAdsSearchads360V23ServicesCreateCustomerClientRequest request,
core.String customerId, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v23/customers/' +
core.Uri.encodeFull('$customerId') +
':createCustomerClient';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleAdsSearchads360V23ServicesCreateCustomerClientResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}