getIdentityVerification method
Returns Identity Verification information.
List of thrown errors: [AuthenticationError]() [AuthorizationError]() [HeaderError]() [InternalError]() [QuotaError]() [RequestError]()
Request parameters:
customerId - Required. The ID of the customer for whom we are requesting
verification information.
Value must have pattern ^\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleAdsSearchads360V23ServicesGetIdentityVerificationResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleAdsSearchads360V23ServicesGetIdentityVerificationResponse>
getIdentityVerification(
core.String customerId, {
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v23/customers/' +
core.Uri.encodeFull('$customerId') +
'/getIdentityVerification';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleAdsSearchads360V23ServicesGetIdentityVerificationResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}