getSmartCampaignStatus method
Returns the status of the requested Smart campaign.
Request parameters:
resourceName - Required. The resource name of the Smart campaign setting
belonging to the Smart campaign to fetch the status of.
Value must have pattern
^customers/\[^/\]+/smartCampaignSettings/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse>
getSmartCampaignStatus(
core.String resourceName, {
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v23/' +
core.Uri.encodeFull('$resourceName') +
':getSmartCampaignStatus';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}