mutate method
- GoogleAdsSearchads360V23ServicesMutateUserListsRequest request,
- String customerId, {
- String? $fields,
Creates or updates user lists.
Operation statuses are returned. List of thrown errors: [AuthenticationError]() [AuthorizationError]() [CollectionSizeError]() [DatabaseError]() [DistinctError]() [FieldError]() [FieldMaskError]() [HeaderError]() [InternalError]() [MutateError]() [NewResourceCreationError]() [NotAllowlistedError]() [NotEmptyError]() [OperationAccessDeniedError]() [QuotaError]() [RangeError]() [RequestError]() [StringFormatError]() [StringLengthError]() [UserListError]()
request - The metadata request object.
Request parameters:
customerId - Required. The ID of the customer whose user lists are being
modified.
Value must have pattern ^\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleAdsSearchads360V23ServicesMutateUserListsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleAdsSearchads360V23ServicesMutateUserListsResponse> mutate(
GoogleAdsSearchads360V23ServicesMutateUserListsRequest request,
core.String customerId, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v23/customers/' +
core.Uri.encodeFull('$customerId') +
'/userLists:mutate';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleAdsSearchads360V23ServicesMutateUserListsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}