GeoTargetConstantsResource class

Constructors

GeoTargetConstantsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
suggest(GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest request, {String? $fields}) Future<GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsResponse>
Returns GeoTargetConstant suggestions by location name or by resource name.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited