suggest method
Future<GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsResponse>
suggest(
- GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest request, {
- String? $fields,
Returns GeoTargetConstant suggestions by location name or by resource name.
List of thrown errors: [AuthenticationError]() [AuthorizationError]() [GeoTargetConstantSuggestionError]() [HeaderError]() [InternalError]() [QuotaError]() [RequestError]()
request - The metadata request object.
Request parameters:
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<
GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsResponse
>
suggest(
GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsRequest request, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
const url_ = 'v23/geoTargetConstants:suggest';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleAdsSearchads360V23ServicesSuggestGeoTargetConstantsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}