GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl class
YouTube Video Asset feature controls.
Constructors
- GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl({bool? allowYoutubeComments})
- GoogleAdsSearchads360V23CommonAdVideoAssetLinkFeatureControl.fromJson(Map json_)
Properties
- allowYoutubeComments ↔ bool?
-
Defines if YouTube comments should be enabled for the creative using this
YouTube video asset served on YouTube Shorts.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited