GoogleAdsSearchads360V23CommonKnowledgeGraphAttributeMetadata class
Metadata associated with a Knowledge Graph Entity attribute.
Constructors
-
GoogleAdsSearchads360V23CommonKnowledgeGraphAttributeMetadata({List<
String> ? entityCapabilities, }) - GoogleAdsSearchads360V23CommonKnowledgeGraphAttributeMetadata.fromJson(Map json_)
Properties
-
entityCapabilities
↔ List<
String> ? -
The capabilities of the entity used in ContentCreatorInsightsService.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
A list of CATEGORY attributes related to this entity.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited