GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField class
One custom question input field instance within a form.
Constructors
- GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField({String? customQuestionText, bool? hasLocationAnswer, GoogleAdsSearchads360V23CommonLeadFormSingleChoiceAnswers? singleChoiceAnswers})
- GoogleAdsSearchads360V23CommonLeadFormCustomQuestionField.fromJson(Map json_)
Properties
- customQuestionText ↔ String?
-
The exact custom question field text (for example, "What kind of vehicle
do you have?").
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasLocationAnswer ↔ bool?
-
Answer configuration for location question.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singleChoiceAnswers ↔ GoogleAdsSearchads360V23CommonLeadFormSingleChoiceAnswers?
-
Answer configuration for a single choice question.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited