GoogleAdsSearchads360V23CommonOperatingSystemVersionInfo class

Represents an operating system version to be targeted.

Properties

hashCode int
The hash code for this object.
no setterinherited
operatingSystemVersionConstant String?
The operating system version constant resource name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited