GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint class

Projected metrics for a specific target CPA amount.

Constructors

GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint({double? appInstalls, double? biddableConversions, double? biddableConversionsValue, String? clicks, String? costMicros, String? impressions, double? inAppActions, String? interactions, String? requiredBudgetAmountMicros, String? targetCpaMicros, double? targetCpaScalingModifier, String? topSlotImpressions})
GoogleAdsSearchads360V23CommonTargetCpaSimulationPoint.fromJson(Map json_)

Properties

appInstalls double?
Projected number of app installs.
getter/setter pair
biddableConversions double?
Projected number of biddable conversions.
getter/setter pair
biddableConversionsValue double?
Projected total value of biddable conversions.
getter/setter pair
clicks String?
Projected number of clicks.
getter/setter pair
costMicros String?
Projected cost in micros.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
impressions String?
Projected number of impressions.
getter/setter pair
inAppActions double?
Projected number of in-app actions.
getter/setter pair
interactions String?
Projected number of interactions.
getter/setter pair
requiredBudgetAmountMicros String?
Projected required daily budget that the advertiser must set in order to receive the estimated traffic, in micros of advertiser currency.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetCpaMicros String?
The simulated target CPA upon which projected metrics are based.
getter/setter pair
targetCpaScalingModifier double?
The simulated scaling modifier upon which projected metrics are based.
getter/setter pair
topSlotImpressions String?
Projected number of top slot impressions.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited