modificationMethod property

String? modificationMethod
getter/setter pair

How the simulation modifies the field.

Output only. Possible string values are:

  • "UNSPECIFIED" : Not specified.
  • "UNKNOWN" : Used for return value only. Represents value unknown in this version.
  • "UNIFORM" : The values in a simulation were applied to all children of a given resource uniformly. Overrides on child resources were not respected.
  • "DEFAULT" : The values in a simulation were applied to the given resource. Overrides on child resources were respected, and traffic estimates do not include these resources.
  • "SCALING" : The values in a simulation were all scaled by the same factor. For example, in a simulated TargetCpa campaign, the campaign target and all ad group targets were scaled by a factor of X.

Implementation

core.String? modificationMethod;