androidPrivacyInteractionDate property
The interaction date used in the shared key encoding in the format of "YYYY-MM-DD" in UTC timezone.
Output only.
Implementation
core.String? androidPrivacyInteractionDate;
The interaction date used in the shared key encoding in the format of "YYYY-MM-DD" in UTC timezone.
Output only.
core.String? androidPrivacyInteractionDate;