referenceCount property
The number of campaigns associated with this shared set.
Read only.
Output only.
Implementation
core.String? referenceCount;
The number of campaigns associated with this shared set.
Read only.
Output only.
core.String? referenceCount;