validateOnly property
If true, the request is validated but not executed.
Only errors are returned, not results.
Implementation
core.bool? validateOnly;
If true, the request is validated but not executed.
Only errors are returned, not results.
core.bool? validateOnly;