GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsResponse class

Response message for OfflineUserDataJobService.AddOfflineUserDataJobOperations.

Properties

hashCode int
The hash code for this object.
no setterinherited
partialFailureError GoogleRpcStatus?
Errors that pertain to operation failures in the partial failure mode.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warning GoogleRpcStatus?
Non blocking errors that pertain to operation failures in the warnings mode.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited