IncentivesResource class
Constructors
- IncentivesResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fetchIncentive(
{String? countryCode, String? email, String? languageCode, String? type, String? $fields}) → Future< GoogleAdsSearchads360V23ServicesFetchIncentiveResponse> - Returns incentives for a given user.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited