AmpIssue class

AMP issue.

Constructors

AmpIssue({String? issueMessage, String? severity})
AmpIssue.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
issueMessage ↔ String?
Brief description of this issue.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Severity of this issue: WARNING or ERROR. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited