RunMobileFriendlyTestRequest class

Mobile-friendly test request.

Constructors

RunMobileFriendlyTestRequest({bool? requestScreenshot, String? url})
RunMobileFriendlyTestRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestScreenshot ↔ bool?
Whether or not screenshot is requested.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
URL for inspection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited