RunMobileFriendlyTestResponse class

Mobile-friendly test response, including mobile-friendly issues and resource issues.

Constructors

RunMobileFriendlyTestResponse({String? mobileFriendliness, List<MobileFriendlyIssue>? mobileFriendlyIssues, List<ResourceIssue>? resourceIssues, Image? screenshot, TestStatus? testStatus})
RunMobileFriendlyTestResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mobileFriendliness ↔ String?
Test verdict, whether the page is mobile friendly or not. Possible string values are:
getter/setter pair
mobileFriendlyIssues ↔ List<MobileFriendlyIssue>?
List of mobile-usability issues.
getter/setter pair
resourceIssues ↔ List<ResourceIssue>?
Information about embedded resources issues.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenshot ↔ Image?
Screenshot of the requested URL.
getter/setter pair
testStatus ↔ TestStatus?
Final state of the test, can be either complete or an error.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited