Automatic class

A replication policy that replicates the Secret payload without any restrictions.

Constructors

Automatic({CustomerManagedEncryption? customerManagedEncryption})
Automatic.fromJson(Map json_)

Properties

customerManagedEncryption ↔ CustomerManagedEncryption?
The customer-managed encryption configuration of the Secret.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited