CloudSQLSingleUserCredentials class
These are the credentials required for Cloud SQL DB for Single user Managed Rotation.
Constructors
- CloudSQLSingleUserCredentials({String? instanceId, String? password, String? username})
- CloudSQLSingleUserCredentials.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instanceId ↔ String?
-
Instance ID of the Cloud SQL instance.
getter/setter pair
- password ↔ String?
-
Password of the Cloud SQL instance.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username ↔ String?
-
Username of the Cloud SQL instance.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited