CustomerManagedEncryptionStatus class

Describes the status of customer-managed encryption.

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyVersionName ↔ String?
The resource name of the Cloud KMS CryptoKeyVersion used to encrypt the secret payload, in the following format: projects / * /locations / * /keyRings / * /cryptoKeys / * /versions / * .
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited