EnableManagedRotationRequest class

Request message for SecretManagerService.EnableManagedRotation.

Properties

cloudSqlSingleUserCredentials ↔ CloudSQLSingleUserCredentials?
Credentials required for Cloud SQL DB for Single user Managed Rotation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited