ListSecretsResponse class

Response message for SecretManagerService.ListSecrets.

Constructors

ListSecretsResponse({String? nextPageToken, List<Secret>? secrets, int? totalSize})
ListSecretsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to retrieve the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secrets ↔ List<Secret>?
The list of Secrets sorted in reverse by create_time (newest first).
getter/setter pair
totalSize ↔ int?
The total number of Secrets but 0 when the ListSecretsRequest.filter field is set.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited