ManagedRotationStatus class

Represents the status of a managed rotation.

This is applicable only to Typed Secrets. It indicates whether the rotation is active and any errors that may have occurred during the asynchronous managed rotation.

Constructors

ManagedRotationStatus({Status? error, String? state})
ManagedRotationStatus.fromJson(Map json_)

Properties

error ↔ Status?
Displays customer-facing issues that occurred during an asynchronous managed rotation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Indicates whether the Managed Rotation is active or not.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited