error property
Displays customer-facing issues that occurred during an asynchronous managed rotation.
For example, if there are some permission errors.
Output only.
Implementation
Status? error;
Displays customer-facing issues that occurred during an asynchronous managed rotation.
For example, if there are some permission errors.
Output only.
Status? error;