enableManagedRotation method
- EnableManagedRotationRequest request,
- String parent, {
- String? $fields,
Enables the managed rotation feature for a Secret.
This method can only be triggered once for a secret. In order to do further rotations, RotateSecret should be used. This method will add a secret version and update the password in Cloud SQL.
request - The metadata request object.
Request parameters:
parent - Required. The resource name of the Secret to associate with the
SecretVersion in the format projects / * /secrets / * or projects / * /locations / * /secrets / * .
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/secrets/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a SecretVersion.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<SecretVersion> enableManagedRotation(
EnableManagedRotationRequest request,
core.String parent, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v1/' + core.Uri.encodeFull('$parent') + ':enableManagedRotation';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return SecretVersion.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}