Replication class

A policy that defines the replication and encryption configuration of data.

Constructors

Replication({Automatic? automatic, UserManaged? userManaged})
Replication.fromJson(Map json_)

Properties

automatic ↔ Automatic?
The Secret will automatically be replicated without any restrictions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userManaged ↔ UserManaged?
The Secret will only be replicated into the locations specified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited