Rotation class

The rotation time and period for a Secret.

At next_rotation_time, Secret Manager will send a Pub/Sub notification to the topics configured on the Secret. Secret.topics must be set to configure rotation.

Constructors

Rotation({ManagedRotationStatus? managedRotationStatus, String? nextRotationTime, String? rotationPeriod})
Rotation.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
managedRotationStatus ↔ ManagedRotationStatus?
The current status of the managed rotation.
getter/setter pair
nextRotationTime ↔ String?
Timestamp in UTC at which the Secret is scheduled to rotate.
getter/setter pair
rotationPeriod ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited