policyMember property

ResourcePolicyMember? policyMember
getter/setter pair

Defines the policy member for the secret.

This will be used to check if the caller has the permission to perform certain operations on the typed secret.

Output only.

Implementation

ResourcePolicyMember? policyMember;