secretType property

String? secretType
getter/setter pair

This defines the type of the secret.

Enforces certain structural requirements on the SecretVersions. For secret of type UNSPECIFIED, the SecretVersions can be of any type.

Optional. Immutable. Possible string values are:

  • "SECRET_TYPE_UNSPECIFIED" : Applicable to all secrets which do not have any restriction on the SecretVersions.
  • "CLOUD_SQL_DB_CREDENTIALS" : Applicable to secrets which are used for the managed rotation feature for Cloud SQL Single User.
  • "ACCESS_KEY" : Applicable to secrets where the payload contains an access key.
  • "CERTIFICATE" : Applicable to secrets where the payload contains a certificate.
  • "OTHER_DB_CREDENTIALS" : Applicable to secrets where the payload contains database credentials.
  • "OTHER" : Applicable to secrets whose type doesn't belong to any of the above defined types.

Implementation

core.String? secretType;