SecretPayload class

A secret payload resource in the Secret Manager API.

This contains the sensitive secret payload that is associated with a SecretVersion.

Constructors

SecretPayload({String? data, String? dataCrc32c})
SecretPayload.fromJson(Map json_)

Properties

data ↔ String?
The secret data.
getter/setter pair
dataAsBytes ↔ List<int>
getter/setter pair
dataCrc32c ↔ String?
If specified, SecretManagerService will verify the integrity of the received data on SecretManagerService.AddSecretVersion calls using the crc32c checksum and store it to include in future SecretManagerService.AccessSecretVersion responses.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited