Code class

The comment on a code line.

Constructors

Code({String? body, String? effectiveCommitSha, String? effectiveRootComment, Position? position, String? reply, bool? resolved})
Code.fromJson(Map json_)

Properties

body ↔ String?
The comment body.
getter/setter pair
effectiveCommitSha ↔ String?
The effective commit sha this code comment is pointing to.
getter/setter pair
effectiveRootComment ↔ String?
The root comment of the conversation, derived from the reply field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
position ↔ Position?
The position of the comment.
getter/setter pair
reply ↔ String?
Input only.
getter/setter pair
resolved ↔ bool?
Boolean indicator if the comment is resolved.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited