FileDiff class

Metadata of a FileDiff.

FileDiff represents a single file diff in a pull request.

Constructors

FileDiff({String? action, String? name, String? patch, String? sha})
FileDiff.fromJson(Map json_)

Properties

action ↔ String?
The action taken on the file (eg.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the file.
getter/setter pair
patch ↔ String?
The git patch containing the file changes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha ↔ String?
The commit pointing to the file changes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited