OpenIssueRequest class

The request to open an issue.

Constructors

OpenIssueRequest({String? etag})
OpenIssueRequest.fromJson(Map json_)

Properties

etag ↔ String?
The current etag of the issue.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited