PullRequestComment class

PullRequestComment represents a comment on a pull request.

Constructors

PullRequestComment({Code? code, Comment? comment, String? createTime, String? name, Review? review, String? updateTime})
PullRequestComment.fromJson(Map json_)

Properties

code ↔ Code?
The comment on a code line.
getter/setter pair
comment ↔ Comment?
The general pull request comment.
getter/setter pair
createTime ↔ String?
Creation timestamp.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
review ↔ Review?
The review summary comment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
Last updated timestamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited