Repository class

Metadata of a Secure Source Manager repository.

Constructors

Repository({String? createTime, String? description, String? etag, InitialConfig? initialConfig, String? instance, String? name, String? uid, String? updateTime, URIs? uris})
Repository.fromJson(Map json_)

Properties

createTime ↔ String?
Create timestamp.
getter/setter pair
description ↔ String?
Description of the repository, which cannot exceed 500 characters.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initialConfig ↔ InitialConfig?
Input only.
getter/setter pair
instance ↔ String?
The name of the instance in which the repository is hosted, formatted as projects/{project_number}/locations/{location_id}/instances/{instance_id} When creating repository via securesourcemanager.googleapis.com, this field is used as input.
getter/setter pair
name ↔ String?
A unique identifier for a repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String?
Unique identifier of the repository.
getter/setter pair
updateTime ↔ String?
Update timestamp.
getter/setter pair
uris ↔ URIs?
URIs for the repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited