Review class

The review summary comment.

Constructors

Review({String? actionType, String? body, String? effectiveCommitSha})
Review.fromJson(Map json_)

Properties

actionType ↔ String?
The review action type.
getter/setter pair
body ↔ String?
The comment body.
getter/setter pair
effectiveCommitSha ↔ String?
The effective commit sha this review is pointing to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited