AccessReview class

Constructors

AccessReview({String? group, String? name, String? ns, String? resource, String? subresource, String? verb, String? version})
AccessReview.fromJson(Map json_)

Properties

group String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
ns String?
getter/setter pair
resource String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subresource String?
getter/setter pair
verb String?
getter/setter pair
version String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited