AdaptiveProtection class

Constructors

AdaptiveProtection({double? confidence})
AdaptiveProtection.fromJson(Map json_)

Properties

confidence ↔ double?
A score of 0 means that there is low confidence that the detected event is an actual attack.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited