AdcApplication class
Represents an ADC application associated with the finding.
Constructors
- AdcApplication({GoogleCloudSecuritycenterV1ResourceApplicationAttributes? attributes, String? name})
- AdcApplication.fromJson(Map json_)
Properties
- attributes ↔ GoogleCloudSecuritycenterV1ResourceApplicationAttributes?
-
Consumer provided attributes for the AppHub application.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
The resource name of an ADC Application.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited