AdcApplicationTemplateRevision class

Represents an ADC template associated with the finding.

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
The resource name of an ADC Application Template Revision.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited