AiModel class

Contains information about the AI model associated with the finding.

Constructors

AiModel({String? deploymentPlatform, String? displayName, String? domain, String? library, String? location, String? name, String? publisher, String? usageCategory})
AiModel.fromJson(Map json_)

Properties

deploymentPlatform ↔ String?
The platform on which the model is deployed. Possible string values are:
getter/setter pair
displayName ↔ String?
The user defined display name of model.
getter/setter pair
domain ↔ String?
The domain of the model, for example, “image-classification”.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
library ↔ String?
The name of the model library, for example, “transformers”.
getter/setter pair
location ↔ String?
The region in which the model is used, for example, “us-central1”.
getter/setter pair
name ↔ String?
The name of the AI model, for example, "gemini:1.0.0".
getter/setter pair
publisher ↔ String?
The publisher of the model, for example, “google” or “nvidia”.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usageCategory ↔ String?
The purpose of the model, for example, "Inteference" or "Training".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited