ArtifactGuardPolicy class
Represents an artifact guard policy.
Constructors
- ArtifactGuardPolicy({String? failureReason, String? policyId, String? type})
- ArtifactGuardPolicy.fromJson(Map json_)
Properties
- failureReason ↔ String?
-
The reason for the policy failure, for example, "severity=HIGH AND
max_vuln_count=2".
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- policyId ↔ String?
-
The ID of the failing policy, for example,
"organizations/3392779/locations/global/policies/prod-policy".
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
The type of the policy evaluation.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited