failureReason property
The reason for the policy failure, for example, "severity=HIGH AND max_vuln_count=2".
Implementation
core.String? failureReason;
The reason for the policy failure, for example, "severity=HIGH AND max_vuln_count=2".
core.String? failureReason;