Attack class

Constructors

Attack({String? classification, int? volumeBps, String? volumeBpsLong, int? volumePps, String? volumePpsLong})
Attack.fromJson(Map json_)

Properties

classification String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
volumeBps int?
getter/setter pair
volumeBpsLong String?
getter/setter pair
volumePps int?
getter/setter pair
volumePpsLong String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited