AttackExposure class

Constructors

AttackExposure({String? attackExposureResult, int? exposedHighValueResourcesCount, int? exposedLowValueResourcesCount, int? exposedMediumValueResourcesCount, String? latestCalculationTime, double? score, String? state})
AttackExposure.fromJson(Map json_)

Properties

attackExposureResult String?
getter/setter pair
exposedHighValueResourcesCount int?
getter/setter pair
exposedLowValueResourcesCount int?
getter/setter pair
exposedMediumValueResourcesCount int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
latestCalculationTime String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double?
getter/setter pair
state String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited