AttackPath class

A path that an attacker could take to reach an exposed resource.

Constructors

AttackPath({List<AttackPathEdge>? edges, String? name, List<AttackPathNode>? pathNodes})
AttackPath.fromJson(Map json_)

Properties

edges ↔ List<AttackPathEdge>?
A list of the edges between nodes in this attack path.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The attack path name, for example, organizations/12/simulation/34/valuedResources/56/attackPaths/78
getter/setter pair
pathNodes ↔ List<AttackPathNode>?
A list of nodes that exist in this attack path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited