AttackStepNode class

Detailed steps the attack can take between path nodes.

Constructors

AttackStepNode({String? description, String? displayName, Map<String, String>? labels, String? type, String? uuid})
AttackStepNode.fromJson(Map json_)

Properties

description ↔ String?
Attack step description
getter/setter pair
displayName ↔ String?
User friendly name of the attack step
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Attack step labels for metadata
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Attack step type.
getter/setter pair
uuid ↔ String?
Unique ID for one Node
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited