AzureMetadata class
Constructors
-
AzureMetadata({List<
AzureManagementGroup> ? managementGroups, AzureResourceGroup? resourceGroup, AzureSubscription? subscription, AzureTenant? tenant}) - AzureMetadata.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
managementGroups
↔ List<
AzureManagementGroup> ? -
getter/setter pair
- resourceGroup ↔ AwsAccount?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subscription ↔ AzureSubscription?
-
getter/setter pair
- tenant ↔ AzureSubscription?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited