BackupDisasterRecovery class

Constructors

BackupDisasterRecovery({String? appliance, List<String>? applications, String? backupCreateTime, String? backupTemplate, String? backupType, String? host, List<String>? policies, List<String>? policyOptions, String? profile, String? storagePool})
BackupDisasterRecovery.fromJson(Map json_)

Properties

appliance ↔ String?
getter/setter pair
applications ↔ List<String>?
getter/setter pair
backupCreateTime ↔ String?
getter/setter pair
backupTemplate ↔ String?
getter/setter pair
backupType ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
getter/setter pair
policies ↔ List<String>?
getter/setter pair
policyOptions ↔ List<String>?
getter/setter pair
profile ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storagePool ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited