BulkMuteFindingsRequest class

Constructors

BulkMuteFindingsRequest({String? filter, String? muteAnnotation, String? muteState})
BulkMuteFindingsRequest.fromJson(Map json_)

Properties

filter String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
muteAnnotation String?
getter/setter pair
muteState String?
Possible string values are:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited