CloudDlpDataProfile class
Constructors
-
CloudDlpDataProfile({String? dataProfile, List<
InfoType> ? infoTypes, String? parentType}) - CloudDlpDataProfile.fromJson(Map json_)
Properties
- dataProfile ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
infoTypes
↔ List<
InfoType> ? -
getter/setter pair
- parentType ↔ String?
-
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited