CloudLoggingEntry class

Constructors

CloudLoggingEntry({String? insertId, String? logId, String? resourceContainer, String? timestamp})
CloudLoggingEntry.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
insertId ↔ String?
getter/setter pair
logId ↔ String?
getter/setter pair
resourceContainer ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited