CreateResourceValueConfigRequest class

Request message to create single resource value config

Properties

hashCode → int
The hash code for this object.
no setterinherited
parent ↔ String?
Resource name of the new ResourceValueConfig's parent.
getter/setter pair
resourceValueConfig ↔ GoogleCloudSecuritycenterV1ResourceValueConfig?
The resource value config being created.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited