CustomModuleValidationError class

Constructors

CustomModuleValidationError({String? description, Position? end, String? fieldPath, Position? start})
CustomModuleValidationError.fromJson(Map json_)

Properties

description ↔ String?
getter/setter pair
end ↔ Position?
getter/setter pair
fieldPath ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ Position?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited