Cve class

Constructors

Cve({Cvssv3? cvssv3, String? exploitReleaseDate, String? exploitationActivity, String? firstExploitationDate, String? id, String? impact, bool? observedInTheWild, List<Reference>? references, bool? upstreamFixAvailable, bool? zeroDay})
Cve.fromJson(Map json_)

Properties

cvssv3 Cvssv3?
getter/setter pair
exploitationActivity String?
Possible string values are:
getter/setter pair
exploitReleaseDate String?
getter/setter pair
firstExploitationDate String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
impact String?
Possible string values are:
getter/setter pair
observedInTheWild bool?
getter/setter pair
references List<Reference>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upstreamFixAvailable bool?
getter/setter pair
zeroDay bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited