Database class

Constructors

Database({String? displayName, List<String>? grantees, String? name, String? query, String? userName, String? version})
Database.fromJson(Map json_)

Properties

displayName String?
getter/setter pair
grantees List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
query String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userName String?
getter/setter pair
version String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited