EventThreatDetectionCustomModule class
Constructors
Properties
- ancestorModule ↔ String?
-
getter/setter pair
- cloudProvider ↔ String?
-
Possible string values are:
getter/setter pair
-
config
↔ Map<
String, Object?> ? -
The values for Object must be JSON objects. It can consist of
num,String,boolandnullas well asMapandListvalues.getter/setter pair - description ↔ String?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- enablementState ↔ String?
-
Possible string values are:
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastEditor ↔ String?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
getter/setter pair
- updateTime ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited