File class

Constructors

File({String? contents, DiskPath? diskPath, String? fileLoadState, String? hashedSize, List<FileOperation>? operations, bool? partiallyHashed, String? path, String? sha256, String? size})
File.fromJson(Map json_)

Properties

contents String?
getter/setter pair
diskPath DiskPath?
getter/setter pair
fileLoadState String?
Possible string values are:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hashedSize String?
getter/setter pair
operations List<FileOperation>?
getter/setter pair
partiallyHashed bool?
getter/setter pair
path String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String?
getter/setter pair
size String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited