Finding class

Constructors

Finding({Access? access, AffectedResources? affectedResources, Agent? agent, AgentAnomaly? agentAnomaly, List<AgentDataAccessEvent>? agentDataAccessEvents, List<AgentSession>? agentSessions, AiModel? aiModel, Application? application, ArtifactGuardPolicies? artifactGuardPolicies, AttackExposure? attackExposure, BackupDisasterRecovery? backupDisasterRecovery, String? canonicalName, String? category, Chokepoint? chokepoint, CloudArmor? cloudArmor, CloudDlpDataProfile? cloudDlpDataProfile, CloudDlpInspection? cloudDlpInspection, ComplianceDetails? complianceDetails, List<Compliance>? compliances, List<Connection>? connections, Map<String, ContactDetails>? contacts, List<Container>? containers, String? createTime, List<DataAccessEvent>? dataAccessEvents, List<DataFlowEvent>? dataFlowEvents, List<DataRetentionDeletionEvent>? dataRetentionDeletionEvents, Database? database, String? description, DiscoveredWorkload? discoveredWorkload, Disk? disk, String? eventTime, Exfiltration? exfiltration, ExternalExposure? externalExposure, Map<String, GoogleCloudSecuritycenterV1ExternalSystem>? externalSystems, String? externalUri, List<File>? files, String? findingClass, List<GroupMembership>? groupMemberships, List<IamBinding>? iamBindings, GoogleCloudSecuritycenterV1IamDetails? iamDetails, Indicator? indicator, IpRules? ipRules, Job? job, KernelRootkit? kernelRootkit, Kubernetes? kubernetes, List<LoadBalancer>? loadBalancers, List<LogEntry>? logEntries, MitreAttack? mitreAttack, String? moduleName, String? mute, MuteInfo? muteInfo, String? muteInitiator, String? muteUpdateTime, String? name, List<LoadBalancer>? networks, String? nextSteps, Notebook? notebook, List<LoadBalancer>? orgPolicies, String? parent, String? parentDisplayName, PolicyViolationSummary? policyViolationSummary, List<Process>? processes, String? resourceName, Secret? secret, SecurityMarks? securityMarks, SecurityPosture? securityPosture, String? severity, Map<String, Object?>? sourceProperties, String? state, ToxicCombination? toxicCombination, VertexAi? vertexAi, Vulnerability? vulnerability})
Finding.fromJson(Map json_)

Properties

access ↔ Access?
getter/setter pair
affectedResources ↔ AffectedResources?
getter/setter pair
agent ↔ AzureSubscription?
getter/setter pair
agentAnomaly ↔ AgentAnomaly?
getter/setter pair
agentDataAccessEvents ↔ List<AgentDataAccessEvent>?
getter/setter pair
agentSessions ↔ List<AgentSession>?
getter/setter pair
aiModel ↔ AiModel?
getter/setter pair
application ↔ Application?
getter/setter pair
artifactGuardPolicies ↔ ArtifactGuardPolicies?
getter/setter pair
attackExposure ↔ AttackExposure?
getter/setter pair
backupDisasterRecovery ↔ BackupDisasterRecovery?
getter/setter pair
canonicalName ↔ String?
getter/setter pair
category ↔ String?
getter/setter pair
chokepoint ↔ Chokepoint?
getter/setter pair
cloudArmor ↔ CloudArmor?
getter/setter pair
cloudDlpDataProfile ↔ CloudDlpDataProfile?
getter/setter pair
cloudDlpInspection ↔ CloudDlpInspection?
getter/setter pair
complianceDetails ↔ ComplianceDetails?
getter/setter pair
compliances ↔ List<Compliance>?
getter/setter pair
connections ↔ List<Connection>?
getter/setter pair
contacts ↔ Map<String, ContactDetails>?
getter/setter pair
containers ↔ List<Container>?
getter/setter pair
createTime ↔ String?
getter/setter pair
dataAccessEvents ↔ List<DataAccessEvent>?
getter/setter pair
database ↔ Database?
getter/setter pair
dataFlowEvents ↔ List<DataFlowEvent>?
getter/setter pair
dataRetentionDeletionEvents ↔ List<DataRetentionDeletionEvent>?
getter/setter pair
description ↔ String?
getter/setter pair
discoveredWorkload ↔ DiscoveredWorkload?
getter/setter pair
disk ↔ Disk?
getter/setter pair
eventTime ↔ String?
getter/setter pair
exfiltration ↔ Exfiltration?
getter/setter pair
externalExposure ↔ ExternalExposure?
getter/setter pair
externalSystems ↔ Map<String, GoogleCloudSecuritycenterV1ExternalSystem>?
getter/setter pair
externalUri ↔ String?
getter/setter pair
files ↔ List<File>?
getter/setter pair
findingClass ↔ String?
Possible string values are:
getter/setter pair
groupMemberships ↔ List<GroupMembership>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iamBindings ↔ List<IamBinding>?
getter/setter pair
iamDetails ↔ GoogleCloudSecuritycenterV1IamDetails?
getter/setter pair
indicator ↔ Indicator?
getter/setter pair
ipRules ↔ IpRules?
getter/setter pair
job ↔ Job?
getter/setter pair
kernelRootkit ↔ KernelRootkit?
getter/setter pair
kubernetes ↔ Kubernetes?
getter/setter pair
loadBalancers ↔ List<LoadBalancer>?
getter/setter pair
logEntries ↔ List<LogEntry>?
getter/setter pair
mitreAttack ↔ MitreAttack?
getter/setter pair
moduleName ↔ String?
getter/setter pair
mute ↔ String?
Possible string values are:
getter/setter pair
muteInfo ↔ MuteInfo?
getter/setter pair
muteInitiator ↔ String?
getter/setter pair
muteUpdateTime ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
networks ↔ List<LoadBalancer>?
getter/setter pair
nextSteps ↔ String?
getter/setter pair
notebook ↔ Notebook?
getter/setter pair
orgPolicies ↔ List<LoadBalancer>?
getter/setter pair
parent ↔ String?
getter/setter pair
parentDisplayName ↔ String?
getter/setter pair
policyViolationSummary ↔ PolicyViolationSummary?
getter/setter pair
processes ↔ List<Process>?
getter/setter pair
resourceName ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret ↔ Secret?
getter/setter pair
securityMarks ↔ SecurityMarks?
getter/setter pair
securityPosture ↔ SecurityPosture?
getter/setter pair
severity ↔ String?
Possible string values are:
getter/setter pair
sourceProperties ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
state ↔ String?
Possible string values are:
getter/setter pair
toxicCombination ↔ ToxicCombination?
getter/setter pair
vertexAi ↔ VertexAi?
getter/setter pair
vulnerability ↔ Vulnerability?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited