Framework class

Compliance framework associated with the finding.

Constructors

Framework({List<String>? category, List<Control>? controls, String? displayName, String? name, String? type})
Framework.fromJson(Map json_)

Properties

category ↔ List<String>?
Category of the framework associated with the finding.
getter/setter pair
controls ↔ List<Control>?
The controls associated with the framework.
getter/setter pair
displayName ↔ String?
Display name of the framework.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the framework associated with the finding
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of the framework associated with the finding, to specify whether the framework is built-in (pre-defined and immutable) or a custom framework defined by the customer (equivalent to security posture) Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited