GoogleCloudSecuritycenterV1CustomConfig class

Properties

customOutput GoogleCloudSecuritycenterV1CustomOutputSpec?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
predicate Expr?
getter/setter pair
recommendation String?
getter/setter pair
resourceSelector GoogleCloudSecuritycenterV1ResourceSelector?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited