GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule class
Constructors
- GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule({String? cloudProvider, GoogleCloudSecuritycenterV1CustomConfig? customConfig, String? displayName, String? enablementState, String? name})
- GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule.fromJson(Map json_)
Properties
- cloudProvider ↔ String?
-
Possible string values are:
getter/setter pair
- customConfig ↔ GoogleCloudSecuritycenterV1CustomConfig?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- enablementState ↔ String?
-
Possible string values are:
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited