GoogleCloudSecuritycenterV1ExternalSystem class
Constructors
-
GoogleCloudSecuritycenterV1ExternalSystem({List<
String> ? assignees, String? caseCloseTime, String? caseCreateTime, String? casePriority, String? caseSla, String? caseUri, String? externalSystemUpdateTime, String? externalUid, String? name, String? status, TicketInfo? ticketInfo}) - GoogleCloudSecuritycenterV1ExternalSystem.fromJson(Map json_)
Properties
-
assignees
↔ List<
String> ? -
getter/setter pair
- caseCloseTime ↔ String?
-
getter/setter pair
- caseCreateTime ↔ String?
-
getter/setter pair
- casePriority ↔ String?
-
getter/setter pair
- caseSla ↔ String?
-
getter/setter pair
- caseUri ↔ String?
-
getter/setter pair
- externalSystemUpdateTime ↔ String?
-
getter/setter pair
- externalUid ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
getter/setter pair
- ticketInfo ↔ TicketInfo?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited