GoogleCloudSecuritycenterV1ResourceApplicationAttributes class

Consumer provided attributes for the application

Properties

businessOwners List<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>?
Business team that ensures user needs are met and value is delivered
getter/setter pair
criticality GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality?
User-defined criticality information.
getter/setter pair
developerOwners List<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>?
Developer team that owns development and coding.
getter/setter pair
environment GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment?
User-defined environment information.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
operatorOwners List<GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo>?
Operator team that ensures runtime and operations.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited