GoogleCloudSecuritycenterV1ResourceValueConfig class

Constructors

GoogleCloudSecuritycenterV1ResourceValueConfig({String? cloudProvider, String? createTime, String? description, String? name, Map<String, String>? resourceLabelsSelector, String? resourceType, String? resourceValue, String? scope, GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping? sensitiveDataProtectionMapping, List<String>? tagValues, String? updateTime})
GoogleCloudSecuritycenterV1ResourceValueConfig.fromJson(Map json_)

Properties

cloudProvider String?
Possible string values are:
getter/setter pair
createTime String?
getter/setter pair
description String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
resourceLabelsSelector Map<String, String>?
getter/setter pair
resourceType String?
getter/setter pair
resourceValue String?
Possible string values are:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
getter/setter pair
sensitiveDataProtectionMapping GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping?
getter/setter pair
tagValues List<String>?
getter/setter pair
updateTime String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited