GroupAssetsRequest class

Constructors

GroupAssetsRequest({String? compareDuration, String? filter, String? groupBy, int? pageSize, String? pageToken, String? readTime})
GroupAssetsRequest.fromJson(Map json_)

Properties

compareDuration ↔ String?
getter/setter pair
filter ↔ String?
getter/setter pair
groupBy ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int?
getter/setter pair
pageToken ↔ String?
getter/setter pair
readTime ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited