GroupAssetsResponse class

Response message for grouping by assets.

Constructors

GroupAssetsResponse({List<GroupResult>? groupByResults, String? nextPageToken, String? readTime, int? totalSize})
GroupAssetsResponse.fromJson(Map json_)

Properties

groupByResults ↔ List<GroupResult>?
Group results.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to retrieve the next page of results, or empty if there are no more results.
getter/setter pair
readTime ↔ String?
Time used for executing the groupBy request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize ↔ int?
The total number of results matching the query.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited