GroupMembership class

Contains details about groups of which this finding is a member.

A group is a collection of findings that are related in some way.

Constructors

GroupMembership({String? groupId, String? groupType})
GroupMembership.fromJson(Map json_)

Properties

groupId ↔ String?
ID of the group.
getter/setter pair
groupType ↔ String?
Type of group. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited