Indicator class

Constructors

Indicator({List<String>? domains, List<String>? ipAddresses, List<ProcessSignature>? signatures, List<String>? uris})
Indicator.fromJson(Map json_)

Properties

domains List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ipAddresses List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signatures List<ProcessSignature>?
getter/setter pair
uris List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited