InfoType class

Type of information detected by the API.

Constructors

InfoType({String? name, SensitivityScore? sensitivityScore, String? version})
InfoType.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the information type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sensitivityScore ↔ SensitivityScore?
Optional custom sensitivity for this InfoType.
getter/setter pair
version ↔ String?
Optional version name for this InfoType.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited