IpRules class

Constructors

IpRules({Allowed? allowed, Denied? denied, List<String>? destinationIpRanges, String? direction, List<String>? exposedServices, List<String>? sourceIpRanges})
IpRules.fromJson(Map json_)

Properties

allowed Allowed?
getter/setter pair
denied Denied?
getter/setter pair
destinationIpRanges List<String>?
getter/setter pair
direction String?
Possible string values are:
getter/setter pair
exposedServices List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceIpRanges List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited