Job class

Constructors

Job({int? errorCode, String? location, String? name, String? state})
Job.fromJson(Map json_)

Properties

errorCode int?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location String?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited