ListSecurityHealthAnalyticsCustomModulesResponse class

Response message for listing Security Health Analytics custom modules.

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
If not empty, indicates that there may be more custom modules to be returned.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityHealthAnalyticsCustomModules ↔ List<GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule>?
Custom modules belonging to the requested parent.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited