ListSourcesResponse class

Response message for listing sources.

Constructors

ListSourcesResponse({String? nextPageToken, List<Source>? sources})
ListSourcesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to retrieve the next page of results, or empty if there are no more results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sources ↔ List<Source>?
Sources belonging to the requested parent.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited