MitreAttack class

Constructors

MitreAttack({List<String>? additionalTactics, List<String>? additionalTechniques, String? primaryTactic, List<String>? primaryTechniques, String? version})
MitreAttack.fromJson(Map json_)

Properties

additionalTactics List<String>?
getter/setter pair
additionalTechniques List<String>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
primaryTactic String?
Possible string values are:
getter/setter pair
primaryTechniques List<String>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
version String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited