NodePool class

Provides GKE node pool information.

Constructors

NodePool({String? name, List<Node>? nodes})
NodePool.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Kubernetes node pool name.
getter/setter pair
nodes ↔ List<Node>?
Nodes associated with the finding.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited