OrganizationSettings class

User specified settings that are attached to the Security Command Center organization.

Constructors

OrganizationSettings({AssetDiscoveryConfig? assetDiscoveryConfig, bool? enableAssetDiscovery, String? name})
OrganizationSettings.fromJson(Map json_)

Properties

assetDiscoveryConfig ↔ AssetDiscoveryConfig?
The configuration used for Asset Discovery runs.
getter/setter pair
enableAssetDiscovery ↔ bool?
A flag that indicates if Asset Discovery should be enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The relative resource name of the settings.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited