list method
Lists the valued resources for a set of simulation results and filter.
Request parameters:
parent - Required. Name of parent to list valued resources. Valid
formats: organizations/{organization},
organizations/{organization}/simulations/{simulation}
organizations/{organization}/simulations/{simulation}/attackExposureResults/{attack_exposure_result_v2}
Value must have pattern ^organizations/\[^/\]+/simulations/\[^/\]+$.
filter - The filter expression that filters the valued resources in the
response. Supported fields: * resource_value supports = *
resource_type supports =
orderBy - Optional. The fields by which to order the valued resources
response. Supported fields: * exposed_score * resource_value *
resource_type * resource * display_name Values should be a comma
separated list of fields. For example: exposed_score,resource_value. The
default sorting order is descending. To specify ascending or descending
order for a field, append a ASC or a DESC suffix, respectively; for
example: exposed_score DESC.
pageSize - The maximum number of results to return in a single response.
Default is 10, minimum is 1, maximum is 1000.
pageToken - The value returned by the last
ListValuedResourcesResponse; indicates that this is a continuation of a
prior ListValuedResources call, and that the system should return the
next page of data.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListValuedResourcesResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListValuedResourcesResponse> list(
core.String parent, {
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/valuedResources';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListValuedResourcesResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}