OrganizationsSourcesResource class

Constructors

OrganizationsSourcesResource(ApiRequester client)

Properties

findings OrganizationsSourcesFindingsResource
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Source request, String parent, {String? $fields}) Future<Source>
request - The metadata request object.
get(String name, {String? $fields}) Future<Source>
Request parameters:
getIamPolicy(GetIamPolicyRequest request, String resource, {String? $fields}) Future<Policy>
request - The metadata request object.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<ListSourcesResponse>
Request parameters:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(Source request, String name, {String? updateMask, String? $fields}) Future<Source>
request - The metadata request object.
setIamPolicy(SetIamPolicyRequest request, String resource, {String? $fields}) Future<Policy>
request - The metadata request object.
testIamPermissions(TestIamPermissionsRequest request, String resource, {String? $fields}) Future<TestIamPermissionsResponse>
request - The metadata request object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited