PathNodeAssociatedFinding class

A finding that is associated with this node in the attack path.

Constructors

PathNodeAssociatedFinding({String? canonicalFinding, String? findingCategory, String? name})
PathNodeAssociatedFinding.fromJson(Map json_)

Properties

canonicalFinding ↔ String?
Canonical name of the associated findings.
getter/setter pair
findingCategory ↔ String?
The additional taxonomy group within findings from a given source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Full resource name of the finding.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited