Pod class

A Kubernetes Pod.

Constructors

Pod({List<Container>? containers, List<Label>? labels, String? name, String? ns})
Pod.fromJson(Map json_)

Properties

containers ↔ List<Container>?
Pod containers associated with this finding, if any.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ List<Label>?
Pod labels.
getter/setter pair
name ↔ String?
Kubernetes Pod name.
getter/setter pair
ns ↔ String?
Kubernetes Pod namespace.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited