list method
- @Deprecated('Not supported. Member documentation may have more information.')
Request parameters:
parent - null
Value must have pattern ^projects/\[^/\]+$.
compareDuration - null
fieldMask - null
filter - null
orderBy - null
pageSize - null
pageToken - null
readTime - null
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListAssetsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
@core.Deprecated(
'Not supported. Member documentation may have more information.',
)
async.Future<ListAssetsResponse> list(
core.String parent, {
core.String? compareDuration,
core.String? fieldMask,
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? readTime,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'compareDuration': ?compareDuration == null ? null : [compareDuration],
'fieldMask': ?fieldMask == null ? null : [fieldMask],
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'readTime': ?readTime == null ? null : [readTime],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/assets';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListAssetsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}