ProjectsMuteConfigsResource class

Constructors

ProjectsMuteConfigsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(GoogleCloudSecuritycenterV1MuteConfig request, String parent, {String? muteConfigId, String? $fields}) Future<GoogleCloudSecuritycenterV1MuteConfig>
request - The metadata request object.
delete(String name, {String? $fields}) Future<Empty>
Request parameters:
get(String name, {String? $fields}) Future<GoogleCloudSecuritycenterV1MuteConfig>
Request parameters:
list(String parent, {int? pageSize, String? pageToken, String? $fields}) Future<ListMuteConfigsResponse>
Request parameters:
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(GoogleCloudSecuritycenterV1MuteConfig request, String name, {String? updateMask, String? $fields}) Future<GoogleCloudSecuritycenterV1MuteConfig>
request - The metadata request object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited