create method
Future<GoogleCloudSecuritycenterV1MuteConfig>
create(
- GoogleCloudSecuritycenterV1MuteConfig request,
- String parent, {
- String? muteConfigId,
- String? $fields,
request - The metadata request object.
Request parameters:
parent - null
Value must have pattern ^projects/\[^/\]+$.
muteConfigId - null
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudSecuritycenterV1MuteConfig.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleCloudSecuritycenterV1MuteConfig> create(
GoogleCloudSecuritycenterV1MuteConfig request,
core.String parent, {
core.String? muteConfigId,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'muteConfigId': ?muteConfigId == null ? null : [muteConfigId],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/muteConfigs';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleCloudSecuritycenterV1MuteConfig.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}