ProjectsSecurityHealthAnalyticsSettingsEffectiveCustomModulesResource class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) → Future<GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule>
Retrieves an EffectiveSecurityHealthAnalyticsCustomModule.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) → Future<ListEffectiveSecurityHealthAnalyticsCustomModulesResponse>
Returns a list of all EffectiveSecurityHealthAnalyticsCustomModules for the given parent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited