ProjectsSourcesResource class

Constructors

ProjectsSourcesResource(ApiRequester client)

Properties

findings → ProjectsSourcesFindingsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

list(String parent, {int? pageSize, String? pageToken, String? $fields}) → Future<ListSourcesResponse>
Lists all sources belonging to an organization.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited