Requests class

Information about the requests relevant to the finding.

Constructors

Requests({int? longTermAllowed, int? longTermDenied, double? ratio, int? shortTermAllowed})
Requests.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
longTermAllowed ↔ int?
Allowed RPS (requests per second) over the long term.
getter/setter pair
longTermDenied ↔ int?
Denied RPS (requests per second) over the long term.
getter/setter pair
ratio ↔ double?
For 'Increasing deny ratio', the ratio is the denied traffic divided by the allowed traffic.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortTermAllowed ↔ int?
Allowed RPS (requests per second) in the short term.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited