Resource class

Constructors

Resource({AdcApplication? adcApplication, AdcApplicationTemplateRevision? adcApplicationTemplate, AdcSharedTemplateRevision? adcSharedTemplate, GoogleCloudSecuritycenterV1ResourceApplication? application, AwsMetadata? awsMetadata, AzureMetadata? azureMetadata, String? cloudProvider, String? displayName, List<Folder>? folders, String? location, String? name, String? organization, String? parentDisplayName, String? parentName, String? projectDisplayName, String? projectName, ResourcePath? resourcePath, String? resourcePathString, String? service, String? type})
Resource.fromJson(Map json_)

Properties

adcApplication AdcApplication?
getter/setter pair
adcApplicationTemplate Disk?
getter/setter pair
adcSharedTemplate Disk?
getter/setter pair
application GoogleCloudSecuritycenterV1ResourceApplication?
getter/setter pair
awsMetadata AwsMetadata?
getter/setter pair
azureMetadata AzureMetadata?
getter/setter pair
cloudProvider String?
Possible string values are:
getter/setter pair
displayName String?
getter/setter pair
folders List<Folder>?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location String?
getter/setter pair
name String?
getter/setter pair
organization String?
getter/setter pair
parentDisplayName String?
getter/setter pair
parentName String?
getter/setter pair
projectDisplayName String?
getter/setter pair
projectName String?
getter/setter pair
resourcePath ResourcePath?
getter/setter pair
resourcePathString String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String?
getter/setter pair
type String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited