Secret class

Details about a secret or credential associated with the finding.

Constructors

Secret({SecretEnvironmentVariable? environmentVariable, SecretFilePath? filePath, SecretStatus? status, String? type})
Secret.fromJson(Map json_)

Properties

environmentVariable SecretEnvironmentVariable?
The environment variable containing the secret.
getter/setter pair
filePath SecretFilePath?
The file containing the secret.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status SecretStatus?
The status of the secret.
getter/setter pair
type String?
The type of secret, for example, GCP_API_KEY.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited