key property

String? key
getter/setter pair

Environment variable name as a JSON encoded string.

Note that value is not included since the value contains the secret data, which is sensitive core content.

Implementation

core.String? key;