SecurityPolicy class

Information about the Google Cloud Armor security policy relevant to the finding.

Constructors

SecurityPolicy({String? name, bool? preview, String? type})
SecurityPolicy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the Google Cloud Armor security policy, for example, "my-security-policy".
getter/setter pair
preview ↔ bool?
Whether or not the associated rule or policy is in preview mode.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of Google Cloud Armor security policy for example, 'backend security policy', 'edge security policy', 'network edge security policy', or 'always-on DDoS protection'.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited