SensitivityScore class

Score is calculated from of all elements in the data profile.

A higher level means the data is more sensitive.

Constructors

SensitivityScore({String? score})
SensitivityScore.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ String?
The sensitivity score applied to the resource. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited