SetFindingStateRequest class

Request message for updating a finding's state.

Constructors

SetFindingStateRequest({String? startTime, String? state})
SetFindingStateRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time at which the updated state takes effect.
getter/setter pair
state ↔ String?
The desired State of the finding.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited