SimulatedResult class

Constructors

SimulatedResult({Status? error, Finding? finding, Empty? noViolation})
SimulatedResult.fromJson(Map json_)

Properties

error ↔ Status?
getter/setter pair
finding ↔ Finding?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
noViolation ↔ Empty?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited