Simulation class

Attack path simulation

Constructors

Simulation({String? cloudProvider, String? createTime, String? name, List<ResourceValueConfigMetadata>? resourceValueConfigsMetadata})
Simulation.fromJson(Map json_)

Properties

cloudProvider ↔ String?
Indicates which cloud provider was used in this simulation. Possible string values are:
getter/setter pair
createTime ↔ String?
Time simulation was created
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Full resource name of the Simulation: organizations/123/simulations/456
getter/setter pair
resourceValueConfigsMetadata ↔ List<ResourceValueConfigMetadata>?
Resource value configurations' metadata used in this simulation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited