Source class

Security Command Center finding source.

A finding source is an entity or a mechanism that can produce a finding. A source is like a container of findings that come from the same scanner, logger, monitor, and other tools.

Constructors

Source({String? canonicalName, String? description, String? displayName, String? name})
Source.fromJson(Map json_)

Properties

canonicalName ↔ String?
The canonical name of the finding source.
getter/setter pair
description ↔ String?
The description of the source (max of 1024 characters).
getter/setter pair
displayName ↔ String?
The source's display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The relative resource name of this source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited