ValuedResource class

Constructors

ValuedResource({String? displayName, double? exposedScore, String? name, String? resource, String? resourceType, String? resourceValue, List<LoadBalancer>? resourceValueConfigsUsed})
ValuedResource.fromJson(Map json_)

Properties

displayName String?
getter/setter pair
exposedScore double?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
resource String?
getter/setter pair
resourceType String?
getter/setter pair
resourceValue String?
Possible string values are:
getter/setter pair
resourceValueConfigsUsed List<LoadBalancer>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited