AssetDetails class

Details of a Cloud Asset Inventory asset that caused a violation.

Constructors

AssetDetails({String? asset, String? assetType})
AssetDetails.fromJson(Map json_)

Properties

asset ↔ String?
Information about the Cloud Asset Inventory asset that violated a policy.
getter/setter pair
assetType ↔ String?
The type of Cloud Asset Inventory asset.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited