Constraint class

Metadata for a constraint in a Policy.

Constructors

Constraint({OrgPolicyConstraint? orgPolicyConstraint, OrgPolicyConstraintCustom? orgPolicyConstraintCustom, SecurityHealthAnalyticsCustomModule? securityHealthAnalyticsCustomModule, SecurityHealthAnalyticsModule? securityHealthAnalyticsModule})
Constraint.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
orgPolicyConstraint ↔ OrgPolicyConstraint?
A predefined organization policy constraint.
getter/setter pair
orgPolicyConstraintCustom ↔ OrgPolicyConstraintCustom?
A custom organization policy constraint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityHealthAnalyticsCustomModule ↔ SecurityHealthAnalyticsCustomModule?
A custom module for Security Health Analytics.
getter/setter pair
securityHealthAnalyticsModule ↔ SecurityHealthAnalyticsModule?
A built-in detector for Security Health Analytics.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited