CustomOutputSpec class

Definitions of custom source properties that can appear in findings.

Constructors

CustomOutputSpec({List<Property>? properties})
CustomOutputSpec.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
properties ↔ List<Property>?
The custom source properties that can appear in findings.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited