ListPosturesResponse class

Response message for ListPostures.

Constructors

ListPosturesResponse({String? nextPageToken, List<Posture>? postures, List<String>? unreachable})
ListPosturesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A pagination token.
getter/setter pair
postures ↔ List<Posture>?
The list of Posture resources.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Locations that were temporarily unavailable and could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited