OrgPolicyConstraintCustom class

A custom organization policy constraint.

Properties

customConstraint ↔ GoogleCloudSecuritypostureV1CustomConstraint?
Metadata for the constraint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
policyRules ↔ List<GoogleCloudSecuritypostureV1PolicyRule>?
The rules enforced by the constraint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited