OrganizationsLocationsResource class

Constructors

OrganizationsLocationsResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
operations OrganizationsLocationsOperationsResource
no setter
postureDeployments OrganizationsLocationsPostureDeploymentsResource
no setter
postures OrganizationsLocationsPosturesResource
no setter
postureTemplates OrganizationsLocationsPostureTemplatesResource
no setter
reports OrganizationsLocationsReportsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

get(String name, {String? $fields}) Future<Location>
Gets information about a location.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) Future<ListLocationsResponse>
Lists information about the supported locations for this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited