PolicyDetails class

Details of a policy that was violated.

Constructors

PolicyDetails({List<String>? complianceStandards, String? constraint, String? constraintType, String? description})
PolicyDetails.fromJson(Map json_)

Properties

complianceStandards ↔ List<String>?
The compliance standards that the policy maps to.
getter/setter pair
constraint ↔ String?
Information about the constraint that was violated.
getter/setter pair
constraintType ↔ String?
The type of constraint that was violated. Possible string values are:
getter/setter pair
description ↔ String?
A description of the policy.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited