PolicySet class

A group of one or more Policy resources.

Constructors

PolicySet({String? description, List<Policy>? policies, String? policySetId})
PolicySet.fromJson(Map json_)

Properties

description ↔ String?
A description of the policy set.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
policies ↔ List<Policy>?
The Policy resources in the policy set.
getter/setter pair
policySetId ↔ String?
An identifier for the policy set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited