PostureDeployment class

Details for a Posture deployment on an organization, folder, or project.

You can deploy at most one posture to each organization, folder, or project. The parent resource for a posture deployment is always the organization, even if the deployment applies to a folder or project.

Constructors

PostureDeployment({Map<String, String>? annotations, List<String>? categories, String? createTime, String? description, String? desiredPostureId, String? desiredPostureRevisionId, String? etag, String? failureMessage, String? name, String? postureId, String? postureRevisionId, bool? reconciling, String? state, String? targetResource, String? updateTime})
PostureDeployment.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
The user-specified annotations for the posture deployment.
getter/setter pair
categories ↔ List<String>?
The categories that the posture deployment belongs to, as determined by the Security Posture API.
getter/setter pair
createTime ↔ String?
The time at which the posture deployment was created.
getter/setter pair
description ↔ String?
A description of the posture deployment.
getter/setter pair
desiredPostureId ↔ String?
The posture ID that was specified for the deployment.
getter/setter pair
desiredPostureRevisionId ↔ String?
The revision ID of the posture that was specified for the deployment.
getter/setter pair
etag ↔ String?
An opaque identifier for the current version of the posture deployment.
getter/setter pair
failureMessage ↔ String?
A description of why the posture deployment failed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
postureId ↔ String?
The posture used in the deployment, in the format organizations/{organization}/locations/global/postures/{posture_id}.
getter/setter pair
postureRevisionId ↔ String?
The revision ID of the posture used in the deployment.
getter/setter pair
reconciling ↔ bool?
Whether the posture deployment is in the process of being updated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the posture deployment.
getter/setter pair
targetResource ↔ String?
The organization, folder, or project where the posture is deployed.
getter/setter pair
updateTime ↔ String?
The time at which the posture deployment was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited