PostureDetails class

Details of a posture deployment.

Constructors

PostureDetails({String? policySet, String? posture, String? postureDeployment, String? postureDeploymentTargetResource, String? postureRevisionId})
PostureDetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
policySet ↔ String?
The identifier for the PolicySet that the relevant policy belongs to.
getter/setter pair
posture ↔ String?
The posture used in the deployment, in the format organizations/{organization}/locations/global/postures/{posture_id}.
getter/setter pair
postureDeployment ↔ String?
The name of the posture deployment, in the format organizations/{organization}/locations/global/postureDeployments/{deployment_id}.
getter/setter pair
postureDeploymentTargetResource ↔ String?
The organization, folder, or project where the posture is deployed.
getter/setter pair
postureRevisionId ↔ String?
The revision ID of the posture used in the deployment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited