Property class

A name-value pair used as a custom source property.

Constructors

Property({String? name, Expr? valueExpression})
Property.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the custom source property.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueExpression ↔ Expr?
The CEL expression for the value of the custom source property.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited