ResourceTypes class

Set multiple resource types for one policy, for example: ``` resourceTypes: included: - compute.googleapis.com/Instance - compute.googleapis.com/Disk

support multiple resource types in the policy.

Only supports managed constraints. Method type is `GOVERN_TAGS`.

Constructors

ResourceTypes({List<String>? included})
ResourceTypes.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
included ↔ List<String>?
The resource types we support.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited