SecurityHealthAnalyticsCustomModule class

A custom module for Security Health Analytics.

Constructors

SecurityHealthAnalyticsCustomModule({CustomConfig? config, String? displayName, String? id, String? moduleEnablementState})
SecurityHealthAnalyticsCustomModule.fromJson(Map json_)

Properties

config ↔ CustomConfig?
Configuration settings for the custom module.
getter/setter pair
displayName ↔ String?
The display name of the custom module.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the custom module.
getter/setter pair
moduleEnablementState ↔ String?
Whether the custom module is enabled at a specified level of the resource hierarchy. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited