Violation class

Details of a violation.

Constructors

Violation({String? assetId, String? nextSteps, String? policyId, String? severity, AssetDetails? violatedAsset, PolicyDetails? violatedPolicy, PostureDetails? violatedPosture})
Violation.fromJson(Map json_)

Properties

assetId ↔ String?
The full resource name of the asset that caused the violation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextSteps ↔ String?
A description of the steps that you can take to fix the violation.
getter/setter pair
policyId ↔ String?
The policy that was violated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of the violation. Possible string values are:
getter/setter pair
violatedAsset ↔ AssetDetails?
Details of the Cloud Asset Inventory asset that caused the violation.
getter/setter pair
violatedPolicy ↔ PolicyDetails?
Details of the policy that was violated.
getter/setter pair
violatedPosture ↔ PostureDetails?
Details for the posture that was violated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited