AddTenantProjectRequest class

Request to add a newly created and configured tenant project to a tenancy unit.

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectConfig ↔ TenantProjectConfig?
Configuration of the new tenant project to be added to tenancy unit resources.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String?
Tag of the added project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited