ApplyTenantProjectConfigRequest class

Request to apply configuration to an existing tenant project.

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectConfig ↔ TenantProjectConfig?
Configuration that should be applied to the existing tenant project.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String?
Tag of the project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited