AttachTenantProjectRequest class

Request to attach an existing project to the tenancy unit as a new tenant resource.

Constructors

AttachTenantProjectRequest({String? externalResource, String? reservedResource, String? tag})
AttachTenantProjectRequest.fromJson(Map json_)

Properties

externalResource ↔ String?
When attaching an external project, this is in the format of projects/{project_number}.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reservedResource ↔ String?
When attaching a reserved project already in tenancy units, this is the tag of a tenant resource under the tenancy unit for the managed service's service producer project.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ String?
Tag of the tenant resource after attachment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited