ServiceAccountConfig class

Describes the service account configuration for the tenant project.

Constructors

ServiceAccountConfig({String? accountId, List<String>? tenantProjectRoles})
ServiceAccountConfig.fromJson(Map json_)

Properties

accountId ↔ String?
ID of the IAM service account to be created in tenant project.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenantProjectRoles ↔ List<String>?
Roles for the associated service account for the tenant project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited