TenantProjectConfig class

This structure defines a tenant project to be added to the specified tenancy unit and its initial configuration and properties.

A project lien is created for the tenant project to prevent the tenant project from being deleted accidentally. The lien is deleted as part of tenant project removal.

Constructors

TenantProjectConfig({BillingConfig? billingConfig, String? folder, Map<String, String>? labels, ServiceAccountConfig? serviceAccountConfig, List<String>? services, TenantProjectPolicy? tenantProjectPolicy})
TenantProjectConfig.fromJson(Map json_)

Properties

billingConfig ↔ BillingConfig?
Billing account properties.
getter/setter pair
folder ↔ String?
Folder where project in this tenancy unit must be located This folder must have been previously created with the required permissions for the caller to create and configure a project in it.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
Labels that are applied to this project.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountConfig ↔ ServiceAccountConfig?
Configuration for the IAM service account on the tenant project.
getter/setter pair
services ↔ List<String>?
Google Cloud API names of services that are activated on this project during provisioning.
getter/setter pair
tenantProjectPolicy ↔ TenantProjectPolicy?
Describes ownership and policies for the new tenant project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited