CheckRequest class

Request message for the Check method.

Constructors

CheckRequest({Operation? operation, bool? requestProjectSettings, String? serviceConfigId, bool? skipActivationCheck})
CheckRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operation ↔ Operation?
The operation to be checked.
getter/setter pair
requestProjectSettings ↔ bool?
Requests the project settings to be returned as part of the check response.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceConfigId ↔ String?
Specifies which version of service configuration should be used to process the request.
getter/setter pair
skipActivationCheck ↔ bool?
Indicates if service activation check should be skipped for this request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited