CheckResponse class

Response message for the Check method.

Constructors

CheckResponse({List<CheckError>? checkErrors, CheckInfo? checkInfo, String? operationId, QuotaInfo? quotaInfo, String? serviceConfigId, String? serviceRolloutId})
CheckResponse.fromJson(Map json_)

Properties

checkErrors ↔ List<CheckError>?
Indicate the decision of the check.
getter/setter pair
checkInfo ↔ CheckInfo?
Feedback data returned from the server during processing a Check request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
operationId ↔ String?
The same operation_id value used in the CheckRequest.
getter/setter pair
quotaInfo ↔ QuotaInfo?
Quota information for the check request associated with this response.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceConfigId ↔ String?
The actual config id used to process the request.
getter/setter pair
serviceRolloutId ↔ String?
The current service rollout id used to process the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited