MetricValue class

Represents a single metric value.

Constructors

MetricValue({bool? boolValue, Distribution? distributionValue, double? doubleValue, String? endTime, String? int64Value, Map<String, String>? labels, Money? moneyValue, String? startTime, String? stringValue})
MetricValue.fromJson(Map json_)

Properties

boolValue ↔ bool?
A boolean value.
getter/setter pair
distributionValue ↔ Distribution?
A distribution value.
getter/setter pair
doubleValue ↔ double?
A double precision floating point value.
getter/setter pair
endTime ↔ String?
The end of the time period over which this metric value's measurement applies.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
int64Value ↔ String?
A signed 64-bit integer value.
getter/setter pair
labels ↔ Map<String, String>?
The labels describing the metric value.
getter/setter pair
moneyValue ↔ Money?
A money value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The start of the time period over which this metric value's measurement applies.
getter/setter pair
stringValue ↔ String?
A text string value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited