MetricValueSet class

Represents a set of metric values in the same metric.

Each metric value in the set should have a unique combination of start time, end time, and label values.

Constructors

MetricValueSet({String? metricName, List<MetricValue>? metricValues})
MetricValueSet.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metricName ↔ String?
The metric name defined in the service configuration.
getter/setter pair
metricValues ↔ List<MetricValue>?
The values in this metric.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited