Operation class

Represents information regarding an operation.

Constructors

Operation({String? consumerId, String? endTime, String? importance, Map<String, String>? labels, List<LogEntry>? logEntries, List<MetricValueSet>? metricValueSets, String? operationId, String? operationName, QuotaProperties? quotaProperties, List<ResourceInfo>? resources, String? startTime, List<TraceSpan>? traceSpans, Map<String, String>? userLabels})
Operation.fromJson(Map json_)

Properties

consumerId ↔ String?
Identity of the consumer who is using the service.
getter/setter pair
endTime ↔ String?
End time of the operation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importance ↔ String?
DO NOT USE.
getter/setter pair
labels ↔ Map<String, String>?
Labels describing the operation.
getter/setter pair
logEntries ↔ List<LogEntry>?
Represents information to be logged.
getter/setter pair
metricValueSets ↔ List<MetricValueSet>?
Represents information about this operation.
getter/setter pair
operationId ↔ String?
Identity of the operation.
getter/setter pair
operationName ↔ String?
Fully qualified name of the operation.
getter/setter pair
quotaProperties ↔ QuotaProperties?
Represents the properties needed for quota check.
getter/setter pair
resources ↔ List<ResourceInfo>?
The resources that are involved in the operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Start time of the operation.
getter/setter pair
traceSpans ↔ List<TraceSpan>?
A list of Cloud Trace spans.
getter/setter pair
userLabels ↔ Map<String, String>?
Private Preview.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited