ReportResponse class

Response message for the Report method.

Constructors

ReportResponse({List<ReportError>? reportErrors, String? serviceConfigId, String? serviceRolloutId})
ReportResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
reportErrors ↔ List<ReportError>?
Partial failures, one for each Operation in the request that failed processing.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceConfigId ↔ String?
The actual config id used to process the request.
getter/setter pair
serviceRolloutId ↔ String?
The current service rollout id used to process the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited