ResourceInfo class

Describes a resource associated with this operation.

Constructors

ResourceInfo({String? permission, String? resourceContainer, String? resourceLocation, String? resourceName})
ResourceInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
permission ↔ String?
The resource permission required for this request.
getter/setter pair
resourceContainer ↔ String?
The identifier of the parent of this resource instance.
getter/setter pair
resourceLocation ↔ String?
The location of the resource.
getter/setter pair
resourceName ↔ String?
Name of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited