ServicesResource class

Constructors

ServicesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allocateQuota(AllocateQuotaRequest request, String serviceName, {String? $fields}) → Future<AllocateQuotaResponse>
Attempts to allocate quota for the specified consumer.
check(CheckRequest request, String serviceName, {String? $fields}) → Future<CheckResponse>
Checks whether an operation on a service should be allowed to proceed based on the configuration of the service and related policies.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report(ReportRequest request, String serviceName, {String? $fields}) → Future<ReportResponse>
Reports operation results to Google Service Control, such as logs and metrics.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited