Api class

This message defines attributes associated with API operations, such as a network API request.

The terminology is based on the conventions used by Google APIs, Istio, and OpenAPI.

Constructors

Api({String? operation, String? protocol, String? service, String? version})
Api.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operation ↔ String?
The API operation name.
getter/setter pair
protocol ↔ String?
The API protocol used for sending the request, such as "http", "https", "grpc", or "internal".
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
The API service name.
getter/setter pair
version ↔ String?
The API version associated with the API operation above, such as "v1" or "v1alpha1".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited