Auth class

This message defines request authentication attributes.

Terminology is based on the JSON Web Token (JWT) standard, but the terms also correlate to concepts in other standards.

Constructors

Auth({List<String>? accessLevels, List<String>? audiences, Map<String, Object?>? claims, String? credentialId, Oauth? oauth, String? presenter, String? principal})
Auth.fromJson(Map json_)

Properties

accessLevels ↔ List<String>?
A list of access level resource names that allow resources to be accessed by authenticated requester.
getter/setter pair
audiences ↔ List<String>?
The intended audience(s) for this authentication information.
getter/setter pair
claims ↔ Map<String, Object?>?
Structured claims presented with the credential.
getter/setter pair
credentialId ↔ String?
Identifies the client credential id used for authentication.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
oauth ↔ Oauth?
Attributes of the OAuth token associated with the request.
getter/setter pair
presenter ↔ String?
The authorized presenter of the credential.
getter/setter pair
principal ↔ String?
The authenticated principal.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited