CheckResponse class

Response message for the Check method.

Constructors

CheckResponse({Map<String, Object?>? dynamicMetadata, Map<String, String>? headers, Status? status})
CheckResponse.fromJson(Map json_)

Properties

dynamicMetadata ↔ Map<String, Object?>?
Optional response metadata that will be emitted as dynamic metadata to be consumed by the caller of ServiceController.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headers ↔ Map<String, String>?
Returns a set of request contexts generated from the CheckRequest.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ Status?
Operation is allowed when this field is not set.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited