Peer class

This message defines attributes for a node that handles a network request.

The node can be either a service or an application that sends, forwards, or receives the request. Service peers should fill in principal and labels as appropriate.

Constructors

Peer({String? ip, Map<String, String>? labels, String? port, String? principal, String? regionCode})
Peer.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ip ↔ String?
The IP address of the peer.
getter/setter pair
labels ↔ Map<String, String>?
The labels associated with the peer.
getter/setter pair
port ↔ String?
The network port of the peer.
getter/setter pair
principal ↔ String?
The identity of this peer.
getter/setter pair
regionCode ↔ String?
The CLDR country/region code associated with the above IP address.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited