ReportRequest class

Request message for the Report method.

Constructors

ReportRequest({List<AttributeContext>? operations, String? serviceConfigId})
ReportRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
operations ↔ List<AttributeContext>?
Describes the list of operations to be reported.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceConfigId ↔ String?
Specifies the version of the service configuration that should be used to process the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited