Resource class

This message defines core attributes for a resource.

A resource is an addressable (named) entity provided by the destination service. For example, a file stored on a network storage service.

Constructors

Resource({Map<String, String>? annotations, String? createTime, String? deleteTime, String? displayName, String? etag, Map<String, String>? labels, String? location, String? name, String? service, String? type, String? uid, String? updateTime})
Resource.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Annotations is an unstructured key-value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
getter/setter pair
createTime ↔ String?
The timestamp when the resource was created.
getter/setter pair
deleteTime ↔ String?
The timestamp when the resource was deleted.
getter/setter pair
displayName ↔ String?
Mutable.
getter/setter pair
etag ↔ String?
An opaque value that uniquely identifies a version or generation of a resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels or tags on the resource, such as AWS resource tags and Kubernetes resource labels.
getter/setter pair
location ↔ String?
The location of the resource.
getter/setter pair
name ↔ String?
The stable identifier (name) of a resource on the service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
The name of the service that this resource belongs to, such as pubsub.googleapis.com.
getter/setter pair
type ↔ String?
The type of the resource.
getter/setter pair
uid ↔ String?
The unique identifier of the resource.
getter/setter pair
updateTime ↔ String?
The timestamp when the resource was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited