ServicesResource class

Constructors

ServicesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

check(CheckRequest request, String serviceName, {String? $fields}) → Future<CheckResponse>
This method provides admission control for services that are integrated with Service Infrastructure.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
report(ReportRequest request, String serviceName, {String? $fields}) → Future<ReportResponse>
This method provides telemetry reporting for services that are integrated with Service Infrastructure.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited