Backend class

Backend defines the backend configuration for a service.

Constructors

Backend({List<BackendRule>? rules})
Backend.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
rules ↔ List<BackendRule>?
A list of API backend rules that apply to individual API methods.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited