BackendRule class

A backend rule provides configuration for an individual API element.

Constructors

BackendRule({String? address, double? deadline, bool? disableAuth, String? jwtAudience, String? loadBalancingPolicy, double? minDeadline, double? operationDeadline, Map<String, BackendRule>? overridesByRequestProtocol, String? pathTranslation, String? protocol, String? selector})
BackendRule.fromJson(Map json_)

Properties

address ↔ String?
The address of the API backend.
getter/setter pair
deadline ↔ double?
The number of seconds to wait for a response from a request.
getter/setter pair
disableAuth ↔ bool?
When disable_auth is true, a JWT ID token won't be generated and the original "Authorization" HTTP header will be preserved.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jwtAudience ↔ String?
The JWT audience is used when generating a JWT ID token for the backend.
getter/setter pair
loadBalancingPolicy ↔ String?
The load balancing policy used for connection to the application backend.
getter/setter pair
minDeadline ↔ double?
Deprecated, do not use.
getter/setter pair
operationDeadline ↔ double?
The number of seconds to wait for the completion of a long running operation.
getter/setter pair
overridesByRequestProtocol ↔ Map<String, BackendRule>?
The map between request protocol and the backend address.
getter/setter pair
pathTranslation ↔ String?
Path translation specifies how to combine the backend address with the request path in order to produce the appropriate forwarding URL for the request.
getter/setter pair
protocol ↔ String?
The protocol used for sending a request to the backend.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector ↔ String?
Selects the methods to which this rule applies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited