pathTranslation property

String? pathTranslation
getter/setter pair

Path translation specifies how to combine the backend address with the request path in order to produce the appropriate forwarding URL for the request.

See PathTranslation for more details. Possible string values are:

Implementation

core.String? pathTranslation;