BatchingConfigProto class

BatchingConfigProto defines the batching configuration for an API method.

Properties

batchDescriptor ↔ BatchingDescriptorProto?
The request and response fields used in batching.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thresholds ↔ BatchingSettingsProto?
The thresholds which trigger a batched request to be sent.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited