BillingDestination class

Configuration of a specific billing destination (Currently only support bill against consumer project).

Constructors

BillingDestination({List<String>? metrics, String? monitoredResource})
BillingDestination.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ List<String>?
Names of the metrics to report to this billing destination.
getter/setter pair
monitoredResource ↔ String?
The monitored resource type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited