ClientLibrarySettings class

Details about how and where to publish client libraries.

Constructors

ClientLibrarySettings({CppSettings? cppSettings, DotnetSettings? dotnetSettings, GoSettings? goSettings, JavaSettings? javaSettings, String? launchStage, NodeSettings? nodeSettings, PhpSettings? phpSettings, PythonSettings? pythonSettings, bool? restNumericEnums, RubySettings? rubySettings, String? version})
ClientLibrarySettings.fromJson(Map json_)

Properties

cppSettings ↔ CppSettings?
Settings for C++ client libraries.
getter/setter pair
dotnetSettings ↔ DotnetSettings?
Settings for .NET client libraries.
getter/setter pair
goSettings ↔ GoSettings?
Settings for Go client libraries.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
javaSettings ↔ JavaSettings?
Settings for legacy Java features, supported in the Service YAML.
getter/setter pair
launchStage ↔ String?
Launch stage of this version of the API. Possible string values are:
getter/setter pair
nodeSettings ↔ NodeSettings?
Settings for Node client libraries.
getter/setter pair
phpSettings ↔ PhpSettings?
Settings for PHP client libraries.
getter/setter pair
pythonSettings ↔ PythonSettings?
Settings for Python client libraries.
getter/setter pair
restNumericEnums ↔ bool?
When using transport=rest, the client request will encode enums as numbers rather than strings.
getter/setter pair
rubySettings ↔ RubySettings?
Settings for Ruby client libraries.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
Version of the API to apply these settings to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited