ConfigFile class

Generic specification of a source configuration file

Constructors

ConfigFile({String? fileContents, String? filePath, String? fileType})
ConfigFile.fromJson(Map json_)

Properties

fileContents ↔ String?
The bytes that constitute the file.
getter/setter pair
fileContentsAsBytes ↔ List<int>
getter/setter pair
filePath ↔ String?
The file name of the configuration file (full or relative path).
getter/setter pair
fileType ↔ String?
The type of configuration file this represents. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited