ContextRule class

A context rule provides information about the context for an individual API element.

Constructors

ContextRule({List<String>? allowedRequestExtensions, List<String>? allowedResponseExtensions, List<String>? provided, List<String>? requested, String? selector})
ContextRule.fromJson(Map json_)

Properties

allowedRequestExtensions ↔ List<String>?
A list of full type names or extension IDs of extensions allowed in grpc side channel from client to backend.
getter/setter pair
allowedResponseExtensions ↔ List<String>?
A list of full type names or extension IDs of extensions allowed in grpc side channel from backend to client.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
provided ↔ List<String>?
A list of full type names of provided contexts.
getter/setter pair
requested ↔ List<String>?
A list of full type names of requested contexts, only the requested context will be made available to the backend.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector ↔ String?
Selects the methods to which this rule applies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited