CustomError class

Customize service error responses.

For example, list any service specific protobuf types that can appear in error detail lists of error responses. Example: custom_error: types: - google.foo.v1.CustomError - google.foo.v1.AnotherError

Constructors

CustomError({List<CustomErrorRule>? rules, List<String>? types})
CustomError.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
rules ↔ List<CustomErrorRule>?
The list of custom error rules that apply to individual API messages.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types ↔ List<String>?
The list of custom error detail types, e.g. 'google.foo.v1.CustomError'.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited