CustomErrorRule class

A custom error rule.

Constructors

CustomErrorRule({bool? isErrorType, String? selector})
CustomErrorRule.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isErrorType ↔ bool?
Mark this message as possible payload in error response.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector ↔ String?
Selects messages to which this rule applies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited