Field class

A single field of a message type.

New usages of this message as an alternative to FieldDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Constructors

Field({String? cardinality, String? defaultValue, String? jsonName, String? kind, String? name, int? number, int? oneofIndex, List<Option>? options, bool? packed, String? typeUrl})
Field.fromJson(Map json_)

Properties

cardinality ↔ String?
The field cardinality. Possible string values are:
getter/setter pair
defaultValue ↔ String?
The string value of the default value of this field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
jsonName ↔ String?
The field JSON name.
getter/setter pair
kind ↔ String?
The field type. Possible string values are:
getter/setter pair
name ↔ String?
The field name.
getter/setter pair
number ↔ int?
The field number.
getter/setter pair
oneofIndex ↔ int?
The index of the field type in Type.oneofs, for message or enumeration types.
getter/setter pair
options ↔ List<Option>?
The protocol buffer options.
getter/setter pair
packed ↔ bool?
Whether to use alternative packed wire representation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeUrl ↔ String?
The field type URL, without the scheme, for message or enumeration types.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited