JavaSettings class

Settings for Java client libraries.

Constructors

JavaSettings({CommonLanguageSettings? common, String? libraryPackage, Map<String, String>? serviceClassNames})
JavaSettings.fromJson(Map json_)

Properties

common ↔ CommonLanguageSettings?
Some settings.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
libraryPackage ↔ String?
The package name to use in Java.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceClassNames ↔ Map<String, String>?
Configure the Java class name to use instead of the service's for its corresponding generated GAPIC client.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited