LoggingDestination class

Configuration of a specific logging destination (the producer project or the consumer project).

Constructors

LoggingDestination({List<String>? logs, String? monitoredResource})
LoggingDestination.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logs ↔ List<String>?
Names of the logs to be sent to this destination.
getter/setter pair
monitoredResource ↔ String?
The monitored resource type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited