LongRunning class

Describes settings to use when generating API methods that use the long-running operation pattern.

All default values below are from those used in the client library generators (e.g. Java).

Constructors

LongRunning({String? initialPollDelay, String? maxPollDelay, double? pollDelayMultiplier, String? totalPollTimeout})
LongRunning.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
initialPollDelay ↔ String?
Initial delay after which the first poll request will be made.
getter/setter pair
maxPollDelay ↔ String?
Maximum time between two subsequent poll requests.
getter/setter pair
pollDelayMultiplier ↔ double?
Multiplier to gradually increase delay between subsequent polls until it reaches max_poll_delay.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalPollTimeout ↔ String?
Total polling timeout.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited