SubmitConfigSourceRequest class

Request message for SubmitConfigSource method.

Constructors

SubmitConfigSourceRequest({ConfigSource? configSource, bool? validateOnly})
SubmitConfigSourceRequest.fromJson(Map json_)

Properties

configSource ↔ ConfigSource?
The source configuration for the service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
If set, this will result in the generation of a google.api.Service configuration based on the ConfigSource provided, but the generated config and the sources will NOT be persisted.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited