SystemParameterRule class

Define a system parameter rule mapping system parameter definitions to methods.

Constructors

SystemParameterRule({List<SystemParameter>? parameters, String? selector})
SystemParameterRule.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameters ↔ List<SystemParameter>?
Define parameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selector ↔ String?
Selects the methods to which this rule applies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited