SystemParameters class

System parameter configuration A system parameter is a special kind of

parameter defined by the API system, not by an individual API.

It is typically mapped to an HTTP header and/or a URL query parameter. This configuration specifies which methods change the names of the system parameters.

Properties

hashCode → int
The hash code for this object.
no setterinherited
rules ↔ List<SystemParameterRule>?
Define system parameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited