Type class

A protocol buffer message type.

New usages of this message as an alternative to DescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Constructors

Type({String? edition, List<Field>? fields, String? name, List<String>? oneofs, List<Option>? options, SourceContext? sourceContext, String? syntax})
Type.fromJson(Map json_)

Properties

edition ↔ String?
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
getter/setter pair
fields ↔ List<Field>?
The list of fields.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The fully qualified message name.
getter/setter pair
oneofs ↔ List<String>?
The list of types appearing in oneof definitions in this type.
getter/setter pair
options ↔ List<Option>?
The protocol buffer options.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceContext ↔ SourceContext?
The source context.
getter/setter pair
syntax ↔ String?
The source syntax. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited