AddDnsZoneRequest class

Request to add a private managed DNS zone in the shared producer host project and a matching DNS peering zone in the consumer project.

Constructors

AddDnsZoneRequest({String? consumerNetwork, String? dnsSuffix, String? name})
AddDnsZoneRequest.fromJson(Map json_)

Properties

consumerNetwork ↔ String?
The network that the consumer is using to connect with services.
getter/setter pair
dnsSuffix ↔ String?
The DNS name suffix for the zones e.g. example.com..
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name for both the private zone in the shared producer host project and the peering zone in the consumer project.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited