AddSubnetworkRequest class

Request to create a subnetwork in a previously peered service network.

Constructors

AddSubnetworkRequest({bool? allowSubnetCidrRoutesOverlap, bool? checkServiceNetworkingUsePermission, String? computeIdempotencyWindow, String? consumer, String? consumerNetwork, String? description, String? internalRange, int? ipPrefixLength, String? outsideAllocationPublicIpRange, String? privateIpv6GoogleAccess, String? purpose, String? region, String? requestedAddress, List<String>? requestedRanges, String? role, List<SecondaryIpRangeSpec>? secondaryIpRangeSpecs, bool? skipRequestedAddressValidation, String? subnetwork, List<String>? subnetworkUsers, bool? useCustomComputeIdempotencyWindow})
AddSubnetworkRequest.fromJson(Map json_)

Properties

allowSubnetCidrRoutesOverlap ↔ bool?
Defines the allowSubnetCidrRoutesOverlap field of the subnet, e.g. Available in alpha and beta according to Compute API documentation
getter/setter pair
checkServiceNetworkingUsePermission ↔ bool?
The IAM permission check determines whether the consumer project has 'servicenetworking.services.use' permission or not.
getter/setter pair
computeIdempotencyWindow ↔ String?
Specifies a custom time bucket for GCE subnetwork request idempotency.
getter/setter pair
consumer ↔ String?
A resource that represents the service consumer, such as projects/123456.
getter/setter pair
consumerNetwork ↔ String?
The name of the service consumer's VPC network.
getter/setter pair
description ↔ String?
Description of the subnet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalRange ↔ String?
The url of an Internal Range.
getter/setter pair
ipPrefixLength ↔ int?
The prefix length of the subnet's IP address range.
getter/setter pair
outsideAllocationPublicIpRange ↔ String?
Enable outside allocation using public IP addresses.
getter/setter pair
privateIpv6GoogleAccess ↔ String?
The private IPv6 google access type for the VMs in this subnet.
getter/setter pair
purpose ↔ String?
Defines the purpose field of the subnet, e.g. 'PRIVATE_SERVICE_CONNECT'.
getter/setter pair
region ↔ String?
The name of a region for the subnet, such europe-west1.
getter/setter pair
requestedAddress ↔ String?
The starting address of a range.
getter/setter pair
requestedRanges ↔ List<String>?
The name of one or more allocated IP address ranges associated with this private service access connection.
getter/setter pair
role ↔ String?
Defines the role field of the subnet, e.g. 'ACTIVE'.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryIpRangeSpecs ↔ List<SecondaryIpRangeSpec>?
A list of secondary IP ranges to be created within the new subnetwork.
getter/setter pair
skipRequestedAddressValidation ↔ bool?
Skips validating if the requested_address is in use by SN VPC’s peering group.
getter/setter pair
subnetwork ↔ String?
A name for the new subnet.
getter/setter pair
subnetworkUsers ↔ List<String>?
A list of members that are granted the roles/servicenetworking.subnetworkAdmin role on the subnet.
getter/setter pair
useCustomComputeIdempotencyWindow ↔ bool?
Specifies if Service Networking should use a custom time bucket for GCE idempotency.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited