CloudSQLConfig class

Cloud SQL configuration.

Constructors

CloudSQLConfig({String? service, String? umbrellaNetwork, String? umbrellaProject})
CloudSQLConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
Peering service used for peering with the Cloud SQL project.
getter/setter pair
umbrellaNetwork ↔ String?
The name of the umbrella network in the Cloud SQL umbrella project.
getter/setter pair
umbrellaProject ↔ String?
The project number of the Cloud SQL umbrella project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited