UpdateConsumerConfigRequest class

Request to update the configuration of a service networking connection including the import/export of custom routes and subnetwork routes with public IP.

Properties

consumerConfig ↔ ConsumerConfig?
The updated peering config.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited