ValidateConsumerConfigResponse class

Constructors

ValidateConsumerConfigResponse({List<Subnetwork>? existingSubnetworkCandidates, bool? isValid, String? validationError})
ValidateConsumerConfigResponse.fromJson(Map json_)

Properties

existingSubnetworkCandidates ↔ List<Subnetwork>?
List of subnetwork candidates from the request which exist with the ip_cidr_range, secondary_ip_cider_ranges, and outside_allocation fields set.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isValid ↔ bool?
Indicates whether all the requested validations passed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validationError ↔ String?
The first validation which failed. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited