Authentication class

Authentication defines the authentication configuration for API methods provided by an API service.

Example: name: calendar.googleapis.com authentication: providers: - id: google_calendar_auth jwks_uri: https://www.googleapis.com/oauth2/v1/certs issuer: https://securetoken.google.com rules: - selector: "*" requirements: provider_id: google_calendar_auth - selector: google.calendar.Delegate oauth: canonical_scopes: https://www.googleapis.com/auth/calendar.read

Constructors

Authentication({List<AuthProvider>? providers, List<AuthenticationRule>? rules})
Authentication.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
providers ↔ List<AuthProvider>?
Defines a set of authentication providers that a service supports.
getter/setter pair
rules ↔ List<AuthenticationRule>?
A list of authentication rules that apply to individual API methods.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited