ListServicesResponse class

Response message for the ListServices method.

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token that can be passed to ListServices to resume a paginated query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
services ↔ List<GoogleApiServiceusageV1Service>?
The available services for the requested project.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited