Method class

Method represents a method of an API interface.

New usages of this message as an alternative to MethodDescriptorProto are strongly discouraged. This message does not reliability preserve all information necessary to model the schema and preserve semantics. Instead make use of FileDescriptorSet which preserves the necessary information.

Constructors

Method({String? edition, String? name, List<Option>? options, bool? requestStreaming, String? requestTypeUrl, bool? responseStreaming, String? responseTypeUrl, String? syntax})
Method.fromJson(Map json_)

Properties

edition ↔ String?
The source edition string, only valid when syntax is SYNTAX_EDITIONS.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The simple name of this method.
getter/setter pair
options ↔ List<Option>?
Any metadata attached to the method.
getter/setter pair
requestStreaming ↔ bool?
If true, the request is streamed.
getter/setter pair
requestTypeUrl ↔ String?
A URL of the input message type.
getter/setter pair
responseStreaming ↔ bool?
If true, the response is streamed.
getter/setter pair
responseTypeUrl ↔ String?
The URL of the output message type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syntax ↔ String?
The source syntax of this method.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited