Page class

Represents a documentation page.

A page can contain subpages to represent nested documentation set structure.

Constructors

Page({String? content, String? name, List<Page>? subpages})
Page.fromJson(Map json_)

Properties

content ↔ String?
The Markdown content of the page.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subpages ↔ List<Page>?
Subpages of this page.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited