Usage class

Configuration controlling usage of a service.

Constructors

Usage({String? producerNotificationChannel, List<String>? requirements, List<UsageRule>? rules})
Usage.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
producerNotificationChannel ↔ String?
The full resource name of a channel used for sending notifications to the service producer.
getter/setter pair
requirements ↔ List<String>?
Requirements that must be satisfied before a consumer project can use the service.
getter/setter pair
rules ↔ List<UsageRule>?
A list of usage rules that apply to individual API methods.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited