$AccountActiveAdSummary class

Used by:

  • dfareporting:v4 : AccountActiveAdSummary
  • dfareporting:v5 : AccountActiveAdSummary

Constructors

$AccountActiveAdSummary({String? accountId, String? activeAds, String? activeAdsLimitTier, String? availableAds, String? kind})
$AccountActiveAdSummary.fromJson(Map json_)

Properties

accountId ↔ String?
ID of the account.
getter/setter pair
activeAds ↔ String?
Ads that have been activated for the account
getter/setter pair
activeAdsLimitTier ↔ String?
Maximum number of active ads allowed for the account. Possible string values are:
getter/setter pair
availableAds ↔ String?
Ads that can be activated for the account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited