$AccountPermission class

Used by:

  • dfareporting:v4 : AccountPermission
  • dfareporting:v5 : AccountPermission

Constructors

$AccountPermission({List<String>? accountProfiles, String? id, String? kind, String? level, String? name, String? permissionGroupId})
$AccountPermission.fromJson(Map json_)

Properties

accountProfiles ↔ List<String>?
Account profiles associated with this account permission.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this account permission.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
level ↔ String?
Administrative level required to enable this account permission. Possible string values are:
getter/setter pair
name ↔ String?
Name of this account permission.
getter/setter pair
permissionGroupId ↔ String?
Permission group of this account permission.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited