$AddRequestHeader class

Used by:

  • accesscontextmanager:v1 : AddRequestHeader
  • cloudasset:v1 : GoogleIdentityAccesscontextmanagerV1AddRequestHeader

Constructors

$AddRequestHeader({String? key, String? value})
$AddRequestHeader.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
key String?
HTTP header key.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
HTTP header value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited