$AdditionalContent class

Used by:

  • content:v2.1 : BuiltInSimpleActionAdditionalContent
  • merchantapi:issueresolution_v1 : AdditionalContent

Constructors

$AdditionalContent({List<String>? paragraphs, String? title})
$AdditionalContent.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
paragraphs ↔ List<String>?
Long text organized into paragraphs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title of the additional content;
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited