$AgentRequest class

Used by:

  • dialogflow:v2 : GoogleCloudDialogflowV2ImportAgentRequest
  • dialogflow:v2 : GoogleCloudDialogflowV2RestoreAgentRequest

Constructors

$AgentRequest({String? agentContent, String? agentUri})
$AgentRequest.fromJson(Map json_)

Properties

agentContent ↔ String?
getter/setter pair
agentContentAsBytes ↔ List<int>
getter/setter pair
agentUri ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited