$AgentTransfer class

Used by:

  • ces:v1 : AgentTransfer
  • contactcenterinsights:v1 : GoogleCloudCesV1mainAgentTransfer

Constructors

$AgentTransfer({String? displayName, String? targetAgent})
$AgentTransfer.fromJson(Map json_)

Properties

displayName String?
Display name of the agent.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetAgent String?
The agent to which the conversation is being transferred.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited