targetAgent property

String? targetAgent
getter/setter pair

The agent to which the conversation is being transferred.

The agent will handle the conversation from this point forward. Format: projects/{project}/locations/{location}/apps/{app}/agents/{agent}

Required.

Implementation

core.String? targetAgent;