$AllowedLocations class

Used by:

  • iamcredentials:v1 : ServiceAccountAllowedLocations
  • iamcredentials:v1 : WorkforcePoolAllowedLocations
  • iamcredentials:v1 : WorkloadIdentityPoolAllowedLocations

Constructors

$AllowedLocations({String? encodedLocations, List<String>? locations})
$AllowedLocations.fromJson(Map json_)

Properties

encodedLocations ↔ String?
The hex encoded bitmap of the trust boundary locations
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locations ↔ List<String>?
The human readable trust boundary locations.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited