$ArtifactsGcsSource class

Used by:

  • artifactregistry:v1 : ImportAptArtifactsGcsSource
  • artifactregistry:v1 : ImportYumArtifactsGcsSource

Constructors

$ArtifactsGcsSource({List<String>? uris, bool? useWildcards})
$ArtifactsGcsSource.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uris ↔ List<String>?
Cloud Storage paths URI (e.g., gs://my_bucket//my_object).
getter/setter pair
useWildcards ↔ bool?
Supports URI wildcards for matching multiple objects from a single URI.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited