$AudienceSegment class

Used by:

  • dfareporting:v4 : AudienceSegment
  • dfareporting:v5 : AudienceSegment

Constructors

$AudienceSegment({int? allocation, String? id, String? name})
$AudienceSegment.fromJson(Map json_)

Properties

allocation ↔ int?
Weight allocated to this segment.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this audience segment.
getter/setter pair
name ↔ String?
Name of this audience segment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited