$AuditAdvertiserResponse class

Used by:

  • displayvideo:v2 : AuditAdvertiserResponse
  • displayvideo:v3 : AuditAdvertiserResponse
  • displayvideo:v4 : AuditAdvertiserResponse

Constructors

$AuditAdvertiserResponse({String? adGroupCriteriaCount, String? campaignCriteriaCount, String? channelsCount, String? negativeKeywordListsCount, String? negativelyTargetedChannelsCount, String? usedCampaignsCount, String? usedInsertionOrdersCount, String? usedLineItemsCount})
$AuditAdvertiserResponse.fromJson(Map json_)

Properties

adGroupCriteriaCount ↔ String?
The number of individual targeting options from the following targeting types that are assigned to a line item under this advertiser.
getter/setter pair
campaignCriteriaCount ↔ String?
The number of individual targeting options from the following targeting types that are assigned to a line item under this advertiser.
getter/setter pair
channelsCount ↔ String?
The number of channels created under this advertiser.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
negativeKeywordListsCount ↔ String?
The number of negative keyword lists created under this advertiser.
getter/setter pair
negativelyTargetedChannelsCount ↔ String?
The number of negatively targeted channels created under this advertiser.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
usedCampaignsCount ↔ String?
The number of ACTIVE and PAUSED campaigns under this advertiser.
getter/setter pair
usedInsertionOrdersCount ↔ String?
The number of ACTIVE, PAUSED and DRAFT insertion orders under this advertiser.
getter/setter pair
usedLineItemsCount ↔ String?
The number of ACTIVE, PAUSED, and DRAFT line items under this advertiser.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited