$AuthProviderRequest class

Used by:

  • agentidentity:v1 : DisableAuthProviderRequest
  • agentidentity:v1 : EnableAuthProviderRequest
  • agentidentity:v1 : UndeleteAuthProviderRequest

Constructors

$AuthProviderRequest({String? requestId})
$AuthProviderRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
An optional request ID to identify requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited