$BillingProfile class

Used by:

  • dfareporting:v4 : BillingProfile
  • dfareporting:v5 : BillingProfile

Constructors

$BillingProfile({bool? consolidatedInvoice, String? countryCode, String? currencyCode, String? id, String? invoiceLevel, bool? isDefault, String? kind, String? name, String? paymentsAccountId, String? paymentsCustomerId, String? purchaseOrder, String? secondaryPaymentsCustomerId, String? status})
$BillingProfile.fromJson(Map json_)

Properties

consolidatedInvoice ↔ bool?
Consolidated invoice option for this billing profile.
getter/setter pair
countryCode ↔ String?
Country code of this billing profile.This is a read-only field.
getter/setter pair
currencyCode ↔ String?
Billing currency code in ISO 4217 format.This is a read-only field.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this billing profile.
getter/setter pair
invoiceLevel ↔ String?
Invoice level for this billing profile.
getter/setter pair
isDefault ↔ bool?
True if the billing profile is the account default profile.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
name ↔ String?
Name of this billing profile.
getter/setter pair
paymentsAccountId ↔ String?
The ID of the payment account the billing profile belongs to.
getter/setter pair
paymentsCustomerId ↔ String?
The ID of the payment customer the billing profile belongs to.
getter/setter pair
purchaseOrder ↔ String?
Purchase order (PO) for this billing profile.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryPaymentsCustomerId ↔ String?
The ID of the secondary payment customer the billing profile belongs to.
getter/setter pair
status ↔ String?
Status of this billing profile.This is a read-only field. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited