$BillingRateTieredRate class

Used by:

  • dfareporting:v4 : BillingRateTieredRate
  • dfareporting:v5 : BillingRateTieredRate

Constructors

$BillingRateTieredRate({String? highValue, String? lowValue, String? rateInMicros})
$BillingRateTieredRate.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
highValue ↔ String?
The maximum for this tier range.
getter/setter pair
lowValue ↔ String?
The minimum for this tier range.
getter/setter pair
rateInMicros ↔ String?
Rate in micros for this tier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited