$Blobstore2Info class

Used by:

  • firebaseappdistribution:v1 : GdataBlobstore2Info
  • walletobjects:v1 : Blobstore2Info

Constructors

$Blobstore2Info({String? blobGeneration, String? blobId, String? downloadExternalReadToken, String? downloadReadHandle, String? readToken, String? uploadFragmentListCreationInfo, String? uploadMetadataContainer})
$Blobstore2Info.fromJson(Map json_)

Properties

blobGeneration ↔ String?
The blob generation id.
getter/setter pair
blobId ↔ String?
The blob id, e.g., /blobstore/prod/playground/scotty
getter/setter pair
downloadExternalReadToken ↔ String?
A serialized External Read Token passed from Bigstore -> Scotty for a GCS download.
getter/setter pair
downloadExternalReadTokenAsBytes ↔ List<int>
getter/setter pair
downloadReadHandle ↔ String?
Read handle passed from Bigstore -> Scotty for a GCS download.
getter/setter pair
downloadReadHandleAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readToken ↔ String?
The blob read token.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uploadFragmentListCreationInfo ↔ String?
A serialized Object Fragment List Creation Info passed from Bigstore -> Scotty for a GCS upload.
getter/setter pair
uploadFragmentListCreationInfoAsBytes ↔ List<int>
getter/setter pair
uploadMetadataContainer ↔ String?
Metadata passed from Blobstore -> Scotty for a new GCS upload.
getter/setter pair
uploadMetadataContainerAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited