$CVSS class
Used by:
- containeranalysis:v1 : CVSS
- ondemandscanning:v1 : CVSS
Constructors
- $CVSS({String? attackComplexity, String? attackRequirements, String? attackVector, String? authentication, String? availabilityImpact, double? baseScore, String? confidentialityImpact, String? exploitMaturity, double? exploitabilityScore, double? impactScore, String? integrityImpact, String? privilegesRequired, String? scope, String? subsequentSystemAvailabilityImpact, String? subsequentSystemConfidentialityImpact, String? subsequentSystemIntegrityImpact, String? userInteraction, String? vulnerableSystemAvailabilityImpact, String? vulnerableSystemConfidentialityImpact, String? vulnerableSystemIntegrityImpact})
- $CVSS.fromJson(Map json_)
Properties
- attackComplexity ↔ String?
-
Attack Complexity (AC).
getter/setter pair
- attackRequirements ↔ String?
-
Attack Requirements (AT).
getter/setter pair
- attackVector ↔ String?
-
Attack Vector (AV).
getter/setter pair
- authentication ↔ String?
-
Authentication (Au).
getter/setter pair
- availabilityImpact ↔ String?
-
Availability Impact (A).
getter/setter pair
- baseScore ↔ double?
-
The base score is a function of the base metric scores.
getter/setter pair
- confidentialityImpact ↔ String?
-
Confidentiality Impact (C).
getter/setter pair
- exploitabilityScore ↔ double?
-
getter/setter pair
- exploitMaturity ↔ String?
-
Exploit Maturity (E).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- impactScore ↔ double?
-
getter/setter pair
- integrityImpact ↔ String?
-
Integrity Impact (I).
getter/setter pair
- privilegesRequired ↔ String?
-
Privileges Required (PR).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope ↔ String?
-
Scope (S).
getter/setter pair
- subsequentSystemAvailabilityImpact ↔ String?
-
Subsequent System Availability Impact (SA).
getter/setter pair
- subsequentSystemConfidentialityImpact ↔ String?
-
Subsequent System Confidentiality Impact (SC).
getter/setter pair
- subsequentSystemIntegrityImpact ↔ String?
-
Subsequent System Integrity Impact (SI).
getter/setter pair
- userInteraction ↔ String?
-
User Interaction (UI).
getter/setter pair
- vulnerableSystemAvailabilityImpact ↔ String?
-
Vulnerable System Availability Impact (VA).
getter/setter pair
- vulnerableSystemConfidentialityImpact ↔ String?
-
Vulnerable System Confidentiality Impact (VC).
getter/setter pair
- vulnerableSystemIntegrityImpact ↔ String?
-
Vulnerable System Integrity Impact (VI).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited