$CertChain class

Used by:

  • privateca:v1 : CertChain
  • redis:v1 : CertChain
  • redis:v1 : RegionalCertChain

Constructors

$CertChain({List<String>? certificates})
$CertChain.fromJson(Map json_)

Properties

certificates ↔ List<String>?
The certificates that form the CA chain, from leaf to root order.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited