$CertificateChains class

Used by:

  • cloudkms:v1 : CertificateChains
  • kmsinventory:v1 : GoogleCloudKmsV1KeyOperationAttestationCertificateChains

Constructors

$CertificateChains({List<String>? caviumCerts, List<String>? googleCardCerts, List<String>? googlePartitionCerts})
$CertificateChains.fromJson(Map json_)

Properties

caviumCerts ↔ List<String>?
Cavium certificate chain corresponding to the attestation.
getter/setter pair
googleCardCerts ↔ List<String>?
Google card certificate chain corresponding to the attestation.
getter/setter pair
googlePartitionCerts ↔ List<String>?
Google partition certificate chain corresponding to the attestation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited