$ChangeLog class

Used by:

  • dfareporting:v4 : ChangeLog
  • dfareporting:v5 : ChangeLog

Constructors

$ChangeLog({String? accountId, String? action, DateTime? changeTime, String? fieldName, String? id, String? kind, String? newValue, String? objectId, String? objectType, String? oldValue, String? subaccountId, String? transactionId, String? userProfileId, String? userProfileName})
$ChangeLog.fromJson(Map json_)

Properties

accountId ↔ String?
Account ID of the modified object.
getter/setter pair
action ↔ String?
Action which caused the change.
getter/setter pair
changeTime ↔ DateTime?
getter/setter pair
fieldName ↔ String?
Field name of the object which changed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this change log.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
newValue ↔ String?
New value of the object field.
getter/setter pair
objectId ↔ String?
ID of the object of this change log.
getter/setter pair
objectType ↔ String?
Object type of the change log.
getter/setter pair
oldValue ↔ String?
Old value of the object field.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subaccountId ↔ String?
Subaccount ID of the modified object.
getter/setter pair
transactionId ↔ String?
Transaction ID of this change log.
getter/setter pair
userProfileId ↔ String?
ID of the user who modified the object.
getter/setter pair
userProfileName ↔ String?
User profile name of the user who modified the object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited