$Channel00 class

Used by:

  • displayvideo:v2 : Channel
  • displayvideo:v3 : Channel
  • displayvideo:v4 : Channel

Constructors

$Channel00({String? advertiserId, String? channelId, String? displayName, String? name, String? negativelyTargetedLineItemCount, String? partnerId, String? positivelyTargetedLineItemCount})
$Channel00.fromJson(Map json_)

Properties

advertiserId ↔ String?
The ID of the advertiser that owns the channel.
getter/setter pair
channelId ↔ String?
The unique ID of the channel.
getter/setter pair
displayName ↔ String?
The display name of the channel.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the channel.
getter/setter pair
negativelyTargetedLineItemCount ↔ String?
Number of line items that are directly targeting this channel negatively.
getter/setter pair
partnerId ↔ String?
The ID of the partner that owns the channel.
getter/setter pair
positivelyTargetedLineItemCount ↔ String?
Number of line items that are directly targeting this channel positively.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited