$City class

Used by:

  • dfareporting:v4 : City
  • dfareporting:v5 : City

Constructors

$City({String? countryCode, String? countryDartId, String? dartId, String? kind, String? metroCode, String? metroDmaId, String? name, String? regionCode, String? regionDartId})
$City.fromJson(Map json_)

Properties

countryCode ↔ String?
Country code of the country to which this city belongs.
getter/setter pair
countryDartId ↔ String?
DART ID of the country to which this city belongs.
getter/setter pair
dartId ↔ String?
DART ID of this city.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
metroCode ↔ String?
Metro region code of the metro region (DMA) to which this city belongs.
getter/setter pair
metroDmaId ↔ String?
ID of the metro region (DMA) to which this city belongs.
getter/setter pair
name ↔ String?
Name of this city.
getter/setter pair
regionCode ↔ String?
Region code of the region to which this city belongs.
getter/setter pair
regionDartId ↔ String?
DART ID of the region to which this city belongs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited