$ClusterUpgradeIgnoredMembership class

Used by:

  • gkehub:v1 : ClusterUpgradeIgnoredMembership
  • gkehub:v2 : ClusterUpgradeIgnoredMembership

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoredTime ↔ String?
Time when the membership was first set to ignored.
getter/setter pair
reason ↔ String?
Reason why the membership is ignored.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited