$CombinedAudience class

Used by:

  • displayvideo:v2 : CombinedAudience
  • displayvideo:v3 : CombinedAudience
  • displayvideo:v4 : CombinedAudience

Constructors

$CombinedAudience({String? combinedAudienceId, String? displayName, String? name})
$CombinedAudience.fromJson(Map json_)

Properties

combinedAudienceId ↔ String?
The unique ID of the combined audience.
getter/setter pair
displayName ↔ String?
The display name of the combined audience.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the combined audience.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited