$Compression class

Used by:

  • analyticshub:v1 : Compression
  • pubsub:v1 : Compression

Constructors

$Compression({String? compressionAlgorithm, String? compressionMode})
$Compression.fromJson(Map json_)

Properties

compressionAlgorithm ↔ String?
Specifies the compression algorithm to use.
getter/setter pair
compressionMode ↔ String?
Specifies whether to compress or decompress the message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited