$ComputationBasedMetricSpec class
Used by:
- aiplatform:v1 : GoogleCloudAiplatformV1ComputationBasedMetricSpec
- aiplatform:v1 : GoogleCloudAiplatformV1EvaluationRunMetricComputationBasedMetricSpec
Constructors
-
$ComputationBasedMetricSpec({Map<
String, Object?> ? parameters, String? type}) - $ComputationBasedMetricSpec.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameters
↔ Map<
String, Object?> ? -
A map of parameters for the metric, e.g. {"rouge_type": "rougeL"}.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
The type of the computation based metric.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited