$ConfigManagementHierarchyControllerConfig class

Used by:

  • gkehub:v1 : ConfigManagementHierarchyControllerConfig
  • gkehub:v2 : ConfigManagementHierarchyControllerConfig

Constructors

$ConfigManagementHierarchyControllerConfig({bool? enableHierarchicalResourceQuota, bool? enablePodTreeLabels, bool? enabled})
$ConfigManagementHierarchyControllerConfig.fromJson(Map json_)

Properties

enabled ↔ bool?
Whether Hierarchy Controller is enabled in this cluster.
getter/setter pair
enableHierarchicalResourceQuota ↔ bool?
Whether hierarchical resource quota is enabled in this cluster.
getter/setter pair
enablePodTreeLabels ↔ bool?
Whether pod tree labels are enabled in this cluster.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited