$ConfigManagementPolicyControllerMigration class

Used by:

  • gkehub:v1 : ConfigManagementPolicyControllerMigration
  • gkehub:v2 : ConfigManagementPolicyControllerMigration

Properties

copyTime ↔ String?
Last time this membership spec was copied to PoCo feature.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stage ↔ String?
Stage of the migration. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited