$ConnectionStatus class

Used by:

  • connectors:v1 : ConnectionStatus
  • integrations:v1 : GoogleCloudConnectorsV1ConnectionStatus

Constructors

$ConnectionStatus({String? description, String? state, String? status})
$ConnectionStatus.fromJson(Map json_)

Properties

description ↔ String?
Description.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State. Possible string values are:
getter/setter pair
status ↔ String?
Status provides detailed information for the state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited