$ContactInfo class

Used by:

  • displayvideo:v3 : ContactInfo
  • displayvideo:v4 : ContactInfo

Constructors

$ContactInfo({String? countryCode, List<String>? hashedEmails, String? hashedFirstName, String? hashedLastName, List<String>? hashedPhoneNumbers, List<String>? zipCodes})
$ContactInfo.fromJson(Map json_)

Properties

countryCode ↔ String?
Country code of the member.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hashedEmails ↔ List<String>?
A list of SHA256 hashed email of the member.
getter/setter pair
hashedFirstName ↔ String?
SHA256 hashed first name of the member.
getter/setter pair
hashedLastName ↔ String?
SHA256 hashed last name of the member.
getter/setter pair
hashedPhoneNumbers ↔ List<String>?
A list of SHA256 hashed phone numbers of the member.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
zipCodes ↔ List<String>?
A list of zip codes of the member.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited