$ContentSourceMetaData class

Used by:

  • dfareporting:v4 : ContentSourceMetaData
  • dfareporting:v5 : ContentSourceMetaData

Constructors

$ContentSourceMetaData({String? charset, List<String>? fieldNames, int? rowNumber, String? separator})
$ContentSourceMetaData.fromJson(Map json_)

Properties

charset ↔ String?
The charset of the content source.
getter/setter pair
fieldNames ↔ List<String>?
The list of column names in the content source.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
rowNumber ↔ int?
The number of rows in the content source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
separator ↔ String?
The separator of the content source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited