$ContentThemeAssignedTargetingOptionDetails class

Used by:

  • displayvideo:v3 : ContentThemeAssignedTargetingOptionDetails
  • displayvideo:v4 : ContentThemeAssignedTargetingOptionDetails

Constructors

$ContentThemeAssignedTargetingOptionDetails({String? contentTheme, String? excludedContentTheme, String? excludedTargetingOptionId})
$ContentThemeAssignedTargetingOptionDetails.fromJson(Map json_)

Properties

contentTheme ↔ String?
An enum for the DV360 content theme classifier.
getter/setter pair
excludedContentTheme ↔ String?
An enum for the DV360 content theme classified to be EXCLUDED.
getter/setter pair
excludedTargetingOptionId ↔ String?
ID of the content theme to be EXCLUDED.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited