$ContentTypeInfo class

Used by:

  • firebaseappdistribution:v1 : GdataContentTypeInfo
  • walletobjects:v1 : ContentTypeInfo

Constructors

$ContentTypeInfo({String? bestGuess, String? fromBytes, String? fromFileName, String? fromFusionId, String? fromHeader, String? fromUrlPath, String? fusionIdDetectionMetadata})
$ContentTypeInfo.fromJson(Map json_)

Properties

bestGuess ↔ String?
Scotty's best guess of what the content type of the file is.
getter/setter pair
fromBytes ↔ String?
The content type of the file derived by looking at specific bytes (i.e. "magic bytes") of the actual file.
getter/setter pair
fromFileName ↔ String?
The content type of the file derived from the file extension of the original file name used by the client.
getter/setter pair
fromFusionId ↔ String?
The content type of the file detected by Fusion ID.
getter/setter pair
fromHeader ↔ String?
The content type of the file as specified in the request headers, multipart headers, or RUPIO start request.
getter/setter pair
fromUrlPath ↔ String?
The content type of the file derived from the file extension of the URL path.
getter/setter pair
fusionIdDetectionMetadata ↔ String?
Metadata information from Fusion ID detection.
getter/setter pair
fusionIdDetectionMetadataAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited