$ContextChildrenRequest class

Used by:

  • aiplatform:v1 : GoogleCloudAiplatformV1AddContextChildrenRequest
  • aiplatform:v1 : GoogleCloudAiplatformV1RemoveContextChildrenRequest

Properties

childContexts ↔ List<String>?
The resource names of the child Contexts.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited