$CryptoKeyVersionTemplate class

Used by:

  • cloudkms:v1 : CryptoKeyVersionTemplate
  • kmsinventory:v1 : GoogleCloudKmsV1CryptoKeyVersionTemplate

Constructors

$CryptoKeyVersionTemplate({String? algorithm, String? protectionLevel})
$CryptoKeyVersionTemplate.fromJson(Map json_)

Properties

algorithm ↔ String?
Algorithm to use when creating a CryptoKeyVersion based on this template.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
protectionLevel ↔ String?
ProtectionLevel to use when creating a CryptoKeyVersion based on this template.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited