$CustomVariable class

Used by:

  • datamanager:v1 : CustomVariable
  • datamanager:v1 : ItemCustomVariable

Constructors

$CustomVariable({List<String>? destinationReferences, String? value, String? variable})
$CustomVariable.fromJson(Map json_)

Properties

destinationReferences ↔ List<String>?
Reference string used to determine which of the Event.destination_references the custom variable should be sent to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The value to store for the custom variable.
getter/setter pair
variable ↔ String?
The name of the custom variable to set.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited