$CustomViewabilityMetricConfiguration class

Used by:

  • dfareporting:v4 : CustomViewabilityMetricConfiguration
  • dfareporting:v5 : CustomViewabilityMetricConfiguration

Constructors

$CustomViewabilityMetricConfiguration({bool? audible, int? timeMillis, int? timePercent, int? viewabilityPercent})
$CustomViewabilityMetricConfiguration.fromJson(Map json_)

Properties

audible ↔ bool?
Whether the video must be audible to count an impression.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeMillis ↔ int?
The time in milliseconds the video must play for the Custom Viewability Metric to count an impression.
getter/setter pair
timePercent ↔ int?
The percentage of video that must play for the Custom Viewability Metric to count an impression.
getter/setter pair
viewabilityPercent ↔ int?
The percentage of video that must be on screen for the Custom Viewability Metric to count an impression.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited