$DataLinkResponse class

Used by:

  • searchads360:v23 : GoogleAdsSearchads360V23Services__CreateDataLinkResponse
  • searchads360:v23 : GoogleAdsSearchads360V23Services__UpdateDataLinkResponse

Constructors

$DataLinkResponse({String? resourceName})
$DataLinkResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
resourceName String?
Returned for successful operations.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited