$DateRange class

Used by:

  • dfareporting:v4 : DateRange
  • dfareporting:v5 : DateRange

Constructors

$DateRange({DateTime? endDate, String? kind, String? relativeDateRange, DateTime? startDate})
$DateRange.fromJson(Map json_)

Properties

endDate ↔ DateTime?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of resource this is, in this case dfareporting#dateRange.
getter/setter pair
relativeDateRange ↔ String?
The date range relative to the date of when the report is run. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDate ↔ DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited