$DcmTrackingInfo class

Used by:

  • displayvideo:v3 : DcmTrackingInfo
  • displayvideo:v4 : DcmTrackingInfo

Constructors

$DcmTrackingInfo({String? creativeId, String? placementId, String? trackingAdId})
$DcmTrackingInfo.fromJson(Map json_)

Properties

creativeId String?
The DCM creative id.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
placementId String?
The DCM placement id.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackingAdId String?
The DCM tracking ad id.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited