aes256GcmChunkSize property
Chunk size used if content was encrypted with the AES 256 GCM Cipher.
Possible values are: - default - small
Implementation
core.String? aes256GcmChunkSize;
Chunk size used if content was encrypted with the AES 256 GCM Cipher.
Possible values are: - default - small
core.String? aes256GcmChunkSize;