wrappedKey property
The URL-safe Base64 encoded wrapped key used to encrypt the contents of the file.
Implementation
core.String? wrappedKey;
The URL-safe Base64 encoded wrapped key used to encrypt the contents of the file.
core.String? wrappedKey;