$DefaultClickThroughEventTagProperties class

Used by:

  • dfareporting:v4 : DefaultClickThroughEventTagProperties
  • dfareporting:v5 : DefaultClickThroughEventTagProperties

Constructors

$DefaultClickThroughEventTagProperties({String? defaultClickThroughEventTagId, bool? overrideInheritedEventTag})
$DefaultClickThroughEventTagProperties.fromJson(Map json_)

Properties

defaultClickThroughEventTagId ↔ String?
ID of the click-through event tag to apply to all ads in this entity's scope.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
overrideInheritedEventTag ↔ bool?
Whether this entity should override the inherited default click-through event tag with its own defined value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited