effectiveBiddingValue property

String? effectiveBiddingValue
getter/setter pair

The value effectively used by the bidding strategy.

This field will be the same as value if set. If value is not set and the strategy is assigned to an ad group, this field will be inherited from the line item's bidding strategy. If type is not DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPA or DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_ROAS, this field will be 0.

Output only.

Implementation

core.String? effectiveBiddingValue;