type property

String? type
getter/setter pair

The type of the bidding strategy.

This can only be set when assigned to a line item. Ad groups will inherit this value from their line item.

Optional. Possible string values are:

  • "DEMAND_GEN_BIDDING_STRATEGY_TYPE_UNSPECIFIED" : Type is not specified or unknown.
  • "DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPA" : A bidding strategy that automatically optimizes conversions per dollar.
  • "DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_ROAS" : A bidding strategy that automatically maximizes revenue while averaging a specific target Return On Ad Spend (ROAS).
  • "DEMAND_GEN_BIDDING_STRATEGY_TYPE_MAXIMIZE_CONVERSIONS" : A bidding strategy that automatically maximizes number of conversions
  • "DEMAND_GEN_BIDDING_STRATEGY_TYPE_MAXIMIZE_CONVERSION_VALUE" : A bidding strategy that automatically maximizes revenue while spending your budget.
  • "DEMAND_GEN_BIDDING_STRATEGY_TYPE_MAXIMIZE_CLICKS" : A bidding strategy that automatically maximizes clicks within a given budget.
  • "DEMAND_GEN_BIDDING_STRATEGY_TYPE_TARGET_CPC" : A bidding strategy that automatically optimizes cost per click.

Implementation

core.String? type;