$DfareportingStudioCreativeAssetsInsertRequest class

Used by:

  • dfareporting:v4 : DfareportingStudioCreativeAssetsInsertRequest
  • dfareporting:v5 : DfareportingStudioCreativeAssetsInsertRequest

Constructors

$DfareportingStudioCreativeAssetsInsertRequest({String? studioAccountId, String? studioAdvertiserId, String? studioCreativeId})
$DfareportingStudioCreativeAssetsInsertRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
studioAccountId ↔ String?
Studio account ID of the studio creative asset.
getter/setter pair
studioAdvertiserId ↔ String?
Studio advertiser ID of the studio creative asset.
getter/setter pair
studioCreativeId ↔ String?
Studio creative ID of the studio creative asset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited