$DfpSettings class

Used by:

  • dfareporting:v4 : DfpSettings
  • dfareporting:v5 : DfpSettings

Constructors

$DfpSettings({String? dfpNetworkCode, String? dfpNetworkName, bool? programmaticPlacementAccepted, bool? pubPaidPlacementAccepted, bool? publisherPortalOnly})
$DfpSettings.fromJson(Map json_)

Properties

dfpNetworkCode ↔ String?
Ad Manager network code for this directory site.
getter/setter pair
dfpNetworkName ↔ String?
Ad Manager network name for this directory site.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
programmaticPlacementAccepted ↔ bool?
Whether this directory site accepts programmatic placements.
getter/setter pair
publisherPortalOnly ↔ bool?
Whether this directory site is available only via Publisher Portal.
getter/setter pair
pubPaidPlacementAccepted ↔ bool?
Whether this directory site accepts publisher-paid tags.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited