$DimensionFilter class

Used by:

  • dfareporting:v4 : DimensionFilter
  • dfareporting:v5 : DimensionFilter

Constructors

$DimensionFilter({String? dimensionName, String? kind, String? value})
$DimensionFilter.fromJson(Map json_)

Properties

dimensionName ↔ String?
The name of the dimension to filter.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of resource this is, in this case dfareporting#dimensionFilter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The value of the dimension to filter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited