$DiscoverySpecCsvOptions class

Used by:

  • dataplex:v1 : GoogleCloudDataplexV1AssetDiscoverySpecCsvOptions
  • dataplex:v1 : GoogleCloudDataplexV1ZoneDiscoverySpecCsvOptions

Constructors

$DiscoverySpecCsvOptions({String? delimiter, bool? disableTypeInference, String? encoding, int? headerRows})
$DiscoverySpecCsvOptions.fromJson(Map json_)

Properties

delimiter ↔ String?
The delimiter being used to separate values.
getter/setter pair
disableTypeInference ↔ bool?
Whether to disable the inference of data type for CSV data.
getter/setter pair
encoding ↔ String?
The character encoding of the data.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headerRows ↔ int?
The number of rows to interpret as header rows that should be skipped when reading data rows.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited