$DiskUpdateKmsKeyRequest class

Used by:

  • compute:v1 : DiskUpdateKmsKeyRequest
  • compute:v1 : RegionDiskUpdateKmsKeyRequest

Properties

hashCode int
The hash code for this object.
no setterinherited
kmsKeyName String?
The new KMS key to replace the current one on the disk.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited