$DisksRemoveResourcePoliciesRequest class

Used by:

  • compute:v1 : DisksRemoveResourcePoliciesRequest
  • compute:v1 : RegionDisksRemoveResourcePoliciesRequest

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourcePolicies ↔ List<String>?
Resource policies to be removed from this disk.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited