$DoubleRange class

Used by:

  • trafficdirector:v2 : DoubleRange
  • trafficdirector:v3 : DoubleRange

Constructors

$DoubleRange({double? end, double? start})
$DoubleRange.fromJson(Map json_)

Properties

end ↔ double?
end of the range (exclusive)
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ double?
start of the range (inclusive)
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited