$DoubleVerifyBrandSafetyCategories class

Used by:

  • displayvideo:v2 : DoubleVerifyBrandSafetyCategories
  • displayvideo:v3 : DoubleVerifyBrandSafetyCategories
  • displayvideo:v4 : DoubleVerifyBrandSafetyCategories

Constructors

$DoubleVerifyBrandSafetyCategories({bool? avoidUnknownBrandSafetyCategory, List<String>? avoidedHighSeverityCategories, List<String>? avoidedMediumSeverityCategories})
$DoubleVerifyBrandSafetyCategories.fromJson(Map json_)

Properties

avoidedHighSeverityCategories ↔ List<String>?
Brand safety high severity avoidance categories.
getter/setter pair
avoidedMediumSeverityCategories ↔ List<String>?
Brand safety medium severity avoidance categories.
getter/setter pair
avoidUnknownBrandSafetyCategory ↔ bool?
Unknown or unrateable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited