$DoubleVerifyFraudInvalidTraffic class

Used by:

  • displayvideo:v2 : DoubleVerifyFraudInvalidTraffic
  • displayvideo:v3 : DoubleVerifyFraudInvalidTraffic
  • displayvideo:v4 : DoubleVerifyFraudInvalidTraffic

Constructors

$DoubleVerifyFraudInvalidTraffic({bool? avoidInsufficientOption, String? avoidedFraudOption})
$DoubleVerifyFraudInvalidTraffic.fromJson(Map json_)

Properties

avoidedFraudOption ↔ String?
Avoid Sites and Apps with historical Fraud & IVT. Possible string values are:
getter/setter pair
avoidInsufficientOption ↔ bool?
Insufficient Historical Fraud & IVT Stats.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited