$DynamicListenerState class

Used by:

  • trafficdirector:v2 : DynamicListenerState
  • trafficdirector:v3 : DynamicListenerState

Constructors

$DynamicListenerState({String? lastUpdated, Map<String, Object?>? listener, String? versionInfo})
$DynamicListenerState.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastUpdated ↔ String?
The timestamp when the Listener was last successfully updated.
getter/setter pair
listener ↔ Map<String, Object?>?
The listener config.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionInfo ↔ String?
This is the per-resource version information.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited