$EncryptionInfo class

Used by:

  • dfareporting:v4 : EncryptionInfo
  • dfareporting:v5 : EncryptionInfo

Constructors

$EncryptionInfo({String? encryptionEntityId, String? encryptionEntityType, String? encryptionSource, String? kind})
$EncryptionInfo.fromJson(Map json_)

Properties

encryptionEntityId ↔ String?
The encryption entity ID.
getter/setter pair
encryptionEntityType ↔ String?
The encryption entity type.
getter/setter pair
encryptionSource ↔ String?
Describes whether the encrypted cookie was received from ad serving (the %m macro) or from Data Transfer. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited