$EncryptionKey class

Used by:

  • connectors:v1 : EncryptionKey
  • integrations:v1 : GoogleCloudConnectorsV1EncryptionKey

Constructors

$EncryptionKey({String? kmsKeyName, String? type})
$EncryptionKey.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
The [KMS key name] with which the content of the Operation is encrypted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited