$EndSession class

Used by:

  • ces:v1 : EndSession
  • contactcenterinsights:v1 : GoogleCloudCesV1mainEndSession

Constructors

$EndSession({Map<String, Object?>? metadata})
$EndSession.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, Object?>?
Provides additional information about the end session signal, such as the reason for ending the session.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited