$Endpoint class

Used by:

  • servicemanagement:v1 : Endpoint
  • serviceusage:v1 : Endpoint

Constructors

$Endpoint({List<String>? aliases, bool? allowCors, String? name, String? target})
$Endpoint.fromJson(Map json_)

Properties

aliases ↔ List<String>?
Aliases for this endpoint, these will be served by the same UrlMap as the parent endpoint, and will be provisioned in the GCP stack for the Regional Endpoints.
getter/setter pair
allowCors ↔ bool?
Allowing CORS, aka cross-domain traffic, would allow the backends served from this endpoint to receive and respond to HTTP OPTIONS requests.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The canonical name of this endpoint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
target ↔ String?
The specification of an Internet routable address of API frontend that will handle requests to this API Endpoint.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited