$ExecutionStats class

Used by:

  • datastore:v1 : ExecutionStats
  • firestore:v1 : ExecutionStats

Constructors

$ExecutionStats({Map<String, Object?>? debugStats, String? executionDuration, String? readOperations, String? resultsReturned})
$ExecutionStats.fromJson(Map json_)

Properties

debugStats ↔ Map<String, Object?>?
Debugging statistics from the execution of the query.
getter/setter pair
executionDuration ↔ String?
Total time to execute the query in the backend.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
readOperations ↔ String?
Total billable read operations.
getter/setter pair
resultsReturned ↔ String?
Total number of results returned, including documents, projections, aggregation results, keys.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited