$ExitEvent class

Used by:

  • displayvideo:v2 : ExitEvent
  • displayvideo:v3 : ExitEvent
  • displayvideo:v4 : ExitEvent

Constructors

$ExitEvent({String? name, String? reportingName, String? type, String? url})
$ExitEvent.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the click tag of the exit event.
getter/setter pair
reportingName ↔ String?
The name used to identify this event in reports.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the exit event.
getter/setter pair
url ↔ String?
The click through URL of the exit event.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited