$ExploitPredictionScoringSystem class

Used by:

  • containeranalysis:v1 : ExploitPredictionScoringSystem
  • ondemandscanning:v1 : ExploitPredictionScoringSystem

Properties

hashCode → int
The hash code for this object.
no setterinherited
percentile ↔ double?
The percentile of the current score, the proportion of all scored vulnerabilities with the same or a lower EPSS score
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double?
The EPSS score representing the probability [0-1] of exploitation in the wild in the next 30 days
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited