$F5BigIpConfig class

Used by:

  • gkeonprem:v1 : VmwareAdminF5BigIpConfig
  • gkeonprem:v1 : VmwareF5BigIpConfig

Constructors

$F5BigIpConfig({String? address, String? partition, String? snatPool})
$F5BigIpConfig.fromJson(Map json_)

Properties

address ↔ String?
The load balancer's IP address.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
partition ↔ String?
The preexisting partition to be used by the load balancer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snatPool ↔ String?
The pool name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited