$FeedSchedule class

Used by:

  • dfareporting:v4 : FeedSchedule
  • dfareporting:v5 : FeedSchedule

Constructors

$FeedSchedule({String? repeatValue, bool? scheduleEnabled, String? startHour, String? startMinute, String? timeZone})
$FeedSchedule.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
repeatValue ↔ String?
The number of times the feed retransforms within one day.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleEnabled ↔ bool?
Whether the schedule is enabled.
getter/setter pair
startHour ↔ String?
The hour of the day to start the feed.
getter/setter pair
startMinute ↔ String?
The minute of the hour to start the feed.
getter/setter pair
timeZone ↔ String?
The time zone to schedule the feed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited