$File class

Used by:

  • containeranalysis:v1 : File
  • ondemandscanning:v1 : File

Constructors

$File({Map<String, String>? digest, String? name})
$File.fromJson(Map json_)

Properties

digest ↔ Map<String, String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited