$FindingLocation class

Used by:

  • containeranalysis:v1 : FindingLocation
  • ondemandscanning:v1 : FindingLocation

Constructors

$FindingLocation({String? filePath, String? lineNumber})
$FindingLocation.fromJson(Map json_)

Properties

filePath String?
Relative path of the file containing the finding.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lineNumber String?
Line number (1-based), or 0 if whole File / unknown.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited