$FixedBidStrategy class

Used by:

  • displayvideo:v2 : FixedBidStrategy
  • displayvideo:v3 : FixedBidStrategy
  • displayvideo:v4 : FixedBidStrategy

Constructors

$FixedBidStrategy({String? bidAmountMicros})
$FixedBidStrategy.fromJson(Map json_)

Properties

bidAmountMicros ↔ String?
The fixed bid amount, in micros of the advertiser's currency.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited