$FolderTreeRequest class

Used by:

  • dataform:v1 : DeleteFolderTreeRequest
  • dataform:v1 : DeleteTeamFolderTreeRequest

Constructors

$FolderTreeRequest({bool? force})
$FolderTreeRequest.fromJson(Map json_)

Properties

force bool?
If false (default): The operation will fail if any Repository within the folder hierarchy has associated Release Configs or Workflow Configs.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited