$Format class

Used by:

  • eventarc:v1 : GoogleCloudEventarcV1PipelineMessagePayloadFormatAvroFormat
  • eventarc:v1 : GoogleCloudEventarcV1PipelineMessagePayloadFormatProtobufFormat

Constructors

$Format({String? schemaDefinition})
$Format.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schemaDefinition ↔ String?
The entire schema definition is stored in this field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited