$ForwardSshTunnelConnectivity class

Used by:

  • datamigration:v1 : ForwardSshTunnelConnectivity
  • datastream:v1 : ForwardSshTunnelConnectivity

Constructors

$ForwardSshTunnelConnectivity({String? hostname, String? password, int? port, String? privateKey, String? username})
$ForwardSshTunnelConnectivity.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
Hostname for the SSH tunnel.
getter/setter pair
password ↔ String?
Input only.
getter/setter pair
port ↔ int?
Port for the SSH tunnel, default value is 22.
getter/setter pair
privateKey ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username ↔ String?
Username for the SSH tunnel.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited