$FsCommand class

Used by:

  • dfareporting:v4 : FsCommand
  • dfareporting:v5 : FsCommand

Constructors

$FsCommand({int? left, String? positionOption, int? top, int? windowHeight, int? windowWidth})
$FsCommand.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
left ↔ int?
Distance from the left of the browser.Applicable when positionOption is DISTANCE_FROM_TOP_LEFT_CORNER.
getter/setter pair
positionOption ↔ String?
Position in the browser where the window will open. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ int?
Distance from the top of the browser.
getter/setter pair
windowHeight ↔ int?
Height of the window.
getter/setter pair
windowWidth ↔ int?
Width of the window.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited