$GenerateCseTokenResponse class

Used by:

  • drive:v2 : GenerateCseTokenResponse
  • drive:v3 : GenerateCseTokenResponse

Constructors

$GenerateCseTokenResponse({String? currentKaclsId, String? currentKaclsName, String? fileId, String? jwt, String? kind})
$GenerateCseTokenResponse.fromJson(Map json_)

Properties

currentKaclsId String?
The current Key ACL Service (KACLS) ID associated with the JWT.
getter/setter pair
currentKaclsName String?
Name of the KACLs that the returned KACLs ID points to.
getter/setter pair
fileId String?
The fileId for which the JWT was generated.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
jwt String?
The signed JSON Web Token (JWT) for the file.
getter/setter pair
kind String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited