$GenerateEnterpriseUpgradeUrlResponse class

Used by:

  • androidenterprise:v1 : GenerateEnterpriseUpgradeUrlResponse
  • androidmanagement:v1 : GenerateEnterpriseUpgradeUrlResponse

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
A URL for an enterprise admin to upgrade their enterprise.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited