$GeoRegionSearchTerms class

Used by:

  • displayvideo:v2 : GeoRegionSearchTerms
  • displayvideo:v3 : GeoRegionSearchTerms
  • displayvideo:v4 : GeoRegionSearchTerms

Constructors

$GeoRegionSearchTerms({String? geoRegionQuery})
$GeoRegionSearchTerms.fromJson(Map json_)

Properties

geoRegionQuery ↔ String?
The search query for the desired geo region.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited