$GlossaryConfig class

Used by:

  • translate:v3 : GlossaryConfig
  • translate:v3 : TranslateTextGlossaryConfig

Constructors

$GlossaryConfig({bool? contextualTranslationEnabled, String? glossary, bool? ignoreCase})
$GlossaryConfig.fromJson(Map json_)

Properties

contextualTranslationEnabled ↔ bool?
If set to true, the glossary will be used for contextual translation.
getter/setter pair
glossary ↔ String?
The glossary to be applied for this translation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreCase ↔ bool?
Indicates match is case insensitive.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited