$GoogleCloudOrgpolicyV2CustomConstraint class

Used by:

  • orgpolicy:v2 : GoogleCloudOrgpolicyV2CustomConstraint
  • policysimulator:v1 : GoogleCloudOrgpolicyV2CustomConstraint

Constructors

$GoogleCloudOrgpolicyV2CustomConstraint({String? actionType, String? condition, String? description, String? displayName, List<String>? methodTypes, String? name, List<String>? resourceTypes, String? updateTime})
$GoogleCloudOrgpolicyV2CustomConstraint.fromJson(Map json_)

Properties

actionType ↔ String?
Allow or deny type. Possible string values are:
getter/setter pair
condition ↔ String?
A Common Expression Language (CEL) condition which is used in the evaluation of the constraint.
getter/setter pair
description ↔ String?
Detailed information about this custom policy constraint.
getter/setter pair
displayName ↔ String?
One line display name for the UI.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
methodTypes ↔ List<String>?
All the operations being applied for this constraint.
getter/setter pair
name ↔ String?
Name of the constraint.
getter/setter pair
resourceTypes ↔ List<String>?
The resource instance type on which this policy applies.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The last time this custom constraint was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited