$GuaranteedOrderStatus class

Used by:

  • displayvideo:v2 : GuaranteedOrderStatus
  • displayvideo:v3 : GuaranteedOrderStatus
  • displayvideo:v4 : GuaranteedOrderStatus

Constructors

$GuaranteedOrderStatus({String? configStatus, String? entityPauseReason, String? entityStatus})
$GuaranteedOrderStatus.fromJson(Map json_)

Properties

configStatus ↔ String?
The configuration status of the guaranteed order.
getter/setter pair
entityPauseReason ↔ String?
The user-provided reason for pausing this guaranteed order.
getter/setter pair
entityStatus ↔ String?
Whether or not the guaranteed order is servable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited