$HttpBody class

Used by:

  • adsense:v2 : HttpBody
  • aiplatform:v1 : GoogleApiHttpBody
  • airquality:v1 : HttpBody
  • apigee:v1 : GoogleApiHttpBody
  • cloudbuild:v1 : HttpBody
  • cloudbuild:v2 : HttpBody
  • cloudtasks:v2 : HttpBody
  • developerconnect:v1 : HttpBody
  • health:v4 : HttpBody
  • healthcare:v1 : HttpBody
  • managedkafka:v1 : HttpBody
  • ml:v1 : GoogleApi__HttpBody
  • networkmanagement:v1 : HttpBody
  • pollen:v1 : HttpBody
  • retail:v2 : GoogleApiHttpBody
  • solar:v1 : HttpBody

Constructors

$HttpBody({String? contentType, String? data, List<Map<String, Object?>>? extensions})
$HttpBody.fromJson(Map json_)

Properties

contentType ↔ String?
The HTTP Content-Type header value specifying the content type of the body.
getter/setter pair
data ↔ String?
The HTTP request/response body as raw binary.
getter/setter pair
dataAsBytes ↔ List<int>
getter/setter pair
extensions ↔ List<Map<String, Object?>>?
Application specific response metadata.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited