$IdentityServiceDiagnosticInterface class

Used by:

  • gkehub:v1 : IdentityServiceDiagnosticInterface
  • gkehub:v2 : IdentityServiceDiagnosticInterface

Properties

enabled ↔ bool?
Determines whether to enable the diagnostic interface.
getter/setter pair
expirationTime ↔ String?
Determines the expiration time of the diagnostic interface enablement.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited