$IdentityServiceGroupConfig class

Used by:

  • gkehub:v1 : IdentityServiceGroupConfig
  • gkehub:v2 : IdentityServiceGroupConfig

Constructors

$IdentityServiceGroupConfig({String? baseDn, String? filter, String? idAttribute})
$IdentityServiceGroupConfig.fromJson(Map json_)

Properties

baseDn ↔ String?
The location of the subtree in the LDAP directory to search for group entries.
getter/setter pair
filter ↔ String?
Optional filter to be used when searching for groups a user belongs to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
idAttribute ↔ String?
The identifying name of each group a user belongs to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited