$IdentityServiceOidcConfig class

Used by:

  • gkehub:v1 : IdentityServiceOidcConfig
  • gkehub:v2 : IdentityServiceOidcConfig

Constructors

$IdentityServiceOidcConfig({String? certificateAuthorityData, String? clientId, String? clientSecret, bool? deployCloudConsoleProxy, bool? enableAccessToken, String? encryptedClientSecret, String? extraParams, String? groupPrefix, String? groupsClaim, String? issuerUri, String? kubectlRedirectUri, String? scopes, String? userClaim, String? userPrefix})
$IdentityServiceOidcConfig.fromJson(Map json_)

Properties

certificateAuthorityData ↔ String?
PEM-encoded CA for OIDC provider.
getter/setter pair
clientId ↔ String?
ID for OIDC client application.
getter/setter pair
clientSecret ↔ String?
Input only.
getter/setter pair
deployCloudConsoleProxy ↔ bool?
Flag to denote if reverse proxy is used to connect to auth provider.
getter/setter pair
enableAccessToken ↔ bool?
Enable access token.
getter/setter pair
encryptedClientSecret ↔ String?
Encrypted OIDC Client secret
getter/setter pair
encryptedClientSecretAsBytes ↔ List<int>
getter/setter pair
extraParams ↔ String?
Comma-separated list of key-value pairs.
getter/setter pair
groupPrefix ↔ String?
Prefix to prepend to group name.
getter/setter pair
groupsClaim ↔ String?
Claim in OIDC ID token that holds group information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
issuerUri ↔ String?
URI for the OIDC provider.
getter/setter pair
kubectlRedirectUri ↔ String?
Registered redirect uri to redirect users going through OAuth flow using kubectl plugin.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ String?
Comma-separated list of identifiers.
getter/setter pair
userClaim ↔ String?
Claim in OIDC ID token that holds username.
getter/setter pair
userPrefix ↔ String?
Prefix to prepend to user name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited