$IdentityServiceSamlConfig class

Used by:

  • gkehub:v1 : IdentityServiceSamlConfig
  • gkehub:v2 : IdentityServiceSamlConfig

Constructors

$IdentityServiceSamlConfig({Map<String, String>? attributeMapping, String? groupPrefix, String? groupsAttribute, List<String>? identityProviderCertificates, String? identityProviderId, String? identityProviderSsoUri, String? userAttribute, String? userPrefix})
$IdentityServiceSamlConfig.fromJson(Map json_)

Properties

attributeMapping ↔ Map<String, String>?
The mapping of additional user attributes like nickname, birthday and address etc..
getter/setter pair
groupPrefix ↔ String?
Prefix to prepend to group name.
getter/setter pair
groupsAttribute ↔ String?
The SAML attribute to read groups from.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
identityProviderCertificates ↔ List<String>?
The list of IdP certificates to validate the SAML response against.
getter/setter pair
identityProviderId ↔ String?
The entity ID of the SAML IdP.
getter/setter pair
identityProviderSsoUri ↔ String?
The URI where the SAML IdP exposes the SSO service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAttribute ↔ String?
The SAML attribute to read username from.
getter/setter pair
userPrefix ↔ String?
Prefix to prepend to user name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited