$IdentityServiceSimpleBindCredentials class

Used by:

  • gkehub:v1 : IdentityServiceSimpleBindCredentials
  • gkehub:v2 : IdentityServiceSimpleBindCredentials

Properties

dn ↔ String?
The distinguished name(DN) of the service account object/user.
getter/setter pair
encryptedPassword ↔ String?
The encrypted password of the service account object/user.
getter/setter pair
encryptedPasswordAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
password ↔ String?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited