$IngestionStatus class

Used by:

  • dfareporting:v4 : IngestionStatus
  • dfareporting:v5 : IngestionStatus

Constructors

$IngestionStatus({String? numActiveRows, String? numRowsProcessed, String? numRowsTotal, String? numRowsWithErrors, String? numWarningsTotal})
$IngestionStatus.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
numActiveRows ↔ String?
The number of active rows in the feed.
getter/setter pair
numRowsProcessed ↔ String?
The number of rows processed in the feed.
getter/setter pair
numRowsTotal ↔ String?
The total number of rows in the feed.
getter/setter pair
numRowsWithErrors ↔ String?
The number of rows with errors in the feed.
getter/setter pair
numWarningsTotal ↔ String?
The total number of warnings in the feed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited