$IngressSource class

Used by:

  • accesscontextmanager:v1 : IngressSource
  • cloudasset:v1 : GoogleIdentityAccesscontextmanagerV1IngressSource

Constructors

$IngressSource({String? accessLevel, String? resource})
$IngressSource.fromJson(Map json_)

Properties

accessLevel ↔ String?
An AccessLevel resource name that allow resources within the ServicePerimeters to be accessed from the internet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resource ↔ String?
A Google Cloud resource that is allowed to ingress the perimeter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited