$InstanceGroupManagersSuspendInstancesRequest class

Used by:

  • compute:v1 : InstanceGroupManagersSuspendInstancesRequest
  • compute:v1 : RegionInstanceGroupManagersSuspendInstancesRequest

Properties

forceSuspend ↔ bool?
If this flag is set to true, the Instance Group Manager will proceed to suspend the instances, skipping initialization on them.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instances ↔ List<String>?
The URLs of one or more instances to suspend.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited