$InstanceRequest00 class

Used by:

  • run:v1 : StartInstanceRequest
  • run:v1 : StopInstanceRequest

Constructors

$InstanceRequest00({String? dryRun})
$InstanceRequest00.fromJson(Map json_)

Properties

dryRun String?
Indicates that the server should validate the request and populate default values without persisting the request.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited