$IssuesRequestPayload class

Used by:

  • content:v2.1 : RenderAccountIssuesRequestPayload
  • content:v2.1 : RenderProductIssuesRequestPayload

Constructors

$IssuesRequestPayload({String? contentOption, String? userInputActionOption})
$IssuesRequestPayload.fromJson(Map json_)

Properties

contentOption ↔ String?
How the detailed content should be returned.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userInputActionOption ↔ String?
How actions with user input form should be handled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited