$LabelDescriptor class

Used by:

  • logging:v2 : LabelDescriptor
  • servicemanagement:v1 : LabelDescriptor
  • serviceusage:v1 : LabelDescriptor

Constructors

$LabelDescriptor({String? description, String? key, String? valueType})
$LabelDescriptor.fromJson(Map json_)

Properties

description ↔ String?
A human-readable description for the label.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The label key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueType ↔ String?
The type of data that can be assigned to the label. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited