$License class

Used by:

  • containeranalysis:v1 : License
  • ondemandscanning:v1 : License

Constructors

$License({String? comments, String? expression})
$License.fromJson(Map json_)

Properties

comments ↔ String?
Comments
getter/setter pair
expression ↔ String?
Often a single license can be used to represent the licensing terms.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited