$Linear class

Used by:

  • logging:v2 : Linear
  • monitoring:v3 : Linear

Constructors

$Linear({int? numFiniteBuckets, double? offset, double? width})
$Linear.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
numFiniteBuckets ↔ int?
Must be greater than 0.
getter/setter pair
offset ↔ double?
Lower bound of the first bucket.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ double?
Must be greater than 0.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited