$Link class

Used by:

  • compute:v1 : HelpLink
  • deploymentmanager:v2 : HelpLink
  • vmmigration:v1 : Link

Constructors

$Link({String? description, String? url})
$Link.fromJson(Map json_)

Properties

description ↔ String?
Describes what the link offers.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The URL of the link.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited