$ListPopulationTerm class

Used by:

  • dfareporting:v4 : ListPopulationTerm
  • dfareporting:v5 : ListPopulationTerm

Constructors

$ListPopulationTerm({bool? contains, bool? negation, String? operator, String? remarketingListId, String? type, String? value, String? variableFriendlyName, String? variableName})
$ListPopulationTerm.fromJson(Map json_)

Properties

contains ↔ bool?
Will be true if the term should check if the user is in the list and false if the term should check if the user is not in the list.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
negation ↔ bool?
Whether to negate the comparison result of this term during rule evaluation.
getter/setter pair
operator ↔ String?
Comparison operator of this term.
getter/setter pair
remarketingListId ↔ String?
ID of the list in question.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
List population term type determines the applicable fields in this object.
getter/setter pair
value ↔ String?
Literal to compare the variable to.
getter/setter pair
variableFriendlyName ↔ String?
Friendly name of this term's variable.
getter/setter pair
variableName ↔ String?
Name of the variable (U1, U2, etc.) being compared in this term.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited