$LockConfig class

Used by:

  • connectors:v1 : LockConfig
  • integrations:v1 : GoogleCloudConnectorsV1LockConfig

Constructors

$LockConfig({bool? locked, String? reason})
$LockConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
locked ↔ bool?
Indicates whether or not the connection is locked.
getter/setter pair
reason ↔ String?
Describes why a connection is locked.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited