$Material class

Used by:

  • containeranalysis:v1 : GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
  • containeranalysis:v1 : Material
  • ondemandscanning:v1 : GrafeasV1SlsaProvenanceZeroTwoSlsaMaterial
  • ondemandscanning:v1 : Material

Constructors

$Material({Map<String, String>? digest, String? uri})
$Material.fromJson(Map json_)

Properties

digest ↔ Map<String, String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited