$MeasurementPartnerCampaignLink class

Used by:

  • dfareporting:v4 : MeasurementPartnerCampaignLink
  • dfareporting:v5 : MeasurementPartnerCampaignLink

Constructors

$MeasurementPartnerCampaignLink({String? linkStatus, String? measurementPartner, String? partnerCampaignId})
$MeasurementPartnerCampaignLink.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
linkStatus ↔ String?
. Possible string values are:
getter/setter pair
measurementPartner ↔ String?
Measurement partner used for tag wrapping. Possible string values are:
getter/setter pair
partnerCampaignId ↔ String?
Partner campaign ID needed for establishing linking with Measurement partner.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited