$Media class

Used by:

  • chat:v1 : Media
  • cloudsearch:v1 : Media
  • displayvideo:v2 : GoogleBytestreamMedia
  • displayvideo:v3 : GoogleBytestreamMedia
  • displayvideo:v4 : GoogleBytestreamMedia

Constructors

$Media({String? resourceName})
$Media.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
resourceName ↔ String?
Name of the media resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited