$MobileApp01 class

Used by:

  • dfareporting:v4 : MobileApp
  • dfareporting:v5 : MobileApp

Constructors

$MobileApp01({String? directory, String? id, String? kind, String? publisherName, String? title})
$MobileApp01.fromJson(Map json_)

Properties

directory ↔ String?
Mobile app directory. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this mobile app.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
publisherName ↔ String?
Publisher name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Title of this mobile app.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited