$MonitoringDestination class

Used by:

  • servicemanagement:v1 : MonitoringDestination
  • serviceusage:v1 : MonitoringDestination

Constructors

$MonitoringDestination({List<String>? metrics, String? monitoredResource})
$MonitoringDestination.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
metrics ↔ List<String>?
Types of the metrics to report to this monitoring destination.
getter/setter pair
monitoredResource ↔ String?
The monitored resource type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited