$NodeConfig class

Used by:

  • connectors:v1 : NodeConfig
  • integrations:v1 : GoogleCloudConnectorsV1NodeConfig

Constructors

$NodeConfig({int? maxNodeCount, int? minNodeCount})
$NodeConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxNodeCount ↔ int?
Maximum number of nodes in the runtime nodes.
getter/setter pair
minNodeCount ↔ int?
Minimum number of nodes in the runtime nodes.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited