$OSPolicyResourceFileGcs class

Used by:

  • osconfig:v1 : OSPolicyResourceFileGcs
  • osconfig:v2 : OSPolicyResourceFileGcs

Constructors

$OSPolicyResourceFileGcs({String? bucket, String? generation, String? object})
$OSPolicyResourceFileGcs.fromJson(Map json_)

Properties

bucket ↔ String?
Bucket of the Cloud Storage object.
getter/setter pair
generation ↔ String?
Generation number of the Cloud Storage object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
object ↔ String?
Name of the Cloud Storage object.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited