$OSPolicyResourceFileRemote class

Used by:

  • osconfig:v1 : OSPolicyResourceFileRemote
  • osconfig:v2 : OSPolicyResourceFileRemote

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha256Checksum ↔ String?
SHA256 checksum of the remote file.
getter/setter pair
uri ↔ String?
URI from which to fetch the object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited