$OSPolicyResourceRepositoryResourceAptRepository class

Used by:

  • osconfig:v1 : OSPolicyResourceRepositoryResourceAptRepository
  • osconfig:v2 : OSPolicyResourceRepositoryResourceAptRepository

Properties

archiveType ↔ String?
Type of archive files in this repository.
getter/setter pair
components ↔ List<String>?
List of components for this repository.
getter/setter pair
distribution ↔ String?
Distribution of this repository.
getter/setter pair
gpgKey ↔ String?
URI of the key file for this repository.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri ↔ String?
URI for this repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited