$OSPolicyResourceRepositoryResourceGooRepository class

Used by:

  • osconfig:v1 : OSPolicyResourceRepositoryResourceGooRepository
  • osconfig:v2 : OSPolicyResourceRepositoryResourceGooRepository

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the repository.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The url of the repository.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited