$ObjectFilter class

Used by:

  • dfareporting:v4 : ObjectFilter
  • dfareporting:v5 : ObjectFilter

Constructors

$ObjectFilter({String? kind, List<String>? objectIds, String? status})
$ObjectFilter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
objectIds ↔ List<String>?
Applicable when status is ASSIGNED.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
Status of the filter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited