$ObjectId class

Used by:

  • firebaseappdistribution:v1 : GdataObjectId
  • walletobjects:v1 : ObjectId

Constructors

$ObjectId({String? bucketName, String? generation, String? objectName})
$ObjectId.fromJson(Map json_)

Properties

bucketName ↔ String?
The name of the bucket to which this object belongs.
getter/setter pair
generation ↔ String?
Generation of the object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectName ↔ String?
The name of the object.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited