$ObjectIdentifier class

Used by:

  • datastream:v1 : OracleObjectIdentifier
  • datastream:v1 : PostgresqlObjectIdentifier
  • datastream:v1 : SqlServerObjectIdentifier

Constructors

$ObjectIdentifier({String? schema, String? table})
$ObjectIdentifier.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema ↔ String?
The schema name.
getter/setter pair
table ↔ String?
The table name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited