$OmnitureSettings class

Used by:

  • dfareporting:v4 : OmnitureSettings
  • dfareporting:v5 : OmnitureSettings

Constructors

$OmnitureSettings({bool? omnitureCostDataEnabled, bool? omnitureIntegrationEnabled})
$OmnitureSettings.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
omnitureCostDataEnabled ↔ bool?
Whether placement cost data will be sent to Omniture.
getter/setter pair
omnitureIntegrationEnabled ↔ bool?
Whether Omniture integration is enabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited