$OperatingSystem class

Used by:

  • dfareporting:v4 : OperatingSystem
  • dfareporting:v5 : OperatingSystem

Constructors

$OperatingSystem({String? dartId, bool? desktop, String? kind, bool? mobile, String? name})
$OperatingSystem.fromJson(Map json_)

Properties

dartId ↔ String?
DART ID of this operating system.
getter/setter pair
desktop ↔ bool?
Whether this operating system is for desktop.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
mobile ↔ bool?
Whether this operating system is for mobile.
getter/setter pair
name ↔ String?
Name of this operating system.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited