$OsInfo class

Used by:

  • cloudasset:v1 : OsInfo
  • osconfig:v1 : InventoryOsInfo

Constructors

$OsInfo({String? architecture, String? hostname, String? kernelRelease, String? kernelVersion, String? longName, String? osconfigAgentVersion, String? shortName, String? version})
$OsInfo.fromJson(Map json_)

Properties

architecture ↔ String?
The system architecture of the operating system.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
The VM hostname.
getter/setter pair
kernelRelease ↔ String?
The kernel release of the operating system.
getter/setter pair
kernelVersion ↔ String?
The kernel version of the operating system.
getter/setter pair
longName ↔ String?
The operating system long name.
getter/setter pair
osconfigAgentVersion ↔ String?
The current version of the OS Config agent running on the VM.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName ↔ String?
The operating system short name.
getter/setter pair
version ↔ String?
The version of the operating system.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited