$PartnerCost class

Used by:

  • displayvideo:v2 : PartnerCost
  • displayvideo:v4 : PartnerCost

Constructors

$PartnerCost({String? costType, String? feeAmount, String? feePercentageMillis, String? feeType, String? invoiceType})
$PartnerCost.fromJson(Map json_)

Properties

costType ↔ String?
The type of the partner cost.
getter/setter pair
feeAmount ↔ String?
The CPM fee amount in micros of advertiser's currency.
getter/setter pair
feePercentageMillis ↔ String?
The media fee percentage in millis (1/1000 of a percent).
getter/setter pair
feeType ↔ String?
The fee type for this partner cost.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
invoiceType ↔ String?
The invoice type for this partner cost.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited