$PerformMaintenanceRequest class

Used by:

  • compute:v1 : ReservationsBlocksPerformMaintenanceRequest
  • compute:v1 : ReservationsPerformMaintenanceRequest

Properties

hashCode → int
The hash code for this object.
no setterinherited
maintenanceScope ↔ String?
Specifies if all, running or unused hosts are in scope for this request. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited