$PhysicalTopology class
Used by:
- compute:v1 : HostPhysicalTopology
- compute:v1 : ReservationSlotPhysicalTopology
Constructors
- $PhysicalTopology({String? block, String? cluster, String? host, String? subBlock})
- $PhysicalTopology.fromJson(Map json_)
Properties
- block ↔ String?
-
The unique identifier of the capacity block within the cluster.
getter/setter pair
- cluster ↔ String?
-
The cluster name of the reservation sub-block.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String?
-
The unique identifier of the capacity host within the capacity sub-block.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subBlock ↔ String?
-
The unique identifier of the capacity sub-block within the capacity
block.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited