$PolicyControllerResourceList class

Used by:

  • gkehub:v1 : PolicyControllerResourceList
  • gkehub:v2 : PolicyControllerResourceList

Properties

cpu ↔ String?
CPU requirement expressed in Kubernetes resource units.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
memory ↔ String?
Memory requirement expressed in Kubernetes resource units.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited