$PostalAddress class

Used by:

  • addressvalidation:v1 : GoogleTypePostalAddress
  • cloudchannel:v1 : GoogleTypePostalAddress
  • documentai:v1 : GoogleTypePostalAddress
  • domains:v1 : PostalAddress
  • jobs:v3 : PostalAddress
  • jobs:v4 : PostalAddress
  • merchantapi:accounts_v1 : PostalAddress
  • mybusinessaccountmanagement:v1 : PostalAddress
  • mybusinessbusinessinformation:v1 : PostalAddress
  • mybusinessverifications:v1 : PostalAddress
  • places:v1 : GoogleTypePostalAddress

Constructors

$PostalAddress({List<String>? addressLines, String? administrativeArea, String? languageCode, String? locality, String? organization, String? postalCode, List<String>? recipients, String? regionCode, int? revision, String? sortingCode, String? sublocality})
$PostalAddress.fromJson(Map json_)

Properties

addressLines ↔ List<String>?
Unstructured address lines describing the lower levels of an address.
getter/setter pair
administrativeArea ↔ String?
Highest administrative subdivision which is used for postal addresses of a country or region.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
BCP-47 language code of the contents of this address (if known).
getter/setter pair
locality ↔ String?
Generally refers to the city or town portion of the address.
getter/setter pair
organization ↔ String?
The name of the organization at the address.
getter/setter pair
postalCode ↔ String?
Postal code of the address.
getter/setter pair
recipients ↔ List<String>?
The recipient at the address.
getter/setter pair
regionCode ↔ String?
CLDR region code of the country/region of the address.
getter/setter pair
revision ↔ int?
The schema revision of the PostalAddress.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortingCode ↔ String?
Additional, country-specific, sorting code.
getter/setter pair
sublocality ↔ String?
Sublocality of the address.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited