$PrewarmedArtifactRequest class

Used by:

  • artifactregistry:v1 : CheckPrewarmedArtifactRequest
  • artifactregistry:v1 : RemovePrewarmedArtifactRequest

Constructors

$PrewarmedArtifactRequest({String? streamLocation, String? tag, String? version})
$PrewarmedArtifactRequest.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamLocation String?
The location of the prewarmed artifact.
getter/setter pair
tag String?
The artifact tag Format:projects/{project}/locations/{location}/repositories/{repository}/packages/{package}/tags/{tag}
getter/setter pair
version String?
The artifact version Format: projects/{project}/locations/{location}/repositories/{repository}/packages/{package}/versions/{version}
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited