$PrivateServiceConnectEndpoint class

Used by:

  • accesscontextmanager:v1 : PrivateServiceConnectEndpoint
  • cloudasset:v1 : GoogleIdentityAccesscontextmanagerV1PrivateServiceConnectEndpoint

Properties

forwardingRule ↔ String?
The full resource name of the global forwarding rule that identifies a Private Service Connect endpoint.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited