$ProductDetail class

Used by:

  • content:v2.1 : ProductProductDetail
  • css:v1 : ProductDetail
  • merchantapi:products_v1 : ProductDetail

Constructors

$ProductDetail({String? attributeName, String? attributeValue, String? sectionName})
$ProductDetail.fromJson(Map json_)

Properties

attributeName ↔ String?
The name of the product detail.
getter/setter pair
attributeValue ↔ String?
The value of the product detail.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sectionName ↔ String?
The section header used to group a set of product details.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited