$ProductWeight class

Used by:

  • css:v1 : ProductWeight
  • merchantapi:products_v1 : ProductWeight

Constructors

$ProductWeight({String? unit, double? value})
$ProductWeight.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit ↔ String?
The weight unit.
getter/setter pair
value ↔ double?
The weight represented as a number.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited