$QuestionAnsweringQualitySpec class

Used by:

  • aiplatform:v1 : GoogleCloudAiplatformV1PairwiseQuestionAnsweringQualitySpec
  • aiplatform:v1 : GoogleCloudAiplatformV1QuestionAnsweringQualitySpec

Constructors

$QuestionAnsweringQualitySpec({bool? useReference, int? version})
$QuestionAnsweringQualitySpec.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
useReference ↔ bool?
Whether to use instance.reference to compute question answering quality.
getter/setter pair
version ↔ int?
Which version to use for evaluation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited