$QuotaLimit class

Used by:

  • servicemanagement:v1 : QuotaLimit
  • serviceusage:v1 : QuotaLimit

Constructors

$QuotaLimit({String? defaultLimit, String? description, String? displayName, String? duration, String? freeTier, String? maxLimit, String? metric, String? name, String? trafficSource, String? unit, Map<String, String>? values})
$QuotaLimit.fromJson(Map json_)

Properties

defaultLimit ↔ String?
Default number of tokens that can be consumed during the specified duration.
getter/setter pair
description ↔ String?
User-visible, extended description for this quota limit.
getter/setter pair
displayName ↔ String?
User-visible display name for this limit.
getter/setter pair
duration ↔ String?
Duration of this limit in textual notation.
getter/setter pair
freeTier ↔ String?
Free tier value displayed in the Developers Console for this limit.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxLimit ↔ String?
Maximum number of tokens that can be consumed during the specified duration.
getter/setter pair
metric ↔ String?
The name of the metric this quota limit applies to.
getter/setter pair
name ↔ String?
Name of the quota limit.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trafficSource ↔ String?
This is only informational, the logic to allocate the quota to the correct metric (such as in metric_rules) should identify which quota metrics to allocate to.
getter/setter pair
unit ↔ String?
Specify the unit of the quota limit.
getter/setter pair
values ↔ Map<String, String>?
Tiered limit values.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited