trafficSource property

String? trafficSource
getter/setter pair

This is only informational, the logic to allocate the quota to the correct metric (such as in metric_rules) should identify which quota metrics to allocate to.

Optional. Possible string values are:

  • "TRAFFIC_SOURCE_UNSPECIFIED" : This quota limit applies to all traffic. This is the default value.
  • "TRAFFIC_SOURCE_NONAGENTIC" : This quota limit applies to traffic not recognized as agentic.
  • "TRAFFIC_SOURCE_AGENTIC" : This quota limit applies to only agentic traffic.

Implementation

core.String? trafficSource;