$Recipient class

Used by:

  • dfareporting:v4 : Recipient
  • dfareporting:v5 : Recipient

Constructors

$Recipient({String? deliveryType, String? email, String? kind})
$Recipient.fromJson(Map json_)

Properties

deliveryType ↔ String?
The delivery type for the recipient. Possible string values are:
getter/setter pair
email ↔ String?
The email address of the recipient.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of resource this is, in this case dfareporting#recipient.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited