$Region class

Used by:

  • content:v2.1 : BreakdownRegion
  • merchantapi:issueresolution_v1 : Region

Constructors

$Region({String? code, String? name})
$Region.fromJson(Map json_)

Properties

code ↔ String?
The CLDR territory code
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The localized name of the region.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited