$Req class

Used by:

  • compute:v1 : InstanceGroupManagersDeletePerInstanceConfigsReq
  • compute:v1 : RegionInstanceGroupManagerDeleteInstanceConfigReq

Constructors

$Req({List<String>? names})
$Req.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
names ↔ List<String>?
The list of instance names for which we want to delete per-instance configs on this managed instance group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited