$Request02 class

Used by:

  • cloudchannel:v1 : GoogleCloudChannelV1ActivateEntitlementRequest
  • cloudchannel:v1 : GoogleCloudChannelV1CancelEntitlementRequest
  • cloudchannel:v1 : GoogleCloudChannelV1StartPaidServiceRequest
  • cloudchannel:v1 : GoogleCloudChannelV1SuspendEntitlementRequest

Constructors

$Request02({String? requestId})
$Request02.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
You can specify an optional unique request ID, and if you need to retry your request, the server will know to ignore the request if it's complete.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited