$Request03 class

Used by:

  • searchads360:v23 : GoogleAdsSearchads360V23Services__EndExperimentRequest
  • searchads360:v23 : GoogleAdsSearchads360V23Services__PromoteExperimentRequest
  • searchads360:v23 : GoogleAdsSearchads360V23Services__RunOfflineUserDataJobRequest
  • searchads360:v23 : GoogleAdsSearchads360V23Services__ScheduleExperimentRequest

Constructors

$Request03({bool? validateOnly})
$Request03.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validateOnly bool?
If true, the request is validated but not executed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited