$RequestValue class

Used by:

  • dfareporting:v4 : RequestValue
  • dfareporting:v5 : RequestValue

Constructors

$RequestValue({List<String>? excludeFromUserAttributeIds, String? key, List<String>? userAttributeIds})
$RequestValue.fromJson(Map json_)

Properties

excludeFromUserAttributeIds ↔ List<String>?
User attribute IDs in the request that should be excluded.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
Custom key in the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAttributeIds ↔ List<String>?
User attribute IDs in the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited