$Response01 class

Used by:

  • chromemanagement:v1 : GoogleChromeManagementVersionsV1CheckEnablementStatusResponse
  • chromemanagement:v1 : GoogleChromeManagementVersionsV1DisableInsightsResponse
  • chromemanagement:v1 : GoogleChromeManagementVersionsV1EnableInsightsResponse

Constructors

$Response01({String? insightsState})
$Response01.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
insightsState String?
The state of the insights feature. Possible string values are:
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited