$Result01 class
Used by:
- containeranalysis:v1 : MaliciousContentLLMResult
- containeranalysis:v1 : MaliciousContentStaticResult
- ondemandscanning:v1 : MaliciousContentLLMResult
- ondemandscanning:v1 : MaliciousContentStaticResult
Constructors
- $Result01({String? maxSeverity, String? scanStatus})
- $Result01.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxSeverity ↔ String?
-
Tracks max severity found.
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scanStatus ↔ String?
-
Status of the scan.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited