$Result02 class

Used by:

  • containeranalysis:v1 : MalwareScanResult
  • containeranalysis:v1 : WorkspacePolicyResult
  • ondemandscanning:v1 : MalwareScanResult
  • ondemandscanning:v1 : WorkspacePolicyResult

Constructors

$Result02({String? scanStatus, String? verdict})
$Result02.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scanStatus String?
Status of the scan. Possible string values are:
getter/setter pair
verdict String?
Verdict of the scan. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited