$RetryPolicy class

Used by:

  • analyticshub:v1 : RetryPolicy
  • pubsub:v1 : RetryPolicy

Constructors

$RetryPolicy({String? maximumBackoff, String? minimumBackoff})
$RetryPolicy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maximumBackoff ↔ String?
The maximum delay between consecutive deliveries of a given message.
getter/setter pair
minimumBackoff ↔ String?
The minimum delay between consecutive deliveries of a given message.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited