$RgbColor class

Used by:

  • docs:v1 : RgbColor
  • slides:v1 : RgbColor

Constructors

$RgbColor({double? blue, double? green, double? red})
$RgbColor.fromJson(Map json_)

Properties

blue ↔ double?
The blue component of the color, from 0.0 to 1.0.
getter/setter pair
green ↔ double?
The green component of the color, from 0.0 to 1.0.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
red ↔ double?
The red component of the color, from 0.0 to 1.0.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited