$ScriptError class

Used by:

  • displayvideo:v2 : ScriptError
  • displayvideo:v3 : ScriptError
  • displayvideo:v4 : ScriptError

Constructors

$ScriptError({String? column, String? errorCode, String? errorMessage, String? line})
$ScriptError.fromJson(Map json_)

Properties

column ↔ String?
The column number in the script where the error was thrown.
getter/setter pair
errorCode ↔ String?
The type of error. Possible string values are:
getter/setter pair
errorMessage ↔ String?
The detailed error message.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
line ↔ String?
The line number in the script where the error was thrown.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited