mode property
Sets which mode to use for Security Posture features. Possible string values are:
- "MODE_UNSPECIFIED" : Default value not specified.
- "DISABLED" : Disables Security Posture features on the cluster.
- "BASIC" : Applies Security Posture features on the cluster.
- "ENTERPRISE" : Deprecated: Security Posture Enterprise features are no longer supported. For more details, see https://cloud.google.com/kubernetes-engine/docs/deprecations/posture-management-deprecation. Applies the Security Posture off cluster Enterprise level features.
Implementation
core.String? mode;