$ServiceMeshCondition class

Used by:

  • gkehub:v1 : ServiceMeshCondition
  • gkehub:v2 : ServiceMeshCondition

Constructors

$ServiceMeshCondition({String? code, String? details, String? documentationLink, String? severity})
$ServiceMeshCondition.fromJson(Map json_)

Properties

code ↔ String?
Unique identifier of the condition which describes the condition recognizable to the user. Possible string values are:
getter/setter pair
details ↔ String?
A short summary about the issue.
getter/setter pair
Links contains actionable information.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
Severity level of the condition. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited