$SetTagsRequest class

Used by:

  • gkebackup:v1 : SetTagsRequest
  • memcache:v1 : SetTagsRequest

Constructors

$SetTagsRequest({String? etag, String? name, String? requestId, Map<String, String>? tags})
$SetTagsRequest.fromJson(Map json_)

Properties

etag ↔ String?
A checksum based on the current bindings which can be passed to prevent race conditions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The full resource name of the service resource.
getter/setter pair
requestId ↔ String?
A unique identifier for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ Map<String, String>?
These bindings will override any bindings previously set and will be effective immediately.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited