$ShareSettingsProjectConfig class

Used by:

  • compute:v1 : ShareSettingsProjectConfig
  • compute:v1 : StoragePoolShareSettingsProjectConfig

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectId ↔ String?
The project ID, should be same as the key of this project config in the parent map.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited