$Shared00 class

Used by:

  • chromepolicy:v1 : Proto2OneofDescriptorProto
  • dialogflow:v2 : GoogleCloudDialogflowV2ToolExtensionTool
  • securitycenter:v1 : AdcApplicationTemplateRevision
  • securitycenter:v1 : AdcSharedTemplateRevision
  • securitycenter:v1 : Disk
  • securitycenter:v1 : LoadBalancer
  • securitycenter:v1 : Network
  • securitycenter:v1 : Node
  • securitycenter:v1 : OrgPolicy
  • securitycenter:v1 : ResourceValueConfigMetadata

Constructors

$Shared00({String? name})
$Shared00.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited