$Shared07 class

Used by:

  • osconfig:v1 : OSPolicyAssignmentInstanceFilterInventory
  • osconfig:v1 : OSPolicyInventoryFilter
  • osconfig:v2 : OSPolicyAssignmentInstanceFilterInventory
  • osconfig:v2 : OSPolicyInventoryFilter

Constructors

$Shared07({String? osShortName, String? osVersion})
$Shared07.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
osShortName ↔ String?
The OS short name
getter/setter pair
osVersion ↔ String?
The OS version Prefix matches are supported if asterisk(*) is provided as the last character.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited