$Shared08 class

Used by:

  • securitycenter:v1 : Agent
  • securitycenter:v1 : AzureManagementGroup
  • securitycenter:v1 : AzureSubscription
  • securitycenter:v1 : AzureTenant

Constructors

$Shared08({String? displayName, String? id})
$Shared08.fromJson(Map json_)

Properties

displayName String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited