$Shared10 class

Used by:

  • dialogflow:v2 : GoogleCloudDialogflowV2ConversationInfo
  • dialogflow:v3 : GoogleCloudDialogflowCxV3ValidateAgentRequest
  • dialogflow:v3 : GoogleCloudDialogflowCxV3ValidateFlowRequest

Constructors

$Shared10({String? languageCode})
$Shared10.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited