$Shared12 class

Used by:

  • admin:reports_v1 : FieldValueTextListValue
  • contentwarehouse:v1 : GoogleCloudContentwarehouseV1TextArray

Constructors

$Shared12({List<String>? values})
$Shared12.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<String>?
List of text values.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited