$Shared13 class

Used by:

  • compute:v1 : InstancesSetServiceAccountRequest
  • compute:v1 : ServiceAccount

Constructors

$Shared13({String? email, List<String>? scopes})
$Shared13.fromJson(Map json_)

Properties

email ↔ String?
Email address of the service account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>?
The list of scopes to be made available for this service account.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited