$Shared27 class

Used by:

  • searchads360:v23 : GoogleAdsSearchads360V23Common__ProductConditionInfo
  • searchads360:v23 : GoogleAdsSearchads360V23Resources_ListingGroupFilterDimension_ProductCondition

Constructors

$Shared27({String? condition})
$Shared27.fromJson(Map json_)

Properties

condition String?
Value of the condition. Possible string values are:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited