$Shared30 class

Used by:

  • securitycenter:v1 : Contact
  • securitycenter:v1 : GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo

Constructors

$Shared30({String? email})
$Shared30.fromJson(Map json_)

Properties

email String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited