$ShippingDimension class

Used by:

  • content:v2.1 : ProductShippingDimension
  • merchantapi:products_v1 : ShippingDimension

Constructors

$ShippingDimension({String? unit, double? value})
$ShippingDimension.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unit ↔ String?
The unit of value.
getter/setter pair
value ↔ double?
The dimension of the product used to calculate the shipping cost of the item.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited