$ShippingImprovements class

Used by:

  • content:v2.1 : AccountShippingImprovements
  • merchantapi:accounts_v1 : AutomaticShippingImprovements

Constructors

$ShippingImprovements({bool? allowShippingImprovements})
$ShippingImprovements.fromJson(Map json_)

Properties

allowShippingImprovements ↔ bool?
Enables automatic shipping improvements.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited