$ShuffleWriteMetrics class

Used by:

  • dataproc:v1 : ShuffleWriteMetrics
  • dataproc:v1 : StageShuffleWriteMetrics

Constructors

$ShuffleWriteMetrics({String? bytesWritten, String? recordsWritten, String? writeTimeNanos})
$ShuffleWriteMetrics.fromJson(Map json_)

Properties

bytesWritten ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
recordsWritten ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
writeTimeNanos ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited