$Site class

Used by:

  • displayvideo:v2 : Site
  • displayvideo:v3 : Site
  • displayvideo:v4 : Site

Constructors

$Site({String? name, String? urlOrAppId})
$Site.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the site.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlOrAppId ↔ String?
The app ID or URL of the site.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited