$Size class

Used by:

  • dfareporting:v3.5 : Size
  • dfareporting:v5 : Size

Constructors

$Size({int? height, bool? iab, String? id, String? kind, int? width})
$Size.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
Height of this size.
getter/setter pair
iab ↔ bool?
IAB standard size.
getter/setter pair
id ↔ String?
ID of this size.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int?
Width of this size.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited