$SqlProperty class

Used by:

  • migrationcenter:v1 : MySqlProperty
  • migrationcenter:v1 : PostgreSqlProperty

Constructors

$SqlProperty({bool? enabled, String? numericValue, String? property})
$SqlProperty.fromJson(Map json_)

Properties

enabled ↔ bool?
The property is enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numericValue ↔ String?
The property numeric value.
getter/setter pair
property ↔ String?
The property name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited