$StudioCreativeDimension class

Used by:

  • dfareporting:v4 : StudioCreativeDimension
  • dfareporting:v5 : StudioCreativeDimension

Constructors

$StudioCreativeDimension({int? height, int? width})
$StudioCreativeDimension.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
Height of the studio creative.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int?
Width of the studio creative.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited