$TagSetting class

Used by:

  • dfareporting:v4 : TagSetting
  • dfareporting:v5 : TagSetting

Constructors

$TagSetting({String? additionalKeyValues, bool? includeClickThroughUrls, bool? includeClickTracking, bool? includeUnescapedlpurlMacro, String? keywordOption})
$TagSetting.fromJson(Map json_)

Properties

additionalKeyValues ↔ String?
Additional key-values to be included in tags.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeClickThroughUrls ↔ bool?
Whether static landing page URLs should be included in the tags.
getter/setter pair
includeClickTracking ↔ bool?
Whether click-tracking string should be included in the tags.
getter/setter pair
includeUnescapedlpurlMacro ↔ bool?
Indicates that the unescapedlpurl macro should be included in the tag for the static landing page.
getter/setter pair
keywordOption ↔ String?
Option specifying how keywords are embedded in ad tags.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited