$TagSettings class

Used by:

  • dfareporting:v4 : TagSettings
  • dfareporting:v5 : TagSettings

Constructors

$TagSettings({bool? dynamicTagEnabled, bool? imageTagEnabled})
$TagSettings.fromJson(Map json_)

Properties

dynamicTagEnabled ↔ bool?
Whether dynamic floodlight tags are enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageTagEnabled ↔ bool?
Whether image tags are enabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited