$TargetFrequency class

Used by:

  • displayvideo:v2 : TargetFrequency
  • displayvideo:v3 : TargetFrequency
  • displayvideo:v4 : TargetFrequency

Constructors

$TargetFrequency({String? targetCount, String? timeUnit, int? timeUnitCount})
$TargetFrequency.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetCount ↔ String?
The target number of times, on average, the ads will be shown to the same person in the timespan dictated by time_unit and time_unit_count.
getter/setter pair
timeUnit ↔ String?
The unit of time in which the target frequency will be applied.
getter/setter pair
timeUnitCount ↔ int?
The number of time_unit the target frequency will last.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited