$TargetWindow class

Used by:

  • dfareporting:v4 : TargetWindow
  • dfareporting:v5 : TargetWindow

Constructors

$TargetWindow({String? customHtml, String? targetWindowOption})
$TargetWindow.fromJson(Map json_)

Properties

customHtml ↔ String?
User-entered value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetWindowOption ↔ String?
Type of browser window for which the backup image of the flash creative can be displayed. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited