$TextList class

Used by:

  • displayvideo:v3 : AdPolicyTopicEvidenceTextList
  • displayvideo:v4 : AdPolicyTopicEvidenceTextList
  • searchads360:v23 : GoogleAdsSearchads360V23Common_PolicyTopicEvidence_TextList

Constructors

$TextList({List<String>? texts})
$TextList.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
texts List<String>?
The fragments of text from the resource that caused the policy finding.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited