$TextSpan class

Used by:

  • language:v1 : TextSpan
  • language:v2 : TextSpan

Constructors

$TextSpan({int? beginOffset, String? content})
$TextSpan.fromJson(Map json_)

Properties

beginOffset ↔ int?
The API calculates the beginning offset of the content in the original document according to the EncodingType specified in the API request.
getter/setter pair
content ↔ String?
The content of the text span, which is a substring of the document.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited