$ThirdPartyOnlyConfig class

Used by:

  • displayvideo:v2 : ThirdPartyOnlyConfig
  • displayvideo:v3 : ThirdPartyOnlyConfig
  • displayvideo:v4 : ThirdPartyOnlyConfig

Constructors

$ThirdPartyOnlyConfig({bool? pixelOrderIdReportingEnabled})
$ThirdPartyOnlyConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pixelOrderIdReportingEnabled ↔ bool?
Whether or not order ID reporting for pixels is enabled.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited