toolset property
The resource name of the Toolset from which this tool is derived.
Format:
projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}
Required.
Implementation
core.String? toolset;
The resource name of the Toolset from which this tool is derived.
Format:
projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}
Required.
core.String? toolset;