$TrackingFloodlightActivityConfig class

Used by:

  • displayvideo:v2 : TrackingFloodlightActivityConfig
  • displayvideo:v3 : TrackingFloodlightActivityConfig
  • displayvideo:v4 : TrackingFloodlightActivityConfig

Constructors

$TrackingFloodlightActivityConfig({String? floodlightActivityId, int? postClickLookbackWindowDays, int? postViewLookbackWindowDays})
$TrackingFloodlightActivityConfig.fromJson(Map json_)

Properties

floodlightActivityId ↔ String?
The ID of the Floodlight activity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
postClickLookbackWindowDays ↔ int?
The number of days after an ad has been clicked in which a conversion may be counted.
getter/setter pair
postViewLookbackWindowDays ↔ int?
The number of days after an ad has been viewed in which a conversion may be counted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited