$TrafficShapingConfig class

Used by:

  • connectors:v1 : TrafficShapingConfig
  • integrations:v1 : GoogleCloudConnectorsV1TrafficShapingConfig

Constructors

$TrafficShapingConfig({String? duration, String? quotaLimit})
$TrafficShapingConfig.fromJson(Map json_)

Properties

duration ↔ String?
  • The duration over which the API call quota limits are calculated.
  • getter/setter pair
    hashCode → int
    The hash code for this object.
    no setterinherited
    quotaLimit ↔ String?
    Maximum number of api calls allowed.
    getter/setter pair
    runtimeType → Type
    A representation of the runtime type of the object.
    no setterinherited

    Methods

    noSuchMethod(Invocation invocation) → dynamic
    Invoked when a nonexistent method or property is accessed.
    inherited
    toJson() → Map<String, dynamic>
    toString() → String
    A string representation of this object.
    inherited

    Operators

    operator ==(Object other) → bool
    The equality operator.
    inherited