$TvCampaignSummary class

Used by:

  • dfareporting:v4 : TvCampaignSummary
  • dfareporting:v5 : TvCampaignSummary

Constructors

$TvCampaignSummary({String? endDate, String? grp, String? id, String? impressions, String? kind, String? name, double? spend, String? startDate, String? type})
$TvCampaignSummary.fromJson(Map json_)

Properties

endDate ↔ String?
The end date of the TV campaign, inclusive.
getter/setter pair
grp ↔ String?
GRP of this TV campaign.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
ID of this TV campaign.
getter/setter pair
impressions ↔ String?
Impressions across the entire TV campaign.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spend ↔ double?
Spend across the entire TV campaign.
getter/setter pair
startDate ↔ String?
The start date of the TV campaign, inclusive.
getter/setter pair
type ↔ String?
"CampaignComponentType" of this TV campaign. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited