$UniversalAdId01 class

Used by:

  • dfareporting:v4 : UniversalAdId
  • dfareporting:v5 : UniversalAdId

Constructors

$UniversalAdId01({String? registry, String? value})
$UniversalAdId01.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
registry ↔ String?
Registry used for the Ad ID value. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
ID value for this creative.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited