$UserDefinedVariableConfiguration class

Used by:

  • dfareporting:v4 : UserDefinedVariableConfiguration
  • dfareporting:v5 : UserDefinedVariableConfiguration

Constructors

$UserDefinedVariableConfiguration({String? dataType, String? reportName, String? variableType})
$UserDefinedVariableConfiguration.fromJson(Map json_)

Properties

dataType ↔ String?
Data type for the variable.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reportName ↔ String?
User-friendly name for the variable which will appear in reports.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
variableType ↔ String?
Variable name in the tag.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited