$VersionedPackage class

Used by:

  • cloudasset:v1 : VersionedPackage
  • osconfig:v1 : InventoryVersionedPackage

Constructors

$VersionedPackage({String? architecture, String? packageName, String? version})
$VersionedPackage.fromJson(Map json_)

Properties

architecture ↔ String?
The system architecture this package is intended for.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
packageName ↔ String?
The name of the package.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version ↔ String?
The version of the package.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited