$VertexRagStoreRagResource class

Used by:

  • aiplatform:v1 : GoogleCloudAiplatformV1RetrieveContextsRequestVertexRagStoreRagResource
  • aiplatform:v1 : GoogleCloudAiplatformV1VertexRagStoreRagResource

Constructors

$VertexRagStoreRagResource({String? ragCorpus, List<String>? ragFileIds})
$VertexRagStoreRagResource.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ragCorpus ↔ String?
RagCorpora resource name.
getter/setter pair
ragFileIds ↔ List<String>?
rag_file_id.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited