$VpcAccessibleServices class

Used by:

  • accesscontextmanager:v1 : VpcAccessibleServices
  • cloudasset:v1 : GoogleIdentityAccesscontextmanagerV1VpcAccessibleServices

Constructors

$VpcAccessibleServices({List<String>? allowedServices, bool? enableRestriction})
$VpcAccessibleServices.fromJson(Map json_)

Properties

allowedServices ↔ List<String>?
The list of APIs usable within the Service Perimeter.
getter/setter pair
enableRestriction ↔ bool?
Whether to restrict API calls within the Service Perimeter to the list of APIs specified in 'allowed_services'.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited