$WebsiteList class

Used by:

  • displayvideo:v3 : AdPolicyTopicEvidenceWebsiteList
  • displayvideo:v4 : AdPolicyTopicEvidenceWebsiteList
  • searchads360:v23 : GoogleAdsSearchads360V23Common_PolicyTopicEvidence_WebsiteList

Constructors

$WebsiteList({List<String>? websites})
$WebsiteList.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
websites List<String>?
Websites that caused the policy finding.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited