$WindowsQuickFixEngineeringPackage class

Used by:

  • cloudasset:v1 : WindowsQuickFixEngineeringPackage
  • osconfig:v1 : InventoryWindowsQuickFixEngineeringPackage

Constructors

$WindowsQuickFixEngineeringPackage({String? caption, String? description, String? hotFixId, String? installTime})
$WindowsQuickFixEngineeringPackage.fromJson(Map json_)

Properties

caption ↔ String?
A short textual description of the QFE update.
getter/setter pair
description ↔ String?
A textual description of the QFE update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hotFixId ↔ String?
Unique identifier associated with a particular QFE update.
getter/setter pair
installTime ↔ String?
Date that the QFE update was installed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited