$YoutubeChannelPackAssignedTargetingOptionDetails class

Used by:

  • displayvideo:v2 : YoutubeChannelPackAssignedTargetingOptionDetails
  • displayvideo:v3 : YoutubeChannelPackAssignedTargetingOptionDetails
  • displayvideo:v4 : YoutubeChannelPackAssignedTargetingOptionDetails

Properties

channelPackId String?
The ID of the YouTube channel pack.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
negative bool?
Indicates if this option is being negatively targeted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited