BandingProperties class

Properties referring a single dimension (either row or column).

If both BandedRange.row_properties and BandedRange.column_properties are set, the fill colors are applied to cells according to the following rules:

  • header_color and footer_color take priority over band colors. * first_band_color takes priority over second_band_color. * row_properties takes priority over column_properties. For example, the first row color takes priority over the first column color, but the first column color takes priority over the second row color. Similarly, the row header takes priority over the column header in the top left cell, but the column header takes priority over the first row color if the row header is not set.

Constructors

BandingProperties({Color? firstBandColor, ColorStyle? firstBandColorStyle, Color? footerColor, ColorStyle? footerColorStyle, Color? headerColor, ColorStyle? headerColorStyle, Color? secondBandColor, ColorStyle? secondBandColorStyle})
BandingProperties.fromJson(Map json_)

Properties

firstBandColor ↔ Color?
The first color that is alternating.
getter/setter pair
firstBandColorStyle ↔ ColorStyle?
The first color that is alternating.
getter/setter pair
footerColor ↔ Color?
The color of the last row or column.
getter/setter pair
footerColorStyle ↔ ColorStyle?
The color of the last row or column.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headerColor ↔ Color?
The color of the first row or column.
getter/setter pair
headerColorStyle ↔ ColorStyle?
The color of the first row or column.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondBandColor ↔ Color?
The second color that is alternating.
getter/setter pair
secondBandColorStyle ↔ ColorStyle?
The second color that is alternating.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited