DataSourceRefreshWeeklySchedule class

A weekly schedule for data to refresh on specific days in a given time interval.

Properties

daysOfWeek ↔ List<String>?
Days of the week to refresh.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ TimeOfDay?
The start time of a time interval in which a data source refresh is scheduled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited