DuplicateSheetRequest class

Duplicates the contents of a sheet.

Constructors

DuplicateSheetRequest({int? insertSheetIndex, int? newSheetId, String? newSheetName, int? sourceSheetId})
DuplicateSheetRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
insertSheetIndex ↔ int?
The zero-based index where the new sheet should be inserted.
getter/setter pair
newSheetId ↔ int?
If set, the ID of the new sheet.
getter/setter pair
newSheetName ↔ String?
The name of the new sheet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceSheetId ↔ int?
The sheet to duplicate.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited