Editors class

The editors of a protected range.

Constructors

Editors({bool? domainUsersCanEdit, List<String>? groups, List<String>? users})
Editors.fromJson(Map json_)

Properties

domainUsersCanEdit ↔ bool?
True if anyone in the document's domain has edit access to the protected range.
getter/setter pair
groups ↔ List<String>?
The email addresses of groups with edit access to the protected range.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
users ↔ List<String>?
The email addresses of users with edit access to the protected range.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited