EmbeddedChart class

A chart embedded in a sheet.

Constructors

EmbeddedChart({EmbeddedObjectBorder? border, int? chartId, EmbeddedObjectPosition? position, ChartSpec? spec})
EmbeddedChart.fromJson(Map json_)

Properties

border ↔ EmbeddedObjectBorder?
The border of the chart.
getter/setter pair
chartId ↔ int?
The ID of the chart.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
position ↔ EmbeddedObjectPosition?
The position of the chart.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spec ↔ ChartSpec?
The specification of the chart.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited