MatchedValueRange class

A value range that was matched by one or more data filers.

Constructors

MatchedValueRange({List<DataFilter>? dataFilters, ValueRange? valueRange})
MatchedValueRange.fromJson(Map json_)

Properties

dataFilters ↔ List<DataFilter>?
The DataFilters from the request that matched the range of values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
valueRange ↔ ValueRange?
The values matched by the DataFilter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited