PivotFilterCriteria class

Criteria for showing/hiding rows in a pivot table.

Constructors

PivotFilterCriteria({BooleanCondition? condition, bool? visibleByDefault, List<String>? visibleValues})
PivotFilterCriteria.fromJson(Map json_)

Properties

condition ↔ BooleanCondition?
A condition that must be true for values to be shown.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visibleByDefault ↔ bool?
Whether values are visible by default.
getter/setter pair
visibleValues ↔ List<String>?
Values that should be included.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited