Sheet class

A sheet in a spreadsheet.

Constructors

Sheet({List<BandedRange>? bandedRanges, BasicFilter? basicFilter, List<EmbeddedChart>? charts, List<DimensionGroup>? columnGroups, List<ConditionalFormatRule>? conditionalFormats, List<GridData>? data, List<DeveloperMetadata>? developerMetadata, List<FilterView>? filterViews, List<GridRange>? merges, SheetProperties? properties, List<ProtectedRange>? protectedRanges, List<DimensionGroup>? rowGroups, List<Slicer>? slicers, List<Table>? tables})
Sheet.fromJson(Map json_)

Properties

bandedRanges ↔ List<BandedRange>?
The banded (alternating colors) ranges on this sheet.
getter/setter pair
basicFilter ↔ BasicFilter?
The filter on this sheet, if any.
getter/setter pair
charts ↔ List<EmbeddedChart>?
The specifications of every chart on this sheet.
getter/setter pair
columnGroups ↔ List<DimensionGroup>?
All column groups on this sheet, ordered by increasing range start index, then by group depth.
getter/setter pair
conditionalFormats ↔ List<ConditionalFormatRule>?
The conditional format rules in this sheet.
getter/setter pair
data ↔ List<GridData>?
Data in the grid, if this is a grid sheet.
getter/setter pair
developerMetadata ↔ List<DeveloperMetadata>?
The developer metadata associated with a sheet.
getter/setter pair
filterViews ↔ List<FilterView>?
The filter views in this sheet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
merges ↔ List<GridRange>?
The ranges that are merged together.
getter/setter pair
properties ↔ SheetProperties?
The properties of the sheet.
getter/setter pair
protectedRanges ↔ List<ProtectedRange>?
The protected ranges in this sheet.
getter/setter pair
rowGroups ↔ List<DimensionGroup>?
All row groups on this sheet, ordered by increasing range start index, then by group depth.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slicers ↔ List<Slicer>?
The slicers on this sheet.
getter/setter pair
tables ↔ List<Table>?
The tables on this sheet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited