SheetProperties class

Properties of a sheet.

Constructors

SheetProperties({DataSourceSheetProperties? dataSourceSheetProperties, GridProperties? gridProperties, bool? hidden, int? index, bool? rightToLeft, int? sheetId, String? sheetType, Color? tabColor, ColorStyle? tabColorStyle, String? title})
SheetProperties.fromJson(Map json_)

Properties

dataSourceSheetProperties ↔ DataSourceSheetProperties?
If present, the field contains DATA_SOURCE sheet specific properties.
getter/setter pair
gridProperties ↔ GridProperties?
Additional properties of the sheet if this sheet is a grid.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hidden ↔ bool?
True if the sheet is hidden in the UI, false if it's visible.
getter/setter pair
index ↔ int?
The index of the sheet within the spreadsheet.
getter/setter pair
rightToLeft ↔ bool?
True if the sheet is an RTL sheet instead of an LTR sheet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetId ↔ int?
The ID of the sheet.
getter/setter pair
sheetType ↔ String?
The type of sheet.
getter/setter pair
tabColor ↔ Color?
The color of the tab in the UI.
getter/setter pair
tabColorStyle ↔ ColorStyle?
The color of the tab in the UI.
getter/setter pair
title ↔ String?
The name of the sheet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited