Slicer class

A slicer in a sheet.

Constructors

Slicer({EmbeddedObjectPosition? position, int? slicerId, SlicerSpec? spec})
Slicer.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
position ↔ EmbeddedObjectPosition?
The position of the slicer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slicerId ↔ int?
The ID of the slicer.
getter/setter pair
spec ↔ SlicerSpec?
The specification of the slicer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited