SlicerSpec class

The specifications of a slicer.

Constructors

SlicerSpec({bool? applyToPivotTables, Color? backgroundColor, ColorStyle? backgroundColorStyle, int? columnIndex, GridRange? dataRange, FilterCriteria? filterCriteria, String? horizontalAlignment, TextFormat? textFormat, String? title})
SlicerSpec.fromJson(Map json_)

Properties

applyToPivotTables ↔ bool?
True if the filter should apply to pivot tables.
getter/setter pair
backgroundColor ↔ Color?
The background color of the slicer.
getter/setter pair
backgroundColorStyle ↔ ColorStyle?
The background color of the slicer.
getter/setter pair
columnIndex ↔ int?
The zero-based column index in the data table on which the filter is applied to.
getter/setter pair
dataRange ↔ GridRange?
The data range of the slicer.
getter/setter pair
filterCriteria ↔ FilterCriteria?
The filtering criteria of the slicer.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
horizontalAlignment ↔ String?
The horizontal alignment of title in the slicer.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textFormat ↔ TextFormat?
The text format of title in the slicer.
getter/setter pair
title ↔ String?
The title of the slicer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited