batchClearByDataFilter method

Future<BatchClearValuesByDataFilterResponse> batchClearByDataFilter(
  1. BatchClearValuesByDataFilterRequest request,
  2. String spreadsheetId, {
  3. String? $fields,
})

Clears one or more ranges of values from a spreadsheet.

For more information, see Read, write, and search metadata. The caller must specify the spreadsheet ID and one or more DataFilters. Ranges matching any of the specified data filters will be cleared. Only values are cleared -- all other properties of the cell (such as formatting, data validation, etc.) are kept.

request - The metadata request object.

Request parameters:

spreadsheetId - The ID of the spreadsheet to update.

$fields - Selector specifying which fields to include in a partial response.

Completes with a BatchClearValuesByDataFilterResponse.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<BatchClearValuesByDataFilterResponse> batchClearByDataFilter(
  BatchClearValuesByDataFilterRequest request,
  core.String spreadsheetId, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'v4/spreadsheets/' +
      commons.escapeVariable('$spreadsheetId') +
      '/values:batchClearByDataFilter';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return BatchClearValuesByDataFilterResponse.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}