SiteVerificationWebResourceResource class

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The string used to identify this site.
getter/setter pair
owners ↔ List<String>?
The email addresses of all verified owners.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
site ↔ SiteVerificationWebResourceResourceSite?
The address and type of a site that is verified or will be verified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited