WebResourceResource class

Constructors

WebResourceResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String id, {String? $fields}) → Future<void>
Relinquish ownership of a website or domain.
get(String id, {String? $fields}) → Future<SiteVerificationWebResourceResource>
Get the most current data for a website or domain.
getToken(SiteVerificationWebResourceGettokenRequest request, {String? $fields}) → Future<SiteVerificationWebResourceGettokenResponse>
Get a verification token for placing on a website or domain.
insert(SiteVerificationWebResourceResource request, String verificationMethod, {String? $fields}) → Future<SiteVerificationWebResourceResource>
Attempt verification of a website or domain.
list({String? $fields}) → Future<SiteVerificationWebResourceListResponse>
Get the list of your verified websites and domains.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(SiteVerificationWebResourceResource request, String id, {String? $fields}) → Future<SiteVerificationWebResourceResource>
Modify the list of owners for your website or domain.
toString() → String
A string representation of this object.
inherited
update(SiteVerificationWebResourceResource request, String id, {String? $fields}) → Future<SiteVerificationWebResourceResource>
Modify the list of owners for your website or domain.

Operators

operator ==(Object other) → bool
The equality operator.
inherited