AutoText class

A TextElement kind that represents auto text.

Constructors

AutoText({String? content, TextStyle? style, String? type})
AutoText.fromJson(Map json_)

Properties

content ↔ String?
The rendered content of this auto text, if available.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle?
The styling applied to this auto text.
getter/setter pair
type ↔ String?
The type of this auto text. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited