Bullet class

Describes the bullet of a paragraph.

Constructors

Bullet({TextStyle? bulletStyle, String? glyph, String? listId, int? nestingLevel})
Bullet.fromJson(Map json_)

Properties

bulletStyle ↔ TextStyle?
The paragraph specific text style applied to this bullet.
getter/setter pair
glyph ↔ String?
The rendered bullet glyph for this paragraph.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
listId ↔ String?
The ID of the list this paragraph belongs to.
getter/setter pair
nestingLevel ↔ int?
The nesting level of this paragraph in the list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited