CreateLineRequest class

Creates a line.

Constructors

CreateLineRequest({String? category, PageElementProperties? elementProperties, String? lineCategory, String? objectId})
CreateLineRequest.fromJson(Map json_)

Properties

category ↔ String?
The category of the line to be created.
getter/setter pair
elementProperties ↔ PageElementProperties?
The element properties for the line.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineCategory ↔ String?
The category of the line to be created.
getter/setter pair
objectId ↔ String?
A user-supplied object ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited