CreateShapeRequest class

Creates a new shape.

Constructors

CreateShapeRequest({PageElementProperties? elementProperties, String? objectId, String? shapeType})
CreateShapeRequest.fromJson(Map json_)

Properties

elementProperties ↔ PageElementProperties?
The element properties for the shape.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String?
A user-supplied object ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shapeType ↔ String?
The shape type. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited