CreateSlideRequest class

Creates a slide.

Constructors

CreateSlideRequest({int? insertionIndex, String? objectId, List<LayoutPlaceholderIdMapping>? placeholderIdMappings, LayoutReference? slideLayoutReference})
CreateSlideRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
insertionIndex ↔ int?
The optional zero-based index indicating where to insert the slides.
getter/setter pair
objectId ↔ String?
A user-supplied object ID.
getter/setter pair
placeholderIdMappings ↔ List<LayoutPlaceholderIdMapping>?
An optional list of object ID mappings from the placeholder(s) on the layout to the placeholders that are created on the slide from the specified layout.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slideLayoutReference ↔ LayoutReference?
Layout reference of the slide to be inserted, based on the current master, which is one of the following: - The master of the previous slide index.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited