CreateTableRequest class

Creates a new table.

Constructors

CreateTableRequest({int? columns, PageElementProperties? elementProperties, String? objectId, int? rows})
CreateTableRequest.fromJson(Map json_)

Properties

columns ↔ int?
Number of columns in the table.
getter/setter pair
elementProperties ↔ PageElementProperties?
The element properties for the table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String?
A user-supplied object ID.
getter/setter pair
rows ↔ int?
Number of rows in the table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited