DeleteParagraphBulletsRequest class

Deletes bullets from all of the paragraphs that overlap with the given text index range.

The nesting level of each paragraph will be visually preserved by adding indent to the start of the corresponding paragraph.

Constructors

DeleteParagraphBulletsRequest({TableCellLocation? cellLocation, String? objectId, Range? textRange})
DeleteParagraphBulletsRequest.fromJson(Map json_)

Properties

cellLocation ↔ TableCellLocation?
The optional table cell location if the text to be modified is in a table cell.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String?
The object ID of the shape or table containing the text to delete bullets from.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textRange ↔ Range?
The range of text to delete bullets from, based on TextElement indexes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited