DeleteTableColumnRequest class

Deletes a column from a table.

Constructors

DeleteTableColumnRequest({TableCellLocation? cellLocation, String? tableObjectId})
DeleteTableColumnRequest.fromJson(Map json_)

Properties

cellLocation ↔ TableCellLocation?
The reference table cell location from which a column will be deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableObjectId ↔ String?
The table to delete columns from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited