GroupObjectsRequest class

Groups objects to create an object group.

For example, groups PageElements to create a Group on the same page as all the children.

Constructors

GroupObjectsRequest({List<String>? childrenObjectIds, String? groupObjectId})
GroupObjectsRequest.fromJson(Map json_)

Properties

childrenObjectIds ↔ List<String>?
The object IDs of the objects to group.
getter/setter pair
groupObjectId ↔ String?
A user-supplied object ID for the group to be created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited