InsertTextRequest class

Inserts text into a shape or a table cell.

Constructors

InsertTextRequest({TableCellLocation? cellLocation, int? insertionIndex, String? objectId, String? text})
InsertTextRequest.fromJson(Map json_)

Properties

cellLocation ↔ TableCellLocation?
The optional table cell location if the text is to be inserted into a table cell.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
insertionIndex ↔ int?
The index where the text will be inserted, in Unicode code units, based on TextElement indexes.
getter/setter pair
objectId ↔ String?
The object ID of the shape or table where the text will be inserted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The text to be inserted.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited