LineConnection class

The properties for one end of a Line connection.

Constructors

LineConnection({String? connectedObjectId, int? connectionSiteIndex})
LineConnection.fromJson(Map json_)

Properties

connectedObjectId ↔ String?
The object ID of the connected page element.
getter/setter pair
connectionSiteIndex ↔ int?
The index of the connection site on the connected page element.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited