LineProperties class

The properties of the Line.

When unset, these fields default to values that match the appearance of new lines created in the Slides editor.

Constructors

LineProperties({String? dashStyle, String? endArrow, LineConnection? endConnection, LineFill? lineFill, Link? link, String? startArrow, LineConnection? startConnection, Dimension? weight})
LineProperties.fromJson(Map json_)

Properties

dashStyle ↔ String?
The dash style of the line. Possible string values are:
getter/setter pair
endArrow ↔ String?
The style of the arrow at the end of the line. Possible string values are:
getter/setter pair
endConnection ↔ LineConnection?
The connection at the end of the line.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lineFill ↔ LineFill?
The fill of the line.
getter/setter pair
The hyperlink destination of the line.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startArrow ↔ String?
The style of the arrow at the beginning of the line. Possible string values are:
getter/setter pair
startConnection ↔ LineConnection?
The connection at the beginning of the line.
getter/setter pair
weight ↔ Dimension?
The thickness of the line.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited