List class

A List describes the look and feel of bullets belonging to paragraphs associated with a list.

A paragraph that is part of a list has an implicit reference to that list's ID.

Constructors

List({String? listId, Map<String, NestingLevel>? nestingLevel})
List.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
listId ↔ String?
The ID of the list.
getter/setter pair
nestingLevel ↔ Map<String, NestingLevel>?
A map of nesting levels to the properties of bullets at the associated level.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited