NotesProperties class

The properties of Page that are only relevant for pages with page_type NOTES.

Constructors

NotesProperties({String? speakerNotesObjectId})
NotesProperties.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speakerNotesObjectId ↔ String?
The object ID of the shape on this notes page that contains the speaker notes for the corresponding slide.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited