Presentation class

A Google Slides presentation.

Constructors

Presentation({List<Page>? layouts, String? locale, List<Page>? masters, Page? notesMaster, Size? pageSize, String? presentationId, String? revisionId, List<Page>? slides, String? title})
Presentation.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
layouts ↔ List<Page>?
The layouts in the presentation.
getter/setter pair
locale ↔ String?
The locale of the presentation, as an IETF BCP 47 language tag.
getter/setter pair
masters ↔ List<Page>?
The slide masters in the presentation.
getter/setter pair
notesMaster ↔ Page?
The notes master in the presentation.
getter/setter pair
pageSize ↔ Size?
The size of pages in the presentation.
getter/setter pair
presentationId ↔ String?
The ID of the presentation.
getter/setter pair
revisionId ↔ String?
The revision ID of the presentation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slides ↔ List<Page>?
The slides in the presentation.
getter/setter pair
title ↔ String?
The title of the presentation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited