RerouteLineRequest class

Reroutes a line such that it's connected at the two closest connection sites on the connected page elements.

Constructors

RerouteLineRequest({String? objectId})
RerouteLineRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String?
The object ID of the line to reroute.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited