Response class

A single response from an update.

Constructors

Response({CreateImageResponse? createImage, CreateLineResponse? createLine, CreateShapeResponse? createShape, CreateSheetsChartResponse? createSheetsChart, CreateSlideResponse? createSlide, CreateTableResponse? createTable, CreateVideoResponse? createVideo, DuplicateObjectResponse? duplicateObject, GroupObjectsResponse? groupObjects, ReplaceAllShapesWithImageResponse? replaceAllShapesWithImage, ReplaceAllShapesWithSheetsChartResponse? replaceAllShapesWithSheetsChart, ReplaceAllTextResponse? replaceAllText})
Response.fromJson(Map json_)

Properties

createImage ↔ CreateImageResponse?
The result of creating an image.
getter/setter pair
createLine ↔ CreateLineResponse?
The result of creating a line.
getter/setter pair
createShape ↔ CreateShapeResponse?
The result of creating a shape.
getter/setter pair
createSheetsChart ↔ CreateSheetsChartResponse?
The result of creating a Google Sheets chart.
getter/setter pair
createSlide ↔ CreateSlideResponse?
The result of creating a slide.
getter/setter pair
createTable ↔ CreateTableResponse?
The result of creating a table.
getter/setter pair
createVideo ↔ CreateVideoResponse?
The result of creating a video.
getter/setter pair
duplicateObject ↔ DuplicateObjectResponse?
The result of duplicating an object.
getter/setter pair
groupObjects ↔ GroupObjectsResponse?
The result of grouping objects.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
replaceAllShapesWithImage ↔ ReplaceAllShapesWithImageResponse?
The result of replacing all shapes matching some criteria with an image.
getter/setter pair
replaceAllShapesWithSheetsChart ↔ ReplaceAllShapesWithSheetsChartResponse?
The result of replacing all shapes matching some criteria with a Google Sheets chart.
getter/setter pair
replaceAllText ↔ ReplaceAllTextResponse?
The result of replacing text.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited