Shadow class

The shadow properties of a page element.

If these fields are unset, they may be inherited from a parent placeholder if it exists. If there is no parent, the fields will default to the value used for new page elements created in the Slides editor, which may depend on the page element kind.

Constructors

Shadow({String? alignment, double? alpha, Dimension? blurRadius, OpaqueColor? color, String? propertyState, bool? rotateWithShape, AffineTransform? transform, String? type})
Shadow.fromJson(Map json_)

Properties

alignment ↔ String?
The alignment point of the shadow, that sets the origin for translate, scale and skew of the shadow.
getter/setter pair
alpha ↔ double?
The alpha of the shadow's color, from 0.0 to 1.0.
getter/setter pair
blurRadius ↔ Dimension?
The radius of the shadow blur.
getter/setter pair
color ↔ OpaqueColor?
The shadow color value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
propertyState ↔ String?
The shadow property state.
getter/setter pair
rotateWithShape ↔ bool?
Whether the shadow should rotate with the shape.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform ↔ AffineTransform?
Transform that encodes the translate, scale, and skew of the shadow, relative to the alignment position.
getter/setter pair
type ↔ String?
The type of the shadow.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited