ShapeProperties class

The properties of a Shape.

If the shape is a placeholder shape as determined by the placeholder field, then these properties may be inherited from a parent placeholder shape. Determining the rendered value of the property depends on the corresponding property_state field value. Any text autofit settings on the shape are automatically deactivated by requests that can impact how text fits in the shape.

Constructors

ShapeProperties({Autofit? autofit, String? contentAlignment, Link? link, Outline? outline, Shadow? shadow, ShapeBackgroundFill? shapeBackgroundFill})
ShapeProperties.fromJson(Map json_)

Properties

autofit ↔ Autofit?
The autofit properties of the shape.
getter/setter pair
contentAlignment ↔ String?
The alignment of the content in the shape.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
The hyperlink destination of the shape.
getter/setter pair
outline ↔ Outline?
The outline of the shape.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadow ↔ Shadow?
The shadow properties of the shape.
getter/setter pair
shapeBackgroundFill ↔ ShapeBackgroundFill?
The background fill of the shape.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited