SlideProperties class

The properties of Page that are only relevant for pages with page_type SLIDE.

Constructors

SlideProperties({bool? isSkipped, String? layoutObjectId, String? masterObjectId, Page? notesPage})
SlideProperties.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isSkipped ↔ bool?
Whether the slide is skipped in the presentation mode.
getter/setter pair
layoutObjectId ↔ String?
The object ID of the layout that this slide is based on.
getter/setter pair
masterObjectId ↔ String?
The object ID of the master that this slide is based on.
getter/setter pair
notesPage ↔ Page?
The notes page that this slide is associated with.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited