TableCell class

Properties and contents of each table cell.

Constructors

TableCell({int? columnSpan, TableCellLocation? location, int? rowSpan, TableCellProperties? tableCellProperties, TextContent? text})
TableCell.fromJson(Map json_)

Properties

columnSpan ↔ int?
Column span of the cell.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ TableCellLocation?
The location of the cell within the table.
getter/setter pair
rowSpan ↔ int?
Row span of the cell.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableCellProperties ↔ TableCellProperties?
The properties of the table cell.
getter/setter pair
text ↔ TextContent?
The text content of the cell.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited