TextElement class

A TextElement describes the content of a range of indices in the text content of a Shape or TableCell.

Constructors

TextElement({AutoText? autoText, int? endIndex, ParagraphMarker? paragraphMarker, int? startIndex, TextRun? textRun})
TextElement.fromJson(Map json_)

Properties

autoText ↔ AutoText?
A TextElement representing a spot in the text that is dynamically replaced with content that can change over time.
getter/setter pair
endIndex ↔ int?
The zero-based end index of this text element, exclusive, in Unicode code units.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
paragraphMarker ↔ ParagraphMarker?
A marker representing the beginning of a new paragraph.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startIndex ↔ int?
The zero-based start index of this text element, in Unicode code units.
getter/setter pair
textRun ↔ TextRun?
A TextElement representing a run of text where all of the characters in the run have the same TextStyle.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited