TextRun class

A TextElement kind that represents a run of text that all has the same styling.

Constructors

TextRun({String? content, TextStyle? style})
TextRun.fromJson(Map json_)

Properties

content ↔ String?
The text of this run.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style ↔ TextStyle?
The styling applied to this run.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited