TextStyle class

Represents the styling that can be applied to a TextRun.

If this text is contained in a shape with a parent placeholder, then these text styles may be inherited from the parent. Which text styles are inherited depend on the nesting level of lists: * A text run in a paragraph that is not in a list will inherit its text style from the the newline character in the paragraph at the 0 nesting level of the list inside the parent placeholder. * A text run in a paragraph that is in a list will inherit its text style from the newline character in the paragraph at its corresponding nesting level of the list inside the parent placeholder. Inherited text styles are represented as unset fields in this message. If text is contained in a shape without a parent placeholder, unsetting these fields will revert the style to a value matching the defaults in the Slides editor.

Constructors

TextStyle({OptionalColor? backgroundColor, String? baselineOffset, bool? bold, String? fontFamily, Dimension? fontSize, OptionalColor? foregroundColor, bool? italic, Link? link, bool? smallCaps, bool? strikethrough, bool? underline, WeightedFontFamily? weightedFontFamily})
TextStyle.fromJson(Map json_)

Properties

backgroundColor ↔ OptionalColor?
The background color of the text.
getter/setter pair
baselineOffset ↔ String?
The text's vertical offset from its normal position.
getter/setter pair
bold ↔ bool?
Whether or not the text is rendered as bold.
getter/setter pair
fontFamily ↔ String?
The font family of the text.
getter/setter pair
fontSize ↔ Dimension?
The size of the text's font.
getter/setter pair
foregroundColor ↔ OptionalColor?
The color of the text itself.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
italic ↔ bool?
Whether or not the text is italicized.
getter/setter pair
The hyperlink destination of the text.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
smallCaps ↔ bool?
Whether or not the text is in small capital letters.
getter/setter pair
strikethrough ↔ bool?
Whether or not the text is struck through.
getter/setter pair
underline ↔ bool?
Whether or not the text is underlined.
getter/setter pair
weightedFontFamily ↔ WeightedFontFamily?
The font family and rendered weight of the text.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited