Thumbnail class

The thumbnail of a page.

Constructors

Thumbnail({String? contentUrl, int? height, int? width})
Thumbnail.fromJson(Map json_)

Properties

contentUrl ↔ String?
The content URL of the thumbnail image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
The positive height in pixels of the thumbnail image.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int?
The positive width in pixels of the thumbnail image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited