UpdateLineCategoryRequest class

Updates the category of a line.

Constructors

UpdateLineCategoryRequest({String? lineCategory, String? objectId})
UpdateLineCategoryRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lineCategory ↔ String?
The line category to update to.
getter/setter pair
objectId ↔ String?
The object ID of the line the update is applied to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited