UpdatePageElementTransformRequest class

Updates the transform of a page element.

Updating the transform of a group will change the absolute transform of the page elements in that group, which can change their visual appearance. See the documentation for PageElement.transform for more details.

Properties

applyMode ↔ String?
The apply mode of the transform update. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String?
The object ID of the page element to update.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transform ↔ AffineTransform?
The input transform matrix used to update the page element.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited