UpdateSlidePropertiesRequest class

Updates the properties of a Slide.

Constructors

UpdateSlidePropertiesRequest({String? fields, String? objectId, SlideProperties? slideProperties})
UpdateSlidePropertiesRequest.fromJson(Map json_)

Properties

fields ↔ String?
The fields that should be updated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String?
The object ID of the slide the update is applied to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slideProperties ↔ SlideProperties?
The slide properties to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited