UpdateSlidesPositionRequest class

Updates the position of slides in the presentation.

Constructors

UpdateSlidesPositionRequest({int? insertionIndex, List<String>? slideObjectIds})
UpdateSlidesPositionRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
insertionIndex ↔ int?
The index where the slides should be inserted, based on the slide arrangement before the move takes place.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slideObjectIds ↔ List<String>?
The IDs of the slides in the presentation that should be moved.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited