UpdateTableBorderPropertiesRequest class

Updates the properties of the table borders in a Table.

Constructors

UpdateTableBorderPropertiesRequest({String? borderPosition, String? fields, String? objectId, TableBorderProperties? tableBorderProperties, TableRange? tableRange})
UpdateTableBorderPropertiesRequest.fromJson(Map json_)

Properties

borderPosition ↔ String?
The border position in the table range the updates should apply to.
getter/setter pair
fields ↔ String?
The fields that should be updated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String?
The object ID of the table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableBorderProperties ↔ TableBorderProperties?
The table border properties to update.
getter/setter pair
tableRange ↔ TableRange?
The table range representing the subset of the table to which the updates are applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited