UpdateTableCellPropertiesRequest class

Update the properties of a TableCell.

Constructors

UpdateTableCellPropertiesRequest({String? fields, String? objectId, TableCellProperties? tableCellProperties, TableRange? tableRange})
UpdateTableCellPropertiesRequest.fromJson(Map json_)

Properties

fields ↔ String?
The fields that should be updated.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
objectId ↔ String?
The object ID of the table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tableCellProperties ↔ TableCellProperties?
The table cell properties to update.
getter/setter pair
tableRange ↔ TableRange?
The table range representing the subset of the table to which the updates are applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited