VideoProperties class

The properties of the Video.

Constructors

VideoProperties({bool? autoPlay, int? end, bool? mute, Outline? outline, int? start})
VideoProperties.fromJson(Map json_)

Properties

autoPlay ↔ bool?
Whether to enable video autoplay when the page is displayed in present mode.
getter/setter pair
end ↔ int?
The time at which to end playback, measured in seconds from the beginning of the video.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mute ↔ bool?
Whether to mute the audio during video playback.
getter/setter pair
outline ↔ Outline?
The outline of the video.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ int?
The time at which to start playback, measured in seconds from the beginning of the video.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited