GoogleHomeEnterpriseSdmV1Structure class

Structure resource represents an instance of enterprise managed home or hotel room.

Properties

ghpName String?
The unique identifier for the structure in Google Home Platform.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The resource name of the structure.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
traits Map<String, Object?>?
Structure traits.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited