BuildingInsightsDetectedArrays class
Information about solar arrays detected on the building.
Constructors
- BuildingInsightsDetectedArrays({String? detectionStatus, Date? latestCaptureDate})
- BuildingInsightsDetectedArrays.fromJson(Map json_)
Properties
- detectionStatus ↔ String?
-
Indicates the detection status of solar arrays for this building.
Possible string values are:
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- latestCaptureDate ↔ Date?
-
The date indicating when the latest solar array data was captured.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited