detectionStatus property
Indicates the detection status of solar arrays for this building. Possible string values are:
- "DETECTION_STATUS_UNSPECIFIED" : Unspecified status.
- "DETECTION_STATUS_DATA_UNAVAILABLE" : Detected solar array data is unavailable for this building.
- "DETECTION_STATUS_ARRAYS_DETECTED" : At least one solar array has been detected for this building.
- "DETECTION_STATUS_NO_ARRAYS_DETECTED" : No solar arrays detected for this building.
Implementation
core.String? detectionStatus;