DataLayersResource class

Constructors

DataLayersResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

get({bool? exactQualityRequired, List<String>? experiments, double? location_latitude, double? location_longitude, double? pixelSizeMeters, double? radiusMeters, String? requiredQuality, String? view, String? $fields}) → Future<DataLayers>
Gets solar information for a region surrounding a location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited