SolarPotential class

Information about the solar potential of a building.

A number of fields in this are defined in terms of "panels". The fields panel_capacity_watts, panel_height_meters, and panel_width_meters describe the parameters of the model of panel used in these calculations.

Constructors

SolarPotential({SizeAndSunshineStats? buildingStats, double? carbonOffsetFactorKgPerMwh, List<FinancialAnalysis>? financialAnalyses, double? maxArrayAreaMeters2, int? maxArrayPanelsCount, double? maxSunshineHoursPerYear, double? panelCapacityWatts, double? panelHeightMeters, int? panelLifetimeYears, double? panelWidthMeters, List<RoofSegmentSizeAndSunshineStats>? roofSegmentStats, List<SolarPanelConfig>? solarPanelConfigs, List<SolarPanel>? solarPanels, SizeAndSunshineStats? wholeRoofStats})
SolarPotential.fromJson(Map json_)

Properties

buildingStats ↔ SizeAndSunshineStats?
Size and sunlight quantiles for the entire building, including parts of the roof that were not assigned to some roof segment.
getter/setter pair
carbonOffsetFactorKgPerMwh ↔ double?
Equivalent amount of CO2 produced per MWh of grid electricity.
getter/setter pair
financialAnalyses ↔ List<FinancialAnalysis>?
A FinancialAnalysis gives the savings from going solar assuming a given monthly bill and a given electricity provider.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxArrayAreaMeters2 ↔ double?
Size, in square meters, of the maximum array.
getter/setter pair
maxArrayPanelsCount ↔ int?
Size of the maximum array - that is, the maximum number of panels that can fit on the roof.
getter/setter pair
maxSunshineHoursPerYear ↔ double?
Maximum number of sunshine hours received per year, by any point on the roof.
getter/setter pair
panelCapacityWatts ↔ double?
Capacity, in watts, of the panel used in the calculations.
getter/setter pair
panelHeightMeters ↔ double?
Height, in meters in portrait orientation, of the panel used in the calculations.
getter/setter pair
panelLifetimeYears ↔ int?
The expected lifetime, in years, of the solar panels.
getter/setter pair
panelWidthMeters ↔ double?
Width, in meters in portrait orientation, of the panel used in the calculations.
getter/setter pair
roofSegmentStats ↔ List<RoofSegmentSizeAndSunshineStats>?
Size and sunlight quantiles for each roof segment.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
solarPanelConfigs ↔ List<SolarPanelConfig>?
Each SolarPanelConfig describes a different arrangement of solar panels on the roof.
getter/setter pair
solarPanels ↔ List<SolarPanel>?
Each SolarPanel describes a single solar panel.
getter/setter pair
wholeRoofStats ↔ SizeAndSunshineStats?
Total size and sunlight quantiles for the part of the roof that was assigned to some roof segment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited