Ack class

Arguments to ack operations.

Constructors

Ack({bool? ignoreNotFound, List<Object?>? key, String? queue})
Ack.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ignoreNotFound ↔ bool?
By default, an attempt to ack a message that does not exist will fail with a NOT_FOUND error.
getter/setter pair
key ↔ List<Object?>?
The primary key of the message to be acked.
getter/setter pair
queue ↔ String?
The queue where the message to be acked is stored.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited