AdaptMessageRequest class

Message sent by the client to the adapter.

Constructors

AdaptMessageRequest({Map<String, String>? attachments, String? payload, String? protocol})
AdaptMessageRequest.fromJson(Map json_)

Properties

attachments ↔ Map<String, String>?
Opaque request state passed by the client to the server.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payload ↔ String?
Uninterpreted bytes from the underlying wire protocol.
getter/setter pair
payloadAsBytes ↔ List<int>
getter/setter pair
protocol ↔ String?
Identifier for the underlying wire protocol.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited