AdaptMessageResponse class

Message sent by the adapter to the client.

Constructors

AdaptMessageResponse({bool? last, String? payload, Map<String, String>? stateUpdates})
AdaptMessageResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
last ↔ bool?
Indicates whether this is the last AdaptMessageResponse in the stream.
getter/setter pair
payload ↔ String?
Uninterpreted bytes from the underlying wire protocol.
getter/setter pair
payloadAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stateUpdates ↔ Map<String, String>?
Opaque state updates to be applied by the client.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited