AutoscalingConfigOverrides class

Overrides the top-level autoscaling configuration for the replicas identified by replica_selection.

All fields in this message are optional. Any unspecified fields will use the corresponding values from the top-level autoscaling configuration.

Constructors

AutoscalingConfigOverrides({AutoscalingLimits? autoscalingLimits, int? autoscalingTargetHighPriorityCpuUtilizationPercent, int? autoscalingTargetTotalCpuUtilizationPercent, bool? disableHighPriorityCpuAutoscaling, bool? disableTotalCpuAutoscaling})
AutoscalingConfigOverrides.fromJson(Map json_)

Properties

autoscalingLimits ↔ AutoscalingLimits?
If specified, overrides the min/max limit in the top-level autoscaling configuration for the selected replicas.
getter/setter pair
autoscalingTargetHighPriorityCpuUtilizationPercent ↔ int?
If specified, overrides the autoscaling target high_priority_cpu_utilization_percent in the top-level autoscaling configuration for the selected replicas.
getter/setter pair
autoscalingTargetTotalCpuUtilizationPercent ↔ int?
If specified, overrides the autoscaling target total_cpu_utilization_percent in the top-level autoscaling configuration for the selected replicas.
getter/setter pair
disableHighPriorityCpuAutoscaling ↔ bool?
If true, disables high priority CPU autoscaling for the selected replicas and ignores high_priority_cpu_utilization_percent in the top-level autoscaling configuration.
getter/setter pair
disableTotalCpuAutoscaling ↔ bool?
If true, disables total CPU autoscaling for the selected replicas and ignores total_cpu_utilization_percent in the top-level autoscaling configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited