totalCpuUtilizationPercent property

int? totalCpuUtilizationPercent
getter/setter pair

The target total CPU utilization percentage that the autoscaler should be trying to achieve for the instance.

This number is on a scale from 0 (no utilization) to 100 (full utilization). The valid range is [10, 90] inclusive. If not specified or set to 0, the autoscaler skips scaling based on total CPU utilization. If both high_priority_cpu_utilization_percent and total_cpu_utilization_percent are specified, the autoscaler provisions the larger of the two required compute capacities to satisfy both targets.

Optional.

Implementation

core.int? totalCpuUtilizationPercent;