Backup class

A backup of a Cloud Spanner database.

Constructors

Backup({List<String>? backupSchedules, String? createTime, String? database, String? databaseDialect, EncryptionInfo? encryptionInfo, List<EncryptionInfo>? encryptionInformation, String? exclusiveSizeBytes, String? expireTime, String? freeableSizeBytes, String? incrementalBackupChainId, List<BackupInstancePartition>? instancePartitions, String? maxExpireTime, String? minimumRestorableEdition, String? name, String? oldestVersionTime, List<String>? referencingBackups, List<String>? referencingDatabases, String? sizeBytes, String? state, String? versionTime})
Backup.fromJson(Map json_)

Properties

backupSchedules ↔ List<String>?
List of backup schedule URIs that are associated with creating this backup.
getter/setter pair
createTime ↔ String?
The time the CreateBackup request is received.
getter/setter pair
database ↔ String?
Required for the CreateBackup operation.
getter/setter pair
databaseDialect ↔ String?
The database dialect information for the backup.
getter/setter pair
encryptionInfo ↔ EncryptionInfo?
The encryption information for the backup.
getter/setter pair
encryptionInformation ↔ List<EncryptionInfo>?
The encryption information for the backup, whether it is protected by one or more KMS keys.
getter/setter pair
exclusiveSizeBytes ↔ String?
For a backup in an incremental backup chain, this is the storage space needed to keep the data that has changed since the previous backup.
getter/setter pair
expireTime ↔ String?
Required for the CreateBackup operation.
getter/setter pair
freeableSizeBytes ↔ String?
The number of bytes that will be freed by deleting this backup.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
incrementalBackupChainId ↔ String?
Populated only for backups in an incremental backup chain.
getter/setter pair
instancePartitions ↔ List<BackupInstancePartition>?
The instance partition storing the backup.
getter/setter pair
maxExpireTime ↔ String?
The max allowed expiration time of the backup, with microseconds granularity.
getter/setter pair
minimumRestorableEdition ↔ String?
The minimum edition required to successfully restore the backup.
getter/setter pair
name ↔ String?
Output only for the CreateBackup operation.
getter/setter pair
oldestVersionTime ↔ String?
Data deleted at a time older than this is guaranteed not to be retained in order to support this backup.
getter/setter pair
referencingBackups ↔ List<String>?
The names of the destination backups being created by copying this source backup.
getter/setter pair
referencingDatabases ↔ List<String>?
The names of the restored databases that reference the backup.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeBytes ↔ String?
Size of the backup in bytes.
getter/setter pair
state ↔ String?
The current state of the backup.
getter/setter pair
versionTime ↔ String?
The backup will contain an externally consistent copy of the database at the timestamp specified by version_time.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited