referencingBackups property
The names of the destination backups being created by copying this source backup.
The backup names are of the form
projects/{project}/instances/{instance}/backups/{backup}. Referencing
backups may exist in different instances. The existence of any referencing
backup prevents the backup from being deleted. When the copy operation is
done (either successfully completed or cancelled or the destination backup
is deleted), the reference to the backup is removed.
Output only.
Implementation
core.List<core.String>? referencingBackups;