BatchWriteResponse class

The result of applying a batch of mutations.

Constructors

BatchWriteResponse({String? commitTimestamp, List<int>? indexes, Status? status})
BatchWriteResponse.fromJson(Map json_)

Properties

commitTimestamp ↔ String?
The commit timestamp of the transaction that applied this batch.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indexes ↔ List<int>?
The mutation groups applied in this batch.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ Status?
An OK status indicates success.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited