ChangeQuorumRequest class

The request for ChangeQuorum.

Constructors

ChangeQuorumRequest({String? etag, String? name, QuorumType? quorumType})
ChangeQuorumRequest.fromJson(Map json_)

Properties

etag ↔ String?
The etag is the hash of the QuorumInfo.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the database in which to apply ChangeQuorum.
getter/setter pair
quorumType ↔ QuorumType?
The type of this quorum.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited