ChildLink class

Metadata associated with a parent-child relationship appearing in a PlanNode.

Constructors

ChildLink({int? childIndex, String? type, String? variable})
ChildLink.fromJson(Map json_)

Properties

childIndex ↔ int?
The node to which the link points.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of the link.
getter/setter pair
variable ↔ String?
Only present if the child node is SCALAR and corresponds to an output variable of the parent node.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited