CommitRequest class

The request for Commit.

Constructors

CommitRequest({String? maxCommitDelay, List<Mutation>? mutations, MultiplexedSessionPrecommitToken? precommitToken, RequestOptions? requestOptions, bool? returnCommitStats, TransactionOptions? singleUseTransaction, String? transactionId})
CommitRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxCommitDelay ↔ String?
The amount of latency this request is configured to incur in order to improve throughput.
getter/setter pair
mutations ↔ List<Mutation>?
The mutations to be executed when this transaction commits.
getter/setter pair
precommitToken ↔ MultiplexedSessionPrecommitToken?
If the read-write transaction was executed on a multiplexed session, then you must include the precommit token with the highest sequence number received in this transaction attempt.
getter/setter pair
requestOptions ↔ RequestOptions?
Common options for this request.
getter/setter pair
returnCommitStats ↔ bool?
If true, then statistics related to the transaction is included in the CommitResponse.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleUseTransaction ↔ TransactionOptions?
Execute mutations in a temporary transaction.
getter/setter pair
transactionId ↔ String?
Commit a previously-started transaction.
getter/setter pair
transactionIdAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited