CommitResponse class
The response for Commit.
Constructors
- CommitResponse({CommitStats? commitStats, String? commitTimestamp, String? isolationLevel, MultiplexedSessionPrecommitToken? precommitToken, String? readLockMode, String? snapshotTimestamp})
- CommitResponse.fromJson(Map json_)
Properties
- commitStats ↔ CommitStats?
-
The statistics about this
Commit.getter/setter pair - commitTimestamp ↔ String?
-
The Cloud Spanner timestamp at which the transaction committed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolationLevel ↔ String?
-
The isolation level used for the read-write transaction.
Possible string values are:
getter/setter pair
- precommitToken ↔ MultiplexedSessionPrecommitToken?
-
If specified, transaction has not committed yet.
getter/setter pair
- readLockMode ↔ String?
-
The read lock mode used for the read-write transaction.
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotTimestamp ↔ String?
-
If
TransactionOptions.isolation_levelis set toIsolationLevel.REPEATABLE_READ, then the snapshot timestamp is the timestamp at which all reads in the transaction ran.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited