ContextValue class

A message representing context for a KeyRangeInfo, including a label, value, unit, and severity.

Constructors

ContextValue({LocalizedString? label, String? severity, String? unit, double? value})
ContextValue.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
label ↔ LocalizedString?
The label for the context value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of this context. Possible string values are:
getter/setter pair
unit ↔ String?
The unit of the context value.
getter/setter pair
value ↔ double?
The value for the context.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited