kmsKeyNames property
Specifies the KMS configuration for the one or more keys used to protect the backup.
Values are of the form
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{kms_key_name}.
The keys referenced by kms_key_names must fully cover all regions of the
backup's instance configuration. Some examples: * For regional
(single-region) instance configurations, specify a regional location KMS
key. * For multi-region instance configurations of type GOOGLE_MANAGED,
either specify a multi-region location KMS key or multiple regional
location KMS keys that cover all regions in the instance configuration. *
For an instance configuration of type USER_MANAGED, specify only
regional location KMS keys to cover each region in the instance
configuration. Multi-region location KMS keys aren't supported for
USER_MANAGED type instance configurations.
Optional.
Implementation
core.List<core.String>? kmsKeyNames;