CreateInstanceConfigRequest class

The request for CreateInstanceConfig.

Constructors

CreateInstanceConfigRequest({InstanceConfig? instanceConfig, String? instanceConfigId, bool? validateOnly})
CreateInstanceConfigRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceConfig ↔ InstanceConfig?
The InstanceConfig proto of the configuration to create.
getter/setter pair
instanceConfigId ↔ String?
The ID of the instance configuration to create.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
An option to validate, but not actually execute, a request, and provide the same response.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited