DatabaseMoveConfig class

The configuration for each database in the target instance configuration.

Constructors

DatabaseMoveConfig({String? databaseId, InstanceEncryptionConfig? encryptionConfig})
DatabaseMoveConfig.fromJson(Map json_)

Properties

databaseId ↔ String?
The unique identifier of the database resource in the Instance.
getter/setter pair
encryptionConfig ↔ InstanceEncryptionConfig?
Encryption configuration to be used for the database in the target configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited