DerivedMetric class

A message representing a derived metric.

Constructors

DerivedMetric({LocalizedString? denominator, LocalizedString? numerator})
DerivedMetric.fromJson(Map json_)

Properties

denominator ↔ LocalizedString?
The name of the denominator metric.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
numerator ↔ LocalizedString?
The name of the numerator metric.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited