DiagnosticMessage class

A message representing the key visualizer diagnostic messages.

Constructors

DiagnosticMessage({LocalizedString? info, LocalizedString? metric, bool? metricSpecific, String? severity, LocalizedString? shortMessage})
DiagnosticMessage.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
info ↔ LocalizedString?
Information about this diagnostic information.
getter/setter pair
metric ↔ LocalizedString?
The metric.
getter/setter pair
metricSpecific ↔ bool?
Whether this message is specific only for the current metric.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of the diagnostic message. Possible string values are:
getter/setter pair
shortMessage ↔ LocalizedString?
The short message.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited