EncryptionConfig class

Encryption configuration for a Cloud Spanner database.

Constructors

EncryptionConfig({String? kmsKeyName, List<String>? kmsKeyNames})
EncryptionConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kmsKeyName ↔ String?
The Cloud KMS key to be used for encrypting and decrypting the database.
getter/setter pair
kmsKeyNames ↔ List<String>?
Specifies the KMS configuration for one or more keys used to encrypt the database.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited