EncryptionInfo class

Encryption information for a Cloud Spanner database or backup.

Constructors

EncryptionInfo({Status? encryptionStatus, String? encryptionType, String? kmsKeyVersion})
EncryptionInfo.fromJson(Map json_)

Properties

encryptionStatus ↔ Status?
If present, the status of a recent encrypt/decrypt call on underlying data for this database or backup.
getter/setter pair
encryptionType ↔ String?
The type of encryption.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kmsKeyVersion ↔ String?
A Cloud KMS key version that is being used to protect the database or backup.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited