ExecuteBatchDmlRequest class

The request for ExecuteBatchDml.

Constructors

ExecuteBatchDmlRequest({bool? lastStatements, RequestOptions? requestOptions, String? seqno, List<Statement>? statements, TransactionSelector? transaction})
ExecuteBatchDmlRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastStatements ↔ bool?
If set to true, this request marks the end of the transaction.
getter/setter pair
requestOptions ↔ RequestOptions?
Common options for this request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seqno ↔ String?
A per-transaction sequence number used to identify this request.
getter/setter pair
statements ↔ List<Statement>?
The list of statements to execute in this batch.
getter/setter pair
transaction ↔ TransactionSelector?
The transaction to use.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited