IndexAdvice class

Recommendation to add new indexes to run queries more efficiently.

Constructors

IndexAdvice({List<String>? ddl, double? improvementFactor})
IndexAdvice.fromJson(Map json_)

Properties

ddl ↔ List<String>?
DDL statements to add new indexes that will improve the query.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
improvementFactor ↔ double?
Estimated latency improvement factor.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited