Instance class

An isolated set of Cloud Spanner resources on which databases can be hosted.

Constructors

Instance({AutoscalingConfig? autoscalingConfig, String? config, String? createTime, String? defaultBackupScheduleType, String? displayName, String? edition, List<String>? endpointUris, FreeInstanceMetadata? freeInstanceMetadata, String? instanceType, Map<String, String>? labels, String? name, int? nodeCount, int? processingUnits, List<ReplicaComputeCapacity>? replicaComputeCapacity, String? state, String? updateTime})
Instance.fromJson(Map json_)

Properties

autoscalingConfig ↔ AutoscalingConfig?
The autoscaling configuration.
getter/setter pair
config ↔ String?
The name of the instance's configuration.
getter/setter pair
createTime ↔ String?
The time at which the instance was created.
getter/setter pair
defaultBackupScheduleType ↔ String?
Controls the default backup schedule behavior for new databases within the instance.
getter/setter pair
displayName ↔ String?
The descriptive name for this instance as it appears in UIs.
getter/setter pair
edition ↔ String?
The Edition of the current instance.
getter/setter pair
endpointUris ↔ List<String>?
This field is not populated.
getter/setter pair
freeInstanceMetadata ↔ FreeInstanceMetadata?
Free instance metadata.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceType ↔ String?
The InstanceType of the current instance. Possible string values are:
getter/setter pair
labels ↔ Map<String, String>?
Cloud Labels are a flexible and lightweight mechanism for organizing cloud resources into groups that reflect a customer's organizational needs and deployment strategies.
getter/setter pair
name ↔ String?
A unique identifier for the instance, which cannot be changed after the instance is created.
getter/setter pair
nodeCount ↔ int?
The number of nodes allocated to this instance.
getter/setter pair
processingUnits ↔ int?
The number of processing units allocated to this instance.
getter/setter pair
replicaComputeCapacity ↔ List<ReplicaComputeCapacity>?
Lists the compute capacity per ReplicaSelection.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The current instance state.
getter/setter pair
updateTime ↔ String?
The time at which the instance was most recently updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited