nodeCount property
The number of nodes allocated to this instance partition.
Users can set the node_count field to specify the target number of nodes
allocated to the instance partition. If autoscaling is enabled, node_count
is treated as an OUTPUT_ONLY field and reflects the current number of
nodes allocated to the instance partition. This may be zero in API
responses for instance partitions that are not yet in state READY.
Implementation
core.int? nodeCount;