processingUnits property
The number of processing units allocated to this instance partition.
Users can set the processing_units field to specify the target number of
processing units allocated to the instance partition. If autoscaling is
enabled, processing_units is treated as an OUTPUT_ONLY field and reflects
the current number of processing units allocated to the instance
partition. This might be zero in API responses for instance partitions
that are not yet in the READY state.
Implementation
core.int? processingUnits;