KeyRangeInfo class

A message representing information for a key range (possibly one key).

Constructors

KeyRangeInfo({List<ContextValue>? contextValues, int? endKeyIndex, LocalizedString? info, String? keysCount, LocalizedString? metric, int? startKeyIndex, String? timeOffset, LocalizedString? unit, double? value})
KeyRangeInfo.fromJson(Map json_)

Properties

contextValues ↔ List<ContextValue>?
The list of context values for this key range.
getter/setter pair
endKeyIndex ↔ int?
The index of the end key in indexed_keys.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
info ↔ LocalizedString?
Information about this key range, for all metrics.
getter/setter pair
keysCount ↔ String?
The number of keys this range covers.
getter/setter pair
metric ↔ LocalizedString?
The name of the metric.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startKeyIndex ↔ int?
The index of the start key in indexed_keys.
getter/setter pair
timeOffset ↔ String?
The time offset.
getter/setter pair
unit ↔ LocalizedString?
The unit of the metric.
getter/setter pair
value ↔ double?
The value of the metric.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited