KeyRangeInfos class

A message representing a list of specific information for multiple key ranges.

Constructors

KeyRangeInfos({List<KeyRangeInfo>? infos, int? totalSize})
KeyRangeInfos.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
infos ↔ List<KeyRangeInfo>?
The list individual KeyRangeInfos.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalSize ↔ int?
The total size of the list of all KeyRangeInfos.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited