ListScansResponse class

Response method from the ListScans method.

Constructors

ListScansResponse({String? nextPageToken, List<Scan>? scans})
ListScansResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to retrieve the next page of results, or empty if there are no more results in the list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scans ↔ List<Scan>?
Available scans based on the list query parameters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited