MoveInstanceRequest class

The request for MoveInstance.

Constructors

MoveInstanceRequest({String? targetConfig, List<DatabaseMoveConfig>? targetDatabaseMoveConfigs})
MoveInstanceRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetConfig ↔ String?
The target instance configuration where to move the instance.
getter/setter pair
targetDatabaseMoveConfigs ↔ List<DatabaseMoveConfig>?
The configuration for each database in the target instance configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited