MultiplexedSessionPrecommitToken class

When a read-write transaction is executed on a multiplexed session, this precommit token is sent back to the client as a part of the Transaction message in the BeginTransaction response and also as a part of the ResultSet and PartialResultSet responses.

Properties

hashCode → int
The hash code for this object.
no setterinherited
precommitToken ↔ String?
Opaque precommit token.
getter/setter pair
precommitTokenAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seqNum ↔ int?
An incrementing seq number is generated on every precommit token that is returned.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited