PartitionOptions class

Options for a PartitionQueryRequest and PartitionReadRequest.

Constructors

PartitionOptions({String? maxPartitions, String? partitionSizeBytes})
PartitionOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxPartitions ↔ String?
Note: This hint is currently ignored by PartitionQuery and PartitionRead requests.
getter/setter pair
partitionSizeBytes ↔ String?
Note: This hint is currently ignored by PartitionQuery and PartitionRead requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited