PlanNode class

Node information for nodes appearing in a QueryPlan.plan_nodes.

Constructors

PlanNode({List<ChildLink>? childLinks, String? displayName, Map<String, Object?>? executionStats, int? index, String? kind, Map<String, Object?>? metadata, ShortRepresentation? shortRepresentation})
PlanNode.fromJson(Map json_)

Properties

List of child node indexes and their relationship to this parent.
getter/setter pair
displayName ↔ String?
The display name for the node.
getter/setter pair
executionStats ↔ Map<String, Object?>?
The execution statistics associated with the node, contained in a group of key-value pairs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int?
The PlanNode's index in node list.
getter/setter pair
kind ↔ String?
Used to determine the type of node.
getter/setter pair
metadata ↔ Map<String, Object?>?
Attributes relevant to the node contained in a group of key-value pairs.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortRepresentation ↔ ShortRepresentation?
Condensed representation for SCALAR nodes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited