QueryPlan class

Contains an ordered list of nodes appearing in the query plan.

Constructors

QueryPlan({List<PlanNode>? planNodes, QueryAdvisorResult? queryAdvice})
QueryPlan.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
planNodes ↔ List<PlanNode>?
The nodes in the query plan.
getter/setter pair
queryAdvice ↔ QueryAdvisorResult?
The advise/recommendations for a query.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited