QuorumInfo class

Information about the dual-region quorum.

Constructors

QuorumInfo({String? etag, String? initiator, QuorumType? quorumType, String? startTime})
QuorumInfo.fromJson(Map json_)

Properties

etag ↔ String?
The etag is used for optimistic concurrency control as a way to help prevent simultaneous ChangeQuorum requests that might create a race condition.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initiator ↔ String?
Whether this ChangeQuorum is Google or User initiated.
getter/setter pair
quorumType ↔ QuorumType?
The type of this quorum.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The timestamp when the request was triggered.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited