QuorumType class

Information about the database quorum type.

This only applies to dual-region instance configs.

Constructors

QuorumType({DualRegionQuorum? dualRegion, SingleRegionQuorum? singleRegion})
QuorumType.fromJson(Map json_)

Properties

dualRegion ↔ FullBackupSpec?
Dual-region quorum type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleRegion ↔ SingleRegionQuorum?
Single-region quorum type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited