ReadOnly class

Message type to initiate a read-only transaction.

Constructors

ReadOnly({String? exactStaleness, String? maxStaleness, String? minReadTimestamp, String? readTimestamp, bool? returnReadTimestamp, bool? strong})
ReadOnly.fromJson(Map json_)

Properties

exactStaleness ↔ String?
Executes all reads at a timestamp that is exact_staleness old.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxStaleness ↔ String?
Read data at a timestamp >= NOW - max_staleness seconds.
getter/setter pair
minReadTimestamp ↔ String?
Executes all reads at a timestamp >= min_read_timestamp.
getter/setter pair
readTimestamp ↔ String?
Executes all reads at the given timestamp.
getter/setter pair
returnReadTimestamp ↔ bool?
If true, the Cloud Spanner-selected read timestamp is included in the Transaction message that describes the transaction.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strong ↔ bool?
Read at a timestamp where all previously committed transactions are visible.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited