ReadWrite class

Message type to initiate a read-write transaction.

Currently this transaction type has no options.

Constructors

ReadWrite({String? multiplexedSessionPreviousTransactionId, String? readLockMode})
ReadWrite.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
multiplexedSessionPreviousTransactionId ↔ String?
Clients should pass the transaction ID of the previous transaction attempt that was aborted if this transaction is being executed on a multiplexed session.
getter/setter pair
multiplexedSessionPreviousTransactionIdAsBytes ↔ List<int>
getter/setter pair
readLockMode ↔ String?
The read lock mode for the transaction. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited