readLockMode property

String? readLockMode
getter/setter pair

The read lock mode for the transaction. Possible string values are:

  • "READ_LOCK_MODE_UNSPECIFIED" : Default value. * If isolation level is SERIALIZABLE, locking semantics default to PESSIMISTIC. * If isolation level is REPEATABLE_READ, locking semantics default to OPTIMISTIC. * See Concurrency control for more details.
  • "PESSIMISTIC" : Pessimistic lock mode. Lock acquisition behavior depends on the isolation level in use. In SERIALIZABLE isolation, reads and writes acquire necessary locks during transaction statement execution. In REPEATABLE_READ isolation, reads that explicitly request to be locked and writes acquire locks. See Concurrency control for details on the types of locks acquired at each transaction step.
  • "OPTIMISTIC" : Optimistic lock mode. Lock acquisition behavior depends on the isolation level in use. In both SERIALIZABLE and REPEATABLE_READ isolation, reads and writes do not acquire locks during transaction statement execution. See Concurrency control for details on how the guarantees of each isolation level are provided at commit time.

Implementation

core.String? readLockMode;