ResultSetMetadata class

Metadata about a ResultSet or PartialResultSet.

Constructors

ResultSetMetadata({StructType? rowType, Transaction? transaction, StructType? undeclaredParameters})
ResultSetMetadata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
rowType ↔ StructType?
Indicates the field names and types for the rows in the result set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transaction ↔ Transaction?
If the read or SQL query began a transaction as a side-effect, the information about the new transaction is yielded here.
getter/setter pair
undeclaredParameters ↔ StructType?
A SQL query can be parameterized.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited