Session class

A session in the Cloud Spanner API.

Constructors

Session({String? approximateLastUseTime, String? createTime, String? creatorRole, Map<String, String>? labels, bool? multiplexed, String? name})
Session.fromJson(Map json_)

Properties

approximateLastUseTime ↔ String?
The approximate timestamp when the session is last used.
getter/setter pair
createTime ↔ String?
The timestamp when the session is created.
getter/setter pair
creatorRole ↔ String?
The database role which created this session.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels for the session.
getter/setter pair
multiplexed ↔ bool?
If true, specifies a multiplexed session.
getter/setter pair
name ↔ String?
The name of the session.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited