Statement class

A single DML statement.

Constructors

Statement({Map<String, Type>? paramTypes, Map<String, Object?>? params, String? sql})
Statement.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
params ↔ Map<String, Object?>?
Parameter names and values that bind to placeholders in the DML string.
getter/setter pair
paramTypes ↔ Map<String, Type>?
It isn't always possible for Cloud Spanner to infer the right SQL type from a JSON value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sql ↔ String?
The DML string.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited