TransactionSelector class

This message is used to select the transaction in which a Read or ExecuteSql call runs.

See TransactionOptions for more information about transactions.

Properties

begin ↔ TransactionOptions?
Begin a new transaction and execute this read or SQL query in it.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Execute the read or SQL query in a previously-started transaction.
getter/setter pair
idAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
singleUse ↔ TransactionOptions?
Execute the read or SQL query in a temporary transaction.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited