Type class

Type indicates the type of a Cloud Spanner value, as might be stored in a table cell or returned from an SQL query.

Constructors

Type({Type? arrayElementType, String? code, String? protoTypeFqn, StructType? structType, String? typeAnnotation})
Type.fromJson(Map json_)

Properties

arrayElementType ↔ Type?
If code == ARRAY, then array_element_type is the type of the array elements.
getter/setter pair
code ↔ String?
The TypeCode for this type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
protoTypeFqn ↔ String?
If code == PROTO or code == ENUM, then proto_type_fqn is the fully qualified name of the proto type representing the proto/enum definition.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
structType ↔ StructType?
If code == STRUCT, then struct_type provides type information for the struct's fields.
getter/setter pair
typeAnnotation ↔ String?
The TypeAnnotationCode that disambiguates SQL type that Spanner will use to represent values of this type during query processing.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited