CreateCustomClassRequest class

Message sent by the client for the CreateCustomClass method.

Constructors

CreateCustomClassRequest({CustomClass? customClass, String? customClassId})
CreateCustomClassRequest.fromJson(Map json_)

Properties

customClass ↔ CustomClass?
The custom class to create.
getter/setter pair
customClassId ↔ String?
The ID to use for the custom class, which will become the final component of the custom class' resource name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited