RecognitionMetadata class

Description of audio data to be recognized.

Constructors

RecognitionMetadata({String? audioTopic, int? industryNaicsCodeOfAudio, String? interactionType, String? microphoneDistance, String? originalMediaType, String? originalMimeType, String? recordingDeviceName, String? recordingDeviceType})
RecognitionMetadata.fromJson(Map json_)

Properties

audioTopic ↔ String?
Description of the content.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
industryNaicsCodeOfAudio ↔ int?
The industry vertical to which this speech recognition request most closely applies.
getter/setter pair
interactionType ↔ String?
The use case most closely describing the audio content to be recognized. Possible string values are:
getter/setter pair
microphoneDistance ↔ String?
The audio type that most closely describes the audio being recognized. Possible string values are:
getter/setter pair
originalMediaType ↔ String?
The original media the speech was recorded on. Possible string values are:
getter/setter pair
originalMimeType ↔ String?
Mime type of the original audio file.
getter/setter pair
recordingDeviceName ↔ String?
The device used to make the recording.
getter/setter pair
recordingDeviceType ↔ String?
The type of device the speech was recorded with. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited