RecognizeResponse class

The only message returned to the client by the Recognize method.

It contains the result as zero or more sequential SpeechRecognitionResult messages.

Constructors

RecognizeResponse({String? requestId, List<SpeechRecognitionResult>? results, SpeechAdaptationInfo? speechAdaptationInfo, String? totalBilledTime, bool? usingLegacyModels})
RecognizeResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
The ID associated with the request.
getter/setter pair
results ↔ List<SpeechRecognitionResult>?
Sequential list of transcription results corresponding to sequential portions of audio.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speechAdaptationInfo ↔ SpeechAdaptationInfo?
Provides information on adaptation behavior in response
getter/setter pair
totalBilledTime ↔ String?
When available, billed audio seconds for the corresponding request.
getter/setter pair
usingLegacyModels ↔ bool?
Whether request used legacy asr models (was not automatically migrated to use conformer models).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited