SpeakerDiarizationConfig class

Config to enable speaker diarization.

Constructors

SpeakerDiarizationConfig({bool? enableSpeakerDiarization, int? maxSpeakerCount, int? minSpeakerCount, int? speakerTag})
SpeakerDiarizationConfig.fromJson(Map json_)

Properties

enableSpeakerDiarization ↔ bool?
If 'true', enables speaker detection for each recognized word in the top alternative of the recognition result using a speaker_label provided in the WordInfo.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxSpeakerCount ↔ int?
Maximum number of speakers in the conversation.
getter/setter pair
minSpeakerCount ↔ int?
Minimum number of speakers in the conversation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speakerTag ↔ int?
Unused.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited