SpeechAdaptation class

Speech adaptation configuration.

Constructors

SpeechAdaptation({ABNFGrammar? abnfGrammar, List<CustomClass>? customClasses, List<String>? phraseSetReferences, List<PhraseSet>? phraseSets})
SpeechAdaptation.fromJson(Map json_)

Properties

abnfGrammar ↔ ABNFGrammar?
Augmented Backus-Naur form (ABNF) is a standardized grammar notation comprised by a set of derivation rules.
getter/setter pair
customClasses ↔ List<CustomClass>?
A collection of custom classes.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
phraseSetReferences ↔ List<String>?
A collection of phrase set resource names to use.
getter/setter pair
phraseSets ↔ List<PhraseSet>?
A collection of phrase sets.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited