AnywhereCache class

An Anywhere Cache instance.

Constructors

AnywhereCache({String? admissionPolicy, String? anywhereCacheId, String? bucket, DateTime? createTime, String? id, String? kind, bool? pendingUpdate, String? selfLink, String? state, String? ttl, DateTime? updateTime, String? zone})
AnywhereCache.fromJson(Map json_)

Properties

admissionPolicy ↔ String?
The cache-level entry admission policy.
getter/setter pair
anywhereCacheId ↔ String?
The ID of the Anywhere cache instance.
getter/setter pair
bucket ↔ String?
The name of the bucket containing this cache instance.
getter/setter pair
createTime ↔ DateTime?
The creation time of the cache instance in RFC 3339 format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID of the resource, including the project number, bucket name and anywhere cache ID.
getter/setter pair
kind ↔ String?
The kind of item this is.
getter/setter pair
pendingUpdate ↔ bool?
True if the cache instance has an active Update long-running operation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
The link to this cache instance.
getter/setter pair
state ↔ String?
The current state of the cache instance.
getter/setter pair
ttl ↔ String?
The TTL of all cache entries in whole seconds.
getter/setter pair
updateTime ↔ DateTime?
The modification time of the cache instance metadata in RFC 3339 format.
getter/setter pair
zone ↔ String?
The zone in which the cache instance is running.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited