Bucket class

A bucket.

Constructors

Bucket({List<BucketAccessControl>? acl, BucketAutoclass? autoclass, BucketBilling? billing, List<BucketCors>? cors, BucketCustomPlacementConfig? customPlacementConfig, bool? defaultEventBasedHold, List<ObjectAccessControl>? defaultObjectAcl, BucketEncryption? encryption, String? etag, String? generation, DateTime? hardDeleteTime, BucketHierarchicalNamespace? hierarchicalNamespace, BucketIamConfiguration? iamConfiguration, String? id, BucketIpFilter? ipFilter, String? kind, Map<String, String>? labels, BucketLifecycle? lifecycle, String? location, String? locationType, BucketLogging? logging, String? metageneration, String? name, BucketObjectRetention? objectRetention, BucketOwner? owner, String? projectNumber, BucketRetentionPolicy? retentionPolicy, String? rpo, bool? satisfiesPZI, bool? satisfiesPZS, String? selfLink, BucketSoftDeletePolicy? softDeletePolicy, DateTime? softDeleteTime, String? storageClass, DateTime? timeCreated, DateTime? updated, BucketVersioning? versioning, BucketWebsite? website})
Bucket.fromJson(Map json_)

Properties

acl ↔ List<BucketAccessControl>?
Access controls on the bucket.
getter/setter pair
autoclass ↔ BucketAutoclass?
The bucket's Autoclass configuration.
getter/setter pair
billing ↔ BucketBilling?
The bucket's billing configuration.
getter/setter pair
cors ↔ List<BucketCors>?
The bucket's Cross-Origin Resource Sharing (CORS) configuration.
getter/setter pair
customPlacementConfig ↔ BucketCustomPlacementConfig?
The bucket's custom placement configuration for Custom Dual Regions.
getter/setter pair
defaultEventBasedHold ↔ bool?
The default value for event-based hold on newly created objects in this bucket.
getter/setter pair
defaultObjectAcl ↔ List<ObjectAccessControl>?
Default access controls to apply to new objects when no ACL is provided.
getter/setter pair
encryption ↔ BucketEncryption?
Encryption configuration for a bucket.
getter/setter pair
etag ↔ String?
HTTP 1.1 Entity tag for the bucket.
getter/setter pair
generation ↔ String?
The generation of this bucket.
getter/setter pair
hardDeleteTime ↔ DateTime?
The hard delete time of the bucket in RFC 3339 format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hierarchicalNamespace ↔ BucketHierarchicalNamespace?
The bucket's hierarchical namespace configuration.
getter/setter pair
iamConfiguration ↔ BucketIamConfiguration?
The bucket's IAM configuration.
getter/setter pair
id ↔ String?
The ID of the bucket.
getter/setter pair
ipFilter ↔ BucketIpFilter?
The bucket's IP filter configuration.
getter/setter pair
kind ↔ String?
The kind of item this is.
getter/setter pair
labels ↔ Map<String, String>?
User-provided labels, in key/value pairs.
getter/setter pair
lifecycle ↔ BucketLifecycle?
The bucket's lifecycle configuration.
getter/setter pair
location ↔ String?
The location of the bucket.
getter/setter pair
locationType ↔ String?
The type of the bucket location.
getter/setter pair
logging ↔ BucketLogging?
The bucket's logging configuration, which defines the destination bucket and optional name prefix for the current bucket's logs.
getter/setter pair
metageneration ↔ String?
The metadata generation of this bucket.
getter/setter pair
name ↔ String?
The name of the bucket.
getter/setter pair
objectRetention ↔ BucketObjectRetention?
The bucket's object retention config.
getter/setter pair
owner ↔ BucketOwner?
The owner of the bucket.
getter/setter pair
projectNumber ↔ String?
The project number of the project the bucket belongs to.
getter/setter pair
retentionPolicy ↔ BucketRetentionPolicy?
The bucket's retention policy.
getter/setter pair
rpo ↔ String?
The Recovery Point Objective (RPO) of this bucket.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
satisfiesPZI ↔ bool?
Reserved for future use.
getter/setter pair
satisfiesPZS ↔ bool?
Reserved for future use.
getter/setter pair
The URI of this bucket.
getter/setter pair
softDeletePolicy ↔ BucketSoftDeletePolicy?
The bucket's soft delete policy, which defines the period of time that soft-deleted objects will be retained, and cannot be permanently deleted.
getter/setter pair
softDeleteTime ↔ DateTime?
The soft delete time of the bucket in RFC 3339 format.
getter/setter pair
storageClass ↔ String?
The bucket's default storage class, used whenever no storageClass is specified for a newly-created object.
getter/setter pair
timeCreated ↔ DateTime?
The creation time of the bucket in RFC 3339 format.
getter/setter pair
updated ↔ DateTime?
The modification time of the bucket in RFC 3339 format.
getter/setter pair
versioning ↔ BucketVersioning?
The bucket's versioning configuration.
getter/setter pair
website ↔ BucketWebsite?
The bucket's website configuration, controlling how the service behaves when accessing bucket contents as a web site.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited