BucketEncryption class

Encryption configuration for a bucket.

Constructors

BucketEncryption({BucketEncryptionCustomerManagedEncryptionEnforcementConfig? customerManagedEncryptionEnforcementConfig, BucketEncryptionCustomerSuppliedEncryptionEnforcementConfig? customerSuppliedEncryptionEnforcementConfig, String? defaultKmsKeyName, BucketEncryptionGoogleManagedEncryptionEnforcementConfig? googleManagedEncryptionEnforcementConfig})
BucketEncryption.fromJson(Map json_)

Properties

customerManagedEncryptionEnforcementConfig ↔ BucketEncryptionCustomerManagedEncryptionEnforcementConfig?
If set, the new objects created in this bucket must comply with this enforcement config.
getter/setter pair
customerSuppliedEncryptionEnforcementConfig ↔ BucketEncryptionCustomerSuppliedEncryptionEnforcementConfig?
If set, the new objects created in this bucket must comply with this enforcement config.
getter/setter pair
defaultKmsKeyName ↔ String?
A Cloud KMS key that will be used to encrypt objects inserted into this bucket, if no encryption method is specified.
getter/setter pair
googleManagedEncryptionEnforcementConfig ↔ BucketEncryptionGoogleManagedEncryptionEnforcementConfig?
If set, the new objects created in this bucket must comply with this enforcement config.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited