BucketLifecycle class

The bucket's lifecycle configuration.

See Lifecycle Management for more information.

Properties

hashCode → int
The hash code for this object.
no setterinherited
rule ↔ List<BucketLifecycleRule>?
A lifecycle management rule, which is made of an action to take and the condition(s) under which the action will be taken.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited