BucketLogging class

The bucket's logging configuration, which defines the destination bucket and optional name prefix for the current bucket's logs.

Constructors

BucketLogging({String? logBucket, String? logObjectPrefix})
BucketLogging.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logBucket ↔ String?
The destination bucket where the current bucket's logs should be placed.
getter/setter pair
logObjectPrefix ↔ String?
A prefix for log object names.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited