BucketStorageLayout class

The storage layout configuration of a bucket.

Constructors

BucketStorageLayout({String? bucket, BucketStorageLayoutCustomPlacementConfig? customPlacementConfig, BucketStorageLayoutHierarchicalNamespace? hierarchicalNamespace, String? kind, String? location, String? locationType})
BucketStorageLayout.fromJson(Map json_)

Properties

bucket ↔ String?
The name of the bucket.
getter/setter pair
customPlacementConfig ↔ BucketStorageLayoutCustomPlacementConfig?
The bucket's custom placement configuration for Custom Dual Regions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hierarchicalNamespace ↔ BucketStorageLayoutHierarchicalNamespace?
The bucket's hierarchical namespace configuration.
getter/setter pair
kind ↔ String?
The kind of item this is.
getter/setter pair
location ↔ String?
The location of the bucket.
getter/setter pair
locationType ↔ String?
The type of the bucket location.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited