BucketWebsite class

The bucket's website configuration, controlling how the service behaves when accessing bucket contents as a web site.

See the Static Website Examples for more information.

Constructors

BucketWebsite({String? mainPageSuffix, String? notFoundPage})
BucketWebsite.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mainPageSuffix ↔ String?
If the requested object path is missing, the service will ensure the path has a trailing '/', append this suffix, and attempt to retrieve the resulting object.
getter/setter pair
notFoundPage ↔ String?
If the requested object path is missing, and any mainPageSuffix object is missing, if applicable, the service will return the named object from this bucket as the content for a 404 Not Found result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited