ComposeRequest class

A Compose request.

Constructors

ComposeRequest({bool? deleteSourceObjects, Object? destination, String? kind, List<ComposeRequestSourceObjects>? sourceObjects})
ComposeRequest.fromJson(Map json_)

Properties

deleteSourceObjects ↔ bool?
If true, the source objects will be deleted.
getter/setter pair
destination ↔ Object?
Properties of the resulting object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of item this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceObjects ↔ List<ComposeRequestSourceObjects>?
The list of source objects that will be concatenated into a single object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited