ComposeRequestSourceObjectsObjectPreconditions class

Conditions that must be met for this operation to execute.

Properties

hashCode → int
The hash code for this object.
no setterinherited
ifGenerationMatch ↔ String?
Only perform the composition if the generation of the source object that would be used matches this value.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited