Expr class

Represents an expression text.

Example: title: "User account presence" description: "Determines whether the request has a user account" expression: "size(request.user) > 0"

Constructors

Expr({String? description, String? expression, String? location, String? title})
Expr.fromJson(Map json_)

Properties

description ↔ String?
An optional description of the expression.
getter/setter pair
expression ↔ String?
Textual representation of an expression in Common Expression Language syntax.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
An optional string indicating the location of the expression for error reporting, e.g. a file name and a position in the file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
An optional title for the expression, i.e. a short string describing its purpose.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited