HmacKey class

JSON template to produce a JSON-style HMAC Key resource for Create responses.

Constructors

HmacKey({String? kind, HmacKeyMetadata? metadata, String? secret})
HmacKey.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
The kind of item this is.
getter/setter pair
metadata ↔ HmacKeyMetadata?
Key metadata.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret ↔ String?
HMAC secret key material.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited