ObjectCustomContextPayload class

The payload of a single user-defined object context.

Constructors

ObjectCustomContextPayload({DateTime? createTime, DateTime? updateTime, String? value})
ObjectCustomContextPayload.fromJson(Map json_)

Properties

createTime ↔ DateTime?
The time at which the object context was created in RFC 3339 format.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ DateTime?
The time at which the object context was last updated in RFC 3339 format.
getter/setter pair
value ↔ String?
The value of the object context.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited