ObjectCustomerEncryption class

Metadata of customer-supplied encryption key, if the object is encrypted by such a key.

Constructors

ObjectCustomerEncryption({String? encryptionAlgorithm, String? keySha256})
ObjectCustomerEncryption.fromJson(Map json_)

Properties

encryptionAlgorithm ↔ String?
The encryption algorithm.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keySha256 ↔ String?
SHA256 hash value of the encryption key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited