ObjectRetention class

A collection of object level retention parameters.

Constructors

ObjectRetention({String? mode, DateTime? retainUntilTime})
ObjectRetention.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?
The bucket's object retention mode, can only be Unlocked or Locked.
getter/setter pair
retainUntilTime ↔ DateTime?
A time in RFC 3339 format until which object retention protects this object.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited