RapidCachesResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disable(String bucket, String rapidCacheId, {String? $fields})
→ Future<GoogleLongrunningOperation>
-
Disables a Rapid Cache instance.
-
get(String bucket, String rapidCacheId, {String? $fields})
→ Future<RapidCache>
-
Returns the metadata of a Rapid Cache instance.
-
insert(RapidCache request, String bucket, {String? $fields})
→ Future<GoogleLongrunningOperation>
-
Creates a Rapid Cache instance.
-
list(String bucket, {int? pageSize, String? pageToken, String? $fields})
→ Future<RapidCaches>
-
Returns a list of Rapid Cache instances of the bucket.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
update(RapidCache request, String bucket, String rapidCacheId, {String? $fields})
→ Future<GoogleLongrunningOperation>
-
Updates the configuration of a Rapid Cache instance.