disable method

Future<GoogleLongrunningOperation> disable(
  1. String bucket,
  2. String rapidCacheId, {
  3. String? $fields,
})

Disables a Rapid Cache instance.

Request parameters:

bucket - Name of the parent bucket.

rapidCacheId - The ID of the requested Rapid Cache instance.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleLongrunningOperation.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleLongrunningOperation> disable(
  core.String bucket,
  core.String rapidCacheId, {
  core.String? $fields,
}) async {
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ =
      'b/' +
      commons.escapeVariable('$bucket') +
      '/rapidCaches/' +
      commons.escapeVariable('$rapidCacheId') +
      '/disable';

  final response_ = await _requester.request(
    url_,
    'POST',
    queryParams: queryParams_,
  );
  return GoogleLongrunningOperation.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}