AccessControlsUpdates class

Represents updates to existing access-control entries on an object.

Constructors

AccessControlsUpdates({List<ObjectAccessControl>? grants, List<String>? removeEntities})
AccessControlsUpdates.fromJson(Map json_)

Properties

grants List<ObjectAccessControl>?
Grants to add or update.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
removeEntities List<String>?
Entities for which all grants should be removed.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited