grants property
Grants to add or update.
If a grant for same entity exists, its role is updated.
Optional.
Implementation
core.List<ObjectAccessControl>? grants;
Grants to add or update.
If a grant for same entity exists, its role is updated.
Optional.
core.List<ObjectAccessControl>? grants;