objectCustomContextsCreated property
Number of object custom contexts created.
This field is only populated for jobs with the UpdateObjectCustomContext transformation.
Output only.
Implementation
core.String? objectCustomContextsCreated;
Number of object custom contexts created.
This field is only populated for jobs with the UpdateObjectCustomContext transformation.
Output only.
core.String? objectCustomContextsCreated;