objectCustomContextsDeleted property
Number of object custom contexts deleted.
This field is only populated for jobs with the UpdateObjectCustomContext transformation.
Output only.
Implementation
core.String? objectCustomContextsDeleted;
Number of object custom contexts deleted.
This field is only populated for jobs with the UpdateObjectCustomContext transformation.
Output only.
core.String? objectCustomContextsDeleted;