objectCustomContextsUpdated property

String? objectCustomContextsUpdated
getter/setter pair

Number of object custom contexts updated.

This counter tracks custom contexts where the key already existed, but the payload was modified. This field is only populated for jobs with the UpdateObjectCustomContext transformation.

Output only.

Implementation

core.String? objectCustomContextsUpdated;