permanentObjectDeletionEnabled property
Controls deletion behavior when versioning is enabled for the object's bucket.
If true, both live and noncurrent objects will be permanently deleted.
Otherwise live objects in versioned buckets will become noncurrent and
objects that were already noncurrent will be skipped. This setting doesn't
have any impact on the Soft Delete feature. All objects deleted by this
service can be be restored for the duration of the Soft Delete retention
duration if enabled. If enabled and the manifest doesn't specify an
object's generation, a GetObjectMetadata call is made to determine the
live object generation.
Required.
Implementation
core.bool? permanentObjectDeletionEnabled;