Job class

The Storage Batch Operations Job description.

Constructors

Job({BucketList? bucketList, String? completeTime, Counters? counters, String? createTime, DeleteObject? deleteObject, String? description, bool? dryRun, List<ErrorSummary>? errorSummaries, LoggingConfig? loggingConfig, String? name, PutMetadata? putMetadata, PutObjectHold? putObjectHold, RewriteObject? rewriteObject, String? scheduleTime, String? state})
Job.fromJson(Map json_)

Properties

bucketList ↔ BucketList?
Specifies a list of buckets and their objects to be transformed.
getter/setter pair
completeTime ↔ String?
The time that the job was completed.
getter/setter pair
counters ↔ Counters?
Information about the progress of the job.
getter/setter pair
createTime ↔ String?
The time that the job was created.
getter/setter pair
deleteObject ↔ DeleteObject?
Delete objects.
getter/setter pair
description ↔ String?
A description provided by the user for the job.
getter/setter pair
dryRun ↔ bool?
If true, the job will run in dry run mode, returning the total object count and, if the object configuration is a prefix list, the bytes found from source.
getter/setter pair
errorSummaries ↔ List<ErrorSummary>?
Summarizes errors encountered with sample error log entries.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
loggingConfig ↔ LoggingConfig?
Logging configuration.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
putMetadata ↔ PutMetadata?
Updates object metadata.
getter/setter pair
putObjectHold ↔ PutObjectHold?
Changes object hold status.
getter/setter pair
rewriteObject ↔ RewriteObject?
Rewrite the object and updates metadata like KMS key.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleTime ↔ String?
The time that the job was scheduled.
getter/setter pair
state ↔ String?
State of the job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited