dryRun property
If true, the job runs in dry run mode, returning the total object count and, if the object configuration is a prefix list, the bytes found from source.
No transformations are performed.
Optional.
Implementation
core.bool? dryRun;
If true, the job runs in dry run mode, returning the total object count and, if the object configuration is a prefix list, the bytes found from source.
No transformations are performed.
Optional.
core.bool? dryRun;