isMultiBucketJob property
If true, this job operates on multiple buckets.
Multi-bucket jobs are subject to different quota limits than single-bucket jobs.
Output only.
Implementation
core.bool? isMultiBucketJob;
If true, this job operates on multiple buckets.
Multi-bucket jobs are subject to different quota limits than single-bucket jobs.
Output only.
core.bool? isMultiBucketJob;