LoggingConfig class

Specifies the Cloud Logging behavior.

Constructors

LoggingConfig({List<String>? logActionStates, List<String>? logActions})
LoggingConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
logActions ↔ List<String>?
Specifies the actions to be logged.
getter/setter pair
logActionStates ↔ List<String>?
States in which Action are logged.If empty, no logs are generated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited