entity property
The entity holding the permission, in one of the following forms: *
allUsers * allAuthenticatedUsers
Required.
Implementation
core.String? entity;
The entity holding the permission, in one of the following forms: *
allUsers * allAuthenticatedUsers
Required.
core.String? entity;