value property

String? value
getter/setter pair

The value of the object custom context.

If set, value can't be an empty string because it is a required field in custom context. If unset, value is ignored and no changes are made to the value field of the custom context payload.

Implementation

core.String? value;