ProjectSource class

Describes the project source where the objects satisfying the filters will be transformed.

Constructors

ProjectSource({Expr? bucketFilters, String? dryRunJobId, String? insightsDatasetConfig, Expr? objectFilters, String? project, String? snapshotTime, TargetLocations? targetLocations})
ProjectSource.fromJson(Map json_)

Properties

bucketFilters Expr?
Filters expressed in Common Expression Language (CEL) to apply to buckets to identify buckets with objects to be transformed.
getter/setter pair
dryRunJobId String?
The unique identifier of a dry run job to use as the baseline for the current job.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
insightsDatasetConfig String?
The resource identifier of the Storage Insights dataset configuration.
getter/setter pair
objectFilters Expr?
Filters expressed in Common Expression Language (CEL) to apply to objects to identify objects to be transformed.
getter/setter pair
project String?
Project name of the objects to be transformed.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
snapshotTime String?
The snapshot time used by the job to read the Storage Insights dataset for bucket and object discovery.
getter/setter pair
targetLocations TargetLocations?
Specifies the Cloud Storage locations to include in the job.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited