bucketFilters property
Filters expressed in Common Expression Language (CEL) to apply to buckets to identify buckets with objects to be transformed.
Optional.
Implementation
Expr? bucketFilters;
Filters expressed in Common Expression Language (CEL) to apply to buckets to identify buckets with objects to be transformed.
Optional.
Expr? bucketFilters;