insightsDatasetConfig property

String? insightsDatasetConfig
getter/setter pair

The resource identifier of the Storage Insights dataset configuration.

Storage batch operations uses the latest snapshot from this dataset as the source to list and filter target objects. Format: projects/{project_id}/locations/{location}/datasetConfigs/{dataset_config}.

Required.

Implementation

core.String? insightsDatasetConfig;