PutMetadata class
Describes options for object metadata update.
Constructors
-
PutMetadata({String? cacheControl, String? contentDisposition, String? contentEncoding, String? contentLanguage, String? contentType, Map<
String, String> ? customMetadata, String? customTime, ObjectRetention? objectRetention}) - PutMetadata.fromJson(Map json_)
Properties
- cacheControl ↔ String?
-
Updates the objects
Cache-Controlfixed metadata.getter/setter pair - contentDisposition ↔ String?
-
Updates objects
Content-Dispositionfixed metadata.getter/setter pair - contentEncoding ↔ String?
-
Updates the objects
Content-Encodingfixed metadata.getter/setter pair - contentLanguage ↔ String?
-
Updates the objects
Content-Languagefixed metadata.getter/setter pair - contentType ↔ String?
-
Updates objects
Content-Typefixed metadata.getter/setter pair -
customMetadata
↔ Map<
String, String> ? -
Updates the object's custom metadata.
getter/setter pair
- customTime ↔ String?
-
Updates the objects
Custom-Timefixed metadata.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- objectRetention ↔ ObjectRetention?
-
Updates an object's retention configuration.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited