RewriteObject class
Describes options for object rewrite.
Constructors
- RewriteObject({String? kmsKey, String? storageClass})
- RewriteObject.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- kmsKey ↔ String?
-
Resource name of the Cloud KMS key that is used to encrypt the object.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageClass ↔ String?
-
Rewrites the object to the specified storage class.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited