storageClass property
Rewrites the object to the specified storage class.
Setting this field will perform a full byte copy of the object if the storage class is different from the object's current storage class. If Autoclass is enabled on the bucket, storage class changes are ignored by Cloud Storage.
Optional. Possible string values are:
- "STORAGE_CLASS_UNSPECIFIED" : The storage class is not specified.
- "STANDARD" : Standard storage class.
- "NEARLINE" : Nearline storage class.
- "COLDLINE" : Coldline storage class.
- "ARCHIVE" : Archive storage class.
Implementation
core.String? storageClass;