locations property

List<String>? locations
getter/setter pair

A list of Cloud Storage locations (e.g., us-central1) to include in the job.

If snapshot_time is omitted, the job automatically defaults to the most recent snapshot timestamp that is successfully populated in BOTH the object_attributes_view and bucket_attributes_view across ALL specified locations. For details on Storage Insights dataset snapshots and views, see: https://docs.cloud.google.com/storage/docs/insights/dataset-tables-and-schemas#schema

Required.

Implementation

core.List<core.String>? locations;