storagebatchoperations/v1 library

Classes

AccessControlsUpdates
Represents updates to existing access-control entries on an object.
Bucket
Describes configuration of a single bucket and its objects to be transformed.
BucketList
Describes list of buckets and their objects to be transformed.
BucketOperation
BucketOperation represents a bucket-level breakdown of a Job.
CancelJobRequest
Message for Job to Cancel
Counters
Describes details about the progress of the job.
CustomContextUpdates
Describes a collection of updates to apply to custom contexts identified by key.
DeleteObject
Describes options to delete an object.
ErrorLogEntry
An entry describing an error that has occurred.
ErrorSummary
A summary of errors by error code, plus a count and sample error log entries.
Job
The storage batch operations job description.
ListBucketOperationsResponse
Message for response to listing BucketOperations
ListJobsResponse
Message for response to listing Jobs
ListLocationsResponse
The response message for Locations.ListLocations.
ListOperationsResponse
The response message for Operations.ListOperations.
LoggingConfig
Specifies the Cloud Logging behavior.
Manifest
Describes list of objects to be transformed.
ObjectAccessControl
Represents an access control entry on an object.
ObjectCustomContextPayload
Describes the payload of a user-defined object custom context.
ObjectRetention
Describes options for object retention update.
Operation
This resource represents a long-running operation that is the result of a network API call.
PrefixList
Describes prefixes of objects to be transformed.
ProjectsLocationsJobsBucketOperationsResource
ProjectsLocationsJobsResource
ProjectsLocationsOperationsResource
ProjectsLocationsResource
ProjectSource
Describes the project source where the objects satisfying the filters will be transformed.
ProjectsResource
PutMetadata
Describes options for object metadata update.
PutObjectHold
Describes options to update object hold.
RewriteObject
Describes options for object rewrite.
SetObjectAcls
Describes options for setting object ACLs.
StorageBatchOperationsApi
TargetLocations
Describes the Cloud Storage locations to include in a ProjectSource job.
UpdateObjectCustomContext
Describes options to update object custom contexts.

Typedefs

CancelJobResponse = $Empty
Message for response to cancel Job.
CancelOperationRequest = $Empty
The request message for Operations.CancelOperation.
Empty = $Empty
A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
Expr = $Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
Location = $Location00
A resource that represents a Google Cloud location.
Status = $Status00
The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.