GoogleIdentityStsV1Jwk class

Constructors

GoogleIdentityStsV1Jwk({String? alg, String? e, String? kid, String? kty, String? n, String? use})
GoogleIdentityStsV1Jwk.fromJson(Map json_)

Properties

alg String?
Algorithm intended for use with the key.
getter/setter pair
e String?
Exponent value for kty="RSA".
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kid String?
Key ID.
getter/setter pair
kty String?
Key type.
getter/setter pair
n String?
Modulus value for kty="RSA".
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
use String?
Public key use.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited