GoogleIdentityStsV1OpenIdProviderConfig class

Response message for GetOpenIdProviderConfig.

Message fields are defined in https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderConfigurationResponse

Constructors

GoogleIdentityStsV1OpenIdProviderConfig({String? authorizationEndpoint, List<String>? idTokenSigningAlgValuesSupported, String? issuer, String? jwksUri, List<String>? responseTypesSupported, List<String>? subjectTypesSupported, String? tokenEndpoint})
GoogleIdentityStsV1OpenIdProviderConfig.fromJson(Map json_)

Properties

authorizationEndpoint String?
URL pointing to an authorization endpoint under this issuer.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idTokenSigningAlgValuesSupported List<String>?
JSON array containing a list of the JWS signing algorithms (alg values) supported by the OP for the ID token to encode the claims in a JWT [JWT].
getter/setter pair
issuer String?
URL using the https scheme with no query or fragment components that the OP asserts as its issuer identifier.
getter/setter pair
jwksUri String?
URL of the OP's JWK Set [JWK] document, which MUST use the https scheme.
getter/setter pair
responseTypesSupported List<String>?
JSON array containing a list of the OAuth 2.0 response_type values that this OP supports.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subjectTypesSupported List<String>?
JSON array containing a list of the subject identifier types that this OP supports.
getter/setter pair
tokenEndpoint String?
URL pointing to a token endpoint under this issuer.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited