authorizationEndpoint property
URL pointing to an authorization endpoint under this issuer.
Note: Currently this endpoint returns a 404.
Implementation
core.String? authorizationEndpoint;
URL pointing to an authorization endpoint under this issuer.
Note: Currently this endpoint returns a 404.
core.String? authorizationEndpoint;