issuer property
URL using the https scheme with no query or fragment components that the OP asserts as its issuer identifier.
Implementation
core.String? issuer;
URL using the https scheme with no query or fragment components that the OP asserts as its issuer identifier.
core.String? issuer;