tokenEndpoint property
URL pointing to a token endpoint under this issuer.
Note: Currently this endpoint returns a 404.
Implementation
core.String? tokenEndpoint;
URL pointing to a token endpoint under this issuer.
Note: Currently this endpoint returns a 404.
core.String? tokenEndpoint;