OrganizationsLocationsWorkloadIdentityPoolsWellKnownResource class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getOpenidConfiguration(String name, {String? $fields}) Future<GoogleIdentityStsV1OpenIdProviderConfig>
Gets the OIDC provider configuration for an agentic or managed workload identity pool following the OIDC 1.0 discovery specification.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited