ProjectsLocationsWorkloadIdentityPoolsOpenidResource class

Constructors

ProjectsLocationsWorkloadIdentityPoolsOpenidResource(ApiRequester client)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getJwks(String name, {String? $fields}) Future<GoogleIdentityStsV1Jwks>
Fetches the signing keys for an agentic or managed workload identity pool and returns them in JWKs format, defined in RFC 7517.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited