Account class

Represents a Google Tag Manager Account.

Constructors

Account({String? accountId, String? fingerprint, String? name, bool? shareData})
Account.fromJson(Map json_)

Properties

accountId ↔ String?
The Account ID uniquely identifies the GTM Account.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Account as computed at storage time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Account display name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shareData ↔ bool?
Whether the account shares data anonymously with Google and others.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited