AccountsContainersResource class

Constructors

AccountsContainersResource(ApiRequester client)

Properties

environments → AccountsContainersEnvironmentsResource
no setter
folders → AccountsContainersFoldersResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
moveFolders → AccountsContainersMoveFoldersResource
no setter
reauthorizeEnvironments → AccountsContainersReauthorizeEnvironmentsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → AccountsContainersTagsResource
no setter
triggers → AccountsContainersTriggersResource
no setter
variables → AccountsContainersVariablesResource
no setter
versions → AccountsContainersVersionsResource
no setter

Methods

create(Container request, String accountId, {String? $fields}) → Future<Container>
Creates a Container.
delete(String accountId, String containerId, {String? $fields}) → Future<void>
Deletes a Container.
get(String accountId, String containerId, {String? $fields}) → Future<Container>
Gets a Container.
list(String accountId, {String? $fields}) → Future<ListContainersResponse>
Lists all Containers that belongs to a GTM Account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
update(Container request, String accountId, String containerId, {String? fingerprint, String? $fields}) → Future<Container>
Updates a Container.

Operators

operator ==(Object other) → bool
The equality operator.
inherited