Container class

Represents a Google Tag Manager Container.

Constructors

Container({String? accountId, String? containerId, List<String>? domainName, List<String>? enabledBuiltInVariable, String? fingerprint, String? name, String? notes, String? publicId, String? timeZoneCountryId, String? timeZoneId, List<String>? usageContext})
Container.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
containerId ↔ String?
The Container ID uniquely identifies the GTM Container.
getter/setter pair
domainName ↔ List<String>?
Optional list of domain names associated with the Container.
getter/setter pair
enabledBuiltInVariable ↔ List<String>?
List of enabled built-in variables.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Container as computed at storage time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Container display name.
getter/setter pair
notes ↔ String?
Container Notes.
getter/setter pair
publicId ↔ String?
Container Public ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeZoneCountryId ↔ String?
Container Country ID.
getter/setter pair
timeZoneId ↔ String?
Container Time Zone ID.
getter/setter pair
usageContext ↔ List<String>?
List of Usage Contexts for the Container.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited