Environment class

Represents a Google Tag Manager Environment.

Note that a user can create, delete and update environments of type USER, but can only update the enable_debug and url fields of environments of other types.

Constructors

Environment({String? accountId, String? authorizationCode, String? authorizationTimestampMs, String? containerId, String? containerVersionId, String? description, bool? enableDebug, String? environmentId, String? fingerprint, String? name, String? type, String? url})
Environment.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
authorizationCode ↔ String?
The environment authorization code.
getter/setter pair
authorizationTimestampMs ↔ String?
The last update time-stamp for the authorization code.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
containerVersionId ↔ String?
getter/setter pair
description ↔ String?
The environment description.
getter/setter pair
enableDebug ↔ bool?
Whether or not to enable debug by default on for the environment.
getter/setter pair
environmentId ↔ String?
GTM Environment ID uniquely identifies the GTM Environment.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM environment as computed at storage time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The environment display name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of this environment. Possible string values are:
getter/setter pair
url ↔ String?
Default preview page url for the environment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited