Folder class

Represents a Google Tag Manager Folder.

Constructors

Folder({String? accountId, String? containerId, String? fingerprint, String? folderId, String? name})
Folder.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Folder as computed at storage time.
getter/setter pair
folderId ↔ String?
The Folder ID uniquely identifies the GTM Folder.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Folder display name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited