Parameter class

Represents a Google Tag Manager Parameter.

Constructors

Parameter({String? key, List<Parameter>? list, List<Parameter>? map, String? type, String? value})
Parameter.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The named key that uniquely identifies a parameter.
getter/setter pair
list ↔ List<Parameter>?
This list parameter's parameters (keys will be ignored).
getter/setter pair
map ↔ List<Parameter>?
This map parameter's parameters (must have keys; keys must be unique).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The parameter type.
getter/setter pair
value ↔ String?
A parameter's value (may contain variable references).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited