Tag class

Represents a Google Tag Manager Tag.

Constructors

Tag({String? accountId, List<String>? blockingTriggerId, String? containerId, String? fingerprint, List<String>? firingTriggerId, bool? liveOnly, String? name, String? notes, List<Parameter>? parameter, String? parentFolderId, bool? paused, Parameter? priority, String? scheduleEndMs, String? scheduleStartMs, List<SetupTag>? setupTag, String? tagFiringOption, String? tagId, List<TeardownTag>? teardownTag, String? type})
Tag.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
blockingTriggerId ↔ List<String>?
Blocking trigger IDs.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Tag as computed at storage time.
getter/setter pair
firingTriggerId ↔ List<String>?
Firing trigger IDs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
liveOnly ↔ bool?
If set to true, this tag will only fire in the live environment (e.g. not in preview or debug mode).
getter/setter pair
name ↔ String?
Tag display name.
getter/setter pair
notes ↔ String?
User notes on how to apply this tag in the container.
getter/setter pair
parameter ↔ List<Parameter>?
The tag's parameters.
getter/setter pair
parentFolderId ↔ String?
Parent folder id.
getter/setter pair
paused ↔ bool?
True if the tag is paused.
getter/setter pair
priority ↔ Parameter?
User defined numeric priority of the tag.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleEndMs ↔ String?
The end timestamp in milliseconds to schedule a tag.
getter/setter pair
scheduleStartMs ↔ String?
The start timestamp in milliseconds to schedule a tag.
getter/setter pair
setupTag ↔ List<SetupTag>?
The list of setup tags.
getter/setter pair
tagFiringOption ↔ String?
Option to fire this tag. Possible string values are:
getter/setter pair
tagId ↔ String?
The Tag ID uniquely identifies the GTM Tag.
getter/setter pair
teardownTag ↔ List<TeardownTag>?
The list of teardown tags.
getter/setter pair
type ↔ String?
GTM Tag Type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited