AccountFeatures class

Constructors

AccountFeatures({bool? supportMultipleContainers, bool? supportUserPermissions})
AccountFeatures.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportMultipleContainers ↔ bool?
Whether this Account supports multiple Containers.
getter/setter pair
supportUserPermissions ↔ bool?
Whether this Account supports user permissions managed by GTM.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited