BuiltInVariable class

Built-in variables are a special category of variables that are pre-created and non-customizable.

They provide common functionality like accessing properties of the gtm data layer, monitoring clicks, or accessing elements of a page URL.

Constructors

BuiltInVariable({String? accountId, String? containerId, String? name, String? path, String? type, String? workspaceId})
BuiltInVariable.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the built-in variable to be used to refer to the built-in variable.
getter/setter pair
path ↔ String?
GTM BuiltInVariable's API relative path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of built-in variable. Possible string values are:
getter/setter pair
workspaceId ↔ String?
GTM Workspace ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited