Client class

Constructors

Client({String? accountId, String? clientId, String? containerId, String? fingerprint, String? name, String? notes, List<Parameter>? parameter, String? parentFolderId, String? path, int? priority, String? tagManagerUrl, String? type, String? workspaceId})
Client.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
clientId ↔ String?
The Client ID uniquely identifies the GTM client.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Client as computed at storage time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Client display name.
getter/setter pair
notes ↔ String?
User notes on how to apply this tag in the container.
getter/setter pair
parameter ↔ List<Parameter>?
The client's parameters.
getter/setter pair
parentFolderId ↔ String?
Parent folder id.
getter/setter pair
path ↔ String?
GTM client's API relative path.
getter/setter pair
priority ↔ int?
Priority determines relative firing order.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagManagerUrl ↔ String?
Auto generated link to the tag manager UI
getter/setter pair
type ↔ String?
Client type.
getter/setter pair
workspaceId ↔ String?
GTM Workspace ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited