Condition class

Represents a predicate.

Constructors

Condition({List<Parameter>? parameter, String? type})
Condition.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
parameter ↔ List<Parameter>?
A list of named parameters (key/value), depending on the condition's type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The type of operator for this condition. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited