Container class

Represents a Google Tag Manager Container, which specifies the platform tags will run on, manages workspaces, and retains container versions.

Constructors

Container({String? accountId, String? containerId, List<String>? domainName, ContainerFeatures? features, String? fingerprint, String? name, String? notes, String? path, String? publicId, List<String>? tagIds, String? tagManagerUrl, List<String>? taggingServerUrls, List<String>? usageContext})
Container.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
containerId ↔ String?
The Container ID uniquely identifies the GTM Container.
getter/setter pair
domainName ↔ List<String>?
List of domain names associated with the Container.
getter/setter pair
features ↔ ContainerFeatures?
Read-only Container feature set.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Container as computed at storage time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Container display name.
getter/setter pair
notes ↔ String?
Container Notes.
getter/setter pair
path ↔ String?
GTM Container's API relative path.
getter/setter pair
publicId ↔ String?
Container Public ID.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taggingServerUrls ↔ List<String>?
List of server-side container URLs for the Container.
getter/setter pair
tagIds ↔ List<String>?
All Tag IDs that refer to this Container.
getter/setter pair
tagManagerUrl ↔ String?
Auto generated link to the tag manager UI
getter/setter pair
usageContext ↔ List<String>?
List of Usage Contexts for the Container.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited