ContainerAccess class

Defines the Google Tag Manager Container access permissions.

Constructors

ContainerAccess({String? containerId, String? permission})
ContainerAccess.fromJson(Map json_)

Properties

containerId ↔ String?
GTM Container ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
permission ↔ String?
List of Container permissions. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited