ContainerFeatures class

Constructors

ContainerFeatures({bool? supportBuiltInVariables, bool? supportClients, bool? supportEnvironments, bool? supportFolders, bool? supportGtagConfigs, bool? supportTags, bool? supportTemplates, bool? supportTransformations, bool? supportTriggers, bool? supportUserPermissions, bool? supportVariables, bool? supportVersions, bool? supportWorkspaces, bool? supportZones})
ContainerFeatures.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportBuiltInVariables ↔ bool?
Whether this Container supports built-in variables
getter/setter pair
supportClients ↔ bool?
Whether this Container supports clients.
getter/setter pair
supportEnvironments ↔ bool?
Whether this Container supports environments.
getter/setter pair
supportFolders ↔ bool?
Whether this Container supports folders.
getter/setter pair
supportGtagConfigs ↔ bool?
Whether this Container supports Google tag config.
getter/setter pair
supportTags ↔ bool?
Whether this Container supports tags.
getter/setter pair
supportTemplates ↔ bool?
Whether this Container supports templates.
getter/setter pair
supportTransformations ↔ bool?
Whether this Container supports transformations.
getter/setter pair
supportTriggers ↔ bool?
Whether this Container supports triggers.
getter/setter pair
supportUserPermissions ↔ bool?
Whether this Container supports user permissions managed by GTM.
getter/setter pair
supportVariables ↔ bool?
Whether this Container supports variables.
getter/setter pair
supportVersions ↔ bool?
Whether this Container supports Container versions.
getter/setter pair
supportWorkspaces ↔ bool?
Whether this Container supports workspaces.
getter/setter pair
supportZones ↔ bool?
Whether this Container supports zones.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited