ContainerVersion class

Represents a Google Tag Manager Container Version.

Constructors

ContainerVersion({String? accountId, List<BuiltInVariable>? builtInVariable, List<Client>? client, Container? container, String? containerId, String? containerVersionId, List<CustomTemplate>? customTemplate, bool? deleted, String? description, String? fingerprint, List<Folder>? folder, List<GtagConfig>? gtagConfig, String? name, String? path, List<Tag>? tag, String? tagManagerUrl, List<Transformation>? transformation, List<Trigger>? trigger, List<Variable>? variable, List<Zone>? zone})
ContainerVersion.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
builtInVariable ↔ List<BuiltInVariable>?
The built-in variables in the container that this version was taken from.
getter/setter pair
client ↔ List<Client>?
The clients in the container that this version was taken from.
getter/setter pair
container ↔ Container?
The container that this version was taken from.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
containerVersionId ↔ String?
The Container Version ID uniquely identifies the GTM Container Version.
getter/setter pair
customTemplate ↔ List<CustomTemplate>?
The custom templates in the container that this version was taken from.
getter/setter pair
deleted ↔ bool?
A value of true indicates this container version has been deleted.
getter/setter pair
description ↔ String?
Container version description.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Container Version as computed at storage time.
getter/setter pair
folder ↔ List<Folder>?
The folders in the container that this version was taken from.
getter/setter pair
gtagConfig ↔ List<GtagConfig>?
The Google tag configs in the container that this version was taken from.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Container version display name.
getter/setter pair
path ↔ String?
GTM Container Version's API relative path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ List<Tag>?
The tags in the container that this version was taken from.
getter/setter pair
tagManagerUrl ↔ String?
Auto generated link to the tag manager UI
getter/setter pair
transformation ↔ List<Transformation>?
The transformations in the container that this version was taken from.
getter/setter pair
trigger ↔ List<Trigger>?
The triggers in the container that this version was taken from.
getter/setter pair
variable ↔ List<Variable>?
The variables in the container that this version was taken from.
getter/setter pair
zone ↔ List<Zone>?
The zones in the container that this version was taken from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited