ContainerVersionHeader class

Represents a Google Tag Manager Container Version Header.

Constructors

ContainerVersionHeader({String? accountId, String? containerId, String? containerVersionId, bool? deleted, String? name, String? numClients, String? numCustomTemplates, String? numGtagConfigs, String? numTags, String? numTransformations, String? numTriggers, String? numVariables, String? numZones, String? path})
ContainerVersionHeader.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
containerVersionId ↔ String?
The Container Version ID uniquely identifies the GTM Container Version.
getter/setter pair
deleted ↔ bool?
A value of true indicates this container version has been deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Container version display name.
getter/setter pair
numClients ↔ String?
Number of clients in the container version.
getter/setter pair
numCustomTemplates ↔ String?
Number of custom templates in the container version.
getter/setter pair
numGtagConfigs ↔ String?
Number of Google tag configs in the container version.
getter/setter pair
numTags ↔ String?
Number of tags in the container version.
getter/setter pair
numTransformations ↔ String?
Number of transformations in the container version.
getter/setter pair
numTriggers ↔ String?
Number of triggers in the container version.
getter/setter pair
numVariables ↔ String?
Number of variables in the container version.
getter/setter pair
numZones ↔ String?
Number of zones in the container version.
getter/setter pair
path ↔ String?
GTM Container Version's API relative path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited