CreateContainerVersionRequestVersionOptions class

Options for new container versions.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the container version to be created.
getter/setter pair
notes ↔ String?
The notes of the container version to be created.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited