CreateContainerVersionResponse class

Create container versions response.

Constructors

CreateContainerVersionResponse({bool? compilerError, ContainerVersion? containerVersion, String? newWorkspacePath, SyncStatus? syncStatus})
CreateContainerVersionResponse.fromJson(Map json_)

Properties

compilerError ↔ bool?
Compiler errors or not.
getter/setter pair
containerVersion ↔ ContainerVersion?
The container version created.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
newWorkspacePath ↔ String?
Auto generated workspace path created as a result of version creation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncStatus ↔ SyncStatus?
Whether version creation failed when syncing the workspace to the latest container version.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited