CustomTemplate class

Represents a Google Tag Manager Custom Template's contents.

Constructors

CustomTemplate({String? accountId, String? containerId, String? fingerprint, GalleryReference? galleryReference, String? name, String? path, String? tagManagerUrl, String? templateData, String? templateId, String? workspaceId})
CustomTemplate.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Custom Template as computed at storage time.
getter/setter pair
galleryReference ↔ GalleryReference?
A reference to the Community Template Gallery entry.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Custom Template display name.
getter/setter pair
path ↔ String?
GTM Custom Template's API relative path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagManagerUrl ↔ String?
Auto generated link to the tag manager UI
getter/setter pair
templateData ↔ String?
The custom template in text format.
getter/setter pair
templateId ↔ String?
The Custom Template ID uniquely identifies the GTM custom template.
getter/setter pair
workspaceId ↔ String?
GTM Workspace ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited