Entity class

A workspace entity that may represent a tag, trigger, variable, or folder in addition to its status in the workspace.

Constructors

Entity({BuiltInVariable? builtInVariable, String? changeStatus, Client? client, CustomTemplate? customTemplate, Folder? folder, GtagConfig? gtagConfig, Tag? tag, Transformation? transformation, Trigger? trigger, Variable? variable, Zone? zone})
Entity.fromJson(Map json_)

Properties

builtInVariable ↔ BuiltInVariable?
The built in variable being represented by the entity.
getter/setter pair
changeStatus ↔ String?
Represents how the entity has been changed in the workspace. Possible string values are:
getter/setter pair
client ↔ Client?
The client being represented by the entity.
getter/setter pair
customTemplate ↔ CustomTemplate?
The custom template being represented by the entity.
getter/setter pair
folder ↔ Folder?
The folder being represented by the entity.
getter/setter pair
gtagConfig ↔ GtagConfig?
The gtag config being represented by the entity.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tag ↔ Tag?
The tag being represented by the entity.
getter/setter pair
transformation ↔ Transformation?
The transformation being represented by the entity.
getter/setter pair
trigger ↔ Trigger?
The trigger being represented by the entity.
getter/setter pair
variable ↔ Variable?
The variable being represented by the entity.
getter/setter pair
zone ↔ Zone?
The zone being represented by the entity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited