ListContainerVersionsResponse class

List container versions response.

Constructors

ListContainerVersionsResponse({List<ContainerVersionHeader>? containerVersionHeader, String? nextPageToken})
ListContainerVersionsResponse.fromJson(Map json_)

Properties

containerVersionHeader ↔ List<ContainerVersionHeader>?
All container version headers of a GTM Container.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Continuation token for fetching the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited