ListContainersResponse class

List Containers Response.

Constructors

ListContainersResponse({List<Container>? container, String? nextPageToken})
ListContainersResponse.fromJson(Map json_)

Properties

container ↔ List<Container>?
All Containers of a GTM Account.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Continuation token for fetching the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited