ListTemplatesResponse class

Constructors

ListTemplatesResponse({String? nextPageToken, List<CustomTemplate>? template})
ListTemplatesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Continuation token for fetching the next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template ↔ List<CustomTemplate>?
All GTM Custom Templates of a GTM Container.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited