SyncStatus class

The status of a workspace after synchronization.

Constructors

SyncStatus({bool? mergeConflict, bool? syncError})
SyncStatus.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mergeConflict ↔ bool?
Synchornization operation detected a merge conflict.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
syncError ↔ bool?
An error occurred during the synchronization operation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited