Transformation class

Represents a Google Tag Manager Transformation.

Constructors

Transformation({String? accountId, String? containerId, String? fingerprint, String? name, String? notes, List<Parameter>? parameter, String? parentFolderId, String? path, String? tagManagerUrl, String? transformationId, String? type, String? workspaceId})
Transformation.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Transformation as computed at storage time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Transformation display name.
getter/setter pair
notes ↔ String?
User notes on how to apply this transformation in the container.
getter/setter pair
parameter ↔ List<Parameter>?
The transformation's parameters.
getter/setter pair
parentFolderId ↔ String?
Parent folder id.
getter/setter pair
path ↔ String?
GTM transformation's API relative path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagManagerUrl ↔ String?
Auto generated link to the tag manager UI
getter/setter pair
transformationId ↔ String?
The Transformation ID uniquely identifies the GTM transformation.
getter/setter pair
type ↔ String?
Transformation type.
getter/setter pair
workspaceId ↔ String?
GTM Workspace ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited