UserPermission class

Represents a user's permissions to an account and its container.

Constructors

UserPermission({AccountAccess? accountAccess, String? accountId, List<ContainerAccess>? containerAccess, String? emailAddress, String? path})
UserPermission.fromJson(Map json_)

Properties

accountAccess ↔ AccountAccess?
GTM Account access permissions.
getter/setter pair
accountId ↔ String?
The Account ID uniquely identifies the GTM Account.
getter/setter pair
containerAccess ↔ List<ContainerAccess>?
GTM Container access permissions.
getter/setter pair
emailAddress ↔ String?
User's email address.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
path ↔ String?
GTM UserPermission's API relative path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited