Variable class

Represents a Google Tag Manager Variable.

Constructors

Variable({String? accountId, String? containerId, List<String>? disablingTriggerId, List<String>? enablingTriggerId, String? fingerprint, VariableFormatValue? formatValue, String? name, String? notes, List<Parameter>? parameter, String? parentFolderId, String? path, String? scheduleEndMs, String? scheduleStartMs, String? tagManagerUrl, String? type, String? variableId, String? workspaceId})
Variable.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
disablingTriggerId ↔ List<String>?
For mobile containers only: A list of trigger IDs for disabling conditional variables; the variable is enabled if one of the enabling trigger is true while all the disabling trigger are false.
getter/setter pair
enablingTriggerId ↔ List<String>?
For mobile containers only: A list of trigger IDs for enabling conditional variables; the variable is enabled if one of the enabling triggers is true while all the disabling triggers are false.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Variable as computed at storage time.
getter/setter pair
formatValue ↔ VariableFormatValue?
Option to convert a variable value to other value.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Variable display name.
getter/setter pair
notes ↔ String?
User notes on how to apply this variable in the container.
getter/setter pair
parameter ↔ List<Parameter>?
The variable's parameters.
getter/setter pair
parentFolderId ↔ String?
Parent folder id.
getter/setter pair
path ↔ String?
GTM Variable's API relative path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scheduleEndMs ↔ String?
The end timestamp in milliseconds to schedule a variable.
getter/setter pair
scheduleStartMs ↔ String?
The start timestamp in milliseconds to schedule a variable.
getter/setter pair
tagManagerUrl ↔ String?
Auto generated link to the tag manager UI
getter/setter pair
type ↔ String?
GTM Variable Type.
getter/setter pair
variableId ↔ String?
The Variable ID uniquely identifies the GTM Variable.
getter/setter pair
workspaceId ↔ String?
GTM Workspace ID.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited