VariableFormatValue class

Constructors

VariableFormatValue({String? caseConversionType, Parameter? convertFalseToValue, Parameter? convertNullToValue, bool? convertToBoolean, String? convertToNumber, Parameter? convertTrueToValue, Parameter? convertUndefinedToValue})
VariableFormatValue.fromJson(Map json_)

Properties

caseConversionType ↔ String?
The option to convert a string-type variable value to either lowercase or uppercase. Possible string values are:
getter/setter pair
convertFalseToValue ↔ Parameter?
The value to convert if a variable value is false.
getter/setter pair
convertNullToValue ↔ Parameter?
The value to convert if a variable value is null.
getter/setter pair
convertToBoolean ↔ bool?
The option to convert a variable value to a boolean.
getter/setter pair
convertToNumber ↔ String?
The option to convert a variable value to a number. Possible string values are:
getter/setter pair
convertTrueToValue ↔ Parameter?
The value to convert if a variable value is true.
getter/setter pair
convertUndefinedToValue ↔ Parameter?
The value to convert if a variable value is undefined.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited