Zone class

Represents a Google Tag Manager Zone's contents.

Constructors

Zone({String? accountId, ZoneBoundary? boundary, List<ZoneChildContainer>? childContainer, String? containerId, String? fingerprint, String? name, String? notes, String? path, String? tagManagerUrl, ZoneTypeRestriction? typeRestriction, String? workspaceId, String? zoneId})
Zone.fromJson(Map json_)

Properties

accountId ↔ String?
GTM Account ID.
getter/setter pair
boundary ↔ ZoneBoundary?
This Zone's boundary.
getter/setter pair
childContainer ↔ List<ZoneChildContainer>?
Containers that are children of this Zone.
getter/setter pair
containerId ↔ String?
GTM Container ID.
getter/setter pair
fingerprint ↔ String?
The fingerprint of the GTM Zone as computed at storage time.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Zone display name.
getter/setter pair
notes ↔ String?
User notes on how to apply this zone in the container.
getter/setter pair
path ↔ String?
GTM Zone's API relative path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tagManagerUrl ↔ String?
Auto generated link to the tag manager UI
getter/setter pair
typeRestriction ↔ ZoneTypeRestriction?
This Zone's type restrictions.
getter/setter pair
workspaceId ↔ String?
GTM Workspace ID.
getter/setter pair
zoneId ↔ String?
The Zone ID uniquely identifies the GTM Zone.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited