AssignmentInfo class

Information about the source of the task assignment (Document, Chat Space).

Constructors

AssignmentInfo({DriveResourceInfo? driveResourceInfo, String? linkToTask, SpaceInfo? spaceInfo, String? surfaceType})
AssignmentInfo.fromJson(Map json_)

Properties

driveResourceInfo ↔ DriveResourceInfo?
Information about the Drive file where this task originates from.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
linkToTask ↔ String?
An absolute link to the original task in the surface of assignment (Docs, Chat spaces, etc.).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spaceInfo ↔ SpaceInfo?
Information about the Chat Space where this task originates from.
getter/setter pair
surfaceType ↔ String?
The type of surface this assigned task originates from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited