SpaceInfo class

Information about the Chat Space where a task was assigned from.

Constructors

SpaceInfo({String? space})
SpaceInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
space ↔ String?
The Chat space where this task originates from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited