Task class

Constructors

Task({AssignmentInfo? assignmentInfo, String? completed, bool? deleted, String? due, String? etag, bool? hidden, String? id, String? kind, List<TaskLinks>? links, String? notes, String? parent, String? position, String? selfLink, String? status, String? title, String? updated, String? webViewLink})
Task.fromJson(Map json_)

Properties

assignmentInfo ↔ AssignmentInfo?
Context information for assigned tasks.
getter/setter pair
completed ↔ String?
Completion date of the task (as a RFC 3339 timestamp).
getter/setter pair
deleted ↔ bool?
Flag indicating whether the task has been deleted.
getter/setter pair
due ↔ String?
Scheduled date for the task (as an RFC 3339 timestamp).
getter/setter pair
etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hidden ↔ bool?
Flag indicating whether the task is hidden.
getter/setter pair
id ↔ String?
Task identifier.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
Collection of links.
getter/setter pair
notes ↔ String?
Notes describing the task.
getter/setter pair
parent ↔ String?
Parent task identifier.
getter/setter pair
position ↔ String?
String indicating the position of the task among its sibling tasks under the same parent task or at the top level.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
URL pointing to this task.
getter/setter pair
status ↔ String?
Status of the task.
getter/setter pair
title ↔ String?
Title of the task.
getter/setter pair
updated ↔ String?
Last modification time of the task (as a RFC 3339 timestamp).
getter/setter pair
An absolute link to the task in the Google Tasks Web UI.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited