TaskLinks class

Constructors

TaskLinks({String? description, String? link, String? type})
TaskLinks.fromJson(Map json_)

Properties

description ↔ String?
The description (might be empty).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
The URL.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of the link, e.g. "email", "generic", "chat_message", "keep_note".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited