TaskList class

Constructors

TaskList({String? etag, String? id, String? kind, String? selfLink, String? title, String? updated})
TaskList.fromJson(Map json_)

Properties

etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Task list identifier.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
URL pointing to this task list.
getter/setter pair
title ↔ String?
Title of the task list.
getter/setter pair
updated ↔ String?
Last modification time of the task list (as a RFC 3339 timestamp).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited