TaskLists class

Constructors

TaskLists({String? etag, List<TaskList>? items, String? kind, String? nextPageToken})
TaskLists.fromJson(Map json_)

Properties

etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<TaskList>?
Collection of task lists.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
nextPageToken ↔ String?
Token that can be used to request the next page of this result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited