Tasks class

Constructors

Tasks({String? etag, List<Task>? items, String? kind, String? nextPageToken})
Tasks.fromJson(Map json_)

Properties

etag ↔ String?
ETag of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Task>?
Collection of tasks.
getter/setter pair
kind ↔ String?
Type of the resource.
getter/setter pair
nextPageToken ↔ String?
Token used to access the next page of this result.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited