TasksApi class

The Google Tasks API lets you manage your tasks and task lists.

Constructors

TasksApi(Client client, {String rootUrl = 'https://tasks.googleapis.com/', String servicePath = ''})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tasklists → TasklistsResource
no setter
tasks → TasksResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

tasksReadonlyScope → const String
View your tasks
tasksScope → const String
Create, edit, organize, and delete all your tasks