AdvancedVoiceOptions class

Used for advanced voice options.

Constructors

AdvancedVoiceOptions({bool? enableTextnorm, bool? lowLatencyJourneySynthesis, bool? relaxSafetyFilters, SafetySettings? safetySettings})
AdvancedVoiceOptions.fromJson(Map json_)

Properties

enableTextnorm ↔ bool?
If true, textnorm will be applied to text input.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lowLatencyJourneySynthesis ↔ bool?
Only for Journey voices.
getter/setter pair
relaxSafetyFilters ↔ bool?
Input only.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safetySettings ↔ SafetySettings?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited