MultiSpeakerVoiceConfig class

Configuration for a multi-speaker text-to-speech setup.

Enables the use of up to two distinct voices in a single synthesis request.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speakerVoiceConfigs List<MultispeakerPrebuiltVoice>?
A list of configurations for the voices of the speakers.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited