SafetySetting class

Safety setting for a single harm category.

Constructors

SafetySetting({String? category, String? threshold})
SafetySetting.fromJson(Map json_)

Properties

category ↔ String?
The harm category to apply the safety setting to. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threshold ↔ String?
The harm block threshold for the safety setting. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited