Turn class

A multi-speaker turn.

Constructors

Turn({String? speaker, String? text})
Turn.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speaker ↔ String?
The speaker of the turn, for example, 'O' or 'Q'.
getter/setter pair
text ↔ String?
The text to speak.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited