NetworkEndpoint class

A network endpoint over which a TPU worker can be reached.

Constructors

NetworkEndpoint({String? ipAddress, int? port})
NetworkEndpoint.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipAddress ↔ String?
The IP address of this network endpoint.
getter/setter pair
port ↔ int?
The port of this network endpoint.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited