SchedulingConfig class

Sets the scheduling options for this node.

Constructors

SchedulingConfig({bool? preemptible, bool? reserved})
SchedulingConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
preemptible ↔ bool?
Defines whether the node is preemptible.
getter/setter pair
reserved ↔ bool?
Whether the node is created under a reservation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited