AcceleratorType class

A accelerator type that a Node can be configured with.

Constructors

AcceleratorType({List<AcceleratorConfig>? acceleratorConfigs, String? name, String? type})
AcceleratorType.fromJson(Map json_)

Properties

acceleratorConfigs ↔ List<AcceleratorConfig>?
The accelerator config.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The accelerator type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited