AttachedDisk class

A node-attached disk resource.

Next ID: 8;

Constructors

AttachedDisk({String? mode, String? sourceDisk})
AttachedDisk.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
mode ↔ String?
The mode in which to attach this disk.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDisk ↔ String?
Specifies the full path to an existing disk.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited