ListRuntimeVersionsResponse class

Response for ListRuntimeVersions.

Constructors

ListRuntimeVersionsResponse({String? nextPageToken, List<RuntimeVersion>? runtimeVersions, List<String>? unreachable})
ListRuntimeVersionsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The next page token or empty if none.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeVersions ↔ List<RuntimeVersion>?
The listed nodes.
getter/setter pair
unreachable ↔ List<String>?
Locations that could not be reached.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited