MultisliceParams class

Parameters to specify for multislice QueuedResource requests.

This message must be populated in case of multislice requests instead of node_id.

Constructors

MultisliceParams({int? nodeCount, String? nodeIdPrefix})
MultisliceParams.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodeCount ↔ int?
Number of nodes with this spec.
getter/setter pair
nodeIdPrefix ↔ String?
Prefix of node_ids in case of multislice request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited