Node class

A TPU instance.

Constructors

Node({AcceleratorConfig? acceleratorConfig, String? acceleratorType, String? apiVersion, BootDiskConfig? bootDiskConfig, String? cidrBlock, String? createTime, List<AttachedDisk>? dataDisks, String? description, String? health, String? healthDescription, String? id, Map<String, String>? labels, Map<String, String>? metadata, bool? multisliceNode, String? name, NetworkConfig? networkConfig, List<NetworkConfig>? networkConfigs, List<NetworkEndpoint>? networkEndpoints, String? queuedResource, String? runtimeVersion, SchedulingConfig? schedulingConfig, ServiceAccount? serviceAccount, ShieldedInstanceConfig? shieldedInstanceConfig, String? state, List<Symptom>? symptoms, List<String>? tags, UpcomingMaintenance? upcomingMaintenance})
Node.fromJson(Map json_)

Properties

acceleratorConfig ↔ AcceleratorConfig?
The AccleratorConfig for the TPU Node.
getter/setter pair
acceleratorType ↔ String?
The type of hardware accelerators associated with this node.
getter/setter pair
apiVersion ↔ String?
The API version that created this Node.
getter/setter pair
bootDiskConfig ↔ BootDiskConfig?
Boot disk configuration.
getter/setter pair
cidrBlock ↔ String?
The CIDR block that the TPU node will use when selecting an IP address.
getter/setter pair
createTime ↔ String?
The time when the node was created.
getter/setter pair
dataDisks ↔ List<AttachedDisk>?
The additional data disks for the Node.
getter/setter pair
description ↔ String?
The user-supplied description of the TPU.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
health ↔ String?
The health status of the TPU node. Possible string values are:
getter/setter pair
healthDescription ↔ String?
If this field is populated, it contains a description of why the TPU Node is unhealthy.
getter/setter pair
id ↔ String?
The unique identifier for the TPU Node.
getter/setter pair
labels ↔ Map<String, String>?
Resource labels to represent user-provided metadata.
getter/setter pair
metadata ↔ Map<String, String>?
Custom metadata to apply to the TPU Node.
getter/setter pair
multisliceNode ↔ bool?
Whether the Node belongs to a Multislice group.
getter/setter pair
name ↔ String?
The name of the TPU.
getter/setter pair
networkConfig ↔ NetworkConfig?
Network configurations for the TPU node.
getter/setter pair
networkConfigs ↔ List<NetworkConfig>?
Repeated network configurations for the TPU node.
getter/setter pair
networkEndpoints ↔ List<NetworkEndpoint>?
The network endpoints where TPU workers can be accessed and sent work.
getter/setter pair
queuedResource ↔ String?
The qualified name of the QueuedResource that requested this Node.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runtimeVersion ↔ String?
The runtime version running in the Node.
getter/setter pair
schedulingConfig ↔ SchedulingConfig?
The scheduling options for this node.
getter/setter pair
serviceAccount ↔ ServiceAccount?
The Google Cloud Platform Service Account to be used by the TPU node VMs.
getter/setter pair
shieldedInstanceConfig ↔ ShieldedInstanceConfig?
Shielded Instance options.
getter/setter pair
state ↔ String?
The current state for the TPU Node.
getter/setter pair
symptoms ↔ List<Symptom>?
The Symptoms that have occurred to the TPU Node.
getter/setter pair
tags ↔ List<String>?
Tags to apply to the TPU Node.
getter/setter pair
upcomingMaintenance ↔ UpcomingMaintenance?
Upcoming maintenance on this TPU node.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited