NodeSpec class

Details of the TPU node(s) being requested.

Users can request either a single node or multiple nodes. NodeSpec provides the specification for node(s) to be created.

Constructors

NodeSpec({MultisliceParams? multisliceParams, Node? node, String? nodeId, String? parent})
NodeSpec.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
multisliceParams ↔ MultisliceParams?
Fields to specify in case of multislice request.
getter/setter pair
node ↔ Node?
The node.
getter/setter pair
nodeId ↔ String?
The unqualified resource name.
getter/setter pair
parent ↔ String?
The parent resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited