QueueingPolicy class

Defines the policy of the QueuedRequest.

Constructors

QueueingPolicy({String? validAfterDuration, String? validAfterTime, Interval? validInterval, String? validUntilDuration, String? validUntilTime})
QueueingPolicy.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validAfterDuration ↔ String?
A relative time after which resources may be created.
getter/setter pair
validAfterTime ↔ String?
An absolute time after which resources may be created.
getter/setter pair
validInterval ↔ Interval?
An absolute time interval within which resources may be created.
getter/setter pair
validUntilDuration ↔ String?
A relative time after which resources should not be created.
getter/setter pair
validUntilTime ↔ String?
An absolute time after which resources should not be created.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited