ClientConfig class

All xds configs for a particular client.

Constructors

ClientConfig({Node? node, List<PerXdsConfig>? xdsConfig})
ClientConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
node ↔ Node?
Node for a particular client.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xdsConfig ↔ List<PerXdsConfig>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited