ClientStatusRequest class

Request for client status of clients identified by a list of NodeMatchers.

Constructors

ClientStatusRequest({List<NodeMatcher>? nodeMatchers})
ClientStatusRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodeMatchers ↔ List<NodeMatcher>?
Management server can use these match criteria to identify clients.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited