DoubleMatcher class

Specifies the way to match a double value.

Constructors

DoubleMatcher({double? exact, DoubleRange? range})
DoubleMatcher.fromJson(Map json_)

Properties

exact ↔ double?
If specified, the input double value must be equal to the value specified here.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
range ↔ DoubleRange?
If specified, the input double value must be in the range specified here.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited