Extension class

Version and identification for an Envoy extension.

[#next-free-field: 6]

Constructors

Extension({String? category, bool? disabled, String? name, String? typeDescriptor, BuildVersion? version})
Extension.fromJson(Map json_)

Properties

category ↔ String?
Category of the extension.
getter/setter pair
disabled ↔ bool?
Indicates that the extension is present but was disabled via dynamic configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
This is the name of the Envoy filter as specified in the Envoy configuration, e.g. envoy.filters.http.router, com.acme.widget.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeDescriptor ↔ String?
[#not-implemented-hide:] Type descriptor of extension configuration proto.
getter/setter pair
version ↔ BuildVersion?
The version is a property of the extension and maintained independently of other extensions and the Envoy API.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited