NodeMatcher class

Specifies the way to match a Node.

The match follows AND semantics.

Constructors

NodeMatcher({StringMatcher? nodeId, List<StructMatcher>? nodeMetadatas})
NodeMatcher.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nodeId ↔ StringMatcher?
Specifies match criteria on the node id.
getter/setter pair
nodeMetadatas ↔ List<StructMatcher>?
Specifies match criteria on the node metadata.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited