RegexMatcher class

A regex matcher designed for safety when used with untrusted input.

Constructors

RegexMatcher({GoogleRE2? googleRe2, String? regex})
RegexMatcher.fromJson(Map json_)

Properties

googleRe2 ↔ GoogleRE2?
Google's RE2 regex engine.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
regex ↔ String?
The regex match string.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited