StringMatcher class

Specifies the way to match a string.

[#next-free-field: 7]

Constructors

StringMatcher({String? exact, bool? ignoreCase, String? prefix, String? regex, RegexMatcher? safeRegex, String? suffix})
StringMatcher.fromJson(Map json_)

Properties

exact ↔ String?
The input string must match exactly the string specified here.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ignoreCase ↔ bool?
If true, indicates the exact/prefix/suffix matching should be case insensitive.
getter/setter pair
prefix ↔ String?
The input string must have the prefix specified here.
getter/setter pair
regex ↔ String?
The input string must match the regular expression specified here.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeRegex ↔ RegexMatcher?
The input string must match the regular expression specified here.
getter/setter pair
suffix ↔ String?
The input string must have the suffix specified here.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited