ClientStatusRequest class

Request for client status of clients identified by a list of NodeMatchers.

Constructors

ClientStatusRequest({bool? excludeResourceContents, Node? node, List<NodeMatcher>? nodeMatchers})
ClientStatusRequest.fromJson(Map json_)

Properties

excludeResourceContents ↔ bool?
If true, the server will not include the resource contents in the response (i.e., the generic_xds_configs.xds_config field will not be populated).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
node ↔ Node?
The node making the csds request.
getter/setter pair
nodeMatchers ↔ List<NodeMatcher>?
Management server can use these match criteria to identify clients.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited