DynamicEndpointConfig class

[#next-free-field: 6]

Constructors

DynamicEndpointConfig({String? clientStatus, Map<String, Object?>? endpointConfig, UpdateFailureState? errorState, String? lastUpdated, String? versionInfo})
DynamicEndpointConfig.fromJson(Map json_)

Properties

clientStatus ↔ String?
The client status of this resource.
getter/setter pair
endpointConfig ↔ Map<String, Object?>?
The endpoint config.
getter/setter pair
errorState ↔ UpdateFailureState?
Set if the last update failed, cleared after the next successful update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdated ↔ String?
[#not-implemented-hide:] The timestamp when the Endpoint was last updated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionInfo ↔ String?
[#not-implemented-hide:] This is the per-resource version information.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited