GenericXdsConfig class

GenericXdsConfig is used to specify the config status and the dump of any xDS resource identified by their type URL.

It is the generalized version of the now deprecated ListenersConfigDump, ClustersConfigDump etc [#next-free-field: 10]

Constructors

GenericXdsConfig({String? clientStatus, String? configStatus, UpdateFailureState? errorState, bool? isStaticResource, String? lastUpdated, String? name, String? typeUrl, String? versionInfo, Map<String, Object?>? xdsConfig})
GenericXdsConfig.fromJson(Map json_)

Properties

clientStatus ↔ String?
Per xDS resource status from the view of a xDS client Possible string values are:
getter/setter pair
configStatus ↔ String?
Per xDS resource config status.
getter/setter pair
errorState ↔ UpdateFailureState?
Set if the last update failed, cleared after the next successful update.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isStaticResource ↔ bool?
Is static resource is true if it is specified in the config supplied through the file at the startup.
getter/setter pair
lastUpdated ↔ String?
Timestamp when the xDS resource was last updated
getter/setter pair
name ↔ String?
Name of the xDS resource
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeUrl ↔ String?
Type_url represents the fully qualified name of xDS resource type like envoy.v3.Cluster, envoy.v3.ClusterLoadAssignment etc.
getter/setter pair
versionInfo ↔ String?
This is the :ref:version_info in the last processed xDS discovery response.
getter/setter pair
xdsConfig ↔ Map<String, Object?>?
The xDS resource config.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited