ListMatcher class

Specifies the way to match a list value.

Constructors

ListMatcher({ValueMatcher? oneOf})
ListMatcher.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
oneOf ↔ ValueMatcher?
If specified, at least one of the values in the list must match the value specified.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited