Node class

Identifies a specific Envoy instance.

The node identifier is presented to the management server, which may use this identifier to distinguish per Envoy configuration for serving. [#next-free-field: 13]

Constructors

Node({List<String>? clientFeatures, String? cluster, Map<String, ContextParams>? dynamicParameters, List<Extension>? extensions, String? id, List<Address>? listeningAddresses, Locality? locality, Map<String, Object?>? metadata, BuildVersion? userAgentBuildVersion, String? userAgentName, String? userAgentVersion})
Node.fromJson(Map json_)

Properties

clientFeatures ↔ List<String>?
Client feature support list.
getter/setter pair
cluster ↔ String?
Defines the local service cluster name where Envoy is running.
getter/setter pair
dynamicParameters ↔ Map<String, ContextParams>?
Map from xDS resource type URL to dynamic context parameters.
getter/setter pair
extensions ↔ List<Extension>?
List of extensions and their versions supported by the node.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
An opaque node identifier for the Envoy node.
getter/setter pair
listeningAddresses ↔ List<Address>?
Known listening ports on the node as a generic hint to the management server for filtering :ref:listeners to be returned.
getter/setter pair
locality ↔ Locality?
Locality specifying where the Envoy instance is running.
getter/setter pair
metadata ↔ Map<String, Object?>?
Opaque metadata extending the node identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userAgentBuildVersion ↔ BuildVersion?
Structured version of the entity requesting config.
getter/setter pair
userAgentName ↔ String?
Free-form string that identifies the entity requesting config.
getter/setter pair
userAgentVersion ↔ String?
Free-form string that identifies the version of the entity requesting config.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited