Animation class

Animation types.

Constructors

Animation({AnimationEnd? animationEnd, AnimationFade? animationFade, AnimationStatic? animationStatic})
Animation.fromJson(Map json_)

Properties

animationEnd ↔ AnimationEnd?
End previous animation.
getter/setter pair
animationFade ↔ AnimationFade?
Display overlay object with fade animation.
getter/setter pair
animationStatic ↔ AnimationStatic?
Display static overlay object.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited