Audio class

Audio preprocessing configuration.

Constructors

Audio({bool? highBoost, bool? lowBoost, double? lufs})
Audio.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
highBoost ↔ bool?
Enable boosting high frequency components.
getter/setter pair
lowBoost ↔ bool?
Enable boosting low frequency components.
getter/setter pair
lufs ↔ double?
Specify audio loudness normalization in loudness units relative to full scale (LUFS).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited