AudioMapping class

The mapping for the JobConfig.edit_list atoms with audio EditAtom.inputs.

Constructors

AudioMapping({String? atomKey, double? gainDb, int? inputChannel, String? inputKey, int? inputTrack, int? outputChannel})
AudioMapping.fromJson(Map json_)

Properties

atomKey ↔ String?
The EditAtom.key that references the atom with audio inputs in the JobConfig.edit_list.
getter/setter pair
gainDb ↔ double?
Audio volume control in dB.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputChannel ↔ int?
The zero-based index of the channel in the input audio stream.
getter/setter pair
inputKey ↔ String?
The Input.key that identifies the input file.
getter/setter pair
inputTrack ↔ int?
The zero-based index of the track in the input file.
getter/setter pair
outputChannel ↔ int?
The zero-based index of the channel in the output audio stream.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited