Color class

Color preprocessing configuration.

Note: This configuration is not supported.

Constructors

Color({double? brightness, double? contrast, double? saturation})
Color.fromJson(Map json_)

Properties

brightness ↔ double?
Control brightness of the video.
getter/setter pair
contrast ↔ double?
Control black and white contrast of the video.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saturation ↔ double?
Control color saturation of the video.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited