DrmSystems class

Defines configuration for DRM systems in use.

Constructors

DrmSystems({Clearkey? clearkey, Fairplay? fairplay, Playready? playready, Widevine? widevine})
DrmSystems.fromJson(Map json_)

Properties

clearkey ↔ Clearkey?
Clearkey configuration.
getter/setter pair
fairplay ↔ Clearkey?
Fairplay configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
playready ↔ Clearkey?
Playready configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widevine ↔ Clearkey?
Widevine configuration.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited