Encryption class

Encryption settings.

Constructors

Encryption({Aes128Encryption? aes128, DrmSystems? drmSystems, String? id, MpegCommonEncryption? mpegCenc, SampleAesEncryption? sampleAes, SecretManagerSource? secretManagerKeySource})
Encryption.fromJson(Map json_)

Properties

aes128 ↔ Clearkey?
Configuration for AES-128 encryption.
getter/setter pair
drmSystems ↔ DrmSystems?
DRM system(s) to use; at least one must be specified.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
Identifier for this set of encryption options.
getter/setter pair
mpegCenc ↔ MpegCommonEncryption?
Configuration for MPEG Common Encryption (MPEG-CENC).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sampleAes ↔ Clearkey?
Configuration for SAMPLE-AES encryption.
getter/setter pair
secretManagerKeySource ↔ SecretManagerSource?
Keys are stored in Google Secret Manager.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited