JobConfig class

Job configuration

Constructors

JobConfig({List<AdBreak>? adBreaks, List<EditAtom>? editList, List<ElementaryStream>? elementaryStreams, List<Encryption>? encryptions, List<Input>? inputs, List<Manifest>? manifests, List<MuxStream>? muxStreams, Output? output, List<Overlay>? overlays, PubsubDestination? pubsubDestination, List<SpriteSheet>? spriteSheets})
JobConfig.fromJson(Map json_)

Properties

adBreaks ↔ List<AdBreak>?
List of ad breaks.
getter/setter pair
editList ↔ List<EditAtom>?
List of edit atoms.
getter/setter pair
elementaryStreams ↔ List<ElementaryStream>?
List of elementary streams.
getter/setter pair
encryptions ↔ List<Encryption>?
List of encryption configurations for the content.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputs ↔ List<Input>?
List of input assets stored in Cloud Storage.
getter/setter pair
manifests ↔ List<Manifest>?
List of output manifests.
getter/setter pair
muxStreams ↔ List<MuxStream>?
List of multiplexing settings for output streams.
getter/setter pair
output ↔ Output?
Output configuration.
getter/setter pair
overlays ↔ List<Overlay>?
List of overlays on the output video, in descending Z-order.
getter/setter pair
pubsubDestination ↔ PubsubDestination?
Destination on Pub/Sub.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spriteSheets ↔ List<SpriteSheet>?
List of output sprite sheets.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited