Manifest class

Manifest configuration.

Constructors

Manifest({DashConfig? dash, String? fileName, List<String>? muxStreams, String? type})
Manifest.fromJson(Map json_)

Properties

dash ↔ DashConfig?
DASH manifest configuration.
getter/setter pair
fileName ↔ String?
The name of the generated file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
muxStreams ↔ List<String>?
List of user supplied MuxStream.key values that should appear in this manifest.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of the manifest.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited