MuxStream class

Multiplexing settings for output stream.

Constructors

MuxStream({String? container, List<String>? elementaryStreams, String? encryptionId, String? fileName, Fmp4Config? fmp4, String? key, SegmentSettings? segmentSettings})
MuxStream.fromJson(Map json_)

Properties

container ↔ String?
The container format.
getter/setter pair
elementaryStreams ↔ List<String>?
List of ElementaryStream.key values multiplexed in this stream.
getter/setter pair
encryptionId ↔ String?
Identifier of the encryption configuration to use.
getter/setter pair
fileName ↔ String?
The name of the generated file.
getter/setter pair
fmp4 ↔ Fmp4Config?
fmp4 container configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
A unique key for this multiplexed stream.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
segmentSettings ↔ SegmentSettings?
Segment settings for ts, fmp4 and vtt.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited