PreprocessingConfig class

Preprocessing configurations.

Constructors

PreprocessingConfig({Audio? audio, Color? color, Crop? crop, Deblock? deblock, Deinterlace? deinterlace, Denoise? denoise, Pad? pad})
PreprocessingConfig.fromJson(Map json_)

Properties

audio ↔ Audio?
Audio preprocessing configuration.
getter/setter pair
color ↔ Color?
Color preprocessing configuration.
getter/setter pair
crop ↔ Crop?
Specify the video cropping configuration.
getter/setter pair
deblock ↔ Deblock?
Deblock preprocessing configuration.
getter/setter pair
deinterlace ↔ Deinterlace?
Specify the video deinterlace configuration.
getter/setter pair
denoise ↔ Denoise?
Denoise preprocessing configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pad ↔ Pad?
Specify the video pad filter configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited