VideoStream class

Video stream resource.

Properties

h264 ↔ H264CodecSettings?
H264 codec settings.
getter/setter pair
h265 ↔ H265CodecSettings?
H265 codec settings.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vp9 ↔ Vp9CodecSettings?
VP9 codec settings.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited