BatchTranslateDocumentRequest class

The BatchTranslateDocument request.

Constructors

BatchTranslateDocumentRequest({String? customizedAttribution, bool? enableRotationCorrection, bool? enableShadowRemovalNativePdf, Map<String, String>? formatConversions, Map<String, TranslateTextGlossaryConfig>? glossaries, List<BatchDocumentInputConfig>? inputConfigs, Map<String, String>? models, BatchDocumentOutputConfig? outputConfig, bool? pdfNativeOnly, String? sourceLanguageCode, List<String>? targetLanguageCodes})
BatchTranslateDocumentRequest.fromJson(Map json_)

Properties

customizedAttribution ↔ String?
This flag is to support user customized attribution.
getter/setter pair
enableRotationCorrection ↔ bool?
If true, enable auto rotation correction in DVS.
getter/setter pair
enableShadowRemovalNativePdf ↔ bool?
If true, use the text removal server to remove the shadow text on background image for native pdf translation.
getter/setter pair
formatConversions ↔ Map<String, String>?
The file format conversion map that is applied to all input files.
getter/setter pair
glossaries ↔ Map<String, TranslateTextGlossaryConfig>?
Glossaries to be applied.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputConfigs ↔ List<BatchDocumentInputConfig>?
Input configurations.
getter/setter pair
models ↔ Map<String, String>?
The models to use for translation.
getter/setter pair
outputConfig ↔ BatchDocumentOutputConfig?
Output configuration.
getter/setter pair
pdfNativeOnly ↔ bool?
If true, only native pdf pages will be translated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguageCode ↔ String?
The ISO-639 language code of the input document if known, for example, "en-US" or "sr-Latn".
getter/setter pair
targetLanguageCodes ↔ List<String>?
The ISO-639 language code to use for translation of the input document.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited