BatchTranslateTextRequest class

The batch translation request.

Constructors

BatchTranslateTextRequest({Map<String, TranslateTextGlossaryConfig>? glossaries, List<InputConfig>? inputConfigs, Map<String, String>? labels, Map<String, String>? models, OutputConfig? outputConfig, String? sourceLanguageCode, List<String>? targetLanguageCodes})
BatchTranslateTextRequest.fromJson(Map json_)

Properties

glossaries ↔ Map<String, TranslateTextGlossaryConfig>?
Glossaries to be applied for translation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputConfigs ↔ List<InputConfig>?
Input configurations.
getter/setter pair
labels ↔ Map<String, String>?
The labels with user-defined metadata for the request.
getter/setter pair
models ↔ Map<String, String>?
The models to use for translation.
getter/setter pair
outputConfig ↔ OutputConfig?
Output configuration.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguageCode ↔ String?
Source language code.
getter/setter pair
targetLanguageCodes ↔ List<String>?
Specify up to 10 language codes here.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited