DetectedLanguage class

The response message for language detection.

Constructors

DetectedLanguage({double? confidence, String? languageCode})
DetectedLanguage.fromJson(Map json_)

Properties

confidence ↔ double?
The confidence of the detection result for this language.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The ISO-639 language code of the source content in the request, detected automatically.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited