Example class

A sentence pair.

Constructors

Example({String? name, String? sourceText, String? targetText, String? usage})
Example.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the example, in form of projects/{project-number-or-id}/locations/{location_id}/datasets/{dataset_id}/examples/{example_id}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceText ↔ String?
Sentence in source language.
getter/setter pair
targetText ↔ String?
Sentence in target language.
getter/setter pair
usage ↔ String?
Usage of the sentence pair.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited