FileInputSource class

An inlined file.

Constructors

FileInputSource({String? content, String? displayName, String? mimeType})
FileInputSource.fromJson(Map json_)

Properties

content ↔ String?
The file's byte contents.
getter/setter pair
contentAsBytes ↔ List<int>
getter/setter pair
displayName ↔ String?
The file's display name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mimeType ↔ String?
The file's mime type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited