GcsDestination class

The Google Cloud Storage location for the output content.

Constructors

GcsDestination({String? outputUriPrefix})
GcsDestination.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
outputUriPrefix ↔ String?
The bucket used in 'output_uri_prefix' must exist and there must be no files under 'output_uri_prefix'.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited