LanguageCodePair class

Used with unidirectional glossaries.

Constructors

LanguageCodePair({String? sourceLanguageCode, String? targetLanguageCode})
LanguageCodePair.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguageCode ↔ String?
The ISO-639 language code of the input text, for example, "en-US".
getter/setter pair
targetLanguageCode ↔ String?
The ISO-639 language code for translation output, for example, "zh-CN".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited