ListAdaptiveMtFilesResponse class

The response for listing all AdaptiveMt files under a given dataset.

Constructors

ListAdaptiveMtFilesResponse({List<AdaptiveMtFile>? adaptiveMtFiles, String? nextPageToken})
ListAdaptiveMtFilesResponse.fromJson(Map json_)

Properties

adaptiveMtFiles ↔ List<AdaptiveMtFile>?
The Adaptive MT files.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to retrieve a page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited