Model class

A trained translation model.

Constructors

Model({String? createTime, String? dataset, String? displayName, String? name, String? sourceLanguageCode, String? targetLanguageCode, int? testExampleCount, int? trainExampleCount, String? updateTime, int? validateExampleCount})
Model.fromJson(Map json_)

Properties

createTime ↔ String?
Timestamp when the model resource was created, which is also when the training started.
getter/setter pair
dataset ↔ String?
The dataset from which the model is trained, in form of projects/{project-number-or-id}/locations/{location_id}/datasets/{dataset_id}
getter/setter pair
displayName ↔ String?
The name of the model to show in the interface.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the model, in form of projects/{project-number-or-id}/locations/{location_id}/models/{model_id}
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguageCode ↔ String?
The BCP-47 language code of the source language.
getter/setter pair
targetLanguageCode ↔ String?
The BCP-47 language code of the target language.
getter/setter pair
testExampleCount ↔ int?
Number of examples (sentence pairs) used to test the model.
getter/setter pair
trainExampleCount ↔ int?
Number of examples (sentence pairs) used to train the model.
getter/setter pair
updateTime ↔ String?
Timestamp when this model was last updated.
getter/setter pair
validateExampleCount ↔ int?
Number of examples (sentence pairs) used to validate the model.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited