ProjectsLocationsAdaptiveMtDatasetsAdaptiveMtFilesResource class

Properties

adaptiveMtSentences → ProjectsLocationsAdaptiveMtDatasetsAdaptiveMtFilesAdaptiveMtSentencesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String name, {String? $fields}) → Future<Empty>
Deletes an AdaptiveMtFile along with its sentences.
get(String name, {String? $fields}) → Future<AdaptiveMtFile>
Gets and AdaptiveMtFile
list(String parent, {int? pageSize, String? pageToken, String? $fields}) → Future<ListAdaptiveMtFilesResponse>
Lists all AdaptiveMtFiles associated to an AdaptiveMtDataset.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited