ProjectsLocationsDatasetsResource class

Constructors

ProjectsLocationsDatasetsResource(ApiRequester client)

Properties

examples → ProjectsLocationsDatasetsExamplesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(Dataset request, String parent, {String? $fields}) → Future<Operation>
Creates a Dataset.
delete(String name, {String? $fields}) → Future<Operation>
Deletes a dataset and all of its contents.
exportData(ExportDataRequest request, String dataset, {String? $fields}) → Future<Operation>
Exports dataset's data to the provided output location.
get(String name, {String? $fields}) → Future<Dataset>
Gets a Dataset.
importData(ImportDataRequest request, String dataset, {String? $fields}) → Future<Operation>
Import sentence pairs into translation Dataset.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) → Future<ListDatasetsResponse>
Lists datasets.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited