ProjectsLocationsResource class

Constructors

ProjectsLocationsResource(ApiRequester client)

Properties

adaptiveMtDatasets → ProjectsLocationsAdaptiveMtDatasetsResource
no setter
datasets → ProjectsLocationsDatasetsResource
no setter
glossaries → ProjectsLocationsGlossariesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
models → ProjectsLocationsModelsResource
no setter
operations → ProjectsLocationsOperationsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

adaptiveMtTranslate(AdaptiveMtTranslateRequest request, String parent, {String? $fields}) → Future<AdaptiveMtTranslateResponse>
Translate text using Adaptive MT.
batchTranslateDocument(BatchTranslateDocumentRequest request, String parent, {String? $fields}) → Future<Operation>
Translates a large volume of document in asynchronous batch mode.
batchTranslateText(BatchTranslateTextRequest request, String parent, {String? $fields}) → Future<Operation>
Translates a large volume of text in asynchronous batch mode.
detectLanguage(DetectLanguageRequest request, String parent, {String? $fields}) → Future<DetectLanguageResponse>
Detects the language of text within a request.
get(String name, {String? $fields}) → Future<Location>
Gets information about a location.
getSupportedLanguages(String parent, {String? displayLanguageCode, String? model, String? $fields}) → Future<SupportedLanguages>
Returns a list of supported languages for translation.
list(String name, {List<String>? extraLocationTypes, String? filter, int? pageSize, String? pageToken, String? $fields}) → Future<ListLocationsResponse>
Lists information about the supported locations for this service.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refineText(RefineTextRequest request, String parent, {String? $fields}) → Future<RefineTextResponse>
Refines the input translated text to improve the quality.
romanizeText(RomanizeTextRequest request, String parent, {String? $fields}) → Future<RomanizeTextResponse>
Romanize input text written in non-Latin scripts to Latin text.
toString() → String
A string representation of this object.
inherited
translateDocument(TranslateDocumentRequest request, String parent, {String? $fields}) → Future<TranslateDocumentResponse>
Translates documents in synchronous mode.
translateText(TranslateTextRequest request, String parent, {String? $fields}) → Future<TranslateTextResponse>
Translates input text and returns translated text.

Operators

operator ==(Object other) → bool
The equality operator.
inherited