RefineTextRequest class

Request message for RefineText.

Constructors

RefineTextRequest({List<RefinementEntry>? refinementEntries, String? sourceLanguageCode, String? targetLanguageCode})
RefineTextRequest.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
refinementEntries ↔ List<RefinementEntry>?
The source texts and original translations in the source and target languages.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguageCode ↔ String?
The BCP-47 language code of the source text in the request, for example, "en-US".
getter/setter pair
targetLanguageCode ↔ String?
The BCP-47 language code for translation output, for example, "zh-CN".
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited