Romanization class

A single romanization response.

Constructors

Romanization({String? detectedLanguageCode, String? romanizedText})
Romanization.fromJson(Map json_)

Properties

detectedLanguageCode ↔ String?
The ISO-639 language code of source text in the initial request, detected automatically, if no source language was passed within the initial request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
romanizedText ↔ String?
Romanized text.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited