TranslateDocumentRequest class

A document translation request.

Constructors

TranslateDocumentRequest({String? customizedAttribution, DocumentInputConfig? documentInputConfig, DocumentOutputConfig? documentOutputConfig, bool? enableRotationCorrection, bool? enableShadowRemovalNativePdf, TranslateTextGlossaryConfig? glossaryConfig, bool? isTranslateNativePdfOnly, Map<String, String>? labels, String? model, String? sourceLanguageCode, String? targetLanguageCode})
TranslateDocumentRequest.fromJson(Map json_)

Properties

customizedAttribution ↔ String?
This flag is to support user customized attribution.
getter/setter pair
documentInputConfig ↔ DocumentInputConfig?
Input configurations.
getter/setter pair
documentOutputConfig ↔ DocumentOutputConfig?
Output configurations.
getter/setter pair
enableRotationCorrection ↔ bool?
If true, enable auto rotation correction in DVS.
getter/setter pair
enableShadowRemovalNativePdf ↔ bool?
If true, use the text removal server to remove the shadow text on background image for native pdf translation.
getter/setter pair
glossaryConfig ↔ GlossaryConfig?
Glossary to be applied.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isTranslateNativePdfOnly ↔ bool?
is_translate_native_pdf_only field for external customers.
getter/setter pair
labels ↔ Map<String, String>?
The labels with user-defined metadata for the request.
getter/setter pair
model ↔ String?
The model type requested for this translation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguageCode ↔ String?
The ISO-639 language code of the input document if known, for example, "en-US" or "sr-Latn".
getter/setter pair
targetLanguageCode ↔ String?
The ISO-639 language code to use for translation of the input document, set to one of the language codes listed in Language Support.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited