TranslateTextRequest class

The request message for synchronous translation.

Constructors

TranslateTextRequest({List<String>? contents, TranslateTextGlossaryConfig? glossaryConfig, Map<String, String>? labels, String? mimeType, String? model, String? sourceLanguageCode, String? targetLanguageCode, TransliterationConfig? transliterationConfig})
TranslateTextRequest.fromJson(Map json_)

Properties

contents ↔ List<String>?
The content of the input in string format.
getter/setter pair
glossaryConfig ↔ GlossaryConfig?
Glossary to be applied.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels with user-defined metadata for the request.
getter/setter pair
mimeType ↔ String?
The format of the source text, for example, "text/html", "text/plain".
getter/setter pair
model ↔ String?
The model type requested for this translation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceLanguageCode ↔ String?
The ISO-639 language code of the input text if known, for example, "en-US" or "sr-Latn".
getter/setter pair
targetLanguageCode ↔ String?
The ISO-639 language code to use for translation of the input text, set to one of the language codes listed in Language Support.
getter/setter pair
transliterationConfig ↔ TransliterationConfig?
Transliteration to be applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited