TranslateTextResponse class

Constructors

TranslateTextResponse({List<Translation>? glossaryTranslations, List<Translation>? translations})
TranslateTextResponse.fromJson(Map json_)

Properties

glossaryTranslations ↔ List<Translation>?
Text translation responses if a glossary is provided in the request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translations ↔ List<Translation>?
Text translation responses with no glossary applied.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited