Translation class

A single translation response.

Constructors

Translation({String? detectedLanguageCode, TranslateTextGlossaryConfig? glossaryConfig, String? model, String? translatedText})
Translation.fromJson(Map json_)

Properties

detectedLanguageCode ↔ String?
The ISO-639 language code of source text in the initial request, detected automatically, if no source language was passed within the initial request.
getter/setter pair
glossaryConfig ↔ GlossaryConfig?
The glossary_config used for this translation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
model ↔ String?
Only present when model is present in the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
translatedText ↔ String?
Text translated into the target language.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited