travelimpactmodel/v1 library

Travel Impact Model API - v1

Travel Impact Model API lets you query travel carbon emission estimates.

For more information, see developers.google.com/travel/impact-model

Create an instance of TravelImpactModelApi to access these resources:

Classes

ComputeDetailedFlightEmissionsRequest
Input definition for the ComputeDetailedFlightEmissions request.
ComputeDetailedFlightEmissionsResponse
Output definition for the ComputeDetailedFlightEmissions response.
ComputeFlightEmissionsRequest
Input definition for the ComputeFlightEmissions request.
ComputeFlightEmissionsResponse
Output definition for the ComputeFlightEmissions response.
ComputeScope3FlightEmissionsRequest
A list of flight segments to request the Scope 3 emissions for.
ComputeScope3FlightEmissionsResponse
A list of flights with Scope 3 emission estimates.
ComputeTypicalFlightEmissionsRequest
A list of pair of airports (markets) to request the typical emissions for.
ComputeTypicalFlightEmissionsResponse
The response includes the emissions but also the model version.
EasaLabelMetadata
Metadata about the EASA Flight Emissions Label.
EmissionsBreakdown
Details about the various emissions portions of the total emissions_grams_per_pax value.
EmissionsGramsPerPax
Grouped emissions per seating class results.
EmissionsMetadata
All additional metadata.
EmissionsProvenance
Information about the provenance of the data used to calculate emissions estimates, including contributing factors and their data sources.
EmissionsProvenanceEntry
Details about a single contributing factor in emissions calculations.
Flight
All details related to a single request item for a direct flight emission estimates.
FlightEmissionsDetails
Details about the specific flight's emissions.
FlightsResource
FlightWithDetailedEmissions
Direct flight with emission estimates details.
FlightWithEmissions
Direct flight with emission estimates.
Market
A pair of airports.
ModelVersion
Travel Impact Model version.
Scope3FlightEmissions
Scope 3 flight with emission estimates.
Scope3FlightSegment
Flight parameters with which the Scope 3 emissions are fetched.
TravelImpactModelApi
Travel Impact Model API lets you query travel carbon emission estimates.
TypicalFlightEmissions
Typical flight emission estimates for a certain market

Typedefs

Date = $Date
Represents a whole or partial calendar date, such as a birthday.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.