AddHeldAccountsRequest class

Add a list of accounts to a hold.

Constructors

AddHeldAccountsRequest({List<String>? accountIds, List<String>? emails})
AddHeldAccountsRequest.fromJson(Map json_)

Properties

accountIds ↔ List<String>?
A comma-separated list of the account IDs of the accounts to add to the hold.
getter/setter pair
emails ↔ List<String>?
A comma-separated list of the emails of the accounts to add to the hold.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited