CalendarOptions class

Additional options for Calendar search

Constructors

CalendarOptions({List<String>? locationQuery, List<String>? minusWords, List<String>? peopleQuery, List<String>? responseStatuses, String? versionDate})
CalendarOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
locationQuery ↔ List<String>?
Matches only those events whose location contains all of the words in the given set.
getter/setter pair
minusWords ↔ List<String>?
Matches only those events that do not contain any of the words in the given set in title, description, location, or attendees.
getter/setter pair
peopleQuery ↔ List<String>?
Matches only those events whose attendees contain all of the words in the given set.
getter/setter pair
responseStatuses ↔ List<String>?
Matches only events for which the custodian gave one of these responses.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
versionDate ↔ String?
Search the current version of the Calendar event, but export the contents of the last version saved before 12:00 AM UTC on the specified date.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited