CorpusQuery class

Service-specific options for holds.

Constructors

CorpusQuery({HeldCalendarQuery? calendarQuery, HeldDriveQuery? driveQuery, HeldGroupsQuery? groupsQuery, HeldHangoutsChatQuery? hangoutsChatQuery, HeldMailQuery? mailQuery, HeldVoiceQuery? voiceQuery})
CorpusQuery.fromJson(Map json_)

Properties

calendarQuery ↔ HeldCalendarQuery?
Service-specific options for Calendar holds.
getter/setter pair
driveQuery ↔ HeldDriveQuery?
Service-specific options for Drive holds.
getter/setter pair
groupsQuery ↔ HeldGroupsQuery?
Service-specific options for Groups holds.
getter/setter pair
hangoutsChatQuery ↔ HeldHangoutsChatQuery?
Service-specific options for Chat holds.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mailQuery ↔ HeldGroupsQuery?
Service-specific options for Gmail holds.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
voiceQuery ↔ HeldVoiceQuery?
Service-specific options for Voice holds.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited