DriveExportOptions class

Options for Drive exports.

Constructors

DriveExportOptions({bool? includeAccessInfo})
DriveExportOptions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeAccessInfo ↔ bool?
To include access level information for users with indirect access to files, set to true.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited