DriveOptions class

Additional options for Drive search.

Constructors

DriveOptions({String? clientSideEncryptedOption, bool? includeSharedDrives, bool? includeTeamDrives, String? sharedDrivesOption, String? versionDate})
DriveOptions.fromJson(Map json_)

Properties

clientSideEncryptedOption ↔ String?
Set whether the results include only content encrypted with [Google Workspace Client-side encryption](https://support.google.com/a?p=cse_ov) content, only unencrypted content, or both.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeSharedDrives ↔ bool?
Set to true to include shared drives.
getter/setter pair
includeTeamDrives ↔ bool?
Set to true to include Team Drive.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedDrivesOption ↔ String?
Options to include or exclude documents in shared drives.
getter/setter pair
versionDate ↔ String?
Search the current version of the Drive file, but export the contents of the last version saved before 12:00 AM UTC on the specified date.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited