Export class

An export.

To work with Vault resources, the account must have the required Vault privileges and access to the matter. To access a matter, the account must have created the matter, have the matter shared with them, or have the View All Matters privilege.

Constructors

Export({CloudStorageSink? cloudStorageSink, String? createTime, ExportOptions? exportOptions, String? id, String? matterId, String? name, String? parentExportId, Query? query, UserInfo? requester, ExportStats? stats, String? status})
Export.fromJson(Map json_)

Properties

cloudStorageSink ↔ CloudStorageSink?
The sink for export files in Cloud Storage.
getter/setter pair
createTime ↔ String?
The time when the export was created.
getter/setter pair
exportOptions ↔ ExportOptions?
Additional export options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The generated export ID.
getter/setter pair
matterId ↔ String?
The matter ID.
getter/setter pair
name ↔ String?
The export name.
getter/setter pair
parentExportId ↔ String?
Identifies the parent export that spawned this child export.
getter/setter pair
query ↔ Query?
The query parameters used to create the export.
getter/setter pair
requester ↔ UserInfo?
The requester of the export.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stats ↔ ExportStats?
Details about the export progress and size.
getter/setter pair
status ↔ String?
The status of the export.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited