HeldDriveQuery class

Options for Drive holds.

Constructors

HeldDriveQuery({bool? includeSharedDriveFiles, bool? includeTeamDriveFiles})
HeldDriveQuery.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
includeSharedDriveFiles ↔ bool?
To include files in shared drives in the hold, set to true.
getter/setter pair
includeTeamDriveFiles ↔ bool?
To include files in Team Drives in the hold, set to true.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited