HeldOrgUnit class

The organizational unit covered by a hold.

This structure is immutable.

Constructors

HeldOrgUnit({String? holdTime, String? orgUnitId})
HeldOrgUnit.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
holdTime ↔ String?
When the organizational unit was put on hold.
getter/setter pair
orgUnitId ↔ String?
The organizational unit's immutable ID as provided by the Admin SDK.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited