MailExportOptions class

Options for Gmail exports.

Constructors

MailExportOptions({String? exportFormat, bool? exportLinkedDriveFiles, bool? showConfidentialModeContent, bool? useNewExport})
MailExportOptions.fromJson(Map json_)

Properties

exportFormat ↔ String?
The file format for exported messages. Possible string values are:
getter/setter pair
exportLinkedDriveFiles ↔ bool?
To enable exporting linked Drive files, set to true.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showConfidentialModeContent ↔ bool?
To export confidential mode content, set to true.
getter/setter pair
useNewExport ↔ bool?
To use the new export system, set to true.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited