Query class

The query definition used for search and export.

Constructors

Query({AccountInfo? accountInfo, CalendarOptions? calendarOptions, String? corpus, String? dataScope, DriveDocumentInfo? driveDocumentInfo, DriveOptions? driveOptions, String? endTime, GeminiOptions? geminiOptions, HangoutsChatInfo? hangoutsChatInfo, HangoutsChatOptions? hangoutsChatOptions, MailOptions? mailOptions, String? method, OrgUnitInfo? orgUnitInfo, String? searchMethod, SharedDriveInfo? sharedDriveInfo, SitesUrlInfo? sitesUrlInfo, String? startTime, TeamDriveInfo? teamDriveInfo, String? terms, String? timeZone, VoiceOptions? voiceOptions})
Query.fromJson(Map json_)

Properties

accountInfo ↔ AccountInfo?
Required when SearchMethod is ACCOUNT.
getter/setter pair
calendarOptions ↔ CalendarOptions?
Set Calendar search-specific options.
getter/setter pair
corpus ↔ String?
The Google Workspace service to search. Possible string values are:
getter/setter pair
dataScope ↔ String?
The data source to search. Possible string values are:
getter/setter pair
driveDocumentInfo ↔ DriveDocumentInfo?
Required when SearchMethod is DRIVE_DOCUMENT.
getter/setter pair
driveOptions ↔ DriveOptions?
Set Drive search-specific options.
getter/setter pair
endTime ↔ String?
The end time for the search query.
getter/setter pair
geminiOptions ↔ HeldCalendarQuery?
Set Gemini search-specific options.
getter/setter pair
hangoutsChatInfo ↔ HangoutsChatInfo?
Required when SearchMethod is ROOM.
getter/setter pair
hangoutsChatOptions ↔ HangoutsChatOptions?
Set Chat search-specific options.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mailOptions ↔ MailOptions?
Set Gmail search-specific options.
getter/setter pair
method ↔ String?
The entity to search.
getter/setter pair
orgUnitInfo ↔ OrgUnitInfo?
Required when SearchMethod is ORG_UNIT.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchMethod ↔ String?
The search method to use. Possible string values are:
getter/setter pair
sharedDriveInfo ↔ SharedDriveInfo?
Required when SearchMethod is SHARED_DRIVE.
getter/setter pair
sitesUrlInfo ↔ SitesUrlInfo?
Required when SearchMethod is SITES_URL.
getter/setter pair
startTime ↔ String?
The start time for the search query.
getter/setter pair
teamDriveInfo ↔ TeamDriveInfo?
Required when SearchMethod is TEAM_DRIVE.
getter/setter pair
terms ↔ String?
Service-specific search operators to filter search results.
getter/setter pair
timeZone ↔ String?
The time zone name.
getter/setter pair
voiceOptions ↔ VoiceOptions?
Set Voice search-specific options.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited