SharedDriveInfo class

The shared drives to search

Constructors

SharedDriveInfo({List<String>? sharedDriveIds})
SharedDriveInfo.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sharedDriveIds ↔ List<String>?
A list of shared drive IDs, as provided by the Drive API.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited