Challenge class

Result message for VerifiedAccess.CreateChallenge.

Constructors

Challenge({SignedData? alternativeChallenge, SignedData? challenge})
Challenge.fromJson(Map json_)

Properties

alternativeChallenge ↔ SignedData?
Challenge generated with the old signing key (this will only be present during key rotation)
getter/setter pair
challenge ↔ SignedData?
Generated challenge
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited