SignedData class

The wrapper message of any data and its signature.

Constructors

SignedData({String? data, String? signature})
SignedData.fromJson(Map json_)

Properties

data ↔ String?
The data to be signed.
getter/setter pair
dataAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signature ↔ String?
The signature of the data field.
getter/setter pair
signatureAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited