CrowdStrikeAgent class

Properties of the CrowdStrike agent installed on a device.

Constructors

CrowdStrikeAgent({String? agentId, String? customerId})
CrowdStrikeAgent.fromJson(Map json_)

Properties

agentId ↔ String?
The Agent ID of the Crowdstrike agent.
getter/setter pair
customerId ↔ String?
The Customer ID to which the agent belongs to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited