DeviceSignals class

The device signals as reported by Chrome.

Unless otherwise specified, signals are available on all platforms.

Constructors

DeviceSignals({bool? allowScreenLock, Antivirus? antivirus, String? browserVersion, bool? builtInDnsClientEnabled, bool? chromeRemoteDesktopAppBlocked, CrowdStrikeAgent? crowdStrikeAgent, List<String>? deviceAffiliationIds, String? deviceEnrollmentDomain, String? deviceManufacturer, String? deviceModel, String? diskEncryption, String? displayName, String? hostname, List<String>? imei, List<String>? macAddresses, List<String>? meid, String? operatingSystem, String? osFirewall, String? osVersion, String? passwordProtectionWarningTrigger, List<String>? profileAffiliationIds, String? profileEnrollmentDomain, String? realtimeUrlCheckMode, String? safeBrowsingProtectionLevel, String? screenLockSecured, String? secureBootMode, String? serialNumber, bool? siteIsolationEnabled, List<String>? systemDnsServers, bool? thirdPartyBlockingEnabled, String? trigger, String? windowsMachineDomain, String? windowsUserDomain})
DeviceSignals.fromJson(Map json_)

Properties

allowScreenLock ↔ bool?
Value of the AllowScreenLock policy on the device.
getter/setter pair
antivirus ↔ Antivirus?
Information about Antivirus software on the device.
getter/setter pair
browserVersion ↔ String?
Current version of the Chrome browser which generated this set of signals.
getter/setter pair
builtInDnsClientEnabled ↔ bool?
Whether Chrome's built-in DNS client is used.
getter/setter pair
chromeRemoteDesktopAppBlocked ↔ bool?
Whether access to the Chrome Remote Desktop application is blocked via a policy.
getter/setter pair
crowdStrikeAgent ↔ CrowdStrikeAgent?
Crowdstrike agent properties installed on the device, if any.
getter/setter pair
deviceAffiliationIds ↔ List<String>?
Affiliation IDs of the organizations that are affiliated with the organization that is currently managing the device.
getter/setter pair
deviceEnrollmentDomain ↔ String?
Enrollment domain of the customer which is currently managing the device.
getter/setter pair
deviceManufacturer ↔ String?
The name of the device's manufacturer.
getter/setter pair
deviceModel ↔ String?
The name of the device's model.
getter/setter pair
diskEncryption ↔ String?
The encryption state of the disk.
getter/setter pair
displayName ↔ String?
The display name of the device, as defined by the user.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
Hostname of the device.
getter/setter pair
imei ↔ List<String>?
International Mobile Equipment Identity (IMEI) of the device.
getter/setter pair
macAddresses ↔ List<String>?
MAC addresses of the device.
getter/setter pair
meid ↔ List<String>?
Mobile Equipment Identifier (MEID) of the device.
getter/setter pair
operatingSystem ↔ String?
The type of the Operating System currently running on the device.
getter/setter pair
osFirewall ↔ String?
The state of the OS level firewall.
getter/setter pair
osVersion ↔ String?
The current version of the Operating System.
getter/setter pair
passwordProtectionWarningTrigger ↔ String?
Whether the Password Protection Warning feature is enabled or not.
getter/setter pair
profileAffiliationIds ↔ List<String>?
Affiliation IDs of the organizations that are affiliated with the organization that is currently managing the Chrome Profile’s user or ChromeOS user.
getter/setter pair
profileEnrollmentDomain ↔ String?
Enrollment domain of the customer which is currently managing the profile.
getter/setter pair
realtimeUrlCheckMode ↔ String?
Whether Enterprise-grade (i.e. custom) unsafe URL scanning is enabled or not.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeBrowsingProtectionLevel ↔ String?
Safe Browsing Protection Level.
getter/setter pair
screenLockSecured ↔ String?
The state of the Screen Lock password protection.
getter/setter pair
secureBootMode ↔ String?
Whether the device's startup software has its Secure Boot feature enabled.
getter/setter pair
serialNumber ↔ String?
The serial number of the device.
getter/setter pair
siteIsolationEnabled ↔ bool?
Whether the Site Isolation (a.k.a Site Per Process) setting is enabled.
getter/setter pair
systemDnsServers ↔ List<String>?
List of the addesses of all OS level DNS servers configured in the device's network settings.
getter/setter pair
thirdPartyBlockingEnabled ↔ bool?
The corresponding policy is now deprecated.
getter/setter pair
trigger ↔ String?
The trigger which generated this set of signals.
getter/setter pair
windowsMachineDomain ↔ String?
Windows domain that the current machine has joined.
getter/setter pair
windowsUserDomain ↔ String?
Windows domain for the current OS user.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited