VerifyChallengeResponseRequest class

Signed ChallengeResponse.

Constructors

VerifyChallengeResponseRequest({String? challengeResponse, String? expectedIdentity})
VerifyChallengeResponseRequest.fromJson(Map json_)

Properties

challengeResponse ↔ String?
The generated response to the challenge, the bytes representation of SignedData.
getter/setter pair
challengeResponseAsBytes ↔ List<int>
getter/setter pair
expectedIdentity ↔ String?
Service can optionally provide identity information about the device or user associated with the key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited