VerifyChallengeResponseResult class

Result message for VerifiedAccess.VerifyChallengeResponse.

The response returned when successful for Managed profiles on Unmanaged browsers will NOT have devicePermanentId, keyTrustLevel, virtualDeviceId and customerId fields. Managed profiles will INSTEAD have the profileCustomerId, virtualProfileId, profilePermanentId and profileKeyTrustLevel fields.

Constructors

VerifyChallengeResponseResult({String? attestedDeviceId, String? customerId, String? deviceEnrollmentId, String? devicePermanentId, String? deviceSignal, DeviceSignals? deviceSignals, String? keyTrustLevel, String? profileCustomerId, String? profileKeyTrustLevel, String? profilePermanentId, String? signedPublicKeyAndChallenge, String? virtualDeviceId, String? virtualProfileId})
VerifyChallengeResponseResult.fromJson(Map json_)

Properties

attestedDeviceId ↔ String?
Attested device ID (ADID).
getter/setter pair
customerId ↔ String?
Unique customer id that this device belongs to, as defined by the Google Admin SDK at https://developers.google.com/admin-sdk/directory/v1/guides/manage-customers
getter/setter pair
deviceEnrollmentId ↔ String?
Device enrollment id for ChromeOS devices.
getter/setter pair
devicePermanentId ↔ String?
Device permanent id is returned in this field (for the machine response only).
getter/setter pair
deviceSignal ↔ String?
Device signal in json string representation.
getter/setter pair
deviceSignals ↔ DeviceSignals?
Device signals.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
keyTrustLevel ↔ String?
Device attested key trust level.
getter/setter pair
profileCustomerId ↔ String?
Unique customer id that this profile belongs to, as defined by the Google Admin SDK at https://developers.google.com/admin-sdk/directory/v1/guides/manage-customers
getter/setter pair
profileKeyTrustLevel ↔ String?
Profile attested key trust level.
getter/setter pair
profilePermanentId ↔ String?
The unique server-side ID of a profile on the device.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signedPublicKeyAndChallenge ↔ String?
Certificate Signing Request (in the SPKAC format, base64 encoded) is returned in this field.
getter/setter pair
virtualDeviceId ↔ String?
Virtual device id of the device.
getter/setter pair
virtualProfileId ↔ String?
The client-provided ID of a profile on the device.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited