AnnotateFileResponse class

Response to a single file annotation request.

A file may contain one or more images, which individually have their own responses.

Constructors

AnnotateFileResponse({Status? error, InputConfig? inputConfig, List<AnnotateImageResponse>? responses, int? totalPages})
AnnotateFileResponse.fromJson(Map json_)

Properties

error ↔ Status?
If set, represents the error message for the failed request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inputConfig ↔ InputConfig?
Information about the file for which this response is generated.
getter/setter pair
responses ↔ List<AnnotateImageResponse>?
Individual responses to images found within the file.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalPages ↔ int?
This field gives the total number of pages in the file.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited