AnnotateImageResponse class

Response to an image annotation request.

Constructors

AnnotateImageResponse({ImageAnnotationContext? context, CropHintsAnnotation? cropHintsAnnotation, Status? error, List<FaceAnnotation>? faceAnnotations, TextAnnotation? fullTextAnnotation, ImageProperties? imagePropertiesAnnotation, List<EntityAnnotation>? labelAnnotations, List<EntityAnnotation>? landmarkAnnotations, List<LocalizedObjectAnnotation>? localizedObjectAnnotations, List<EntityAnnotation>? logoAnnotations, ProductSearchResults? productSearchResults, SafeSearchAnnotation? safeSearchAnnotation, List<EntityAnnotation>? textAnnotations, WebDetection? webDetection})
AnnotateImageResponse.fromJson(Map json_)

Properties

context ↔ ImageAnnotationContext?
If present, contextual information is needed to understand where this image comes from.
getter/setter pair
cropHintsAnnotation ↔ CropHintsAnnotation?
If present, crop hints have completed successfully.
getter/setter pair
error ↔ Status?
If set, represents the error message for the operation.
getter/setter pair
faceAnnotations ↔ List<FaceAnnotation>?
If present, face detection has completed successfully.
getter/setter pair
fullTextAnnotation ↔ TextAnnotation?
If present, text (OCR) detection or document (OCR) text detection has completed successfully.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imagePropertiesAnnotation ↔ ImageProperties?
If present, image properties were extracted successfully.
getter/setter pair
labelAnnotations ↔ List<EntityAnnotation>?
If present, label detection has completed successfully.
getter/setter pair
landmarkAnnotations ↔ List<EntityAnnotation>?
If present, landmark detection has completed successfully.
getter/setter pair
localizedObjectAnnotations ↔ List<LocalizedObjectAnnotation>?
If present, localized object detection has completed successfully.
getter/setter pair
logoAnnotations ↔ List<EntityAnnotation>?
If present, logo detection has completed successfully.
getter/setter pair
productSearchResults ↔ ProductSearchResults?
If present, product search has completed successfully.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
safeSearchAnnotation ↔ SafeSearchAnnotation?
If present, safe-search annotation has completed successfully.
getter/setter pair
textAnnotations ↔ List<EntityAnnotation>?
If present, text (OCR) detection has completed successfully.
getter/setter pair
webDetection ↔ WebDetection?
If present, web detection has completed successfully.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited