AsyncAnnotateFileRequest class

An offline file annotation request.

Constructors

AsyncAnnotateFileRequest({List<Feature>? features, ImageContext? imageContext, InputConfig? inputConfig, OutputConfig? outputConfig})
AsyncAnnotateFileRequest.fromJson(Map json_)

Properties

features ↔ List<Feature>?
Requested features.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
imageContext ↔ ImageContext?
Additional context that may accompany the image(s) in the file.
getter/setter pair
inputConfig ↔ InputConfig?
Information about the input file.
getter/setter pair
outputConfig ↔ OutputConfig?
The desired output location and metadata (e.g. format).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited