Block class

Logical element on the page.

Constructors

Block({String? blockType, BoundingPoly? boundingBox, double? confidence, List<Paragraph>? paragraphs, TextProperty? property})
Block.fromJson(Map json_)

Properties

blockType ↔ String?
Detected block type (text, image etc) for this block. Possible string values are:
getter/setter pair
boundingBox ↔ BoundingPoly?
The bounding box for the block.
getter/setter pair
confidence ↔ double?
Confidence of the OCR results on the block.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
paragraphs ↔ List<Paragraph>?
List of paragraphs in this block (if this blocks is of type text).
getter/setter pair
property ↔ TextProperty?
Additional information detected for the block.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited