BoundingPoly class

A bounding polygon for the detected image annotation.

Constructors

BoundingPoly({List<NormalizedVertex>? normalizedVertices, List<Vertex>? vertices})
BoundingPoly.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
normalizedVertices ↔ List<NormalizedVertex>?
The bounding polygon normalized vertices.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vertices ↔ List<Vertex>?
The bounding polygon vertices.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited