ColorInfo class

Color information consists of RGB channels, score, and the fraction of the image that the color occupies in the image.

Constructors

ColorInfo({Color? color, double? pixelFraction, double? score})
ColorInfo.fromJson(Map json_)

Properties

color ↔ Color?
RGB components of the color.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pixelFraction ↔ double?
The fraction of pixels the color occupies in the image.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double?
Image-specific score for this color.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited