CropHint class

Single crop hint that is used to generate a new crop when serving an image.

Constructors

CropHint({BoundingPoly? boundingPoly, double? confidence, double? importanceFraction})
CropHint.fromJson(Map json_)

Properties

boundingPoly ↔ BoundingPoly?
The bounding polygon for the crop region.
getter/setter pair
confidence ↔ double?
Confidence of this being a salient region.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
importanceFraction ↔ double?
Fraction of importance of this salient region with respect to the original image.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited