DetectedBreak class

Detected start or end of a structural component.

Constructors

DetectedBreak({bool? isPrefix, String? type})
DetectedBreak.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isPrefix ↔ bool?
True if break prepends the element.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Detected break type. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited