EntityAnnotation class

Set of detected entity features.

Constructors

EntityAnnotation({BoundingPoly? boundingPoly, double? confidence, String? description, String? locale, List<LocationInfo>? locations, String? mid, List<Property>? properties, double? score, double? topicality})
EntityAnnotation.fromJson(Map json_)

Properties

boundingPoly ↔ BoundingPoly?
Image region to which this entity belongs.
getter/setter pair
confidence ↔ double?
**Deprecated.
getter/setter pair
description ↔ String?
Entity textual description, expressed in its locale language.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locale ↔ String?
The language code for the locale in which the entity textual description is expressed.
getter/setter pair
locations ↔ List<LocationInfo>?
The location information for the detected entity.
getter/setter pair
mid ↔ String?
Opaque entity ID.
getter/setter pair
properties ↔ List<Property>?
Some entities may have optional user-supplied Property (name/value) fields, such a score or string that qualifies the entity.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double?
Overall score of the result.
getter/setter pair
topicality ↔ double?
The relevancy of the ICA (Image Content Annotation) label to the image.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited