FaceAnnotation class

A face annotation object contains the results of face detection.

Constructors

FaceAnnotation({String? angerLikelihood, String? blurredLikelihood, BoundingPoly? boundingPoly, double? detectionConfidence, BoundingPoly? fdBoundingPoly, String? headwearLikelihood, String? joyLikelihood, double? landmarkingConfidence, List<Landmark>? landmarks, double? panAngle, double? rollAngle, String? sorrowLikelihood, String? surpriseLikelihood, double? tiltAngle, String? underExposedLikelihood})
FaceAnnotation.fromJson(Map json_)

Properties

angerLikelihood ↔ String?
Anger likelihood. Possible string values are:
getter/setter pair
blurredLikelihood ↔ String?
Blurred likelihood. Possible string values are:
getter/setter pair
boundingPoly ↔ BoundingPoly?
The bounding polygon around the face.
getter/setter pair
detectionConfidence ↔ double?
Detection confidence.
getter/setter pair
fdBoundingPoly ↔ BoundingPoly?
The fd_bounding_poly bounding polygon is tighter than the boundingPoly, and encloses only the skin part of the face.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
headwearLikelihood ↔ String?
Headwear likelihood. Possible string values are:
getter/setter pair
joyLikelihood ↔ String?
Joy likelihood. Possible string values are:
getter/setter pair
landmarkingConfidence ↔ double?
Face landmarking confidence.
getter/setter pair
landmarks ↔ List<Landmark>?
Detected face landmarks.
getter/setter pair
panAngle ↔ double?
Yaw angle, which indicates the leftward/rightward angle that the face is pointing relative to the vertical plane perpendicular to the image.
getter/setter pair
rollAngle ↔ double?
Roll angle, which indicates the amount of clockwise/anti-clockwise rotation of the face relative to the image vertical about the axis perpendicular to the face.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sorrowLikelihood ↔ String?
Sorrow likelihood. Possible string values are:
getter/setter pair
surpriseLikelihood ↔ String?
Surprise likelihood. Possible string values are:
getter/setter pair
tiltAngle ↔ double?
Pitch angle, which indicates the upwards/downwards angle that the face is pointing relative to the image's horizontal plane.
getter/setter pair
underExposedLikelihood ↔ String?
Under-exposed likelihood. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited