Image class

Client image to perform Google Cloud Vision API tasks over.

Constructors

Image({String? content, ImageSource? source})
Image.fromJson(Map json_)

Properties

content ↔ String?
Image content, represented as a stream of bytes.
getter/setter pair
contentAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ ImageSource?
Google Cloud Storage image location, or publicly-accessible image URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited