ImportProductSetsGcsSource class

The Google Cloud Storage location for a csv file which preserves a list of ImportProductSetRequests in each line.

Properties

csvFileUri ↔ String?
The Google Cloud Storage URI of the input csv file.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited