ImportProductSetsInputConfig class

The input content for the ImportProductSets method.

Properties

gcsSource ↔ ImportProductSetsGcsSource?
The Google Cloud Storage location for a csv file which preserves a list of ImportProductSetRequests in each line.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited