ListReferenceImagesResponse class

Response message for the ListReferenceImages method.

Constructors

ListReferenceImagesResponse({String? nextPageToken, int? pageSize, List<ReferenceImage>? referenceImages})
ListReferenceImagesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
The next_page_token returned from a previous List request, if any.
getter/setter pair
pageSize ↔ int?
The maximum number of items to return.
getter/setter pair
referenceImages ↔ List<ReferenceImage>?
The list of reference images.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited