LocalizedObjectAnnotation class

Set of detected objects with bounding boxes.

Constructors

LocalizedObjectAnnotation({BoundingPoly? boundingPoly, String? languageCode, String? mid, String? name, double? score})
LocalizedObjectAnnotation.fromJson(Map json_)

Properties

boundingPoly ↔ BoundingPoly?
Image region to which this object belongs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
languageCode ↔ String?
The BCP-47 language code, such as "en-US" or "sr-Latn".
getter/setter pair
mid ↔ String?
Object ID that should align with EntityAnnotation mid.
getter/setter pair
name ↔ String?
Object name, expressed in its language_code language.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double?
Score of the result.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited