OutputConfig class

The desired output location and metadata.

Constructors

OutputConfig({int? batchSize, GcsDestination? gcsDestination})
OutputConfig.fromJson(Map json_)

Properties

batchSize ↔ int?
The max number of response protos to put into each output JSON file on Google Cloud Storage.
getter/setter pair
gcsDestination ↔ GcsDestination?
The Google Cloud Storage location to write the output(s) to.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited