Page class

Detected page from OCR.

Constructors

Page({List<Block>? blocks, double? confidence, int? height, TextProperty? property, int? width})
Page.fromJson(Map json_)

Properties

blocks ↔ List<Block>?
List of blocks of text, images etc on this page.
getter/setter pair
confidence ↔ double?
Confidence of the OCR results on the page.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
Page height.
getter/setter pair
property ↔ TextProperty?
Additional information detected on the page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width ↔ int?
Page width.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited