Paragraph class

Structural unit of text representing a number of words in certain order.

Constructors

Paragraph({BoundingPoly? boundingBox, double? confidence, TextProperty? property, List<Word>? words})
Paragraph.fromJson(Map json_)

Properties

boundingBox ↔ BoundingPoly?
The bounding box for the paragraph.
getter/setter pair
confidence ↔ double?
Confidence of the OCR results for the paragraph.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
property ↔ TextProperty?
Additional information detected for the paragraph.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
words ↔ List<Word>?
List of all words in this paragraph.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited