Position class

A 3D position in the image, used primarily for Face detection landmarks.

A valid Position must have both x and y coordinates. The position coordinates are in the same scale as the original image.

Constructors

Position({double? x, double? y, double? z})
Position.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
x ↔ double?
X coordinate.
getter/setter pair
y ↔ double?
Y coordinate.
getter/setter pair
z ↔ double?
Z coordinate (or depth).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited