Product class

A Product contains ReferenceImages.

Constructors

Product({String? description, String? displayName, String? name, String? productCategory, List<KeyValue>? productLabels})
Product.fromJson(Map json_)

Properties

description ↔ String?
User-provided metadata to be stored with this product.
getter/setter pair
displayName ↔ String?
The user-provided name for this Product.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of the product.
getter/setter pair
productCategory ↔ String?
The category for the product identified by the reference image.
getter/setter pair
productLabels ↔ List<KeyValue>?
Key-value pairs that can be attached to a product.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited