ProductSet class

A ProductSet contains Products.

A ProductSet can contain a maximum of 1 million reference images. If the limit is exceeded, periodic indexing will fail.

Constructors

ProductSet({String? displayName, Status? indexError, String? indexTime, String? name})
ProductSet.fromJson(Map json_)

Properties

displayName ↔ String?
The user-provided name for this ProductSet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
indexError ↔ Status?
If there was an error with indexing the product set, the field is populated.
getter/setter pair
indexTime ↔ String?
The time at which this ProductSet was last indexed.
getter/setter pair
name ↔ String?
The resource name of the ProductSet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited