ProjectsLocationsProductsReferenceImagesResource class

Constructors

ProjectsLocationsProductsReferenceImagesResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(ReferenceImage request, String parent, {String? referenceImageId, String? $fields}) → Future<ReferenceImage>
Creates and returns a new ReferenceImage resource.
delete(String name, {String? $fields}) → Future<Empty>
Permanently deletes a reference image.
get(String name, {String? $fields}) → Future<ReferenceImage>
Gets information associated with a ReferenceImage.
list(String parent, {int? pageSize, String? pageToken, String? $fields}) → Future<ListReferenceImagesResponse>
Lists reference images.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited