Property class

A Property consists of a user-supplied name/value pair.

Constructors

Property({String? name, String? uint64Value, String? value})
Property.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Name of the property.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uint64Value ↔ String?
Value of numeric properties.
getter/setter pair
value ↔ String?
Value of the property.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited