SafeSearchAnnotation class

Set of features pertaining to the image, computed by computer vision methods over safe-search verticals (for example, adult, spoof, medical, violence).

Constructors

SafeSearchAnnotation({String? adult, String? medical, String? racy, String? spoof, String? violence})
SafeSearchAnnotation.fromJson(Map json_)

Properties

adult ↔ String?
Represents the adult content likelihood for the image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
medical ↔ String?
Likelihood that this is a medical image. Possible string values are:
getter/setter pair
racy ↔ String?
Likelihood that the request image contains racy content.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spoof ↔ String?
Spoof likelihood.
getter/setter pair
violence ↔ String?
Likelihood that this image contains violent content.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited