Symbol class

A single symbol representation.

Constructors

Symbol({BoundingPoly? boundingBox, double? confidence, TextProperty? property, String? text})
Symbol.fromJson(Map json_)

Properties

boundingBox ↔ BoundingPoly?
The bounding box for the symbol.
getter/setter pair
confidence ↔ double?
Confidence of the OCR results for the symbol.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
property ↔ TextProperty?
Additional information detected for the symbol.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String?
The actual UTF-8 representation of the symbol.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited