VisionApi class

Integrates Google Vision features, including image labeling, face, logo, and landmark detection, optical character recognition (OCR), and detection of explicit content, into applications.

Constructors

VisionApi(Client client, {String rootUrl = 'https://vision.googleapis.com/', String servicePath = ''})

Properties

files → FilesResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
images → ImagesResource
no setter
locations → LocationsResource
no setter
operations → OperationsResource
no setter
projects → ProjectsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

cloudPlatformScope → const String
See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.
cloudVisionScope → const String
Apply machine learning models to understand and label images