WebDetection class

Relevant information for the image from the Internet.

Constructors

WebDetection({List<WebLabel>? bestGuessLabels, List<WebImage>? fullMatchingImages, List<WebPage>? pagesWithMatchingImages, List<WebImage>? partialMatchingImages, List<WebImage>? visuallySimilarImages, List<WebEntity>? webEntities})
WebDetection.fromJson(Map json_)

Properties

bestGuessLabels ↔ List<WebLabel>?
The service's best guess as to the topic of the request image.
getter/setter pair
fullMatchingImages ↔ List<WebImage>?
Fully matching images from the Internet.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pagesWithMatchingImages ↔ List<WebPage>?
Web pages containing the matching images from the Internet.
getter/setter pair
partialMatchingImages ↔ List<WebImage>?
Partial matching images from the Internet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
visuallySimilarImages ↔ List<WebImage>?
The visually similar image results.
getter/setter pair
webEntities ↔ List<WebEntity>?
Deduced entities from similar images on the Internet.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited