WebEntity class

Entity deduced from similar images on the Internet.

Constructors

WebEntity({String? description, String? entityId, double? score})
WebEntity.fromJson(Map json_)

Properties

description ↔ String?
Canonical description of the entity, in English.
getter/setter pair
entityId ↔ String?
Opaque entity ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double?
Overall relevancy score for the entity.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited