WebImage class

Metadata for online images.

Constructors

WebImage({double? score, String? url})
WebImage.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double?
(Deprecated) Overall relevancy score for the image.
getter/setter pair
url ↔ String?
The result image URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited