WebPage class

Metadata for web pages.

Constructors

WebPage({List<WebImage>? fullMatchingImages, String? pageTitle, List<WebImage>? partialMatchingImages, double? score, String? url})
WebPage.fromJson(Map json_)

Properties

fullMatchingImages ↔ List<WebImage>?
Fully matching images on the page.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageTitle ↔ String?
Title for the web page, may contain HTML markups.
getter/setter pair
partialMatchingImages ↔ List<WebImage>?
Partial matching images on the page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double?
(Deprecated) Overall relevancy score for the web page.
getter/setter pair
url ↔ String?
The result web page URL.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited