AccessKeyCredentials class

Message describing AWS Credentials using access key id and secret.

Constructors

AccessKeyCredentials({String? accessKeyId, String? secretAccessKey, String? sessionToken})
AccessKeyCredentials.fromJson(Map json_)

Properties

accessKeyId ↔ String?
AWS access key ID.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretAccessKey ↔ String?
Input only.
getter/setter pair
sessionToken ↔ String?
Input only.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited