AdaptationModifier class

AdaptationModifier a modifier to be used for configuration of the OS adaptation process.

Constructors

AdaptationModifier({String? modifier, String? value})
AdaptationModifier.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
modifier ↔ String?
The modifier name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ String?
The value of the modifier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited