AvailableUpdates class

Holds information about the available versions for upgrade.

Constructors

AvailableUpdates({ApplianceVersion? inPlaceUpdate, ApplianceVersion? newDeployableAppliance})
AvailableUpdates.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
inPlaceUpdate ↔ ApplianceVersion?
The latest version for in place update.
getter/setter pair
newDeployableAppliance ↔ ApplianceVersion?
The newest deployable version of the appliance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited