AzureSourceVmDetails class

Represent the source Azure VM details.

Constructors

AzureSourceVmDetails({String? architecture, String? committedStorageBytes, List<AzureDiskDetails>? disks, String? firmware, VmCapabilities? vmCapabilitiesInfo})
AzureSourceVmDetails.fromJson(Map json_)

Properties

architecture ↔ String?
The VM architecture.
getter/setter pair
committedStorageBytes ↔ String?
The total size of the disks being migrated in bytes.
getter/setter pair
disks ↔ List<AzureDiskDetails>?
The disks attached to the source VM.
getter/setter pair
firmware ↔ String?
The firmware type of the source VM.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vmCapabilitiesInfo ↔ VmCapabilities?
Information about VM capabilities needed for some Compute Engine features.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited