BootDiskDefaults class

BootDiskDefaults hold information about the boot disk of a VM.

Constructors

BootDiskDefaults({String? deviceName, String? diskName, String? diskType, Encryption? encryption, DiskImageDefaults? image})
BootDiskDefaults.fromJson(Map json_)

Properties

deviceName ↔ String?
Specifies a unique device name of your choice that is reflected into the /dev/disk/by-id/google-* tree of a Linux operating system running within the instance.
getter/setter pair
diskName ↔ String?
The name of the disk.
getter/setter pair
diskType ↔ String?
The type of disk provisioning to use for the VM.
getter/setter pair
encryption ↔ Encryption?
The encryption to apply to the boot disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
image ↔ DiskImageDefaults?
The image to use when creating the disk.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited