CloneJob class

CloneJob describes the process of creating a clone of a MigratingVM to the requested target based on the latest successful uploaded snapshots.

While the migration cycles of a MigratingVm take place, it is possible to verify the uploaded VM can be started in the cloud, by creating a clone. The clone can be created without any downtime, and it is created using the latest snapshots which are already in the cloud. The cloneJob is only responsible for its work, not its products, which means once it is finished, it will never touch the instance it created. It will only delete it in case of the CloneJob being cancelled or upon failure to clone.

Constructors

CloneJob({ComputeEngineDisksTargetDetails? computeEngineDisksTargetDetails, ComputeEngineTargetDetails? computeEngineTargetDetails, String? createTime, String? endTime, Status? error, String? name, String? state, String? stateTime, List<CloneStep>? steps})
CloneJob.fromJson(Map json_)

Properties

computeEngineDisksTargetDetails ↔ ComputeEngineDisksTargetDetails?
Details of the target Persistent Disks in Compute Engine.
getter/setter pair
computeEngineTargetDetails ↔ ComputeEngineTargetDetails?
Details of the target VM in Compute Engine.
getter/setter pair
createTime ↔ String?
The time the clone job was created (as an API call, not when it was actually created in the target).
getter/setter pair
endTime ↔ String?
The time the clone job was ended.
getter/setter pair
error ↔ Status?
Provides details for the errors that led to the Clone Job's state.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the clone.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the clone job.
getter/setter pair
stateTime ↔ String?
The time the state was last updated.
getter/setter pair
steps ↔ List<CloneStep>?
The clone steps list representing its progress.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited