CloneStep class

CloneStep holds information about the clone step progress.

Constructors

CloneStep({AdaptingOSStep? adaptingOs, String? endTime, InstantiatingMigratedVMStep? instantiatingMigratedVm, PreparingVMDisksStep? preparingVmDisks, String? startTime})
CloneStep.fromJson(Map json_)

Properties

adaptingOs ↔ AdaptingOSStep?
Adapting OS step.
getter/setter pair
endTime ↔ String?
The time the step has ended.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instantiatingMigratedVm ↔ AdaptingOSStep?
Instantiating migrated VM step.
getter/setter pair
preparingVmDisks ↔ AdaptingOSStep?
Preparing VM disks step.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time the step has started.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited