ComputeEngineDisksTargetDefaults class

ComputeEngineDisksTargetDefaults is a collection of details for creating Persistent Disks in a target Compute Engine project.

Properties

disks ↔ List<PersistentDiskDefaults>?
The details of each Persistent Disk to create.
getter/setter pair
disksTargetDefaults ↔ AdaptingOSStep?
Details of the disk only migration target.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetProject ↔ String?
The full path of the resource of type TargetProject which represents the Compute Engine project in which to create the Persistent Disks.
getter/setter pair
vmTargetDefaults ↔ DisksMigrationVmTargetDefaults?
Details of the VM migration target.
getter/setter pair
zone ↔ String?
The zone in which to create the Persistent Disks.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited