ComputeEngineDisksTargetDetails class

ComputeEngineDisksTargetDetails is a collection of created Persistent Disks details.

Properties

disks ↔ List<PersistentDisk>?
The details of each created Persistent Disk.
getter/setter pair
disksTargetDetails ↔ AdaptingOSStep?
Details of the disks-only migration target.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vmTargetDetails ↔ DisksMigrationVmTargetDetails?
Details for the VM the migrated data disks are attached to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited