ComputeEngineTargetDefaults class

ComputeEngineTargetDefaults is a collection of details for creating a VM in a target Compute Engine project.

Constructors

ComputeEngineTargetDefaults({List<AdaptationModifier>? adaptationModifiers, List<String>? additionalLicenses, AppliedLicense? appliedLicense, String? bootConversion, String? bootOption, ComputeScheduling? computeScheduling, List<String>? diskReplicaZones, String? diskType, List<PersistentDiskDefaults>? disks, bool? enableIntegrityMonitoring, bool? enableVtpm, Encryption? encryption, String? hostname, Map<String, String>? labels, String? licenseType, String? machineType, String? machineTypeSeries, Map<String, String>? metadata, List<NetworkInterface>? networkInterfaces, List<String>? networkTags, bool? secureBoot, String? serviceAccount, String? storagePool, String? targetProject, String? vmName, String? zone})
ComputeEngineTargetDefaults.fromJson(Map json_)

Properties

adaptationModifiers ↔ List<AdaptationModifier>?
AdaptationModifiers are the set of modifiers used during OS adaptation.
getter/setter pair
additionalLicenses ↔ List<String>?
Additional licenses to assign to the VM.
getter/setter pair
appliedLicense ↔ AppliedLicense?
The OS license returned from the adaptation module report.
getter/setter pair
bootConversion ↔ String?
By default the virtual machine will keep its existing boot option.
getter/setter pair
bootOption ↔ String?
The VM Boot Option, as set in the source VM.
getter/setter pair
computeScheduling ↔ ComputeScheduling?
Compute instance scheduling information (if empty default is used).
getter/setter pair
diskReplicaZones ↔ List<String>?
Additional replica zones of the target regional disks.
getter/setter pair
disks ↔ List<PersistentDiskDefaults>?
The details of each disk to create.
getter/setter pair
diskType ↔ String?
The disk type to use in the VM. Possible string values are:
getter/setter pair
enableIntegrityMonitoring ↔ bool?
Defines whether the instance has integrity monitoring enabled.
getter/setter pair
enableVtpm ↔ bool?
Defines whether the instance has vTPM enabled.
getter/setter pair
encryption ↔ Encryption?
The encryption to apply to the VM disks.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hostname ↔ String?
The hostname to assign to the VM.
getter/setter pair
labels ↔ Map<String, String>?
A map of labels to associate with the VM.
getter/setter pair
licenseType ↔ String?
The license type to use in OS adaptation. Possible string values are:
getter/setter pair
machineType ↔ String?
The machine type to create the VM with.
getter/setter pair
machineTypeSeries ↔ String?
The machine type series to create the VM with.
getter/setter pair
metadata ↔ Map<String, String>?
The metadata key/value pairs to assign to the VM.
getter/setter pair
networkInterfaces ↔ List<NetworkInterface>?
List of NICs connected to this VM.
getter/setter pair
networkTags ↔ List<String>?
A list of network tags to associate with the VM.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureBoot ↔ bool?
Defines whether the instance has Secure Boot enabled.
getter/setter pair
serviceAccount ↔ String?
The service account to associate the VM with.
getter/setter pair
storagePool ↔ String?
If specified this will be the storage pool in which the disk is created.
getter/setter pair
targetProject ↔ String?
The full path of the resource of type TargetProject which represents the Compute Engine project in which to create this VM.
getter/setter pair
vmName ↔ String?
The name of the VM to create.
getter/setter pair
zone ↔ String?
The zone in which to create the VM.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited