CutoverStep class

CutoverStep holds information about the cutover step progress.

Constructors

CutoverStep({String? endTime, ReplicationCycle? finalSync, InstantiatingMigratedVMStep? instantiatingMigratedVm, PreparingVMDisksStep? preparingVmDisks, ReplicationCycle? previousReplicationCycle, ShuttingDownSourceVMStep? shuttingDownSourceVm, String? startTime})
CutoverStep.fromJson(Map json_)

Properties

endTime ↔ String?
The time the step has ended.
getter/setter pair
finalSync ↔ ReplicationCycle?
Final sync step.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instantiatingMigratedVm ↔ AdaptingOSStep?
Instantiating migrated VM step.
getter/setter pair
preparingVmDisks ↔ AdaptingOSStep?
Preparing VM disks step.
getter/setter pair
previousReplicationCycle ↔ ReplicationCycle?
A replication cycle prior cutover step.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shuttingDownSourceVm ↔ AdaptingOSStep?
Shutting down VM step.
getter/setter pair
startTime ↔ String?
The time the step has started.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited