CycleStep class

CycleStep holds information about a step progress.

Constructors

CycleStep({String? endTime, InitializingReplicationStep? initializingReplication, PostProcessingStep? postProcessing, ReplicatingStep? replicating, String? startTime})
CycleStep.fromJson(Map json_)

Properties

endTime ↔ String?
The time the cycle step has ended.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initializingReplication ↔ AdaptingOSStep?
Initializing replication step.
getter/setter pair
postProcessing ↔ AdaptingOSStep?
Post processing step.
getter/setter pair
replicating ↔ ReplicatingStep?
Replicating step.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time the cycle step has started.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited