DatacenterConnector class

DatacenterConnector message describes a connector between the Source and Google Cloud, which is installed on a vmware datacenter (an OVA vm installed by the user) to connect the Datacenter to Google Cloud and support vm migration data transfer.

Constructors

DatacenterConnector({String? applianceInfrastructureVersion, String? applianceSoftwareVersion, AvailableUpdates? availableVersions, String? bucket, String? createTime, Status? error, String? name, String? registrationId, String? serviceAccount, String? state, String? stateTime, String? updateTime, UpgradeStatus? upgradeStatus, String? version})
DatacenterConnector.fromJson(Map json_)

Properties

applianceInfrastructureVersion ↔ String?
Appliance OVA version.
getter/setter pair
applianceSoftwareVersion ↔ String?
Appliance last installed update bundle version.
getter/setter pair
availableVersions ↔ AvailableUpdates?
The available versions for updating this appliance.
getter/setter pair
bucket ↔ String?
The communication channel between the datacenter connector and Google Cloud.
getter/setter pair
createTime ↔ String?
The time the connector was created (as an API call, not when it was actually installed).
getter/setter pair
error ↔ Status?
Provides details on the state of the Datacenter Connector in case of an error.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The connector's name.
getter/setter pair
registrationId ↔ String?
A unique key for this connector.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
The service account to use in the connector when communicating with the cloud.
getter/setter pair
state ↔ String?
State of the DatacenterConnector, as determined by the health checks.
getter/setter pair
stateTime ↔ String?
The time the state was last set.
getter/setter pair
updateTime ↔ String?
The last time the connector was updated with an API call.
getter/setter pair
upgradeStatus ↔ UpgradeStatus?
The status of the current / last upgradeAppliance operation.
getter/setter pair
version ↔ String?
The version running in the DatacenterConnector.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited