Disk class

A message describing a data disk.

Constructors

Disk({int? lun, String? name, int? sizeGb})
Disk.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lun ↔ int?
The disk's Logical Unit Number (LUN).
getter/setter pair
name ↔ String?
The disk name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeGb ↔ int?
The disk size in GB.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited