DiskMigrationJobTargetDetails class

Details of the target disk in Compute Engine.

Constructors

DiskMigrationJobTargetDetails({Encryption? encryption, Map<String, String>? labels, ComputeEngineDisk? targetDisk, String? targetProject})
DiskMigrationJobTargetDetails.fromJson(Map json_)

Properties

encryption ↔ Encryption?
The encryption to apply to the disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
A map of labels to associate with the disk.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
targetDisk ↔ ComputeEngineDisk?
The target disk.
getter/setter pair
targetProject ↔ String?
The name of the resource of type TargetProject which represents the Compute Engine project in which to create the disk.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited