DiskMigrationStep class

DiskMigrationStep holds information about the disk migration step progress.

Constructors

DiskMigrationStep({CopyingSourceDiskSnapshotStep? copyingSourceDiskSnapshot, CreatingSourceDiskSnapshotStep? creatingSourceDiskSnapshot, String? endTime, ProvisioningTargetDiskStep? provisioningTargetDisk, String? startTime})
DiskMigrationStep.fromJson(Map json_)

Properties

copyingSourceDiskSnapshot ↔ AdaptingOSStep?
Copying source disk snapshot step.
getter/setter pair
creatingSourceDiskSnapshot ↔ AdaptingOSStep?
Creating source disk snapshot step.
getter/setter pair
endTime ↔ String?
The time the step has ended.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
provisioningTargetDisk ↔ AdaptingOSStep?
Creating target disk step.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time the step has started.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited