FetchStorageInventoryResponse class

Response message for fetchStorageInventory.

Constructors

FetchStorageInventoryResponse({String? nextPageToken, List<SourceStorageResource>? resources, String? updateTime})
FetchStorageInventoryResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
resources ↔ List<SourceStorageResource>?
The list of storage resources in the source.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The timestamp when the source was last queried (if the result is from the cache).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited