ImageImport class

ImageImport describes the configuration of the image import to run.

Constructors

ImageImport({String? cloudStorageUri, String? createTime, DiskImageTargetDetails? diskImageTargetDefaults, Encryption? encryption, MachineImageTargetDetails? machineImageTargetDefaults, String? name, List<ImageImportJob>? recentImageImportJobs})
ImageImport.fromJson(Map json_)

Properties

cloudStorageUri ↔ String?
The path to the Cloud Storage file from which the image should be imported.
getter/setter pair
createTime ↔ String?
The time the image import was created.
getter/setter pair
diskImageTargetDefaults ↔ DiskImageTargetDetails?
Target details for importing a disk image, will be used by ImageImportJob.
getter/setter pair
encryption ↔ Encryption?
The encryption details used by the image import process during the image adaptation for Compute Engine.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
machineImageTargetDefaults ↔ MachineImageTargetDetails?
Target details for importing a machine image, will be used by ImageImportJob.
getter/setter pair
name ↔ String?
The resource path of the ImageImport.
getter/setter pair
recentImageImportJobs ↔ List<ImageImportJob>?
The result of the most recent runs for this ImageImport.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited