ImageImportJob class

ImageImportJob describes the progress and result of an image import.

Constructors

ImageImportJob({String? cloudStorageUri, String? createTime, List<String>? createdResources, DiskImageTargetDetails? diskImageTargetDetails, String? endTime, List<Status>? errors, MachineImageTargetDetails? machineImageTargetDetails, String? name, String? state, List<ImageImportStep>? steps, List<MigrationWarning>? warnings})
ImageImportJob.fromJson(Map json_)

Properties

cloudStorageUri ↔ String?
The path to the Cloud Storage file from which the image should be imported.
getter/setter pair
createdResources ↔ List<String>?
The resource paths of the resources created by the image import job.
getter/setter pair
createTime ↔ String?
The time the image import was created (as an API call, not when it was actually created in the target).
getter/setter pair
diskImageTargetDetails ↔ DiskImageTargetDetails?
Target details used to import a disk image.
getter/setter pair
endTime ↔ String?
The time the image import was ended.
getter/setter pair
errors ↔ List<Status>?
Provides details on the error that led to the image import state in case of an error.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
machineImageTargetDetails ↔ MachineImageTargetDetails?
Target details used to import a machine image.
getter/setter pair
name ↔ String?
The resource path of the ImageImportJob.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the image import.
getter/setter pair
steps ↔ List<ImageImportStep>?
The image import steps list representing its progress.
getter/setter pair
warnings ↔ List<MigrationWarning>?
Warnings that occurred during the image import.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited