ImageImportOsAdaptationParameters class

Parameters affecting the OS adaptation process.

Constructors

ImageImportOsAdaptationParameters({List<AdaptationModifier>? adaptationModifiers, String? bootConversion, bool? generalize, String? licenseType})
ImageImportOsAdaptationParameters.fromJson(Map json_)

Properties

adaptationModifiers ↔ List<AdaptationModifier>?
Modifiers to be used as configuration of the OS adaptation process.
getter/setter pair
bootConversion ↔ String?
By default the image will keep its existing boot option.
getter/setter pair
generalize ↔ bool?
Set to true in order to generalize the imported image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
licenseType ↔ String?
Choose which type of license to apply to the imported image.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited