ImageImportStep class

ImageImportStep holds information about the image import step progress.

Constructors

ImageImportStep({AdaptingOSStep? adaptingOs, CreatingImageStep? creatingImage, String? endTime, InitializingImageImportStep? initializing, LoadingImageSourceFilesStep? loadingSourceFiles, String? startTime})
ImageImportStep.fromJson(Map json_)

Properties

adaptingOs ↔ AdaptingOSStep?
Adapting OS step.
getter/setter pair
creatingImage ↔ AdaptingOSStep?
Creating image step.
getter/setter pair
endTime ↔ String?
The time the step has ended.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
initializing ↔ AdaptingOSStep?
Initializing step.
getter/setter pair
loadingSourceFiles ↔ AdaptingOSStep?
Loading source files step.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The time the step has started.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited