MachineImageTargetDetails class

The target details of the machine image resource that will be created by the image import job.

Constructors

MachineImageTargetDetails({List<String>? additionalLicenses, String? description, Encryption? encryption, Map<String, String>? labels, String? machineImageName, MachineImageParametersOverrides? machineImageParametersOverrides, List<NetworkInterface>? networkInterfaces, ImageImportOsAdaptationParameters? osAdaptationParameters, ServiceAccount? serviceAccount, ShieldedInstanceConfig? shieldedInstanceConfig, bool? singleRegionStorage, SkipOsAdaptation? skipOsAdaptation, List<String>? tags, String? targetProject})
MachineImageTargetDetails.fromJson(Map json_)

Properties

additionalLicenses ↔ List<String>?
Additional licenses to assign to the instance created by the machine image.
getter/setter pair
description ↔ String?
An optional description of the machine image.
getter/setter pair
encryption ↔ Encryption?
The encryption to apply to the machine image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels to apply to the instance created by the machine image.
getter/setter pair
machineImageName ↔ String?
The name of the machine image to be created.
getter/setter pair
machineImageParametersOverrides ↔ MachineImageParametersOverrides?
Parameters overriding decisions based on the source machine image configurations.
getter/setter pair
networkInterfaces ↔ List<NetworkInterface>?
The network interfaces to create with the instance created by the machine image.
getter/setter pair
osAdaptationParameters ↔ ImageImportOsAdaptationParameters?
Use to set the parameters relevant for the OS adaptation process.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ ServiceAccount?
The service account to assign to the instance created by the machine image.
getter/setter pair
shieldedInstanceConfig ↔ ShieldedInstanceConfig?
Shielded instance configuration.
getter/setter pair
singleRegionStorage ↔ bool?
Set to true to set the machine image storageLocations to the single region of the import job.
getter/setter pair
skipOsAdaptation ↔ AdaptingOSStep?
Use to skip OS adaptation process.
getter/setter pair
tags ↔ List<String>?
The tags to apply to the instance created by the machine image.
getter/setter pair
targetProject ↔ String?
Reference to the TargetProject resource that represents the target project in which the imported machine image will be created.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited