MigratingVm class

MigratingVm describes the VM that will be migrated from a Source environment and its replication state.

Constructors

MigratingVm({AwsSourceVmDetails? awsSourceVmDetails, AzureSourceVmDetails? azureSourceVmDetails, ComputeEngineDisksTargetDefaults? computeEngineDisksTargetDefaults, ComputeEngineTargetDefaults? computeEngineTargetDefaults, String? createTime, ReplicationCycle? currentSyncInfo, CutoverForecast? cutoverForecast, String? description, String? displayName, Status? error, Expiration? expiration, String? group, Map<String, String>? labels, ReplicationCycle? lastReplicationCycle, ReplicationSync? lastSync, String? name, SchedulePolicy? policy, List<CloneJob>? recentCloneJobs, List<CutoverJob>? recentCutoverJobs, String? sourceVmId, String? state, String? stateTime, String? updateTime, VmwareSourceVmDetails? vmwareSourceVmDetails})
MigratingVm.fromJson(Map json_)

Properties

awsSourceVmDetails ↔ AwsSourceVmDetails?
Details of the VM from an AWS source.
getter/setter pair
azureSourceVmDetails ↔ AzureSourceVmDetails?
Details of the VM from an Azure source.
getter/setter pair
computeEngineDisksTargetDefaults ↔ ComputeEngineDisksTargetDefaults?
Details of the target Persistent Disks in Compute Engine.
getter/setter pair
computeEngineTargetDefaults ↔ ComputeEngineTargetDefaults?
Details of the target VM in Compute Engine.
getter/setter pair
createTime ↔ String?
The time the migrating VM was created (this refers to this resource and not to the time it was installed in the source).
getter/setter pair
currentSyncInfo ↔ ReplicationCycle?
Details of the current running replication cycle.
getter/setter pair
cutoverForecast ↔ CutoverForecast?
Provides details of future CutoverJobs of a MigratingVm.
getter/setter pair
description ↔ String?
The description attached to the migrating VM by the user.
getter/setter pair
displayName ↔ String?
The display name attached to the MigratingVm by the user.
getter/setter pair
error ↔ Status?
Provides details on the state of the Migrating VM in case of an error in replication.
getter/setter pair
expiration ↔ Expiration?
Provides details about the expiration state of the migrating VM.
getter/setter pair
group ↔ String?
The group this migrating vm is included in, if any.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels of the migrating VM.
getter/setter pair
lastReplicationCycle ↔ ReplicationCycle?
Details of the last replication cycle.
getter/setter pair
lastSync ↔ ReplicationSync?
The most updated snapshot created time in the source that finished replication.
getter/setter pair
name ↔ String?
The identifier of the MigratingVm.
getter/setter pair
policy ↔ SchedulePolicy?
The replication schedule policy.
getter/setter pair
recentCloneJobs ↔ List<CloneJob>?
The recent clone jobs performed on the migrating VM.
getter/setter pair
recentCutoverJobs ↔ List<CutoverJob>?
The recent cutover jobs performed on the migrating VM.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceVmId ↔ String?
The unique ID of the VM in the source.
getter/setter pair
state ↔ String?
State of the MigratingVm.
getter/setter pair
stateTime ↔ String?
The last time the migrating VM state was updated.
getter/setter pair
updateTime ↔ String?
The last time the migrating VM resource was updated.
getter/setter pair
vmwareSourceVmDetails ↔ VmwareSourceVmDetails?
Details of the VM from a Vmware source.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited