OSDescription class

A message describing the VM's OS.

Including OS, Publisher, Offer and Plan if applicable.

Constructors

OSDescription({String? offer, String? plan, String? publisher, String? type})
OSDescription.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
offer ↔ String?
OS offer.
getter/setter pair
plan ↔ String?
OS plan.
getter/setter pair
publisher ↔ String?
OS publisher.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
OS type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited