OSDisk class

A message describing the OS disk.

Constructors

OSDisk({String? name, int? sizeGb, String? type})
OSDisk.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The disk's full name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sizeGb ↔ int?
The disk's size in GB.
getter/setter pair
type ↔ String?
The disk's type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited