PersistentDisk class

Details of a created Persistent Disk.

Constructors

PersistentDisk({String? diskUri, int? sourceDiskNumber})
PersistentDisk.fromJson(Map json_)

Properties

diskUri ↔ String?
The URI of the Persistent Disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDiskNumber ↔ int?
The ordinal number of the source VM disk.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited