PersistentDiskDefaults class

Details for creation of a Persistent Disk.

Constructors

PersistentDiskDefaults({Map<String, String>? additionalLabels, String? diskName, String? diskType, Encryption? encryption, int? sourceDiskNumber, VmAttachmentDetails? vmAttachmentDetails})
PersistentDiskDefaults.fromJson(Map json_)

Properties

additionalLabels ↔ Map<String, String>?
A map of labels to associate with the Persistent Disk.
getter/setter pair
diskName ↔ String?
The name of the Persistent Disk to create.
getter/setter pair
diskType ↔ String?
The disk type to use. Possible string values are:
getter/setter pair
encryption ↔ Encryption?
The encryption to apply to the disk.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceDiskNumber ↔ int?
The ordinal number of the source VM disk.
getter/setter pair
vmAttachmentDetails ↔ VmAttachmentDetails?
Details for attachment of the disk to a VM.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited