ReplicationSync class

ReplicationSync contain information about the last replica sync to the cloud.

Constructors

ReplicationSync({String? lastSyncTime})
ReplicationSync.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
lastSyncTime ↔ String?
The most updated snapshot created time in the source that finished replication.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited