SchedulingNodeAffinity class

Node Affinity: the configuration of desired nodes onto which this Instance could be scheduled.

Based on https://cloud.google.com/compute/docs/reference/rest/v1/instances/setScheduling

Constructors

SchedulingNodeAffinity({String? key, String? operator, List<String>? values})
SchedulingNodeAffinity.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
The label key of Node resource to reference.
getter/setter pair
operator ↔ String?
The operator to use for the node resources specified in the values parameter. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<String>?
Corresponds to the label values of Node resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited