ShieldedInstanceConfig class

Shielded instance configuration.

Constructors

ShieldedInstanceConfig({bool? enableIntegrityMonitoring, bool? enableVtpm, String? secureBoot})
ShieldedInstanceConfig.fromJson(Map json_)

Properties

enableIntegrityMonitoring ↔ bool?
Defines whether the instance created by the machine image has integrity monitoring enabled.
getter/setter pair
enableVtpm ↔ bool?
Defines whether the instance created by the machine image has vTPM enabled.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secureBoot ↔ String?
Defines whether the instance created by the machine image has Secure Boot enabled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited