Source class

Source message describes a specific vm migration Source resource.

It contains the source environment information.

Constructors

Source({AwsSourceDetails? aws, AzureSourceDetails? azure, String? createTime, String? description, Encryption? encryption, Map<String, String>? labels, String? name, String? updateTime, VmwareSourceDetails? vmware})
Source.fromJson(Map json_)

Properties

aws ↔ AwsSourceDetails?
AWS type source details.
getter/setter pair
azure ↔ AzureSourceDetails?
Azure type source details.
getter/setter pair
createTime ↔ String?
The create time timestamp.
getter/setter pair
description ↔ String?
User-provided description of the source.
getter/setter pair
encryption ↔ Encryption?
The encryption details of the source data stored by the service.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
labels ↔ Map<String, String>?
The labels of the source.
getter/setter pair
name ↔ String?
The Source name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The update time timestamp.
getter/setter pair
vmware ↔ VmwareSourceDetails?
Vmware type source details.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited