TargetProject class

TargetProject message represents a target Compute Engine project for a migration or a clone.

Constructors

TargetProject({String? createTime, String? description, String? name, String? project, String? updateTime})
TargetProject.fromJson(Map json_)

Properties

createTime ↔ String?
The time this target project resource was created (not related to when the Compute Engine project it points to was created).
getter/setter pair
description ↔ String?
The target project's description.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the target project.
getter/setter pair
project ↔ String?
The target project ID (number) or project name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The last time the target project resource was updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited