UtilizationReport class

Utilization report details the utilization (CPU, memory, etc.) of selected source VMs.

Constructors

UtilizationReport({String? createTime, String? displayName, Status? error, String? frameEndTime, String? name, String? state, String? stateTime, String? timeFrame, int? vmCount, List<VmUtilizationInfo>? vms})
UtilizationReport.fromJson(Map json_)

Properties

createTime ↔ String?
The time the report was created (this refers to the time of the request, not the time the report creation completed).
getter/setter pair
displayName ↔ String?
The report display name, as assigned by the user.
getter/setter pair
error ↔ Status?
Provides details on the state of the report in case of an error.
getter/setter pair
frameEndTime ↔ String?
The point in time when the time frame ends.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The report unique name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Current state of the report.
getter/setter pair
stateTime ↔ String?
The time the state was last set.
getter/setter pair
timeFrame ↔ String?
Time frame of the report. Possible string values are:
getter/setter pair
vmCount ↔ int?
Total number of VMs included in the report.
getter/setter pair
vms ↔ List<VmUtilizationInfo>?
List of utilization information per VM.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited