VmwareSourceDetails class

VmwareSourceDetails message describes a specific source details for the vmware source type.

Constructors

VmwareSourceDetails({String? password, String? resolvedVcenterHost, String? thumbprint, String? username, String? vcenterIp})
VmwareSourceDetails.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
password ↔ String?
Input only.
getter/setter pair
resolvedVcenterHost ↔ String?
The hostname of the vcenter.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbprint ↔ String?
The thumbprint representing the certificate for the vcenter.
getter/setter pair
username ↔ String?
The credentials username.
getter/setter pair
vcenterIp ↔ String?
The ip address of the vcenter this Source represents.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited