Announcement class

Announcement for the resources of Vmware Engine.

Constructors

Announcement({String? activityType, String? cluster, String? code, String? createTime, String? description, Map<String, String>? metadata, String? name, String? privateCloud, String? state, String? targetResourceType, String? updateTime})
Announcement.fromJson(Map json_)

Properties

activityType ↔ String?
Activity type of the announcement There can be only one active announcement for a given activity type and target resource.
getter/setter pair
cluster ↔ String?
A Cluster resource name.
getter/setter pair
code ↔ String?
Code of the announcement.
getter/setter pair
createTime ↔ String?
Creation time of this resource.
getter/setter pair
description ↔ String?
Description of the announcement.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, String>?
Additional structured details about this announcement.
getter/setter pair
name ↔ String?
The resource name of the announcement.
getter/setter pair
privateCloud ↔ String?
A Private Cloud resource name.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the resource.
getter/setter pair
targetResourceType ↔ String?
Target Resource Type defines the type of the target for the announcement
getter/setter pair
updateTime ↔ String?
Last update time of this resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited