DatastoreNetwork class

The network configuration for the datastore.

Constructors

DatastoreNetwork({int? connectionCount, int? mtu, String? networkPeering, String? subnet})
DatastoreNetwork.fromJson(Map json_)

Properties

connectionCount ↔ int?
connection_count is used to set multiple connections from NFS client on ESXi host to NFS server.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
mtu ↔ int?
MTU value is set on the VMKernel adapter for the NFS traffic.
getter/setter pair
networkPeering ↔ String?
The resource name of the network peering, used to access the file share by clients on private cloud.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subnet ↔ String?
The resource name of the subnet Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited