connectionCount property

int? connectionCount
getter/setter pair

connection_count is used to set multiple connections from NFS client on ESXi host to NFS server.

A higher number of connections results in better performance on datastores. In MountDatastore API by default max 4 connections are configured. User can set value of connection_count between 1 to 4. Connection_count is supported from vsphere 8.0u1 for earlier version 1 connection count is set on the ESXi hosts.

Optional.

Implementation

core.int? connectionCount;