DnsBindPermission class

DnsBindPermission resource that contains the accounts having the consumer DNS bind permission on the corresponding intranet VPC of the consumer project.

Constructors

DnsBindPermission({String? name, List<Principal>? principals})
DnsBindPermission.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the resource which stores the users/service accounts having the permission to bind to the corresponding intranet VPC of the consumer project.
getter/setter pair
principals ↔ List<Principal>?
Users/Service accounts which have access for binding on the intranet VPC project corresponding to the consumer project.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited