cryptoKeyName property

String? cryptoKeyName
getter/setter pair

The resource name of the Cloud KMS key to be used for CMEK encryption.

The format of this field is projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}. The key must be in the same region as the private cloud. This key is used for wrapping the key-encrypting key of vSAN clusters. This field must be provided when type is CMEK or LEGACY_CMEK, and must not be set when type is OTHER.

Optional.

Implementation

core.String? cryptoKeyName;