ExternalAddress class

Represents an allocated external IP address and its corresponding internal IP address in a private cloud.

Constructors

ExternalAddress({String? createTime, String? description, String? externalIp, String? internalIp, String? name, String? state, String? uid, String? updateTime})
ExternalAddress.fromJson(Map json_)

Properties

createTime ↔ String?
Creation time of this resource.
getter/setter pair
description ↔ String?
User-provided description for this resource.
getter/setter pair
externalIp ↔ String?
The external IP address of a workload VM.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
internalIp ↔ String?
The internal IP address of a workload VM.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the resource.
getter/setter pair
uid ↔ String?
System-generated unique identifier for the resource.
getter/setter pair
updateTime ↔ String?
Last update time of this resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited