HcxActivationKey class

HCX activation key.

A default key is created during private cloud provisioning, but this behavior is subject to change and you should always verify active keys. Use VmwareEngine.ListHcxActivationKeys to retrieve existing keys and VmwareEngine.CreateHcxActivationKey to create new ones.

Constructors

HcxActivationKey({String? activationKey, String? createTime, String? name, String? state, String? uid})
HcxActivationKey.fromJson(Map json_)

Properties

activationKey ↔ String?
HCX activation key.
getter/setter pair
createTime ↔ String?
Creation time of HCX activation key.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The resource name of this HcxActivationKey.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of HCX activation key.
getter/setter pair
uid ↔ String?
System-generated unique identifier for the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited