ListClustersResponse class

Response message for VmwareEngine.ListClusters

Constructors

ListClustersResponse({List<Cluster>? clusters, String? nextPageToken, List<String>? unreachable})
ListClustersResponse.fromJson(Map json_)

Properties

clusters ↔ List<Cluster>?
A list of private cloud clusters.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Locations that could not be reached when making an aggregated query using wildcards.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited