ListNetworkPeeringsResponse class

Response message for VmwareEngine.ListNetworkPeerings

Constructors

ListNetworkPeeringsResponse({List<NetworkPeering>? networkPeerings, String? nextPageToken, List<String>? unreachable})
ListNetworkPeeringsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
networkPeerings ↔ List<NetworkPeering>?
A list of network peerings.
getter/setter pair
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unreachable resources.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited