ListPrivateConnectionsResponse class

Response message for VmwareEngine.ListPrivateConnections

Constructors

ListPrivateConnectionsResponse({String? nextPageToken, List<PrivateConnection>? privateConnections, List<String>? unreachable})
ListPrivateConnectionsResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token, which can be sent as page_token to retrieve the next page.
getter/setter pair
privateConnections ↔ List<PrivateConnection>?
A list of private connections.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unreachable resources.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited