clusterId property

String? clusterId
getter/setter pair

The user-provided identifier of the workload cluster to which the management VMs are to be migrated.

The cluster must be in the same private cloud as the one specified in name, and must be a workload cluster. The eventual cluster name will be constructed from the private cloud name and this cluster ID.

Required.

Implementation

core.String? clusterId;