NetworkConfig class

Network configuration in the consumer project with which the peering has to be done.

Constructors

NetworkConfig({String? dnsServerIp, String? managementCidr, int? managementIpAddressLayoutVersion, String? vmwareEngineNetwork, String? vmwareEngineNetworkCanonical})
NetworkConfig.fromJson(Map json_)

Properties

dnsServerIp ↔ String?
DNS Server IP of the Private Cloud.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
managementCidr ↔ String?
Management CIDR used by VMware management appliances.
getter/setter pair
managementIpAddressLayoutVersion ↔ int?
The IP address layout version of the management IP address range.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vmwareEngineNetwork ↔ String?
The relative resource name of the VMware Engine network attached to the private cloud.
getter/setter pair
vmwareEngineNetworkCanonical ↔ String?
The canonical name of the VMware Engine network in the form: projects/{project_number}/locations/{location}/vmwareEngineNetworks/{vmware_engine_network_id}
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited