PrivateCloud class

Represents a private cloud resource.

Private clouds of type STANDARD and TIME_LIMITED are zonal resources, STRETCHED private clouds are regional.

Constructors

PrivateCloud({String? createTime, String? deleteTime, String? description, String? expireTime, Hcx? hcx, ManagementCluster? managementCluster, String? name, NetworkConfig? networkConfig, Nsx? nsx, String? state, String? type, String? uid, String? updateTime, Vcenter? vcenter})
PrivateCloud.fromJson(Map json_)

Properties

createTime ↔ String?
Creation time of this resource.
getter/setter pair
deleteTime ↔ String?
Time when the resource was scheduled for deletion.
getter/setter pair
description ↔ String?
User-provided description for this private cloud.
getter/setter pair
expireTime ↔ String?
Time when the resource will be irreversibly deleted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hcx ↔ Hcx?
HCX appliance.
getter/setter pair
managementCluster ↔ ManagementCluster?
Input only.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
networkConfig ↔ NetworkConfig?
Network configuration of the private cloud.
getter/setter pair
nsx ↔ Nsx?
NSX appliance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the resource.
getter/setter pair
type ↔ String?
Type of the private cloud.
getter/setter pair
uid ↔ String?
System-generated unique identifier for the resource.
getter/setter pair
updateTime ↔ String?
Last update time of this resource.
getter/setter pair
vcenter ↔ Nsx?
Vcenter appliance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited