Schedule class

Schedule for the upgrade.

Constructors

Schedule({Constraints? constraints, Interval? editWindow, String? lastEditor, String? startTime, List<TimeWindow>? weeklyWindows})
Schedule.fromJson(Map json_)

Properties

constraints ↔ Constraints?
Constraints applied to the schedule.
getter/setter pair
editWindow ↔ Interval?
The schedule is open for edits during this time interval or window.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastEditor ↔ String?
Indicates who most recently edited the upgrade schedule.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
The scheduled start time for the upgrade.
getter/setter pair
weeklyWindows ↔ List<TimeWindow>?
Weekly time windows for upgrade activities.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited