StretchedClusterConfig class

Configuration of a stretched cluster.

Constructors

StretchedClusterConfig({String? preferredLocation, String? secondaryLocation})
StretchedClusterConfig.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
preferredLocation ↔ String?
Zone that will remain operational when connection between the two zones is lost.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryLocation ↔ String?
Additional zone for a higher level of availability and load balancing.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited