VmwareUpgradeComponent class

Per component upgrade resource

Constructors

VmwareUpgradeComponent({String? componentType, String? state})
VmwareUpgradeComponent.fromJson(Map json_)

Properties

componentType ↔ String?
Type of component
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Component's upgrade state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited