Connector class

Definition of a Serverless VPC Access connector.

Constructors

Connector({List<String>? connectedProjects, String? ipCidrRange, String? machineType, int? maxInstances, int? maxThroughput, int? minInstances, int? minThroughput, String? name, String? network, String? state, Subnet? subnet})
Connector.fromJson(Map json_)

Properties

connectedProjects ↔ List<String>?
List of projects using the connector.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipCidrRange ↔ String?
The range of internal addresses that follows RFC 4632 notation.
getter/setter pair
machineType ↔ String?
Machine type of VM Instance underlying connector.
getter/setter pair
maxInstances ↔ int?
Maximum value of instances in autoscaling group underlying the connector.
getter/setter pair
maxThroughput ↔ int?
Maximum throughput of the connector in Mbps.
getter/setter pair
minInstances ↔ int?
Minimum value of instances in autoscaling group underlying the connector.
getter/setter pair
minThroughput ↔ int?
Minimum throughput of the connector in Mbps.
getter/setter pair
name ↔ String?
The resource name in the format `projects / * /locations / * /connectors /
getter/setter pair
network ↔ String?
Name of a VPC network.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
State of the VPC access connector.
getter/setter pair
subnet ↔ Subnet?
The subnet in which to house the VPC Access Connector.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited