BoardingAndSeatingInfo class

Constructors

BoardingAndSeatingInfo({String? boardingDoor, String? boardingGroup, String? boardingPosition, Image? boardingPrivilegeImage, String? kind, LocalizedString? seatAssignment, String? seatClass, String? seatNumber, String? sequenceNumber})
BoardingAndSeatingInfo.fromJson(Map json_)

Properties

boardingDoor ↔ String?
Set this field only if this flight boards through more than one door or bridge and you want to explicitly print the door location on the boarding pass.
getter/setter pair
boardingGroup ↔ String?
The value of boarding group (or zone) this passenger shall board with.
getter/setter pair
boardingPosition ↔ String?
The value of boarding position.
getter/setter pair
boardingPrivilegeImage ↔ Image?
A small image shown above the boarding barcode.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seatAssignment ↔ LocalizedString?
The passenger's seat assignment.
getter/setter pair
seatClass ↔ String?
The value of the seat class.
getter/setter pair
seatNumber ↔ String?
The value of passenger seat.
getter/setter pair
sequenceNumber ↔ String?
The sequence number on the boarding pass.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited