BoardingAndSeatingPolicy class

Constructors

BoardingAndSeatingPolicy({String? boardingPolicy, String? kind, String? seatClassPolicy})
BoardingAndSeatingPolicy.fromJson(Map json_)

Properties

boardingPolicy ↔ String?
Indicates the policy the airline uses for boarding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seatClassPolicy ↔ String?
Seating policy which dictates how we display the seat class.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited