CompositeMedia class

A sequence of media data references representing composite data.

Introduced to support Bigstore composite objects. For details, visit http://go/bigstore-composites.

Constructors

CompositeMedia({String? blobRef, Blobstore2Info? blobstore2Info, String? cosmoBinaryReference, int? crc32cHash, String? inline, String? length, String? md5Hash, ObjectId? objectId, String? path, String? referenceType, String? sha1Hash})
CompositeMedia.fromJson(Map json_)

Properties

blobRef ↔ String?
Blobstore v1 reference, set if reference_type is BLOBSTORE_REF This should be the byte representation of a blobstore.BlobRef.
getter/setter pair
blobRefAsBytes ↔ List<int>
getter/setter pair
blobstore2Info ↔ Blobstore2Info?
Blobstore v2 info, set if reference_type is BLOBSTORE_REF and it refers to a v2 blob.
getter/setter pair
cosmoBinaryReference ↔ String?
A binary data reference for a media download.
getter/setter pair
cosmoBinaryReferenceAsBytes ↔ List<int>
getter/setter pair
crc32cHash ↔ int?
crc32.c hash for the payload.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inline ↔ String?
Media data, set if reference_type is INLINE
getter/setter pair
inlineAsBytes ↔ List<int>
getter/setter pair
length ↔ String?
Size of the data, in bytes
getter/setter pair
md5Hash ↔ String?
MD5 hash for the payload.
getter/setter pair
md5HashAsBytes ↔ List<int>
getter/setter pair
objectId ↔ ObjectId?
Reference to a TI Blob, set if reference_type is BIGSTORE_REF.
getter/setter pair
path ↔ String?
Path to the data, set if reference_type is PATH
getter/setter pair
referenceType ↔ String?
Describes what the field reference contains. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1Hash ↔ String?
SHA-1 hash for the payload.
getter/setter pair
sha1HashAsBytes ↔ List<int>
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited