DiscoverableProgram class

Information about how a class may be discovered and instantiated from within the Google Wallet app.

This is done by searching for a loyalty or gift card program and scanning or manually entering.

Properties

hashCode → int
The hash code for this object.
no setterinherited
merchantSigninInfo ↔ DiscoverableProgramMerchantSigninInfo?
Information about the ability to signin and add a valuable for this program through a merchant site.
getter/setter pair
merchantSignupInfo ↔ DiscoverableProgramMerchantSignupInfo?
Information about the ability to signup and add a valuable for this program through a merchant site.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
Visibility state of the discoverable program. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited