GroupingInfo class

Constructors

GroupingInfo({String? groupingId, int? sortIndex})
GroupingInfo.fromJson(Map json_)

Properties

groupingId ↔ String?
Optional grouping ID for grouping the passes with the same ID visually together.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortIndex ↔ int?
Optional index for sorting the passes when they are grouped with other passes.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited