IssuerContactInfo class

Constructors

IssuerContactInfo({List<String>? alertsEmails, String? email, String? name, String? phone})
IssuerContactInfo.fromJson(Map json_)

Properties

alertsEmails ↔ List<String>?
Email addresses which will receive alerts.
getter/setter pair
email ↔ String?
The primary contact email address.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The primary contact name.
getter/setter pair
phone ↔ String?
The primary contact phone number.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited