JwtResource class

A JWT representation of a pass.

Constructors

JwtResource({String? jwt})
JwtResource.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
jwt ↔ String?
A string representing a JWT of the format described at https://developers.google.com/wallet/reference/rest/v1/Jwt
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited