JwtValidateRequest class
Request to validate the JWT or JSON representation of a pass.
Constructors
- JwtValidateRequest({JsonResource? jsonResource, JwtResource? jwtResource})
- JwtValidateRequest.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- jsonResource ↔ JsonResource?
-
A JSON representation of a pass to be validated.
getter/setter pair
- jwtResource ↔ JwtResource?
-
A JWT representation of a pass to be validated.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited