JwtValidateResponse typedef
JwtValidateResponse = $Empty
Empty if the resource in the request is valid.
Returns exception if invalid.
Implementation
typedef JwtValidateResponse = $Empty;
Empty if the resource in the request is valid.
Returns exception if invalid.
typedef JwtValidateResponse = $Empty;