ListTemplateOverride class

Constructors

ListTemplateOverride({FirstRowOption? firstRowOption, FieldSelector? secondRowOption, FieldSelector? thirdRowOption})
ListTemplateOverride.fromJson(Map json_)

Properties

firstRowOption ↔ FirstRowOption?
Specifies from a predefined set of options or from a reference to the field what will be displayed in the first row.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondRowOption ↔ FieldSelector?
A reference to the field to be displayed in the second row.
getter/setter pair
thirdRowOption ↔ FieldSelector?
An unused/deprecated field.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited