LoyaltyPoints class

Constructors

LoyaltyPoints({LoyaltyPointsBalance? balance, String? label, LocalizedString? localizedLabel})
LoyaltyPoints.fromJson(Map json_)

Properties

balance ↔ LoyaltyPointsBalance?
The account holder's loyalty point balance, such as "500" or "$10.00".
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
label ↔ String?
The loyalty points label, such as "Points".
getter/setter pair
localizedLabel ↔ LocalizedString?
Translated strings for the label.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited