Media class

A reference to data stored on the filesystem, on GFS or in blobstore.

Constructors

Media({String? algorithm, String? bigstoreObjectRef, String? blobRef, Blobstore2Info? blobstore2Info, List<CompositeMedia>? compositeMedia, String? contentType, ContentTypeInfo? contentTypeInfo, String? cosmoBinaryReference, int? crc32cHash, DiffChecksumsResponse? diffChecksumsResponse, DiffDownloadResponse? diffDownloadResponse, DiffUploadRequest? diffUploadRequest, DiffUploadResponse? diffUploadResponse, DiffVersionResponse? diffVersionResponse, DownloadParameters? downloadParameters, String? filename, String? hash, bool? hashVerified, String? inline, bool? isPotentialRetry, String? length, String? md5Hash, String? mediaId, ObjectId? objectId, String? path, String? referenceType, String? sha1Hash, String? sha256Hash, String? sha512Hash, String? timestamp, String? token})
Media.fromJson(Map json_)

Properties

algorithm ↔ String?
Deprecated, use one of explicit hash type fields instead.
getter/setter pair
bigstoreObjectRef ↔ String?
Use object_id instead.
getter/setter pair
bigstoreObjectRefAsBytes ↔ List<int>
getter/setter pair
blobRef ↔ String?
Blobstore v1 reference, set if reference_type is BLOBSTORE_REF This should be the byte representation of a blobstore.BlobRef.
getter/setter pair
blobRefAsBytes ↔ List<int>
getter/setter pair
blobstore2Info ↔ Blobstore2Info?
Blobstore v2 info, set if reference_type is BLOBSTORE_REF and it refers to a v2 blob.
getter/setter pair
compositeMedia ↔ List<CompositeMedia>?
A composite media composed of one or more media objects, set if reference_type is COMPOSITE_MEDIA.
getter/setter pair
contentType ↔ String?
MIME type of the data
getter/setter pair
contentTypeInfo ↔ ContentTypeInfo?
Extended content type information provided for Scotty uploads.
getter/setter pair
cosmoBinaryReference ↔ String?
A binary data reference for a media download.
getter/setter pair
cosmoBinaryReferenceAsBytes ↔ List<int>
getter/setter pair
crc32cHash ↔ int?
For Scotty Uploads: Scotty-provided hashes for uploads For Scotty Downloads: (WARNING: DO NOT USE WITHOUT PERMISSION FROM THE SCOTTY TEAM.) A Hash provided by the agent to be used to verify the data being downloaded.
getter/setter pair
diffChecksumsResponse ↔ DiffChecksumsResponse?
Set if reference_type is DIFF_CHECKSUMS_RESPONSE.
getter/setter pair
diffDownloadResponse ↔ DiffDownloadResponse?
Set if reference_type is DIFF_DOWNLOAD_RESPONSE.
getter/setter pair
diffUploadRequest ↔ DiffUploadRequest?
Set if reference_type is DIFF_UPLOAD_REQUEST.
getter/setter pair
diffUploadResponse ↔ DiffUploadResponse?
Set if reference_type is DIFF_UPLOAD_RESPONSE.
getter/setter pair
diffVersionResponse ↔ DiffVersionResponse?
Set if reference_type is DIFF_VERSION_RESPONSE.
getter/setter pair
downloadParameters ↔ DownloadParameters?
Parameters for a media download.
getter/setter pair
filename ↔ String?
Original file name
getter/setter pair
hash ↔ String?
Deprecated, use one of explicit hash type fields instead.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hashVerified ↔ bool?
For Scotty uploads only.
getter/setter pair
inline ↔ String?
Media data, set if reference_type is INLINE
getter/setter pair
inlineAsBytes ↔ List<int>
getter/setter pair
isPotentialRetry ↔ bool?
|is_potential_retry| is set false only when Scotty is certain that it has not sent the request before.
getter/setter pair
length ↔ String?
Size of the data, in bytes
getter/setter pair
md5Hash ↔ String?
Scotty-provided MD5 hash for an upload.
getter/setter pair
md5HashAsBytes ↔ List<int>
getter/setter pair
mediaId ↔ String?
Media id to forward to the operation GetMedia.
getter/setter pair
mediaIdAsBytes ↔ List<int>
getter/setter pair
objectId ↔ ObjectId?
Reference to a TI Blob, set if reference_type is BIGSTORE_REF.
getter/setter pair
path ↔ String?
Path to the data, set if reference_type is PATH
getter/setter pair
referenceType ↔ String?
Describes what the field reference contains. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sha1Hash ↔ String?
Scotty-provided SHA1 hash for an upload.
getter/setter pair
sha1HashAsBytes ↔ List<int>
getter/setter pair
sha256Hash ↔ String?
Scotty-provided SHA256 hash for an upload.
getter/setter pair
sha256HashAsBytes ↔ List<int>
getter/setter pair
sha512Hash ↔ String?
Scotty-provided SHA512 hash for an upload.
getter/setter pair
sha512HashAsBytes ↔ List<int>
getter/setter pair
timestamp ↔ String?
Time at which the media data was last updated, in milliseconds since UNIX epoch
getter/setter pair
token ↔ String?
A unique fingerprint/version id for the media data
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited