MediaRequestInfo class

Extra information added to operations that support Scotty media requests.

Constructors

MediaRequestInfo({String? currentBytes, String? customData, String? diffObjectVersion, int? finalStatus, String? notificationType, String? physicalHeaders, String? requestId, String? requestReceivedParamsServingInfo, String? totalBytes, bool? totalBytesIsEstimated})
MediaRequestInfo.fromJson(Map json_)

Properties

currentBytes ↔ String?
The number of current bytes uploaded or downloaded.
getter/setter pair
customData ↔ String?
Data to be copied to backend requests.
getter/setter pair
diffObjectVersion ↔ String?
Set if the http request info is diff encoded.
getter/setter pair
finalStatus ↔ int?
The existence of the final_status field indicates that this is the last call to the agent for this request_id.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
notificationType ↔ String?
The type of notification received from Scotty. Possible string values are:
getter/setter pair
physicalHeaders ↔ String?
The physical headers provided by RequestReceivedParameters in Scotty request.
getter/setter pair
physicalHeadersAsBytes ↔ List<int>
getter/setter pair
requestId ↔ String?
The Scotty request ID.
getter/setter pair
requestReceivedParamsServingInfo ↔ String?
The partition of the Scotty server handling this request.
getter/setter pair
requestReceivedParamsServingInfoAsBytes ↔ List<int>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalBytes ↔ String?
The total size of the file.
getter/setter pair
totalBytesIsEstimated ↔ bool?
Whether the total bytes field contains an estimated data.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited