OfferclassResource class

Constructors

OfferclassResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addmessage(AddMessageRequest request, String resourceId, {String? $fields}) → Future<OfferClassAddMessageResponse>
Adds a message to the offer class referenced by the given class ID.
get(String resourceId, {String? $fields}) → Future<OfferClass>
Returns the offer class with the given class ID.
insert(OfferClass request, {String? $fields}) → Future<OfferClass>
Inserts an offer class with the given ID and properties.
list({String? issuerId, int? maxResults, String? token, String? $fields}) → Future<OfferClassListResponse>
Returns a list of all offer classes for a given issuer ID.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(OfferClass request, String resourceId, {String? $fields}) → Future<OfferClass>
Updates the offer class referenced by the given class ID.
toString() → String
A string representation of this object.
inherited
update(OfferClass request, String resourceId, {String? $fields}) → Future<OfferClass>
Updates the offer class referenced by the given class ID.

Operators

operator ==(Object other) → bool
The equality operator.
inherited