Pagination class

Constructors

Pagination({String? kind, String? nextPageToken, int? resultsPerPage})
Pagination.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
nextPageToken ↔ String?
Page token to send to fetch the next page.
getter/setter pair
resultsPerPage ↔ int?
Number of results returned in this page.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited