Permissions class

Constructors

Permissions({String? issuerId, List<Permission>? permissions})
Permissions.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
issuerId ↔ String?
ID of the issuer the list of permissions refer to.
getter/setter pair
permissions ↔ List<Permission>?
The complete list of permissions for the issuer account.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited