RotatingBarcodeValues class

A payload containing many barcode values and start date/time.

Constructors

RotatingBarcodeValues({String? periodMillis, String? startDateTime, List<String>? values})
RotatingBarcodeValues.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
periodMillis ↔ String?
The amount of time each barcode is valid for.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startDateTime ↔ String?
The date/time the first barcode is valid from.
getter/setter pair
values ↔ List<String>?
The values to encode in the barcode.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited