TemplateItem class

Constructors

TemplateItem({FieldSelector? firstValue, String? predefinedItem, FieldSelector? secondValue})
TemplateItem.fromJson(Map json_)

Properties

firstValue ↔ FieldSelector?
A reference to a field to display.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
predefinedItem ↔ String?
A predefined item to display.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondValue ↔ FieldSelector?
A reference to a field to display.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited