TicketCost class

Constructors

TicketCost({LocalizedString? discountMessage, Money? faceValue, Money? purchasePrice})
TicketCost.fromJson(Map json_)

Properties

discountMessage ↔ LocalizedString?
A message describing any kind of discount that was applied.
getter/setter pair
faceValue ↔ Money?
The face value of the ticket.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
purchasePrice ↔ Money?
The actual purchase price of the ticket, after tax and/or discounts.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited