ValueAddedModuleData class

Data for Value Added module.

Required fields are header and uri.

Constructors

ValueAddedModuleData({LocalizedString? body, LocalizedString? header, Image? image, int? sortIndex, String? uri, ModuleViewConstraints? viewConstraints})
ValueAddedModuleData.fromJson(Map json_)

Properties

body ↔ LocalizedString?
Body to be displayed on the module.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
Header to be displayed on the module.
getter/setter pair
image ↔ Image?
Image to be displayed on the module.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sortIndex ↔ int?
The index for sorting the modules.
getter/setter pair
uri ↔ String?
URI that the module leads to on click.
getter/setter pair
viewConstraints ↔ ModuleViewConstraints?
Constraints that all must be met for the module to be shown.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited