webcontentpublisher/v1 library

Web Content Publisher API - v1

webcontentpublisher.googleapis.com API, a service for web content publishers.

For more information, see developers.google.com/news/subscribe

Create an instance of WebContentPublisherApi to access these resources:

Classes

CheckFreeAccessResponse
Response message for CheckFreeAccess
ContentPolicyStatus
The content policy status of the publication, indicating any violations.
Cta
Represents a Call-To-Action (CTA) configuration for a publication.
DomainProperty
Represents a domain property associated with a publication, typically used to verify ownership and scope access.
GeneratePlatformSiteTokensResponse
Response message for GeneratePlatformSiteTokens.
ListCtasResponse
Response message for ListCtas.
ListPublicationsResponse
Response message for ListPublications.
NewsletterConfig
Configuration for newsletter signup calls-to-action (CTAs).
OrganizationsPublicationsCtasResource
OrganizationsPublicationsResource
OrganizationsResource
Publication
Represents a publisher's publication in Reader Revenue Manager.
PublicationsResource
RrmProduct
Configuration and status of the Reader Revenue Manager (RRM) product for a publication.
SiteToken
Represents a domain-scoped secure token mapping.
SlProduct
Subscription Linking (SL) product settings and status.
TosAcceptance
Details about the acceptance of the Terms of Service (TOS).
UsersResource
WebContentPublisherApi
webcontentpublisher.googleapis.com API, a service for web content publishers.

Typedefs

GeneratePlatformSiteTokensRequest = $Empty
Request message for GeneratePlatformSiteTokens.

Exceptions / Errors

ApiRequestError
Represents a general error reported by the API endpoint.
DetailedApiRequestError
Represents a specific error reported by the API endpoint.