state property
The current policy state.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : State is unspecified.
- "OK" : Content policy is in a good state; no violations.
- "VIOLATION_GRACE_PERIOD" : The publication has a content policy violation but is within a grace period.
- "VIOLATION_ACTIVE" : The publication has an active content policy violation.
- "ORGANIZATION_VIOLATION_GRACE_PERIOD" : The organization has a content policy violation but is within a grace period.
- "ORGANIZATION_VIOLATION_ACTIVE" : The organization has an active content policy violation.
- "ORGANIZATION_VIOLATION_ACTIVE_IMMEDIATE" : The organization has an active content policy violation requiring immediate action.
Implementation
core.String? state;