Cta class

Represents a Call-To-Action (CTA) configuration for a publication.

Constructors

Cta({String? displayName, String? name, NewsletterConfig? newsletterConfig, String? state, String? type})
Cta.fromJson(Map json_)

Properties

displayName String?
The user-visible display name of the CTA.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
newsletterConfig NewsletterConfig?
Configuration specific to newsletter signup CTAs.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
The current state of this CTA.
getter/setter pair
type String?
The type of this CTA.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited