ListPublicationsResponse class
Response message for ListPublications.
Constructors
-
ListPublicationsResponse({String? nextPageToken, List<
Publication> ? publications}) - ListPublicationsResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
A token to retrieve the next page of results, or empty if there are no
more results.
getter/setter pair
-
publications
↔ List<
Publication> ? -
The list of publications.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited