NewsletterConfig class

Configuration for newsletter signup calls-to-action (CTAs).

Constructors

NewsletterConfig({String? customConsentText, String? customMessage, bool? nameRequired, bool? optInRequired, String? title})
NewsletterConfig.fromJson(Map json_)

Properties

customConsentText String?
Custom consent or disclosure text shown to the user.
getter/setter pair
customMessage String?
A custom message displayed to the user in the signup prompt.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nameRequired bool?
Whether the user is required to provide their name to sign up.
getter/setter pair
optInRequired bool?
Whether checking the opt-in checkbox is required.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
The title of the newsletter signup prompt.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited