create method
Future<Publication>
create(
- Publication request,
- String parent, {
- String? publicationId,
- String? $fields,
Creates a publication.
request - The metadata request object.
Request parameters:
parent - Required. The parent resource where this publication will be
created. Format: organizations/{organization}.
Value must have pattern ^organizations/\[^/\]+$.
publicationId - Optional. The unique identifier of the publication to
create. If not specified, the server will generate a random publication
ID.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Publication.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Publication> create(
Publication request,
core.String parent, {
core.String? publicationId,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'publicationId': ?publicationId == null ? null : [publicationId],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/publications';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Publication.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}