SiteToken class

Represents a domain-scoped secure token mapping.

Constructors

SiteToken({String? domain, String? token})
SiteToken.fromJson(Map json_)

Properties

domain String?
The domain scope this token is valid for.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String?
The domain-scoped secure token value (ESUT).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited