SlProduct class

Subscription Linking (SL) product settings and status.

Constructors

SlProduct({bool? enabled, String? gcpProjectNumber})
SlProduct.fromJson(Map json_)

Properties

enabled bool?
Whether the Subscription Linking product is enabled.
getter/setter pair
gcpProjectNumber String?
The Google Cloud Project number associated with the publication.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited