WebContentPublisherApi class
webcontentpublisher.googleapis.com API, a service for web content publishers.
Constructors
- WebContentPublisherApi(Client client, {String rootUrl = 'https://webcontentpublisher.googleapis.com/', String servicePath = ''})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizations → OrganizationsResource
-
no setter
- publications → PublicationsResource
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- users → UsersResource
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- subscribewithgooglePublicationsEntitlementsManageScope → const String
- Private Service: https://www.googleapis.com/auth/subscribewithgoogle.publications.entitlements.manage
- subscribewithgooglePublicationsEntitlementsReadonlyScope → const String
- See and review your subscription information