create method

Creates a Submission of a URI suspected of containing phishing content for review.

If the review confirms malicious phishing content, Google adds the site to Google's Social Engineering lists to help protect users. Only allowlisted projects can use this method during Early Access. To obtain access, contact Sales or your customer engineer.

request - The metadata request object.

Request parameters:

parent - Required. The name of the project that is making the submission. This string is in the format "projects/{project_number}". Value must have pattern ^projects/\[^/\]+$.

$fields - Selector specifying which fields to include in a partial response.

Completes with a GoogleCloudWebriskV1Submission.

Completes with a commons.ApiRequestError if the API endpoint returned an error.

If the used http.Client completes with an error when making a REST call, this method will complete with the same error.

Implementation

async.Future<GoogleCloudWebriskV1Submission> create(
  GoogleCloudWebriskV1Submission request,
  core.String parent, {
  core.String? $fields,
}) async {
  final body_ = convert.json.encode(request);
  final queryParams_ = <core.String, core.List<core.String>>{
    'fields': ?$fields == null ? null : [$fields],
  };

  final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/submissions';

  final response_ = await _requester.request(
    url_,
    'POST',
    body: body_,
    queryParams: queryParams_,
  );
  return GoogleCloudWebriskV1Submission.fromJson(
    response_ as core.Map<core.String, core.dynamic>,
  );
}