CrawledUrl class

A CrawledUrl resource represents a URL that was crawled during a ScanRun.

Web Security Scanner Service crawls the web applications, following all links within the scope of sites, to find the URLs to test against.

Constructors

CrawledUrl({String? body, String? httpMethod, String? url})
CrawledUrl.fromJson(Map json_)

Properties

body ↔ String?
The body of the request that was used to visit the URL.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpMethod ↔ String?
The http method of the request that was used to visit the URL, in uppercase.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url ↔ String?
The URL that was crawled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited