Error class

Error describes why the execution was abnormally terminated.

Constructors

Error({String? context, String? payload, StackTrace? stackTrace})
Error.fromJson(Map json_)

Properties

context ↔ String?
Human-readable stack trace string.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
payload ↔ String?
Error message and data returned represented as a JSON string.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace ↔ StackTrace?
Stack trace with detailed information of where error was generated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited