ListStepEntriesResponse class

Response message for ExecutionHistory.ListStepEntries.

Constructors

ListStepEntriesResponse({String? nextPageToken, List<StepEntry>? stepEntries, int? totalSize})
ListStepEntriesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
A token to retrieve next page of results.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepEntries ↔ List<StepEntry>?
The list of entries.
getter/setter pair
totalSize ↔ int?
Indicates the total number of StepEntries that matched the request filter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited