NavigationInfo class

NavigationInfo describes what steps if any come before or after this step, or what steps are parents or children of this step.

Constructors

Properties

children ↔ List<String>?
Step entries that can be reached by "stepping into" e.g. a subworkflow call.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
next ↔ String?
The index of the next step in the current workflow, if any.
getter/setter pair
parent ↔ String?
The step entry, if any, that can be reached by "stepping out" of the current workflow being executed.
getter/setter pair
previous ↔ String?
The index of the previous step in the current workflow, if any.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited