ProjectsLocationsWorkflowsExecutionsResource class

Constructors

ProjectsLocationsWorkflowsExecutionsResource(ApiRequester client)

Properties

callbacks → ProjectsLocationsWorkflowsExecutionsCallbacksResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stepEntries → ProjectsLocationsWorkflowsExecutionsStepEntriesResource
no setter

Methods

cancel(CancelExecutionRequest request, String name, {String? $fields}) → Future<Execution>
Cancels an execution of the given name.
create(Execution request, String parent, {String? $fields}) → Future<Execution>
Creates a new execution using the latest revision of the given workflow.
deleteExecutionHistory(DeleteExecutionHistoryRequest request, String name, {String? $fields}) → Future<Empty>
Deletes all step entries for an execution.
exportData(String name, {String? $fields}) → Future<ExportDataResponse>
Returns all metadata stored about an execution, excluding most data that is already accessible using other API methods.
get(String name, {String? view, String? $fields}) → Future<Execution>
Returns an execution of the given name.
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? view, String? $fields}) → Future<ListExecutionsResponse>
Returns a list of executions which belong to the workflow with the given name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited