ProjectsLocationsWorkflowsResource class

Constructors

ProjectsLocationsWorkflowsResource(ApiRequester client)

Properties

executions → ProjectsLocationsWorkflowsExecutionsResource
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
triggerPubsubExecution(TriggerPubsubExecutionRequest request, String workflow, {String? $fields}) → Future<Execution>
Triggers a new execution using the latest revision of the given workflow by a Pub/Sub push notification.

Operators

operator ==(Object other) → bool
The equality operator.
inherited