StackTraceElement class

A single stack element (frame) where an error occurred.

Constructors

StackTraceElement({Position? position, String? routine, String? step})
StackTraceElement.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
position ↔ Position?
The source position information of the stack trace element.
getter/setter pair
routine ↔ String?
The routine where the error occurred.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
step ↔ String?
The step the error occurred at.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited