StepEntry class

An StepEntry contains debugging information for a step transition in a workflow execution.

Constructors

StepEntry({String? createTime, String? entryId, Exception? exception, String? name, NavigationInfo? navigationInfo, String? routine, String? state, String? step, StepEntryMetadata? stepEntryMetadata, String? stepType, String? updateTime, VariableData? variableData})
StepEntry.fromJson(Map json_)

Properties

createTime ↔ String?
The creation time of the step entry.
getter/setter pair
entryId ↔ String?
The numeric ID of this step entry, used for navigation.
getter/setter pair
exception ↔ Exception?
The exception thrown by the step entry.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The full resource name of the step entry.
getter/setter pair
The NavigationInfo associated with this step.
getter/setter pair
routine ↔ String?
The name of the routine this step entry belongs to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the step entry.
getter/setter pair
step ↔ String?
The name of the step this step entry belongs to.
getter/setter pair
stepEntryMetadata ↔ StepEntryMetadata?
The StepEntryMetadata associated with this step.
getter/setter pair
stepType ↔ String?
The type of the step this step entry belongs to.
getter/setter pair
updateTime ↔ String?
The most recently updated time of the step entry.
getter/setter pair
variableData ↔ VariableData?
The VariableData associated with this step.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited