ActiveDirectory class

Active Directory details.

Constructors

ActiveDirectory({String? dnsAddress, String? domain, String? domainUsername, String? secretManagerSecret, String? type})
ActiveDirectory.fromJson(Map json_)

Properties

dnsAddress String?
DNS IP address.
getter/setter pair
domain String?
Human readable form of a domain such as example.com.
getter/setter pair
domainUsername String?
Domain username.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretManagerSecret String?
Secret Manager secret.
getter/setter pair
type String?
Active Directory type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited