Actuation class

The Actuation object represents the bootstrap state and output results of deployed infrastructure and software.

Constructors

Actuation({ActuationOutput? actuationOutput, List<DeploymentOutput>? deploymentOutput, String? endTime, String? name, String? startTime, String? state})
Actuation.fromJson(Map json_)

Properties

actuationOutput ↔ ActuationOutput?
Actuation output.
getter/setter pair
deploymentOutput ↔ List<DeploymentOutput>?
Deployment output.
getter/setter pair
endTime ↔ String?
End time stamp.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the actuation resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Start time stamp.
getter/setter pair
state ↔ String?
Actuation state.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited