state property

String? state
getter/setter pair

Actuation state.

Output only. Possible string values are:

  • "STATE_UNSPECIFIED" : State unspecified.
  • "INFRA_CREATING" : Creating infrastructure in backend (Terraform applying).
  • "SUCCEEDED" : Success.
  • "FAILED" : Failed either in infra creating, post infra configuring, or infra destroying.
  • "POST_INFRA_CONFIGURING" : Configure workload after infrastructure is ready (Ansible running).
  • "INFRA_DESTROYING" : Destroying infrastructure in backend (Terraform destroying).
  • "TIMEOUT" : Ansible timed out due to losing heartbeat in post infra configuring.

Implementation

core.String? state;