ActuationOutput class

Message for output of actuation.

Constructors

ActuationOutput({String? actuateLogs, String? ansibleError, List<String>? ansibleFailedTask, String? blueprintId, String? cloudbuildId, String? errorCode, String? errorLogs, bool? hasUserFacingErrorMsg, String? terraformError, String? terraformTemplate})
ActuationOutput.fromJson(Map json_)

Properties

actuateLogs String?
A link to the Cloud Storage file that stores build logs.
getter/setter pair
ansibleError String?
Error message returned from Ansible.
getter/setter pair
ansibleFailedTask List<String>?
Failed task name returned from Ansible.
getter/setter pair
blueprintId String?
Reference to the Blueprint Controller deployment and revision resource.
getter/setter pair
cloudbuildId String?
Cloud Build instance UUID associated with this revision, without any suffix or prefix
getter/setter pair
errorCode String?
Code describing any errors that may have occurred.
getter/setter pair
errorLogs String?
A link to the actuation Cloud Build log.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasUserFacingErrorMsg bool?
Whether the error message is user facing.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terraformError String?
Error message returned from Terraform.
getter/setter pair
terraformTemplate String?
Reference to the Terraform template used.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited