hasUserFacingErrorMsg property
Whether the error message is user facing.
If true, the error message will be shown in the UI.
Output only.
Implementation
core.bool? hasUserFacingErrorMsg;
Whether the error message is user facing.
If true, the error message will be shown in the UI.
Output only.
core.bool? hasUserFacingErrorMsg;