AgentCommand class
An AgentCommand specifies a one-time executable program for the agent to run.
Constructors
-
AgentCommand({String? command, Map<
String, String> ? parameters}) - AgentCommand.fromJson(Map json_)
Properties
- command ↔ String?
-
The name of the agent one-time executable that will be invoked.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
parameters
↔ Map<
String, String> ? -
A map of key/value pairs that can be used to specify additional one-time
executable settings.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited