AgentStates class

Agent status.

Constructors

AgentStates({String? availableVersion, ServiceStates? hanaMonitoring, String? installedVersion, bool? isFullyEnabled, ServiceStates? processMetrics, ServiceStates? systemDiscovery})
AgentStates.fromJson(Map json_)

Properties

availableVersion ↔ String?
The available version of the agent in artifact registry.
getter/setter pair
hanaMonitoring ↔ ServiceStates?
HANA monitoring metrics of the agent.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
installedVersion ↔ String?
The installed version of the agent on the host.
getter/setter pair
isFullyEnabled ↔ bool?
Whether the agent is fully enabled.
getter/setter pair
processMetrics ↔ ServiceStates?
The Process metrics of the agent.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemDiscovery ↔ ServiceStates?
The System discovery metrics of the agent.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited