AgentStatusServiceStatus class

The status of a service (process metrics, host metrics, etc.).

Constructors

AgentStatusServiceStatus({List<AgentStatusConfigValue>? configValues, String? errorMessage, String? fullyFunctional, List<AgentStatusIAMPermission>? iamPermissions, String? name, String? state, String? unspecifiedStateMessage})
AgentStatusServiceStatus.fromJson(Map json_)

Properties

configValues ↔ List<AgentStatusConfigValue>?
The configuration values for the service.
getter/setter pair
errorMessage ↔ String?
The error message for the service if it is not fully functional.
getter/setter pair
fullyFunctional ↔ String?
Whether the service is fully functional (all checks passed).
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iamPermissions ↔ List<AgentStatusIAMPermission>?
The permissions required for the service.
getter/setter pair
name ↔ String?
The name of the service.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the service (enabled or disabled in the configuration).
getter/setter pair
unspecifiedStateMessage ↔ String?
The message to display when the service state is unspecified.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited