AppDetails class

Message for SAP instance details.

Constructors

AppDetails({String? appInstanceId, String? appServiceAccount, List<String>? appVmNames, String? ascsImage, String? ascsInstanceId, String? ascsMachineType, String? ascsServiceAccount, String? ascsVm, String? ersInstanceId, String? ersVm, String? image, String? machineType, String? secretManagerSecret, String? sharedStorage, String? sid, int? vmsMultiplier})
AppDetails.fromJson(Map json_)

Properties

appInstanceId String?
Instance ID for app.
getter/setter pair
appServiceAccount String?
Application service account.
getter/setter pair
appVmNames List<String>?
Customized VM names.
getter/setter pair
ascsImage String?
Image for the ASCS server.
getter/setter pair
ascsInstanceId String?
Instance ID for ASCS.
getter/setter pair
ascsMachineType String?
ASCS machine type.
getter/setter pair
ascsServiceAccount String?
ASCS service account.
getter/setter pair
ascsVm String?
ASCS VM name.
getter/setter pair
ersInstanceId String?
Instance ID for ERS.
getter/setter pair
ersVm String?
ERS VM name.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image String?
Image for the app server and ASCS server.
getter/setter pair
machineType String?
Machine type.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretManagerSecret String?
Secret Manager secret.
getter/setter pair
sharedStorage String?
Storage location.
getter/setter pair
sid String?
The SAP SID is a three-digit server-specific unique identification code.
getter/setter pair
vmsMultiplier int?
VMs multiplier.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited