appServiceAccount property
Application service account.
Let customers bring their own service account for the application.
Implementation
core.String? appServiceAccount;
Application service account.
Let customers bring their own service account for the application.
core.String? appServiceAccount;