ascsServiceAccount property
ASCS service account.
Let customers bring their own service account for ASCS.
Implementation
core.String? ascsServiceAccount;
ASCS service account.
Let customers bring their own service account for ASCS.
core.String? ascsServiceAccount;