createNewResultsTable property
Determines if a new results table will be created when an Execution is created.
Optional.
Implementation
core.bool? createNewResultsTable;
Determines if a new results table will be created when an Execution is created.
Optional.
core.bool? createNewResultsTable;