CloudResource class

The resource on GCP

Constructors

CloudResource({InstanceProperties? instanceProperties, String? kind, String? name})
CloudResource.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
instanceProperties ↔ InstanceProperties?
All instance properties.
getter/setter pair
kind ↔ String?
Output only. Possible string values are:
getter/setter pair
name ↔ String?
resource name Example: compute.googleapis.com/projects/wlm-obs-dev/zones/us-central1-a/instances/sap-pri
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited