Deployment class

The Deployment object represents user intent for deploying a specific type of workload.

Constructors

Deployment({String? createTime, String? description, String? name, SapSystemS4Config? sapSystemS4Config, String? serviceAccount, SqlServerWorkload? sqlServerWorkload, String? state, Map<String, TerraformVariable>? terraformVariables, String? updateTime, String? workerPool, String? workloadType})
Deployment.fromJson(Map json_)

Properties

createTime String?
Create time stamp.
getter/setter pair
description String?
Description of the deployment.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the deployment resource.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sapSystemS4Config SapSystemS4Config?
SAP system workload input.
getter/setter pair
serviceAccount String?
User-specified Service Account (SA) credentials to be used for Cloud Build.
getter/setter pair
sqlServerWorkload SqlServerWorkload?
MS SQL workload input.
getter/setter pair
state String?
Current state of the deployment.
getter/setter pair
terraformVariables Map<String, TerraformVariable>?
terraform_variables represents all the Terraform variables for the deployment workload.
getter/setter pair
updateTime String?
Update time stamp.
getter/setter pair
workerPool String?
The user-specified Cloud Build worker pool resource in which the Cloud Build job will execute.
getter/setter pair
workloadType String?
Workload type of the deployment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited