bigQueryDestination property
The BigQuery destination for detailed evaluation results.
If this field is specified, the results of each evaluation execution are exported to BigQuery.
Optional.
Implementation
BigQueryDestination? bigQueryDestination;
The BigQuery destination for detailed evaluation results.
If this field is specified, the results of each evaluation execution are exported to BigQuery.
Optional.
BigQueryDestination? bigQueryDestination;