ExecutionResult class

The result of an execution.

Constructors

ExecutionResult({List<Command>? commands, String? documentationUrl, Resource? resource, String? rule, String? severity, String? type, ViolationDetails? violationDetails, String? violationMessage})
ExecutionResult.fromJson(Map json_)

Properties

commands ↔ List<Command>?
The commands to remediate the violation.
getter/setter pair
documentationUrl ↔ String?
The URL for the documentation of the rule.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resource ↔ Resource?
The resource that violates the rule.
getter/setter pair
rule ↔ String?
The rule that is violated in an evaluation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
The severity of violation.
getter/setter pair
type ↔ String?
Execution result type of the scanned resource. Possible string values are:
getter/setter pair
violationDetails ↔ ViolationDetails?
The details of violation in an evaluation result.
getter/setter pair
violationMessage ↔ String?
The violation message of an execution.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited