GceInstanceFilter class

A filter for matching Compute Engine instances.

Constructors

GceInstanceFilter({List<String>? serviceAccounts})
GceInstanceFilter.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAccounts List<String>?
If non-empty, only Compute Engine instances associated with at least one of the provided service accounts will be included in the evaluation.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited