serviceAccounts property

List<String>? serviceAccounts
getter/setter pair

If non-empty, only Compute Engine instances associated with at least one of the provided service accounts will be included in the evaluation.

Implementation

core.List<core.String>? serviceAccounts;