IAMPermission class

The IAM permission status.

Constructors

IAMPermission({bool? granted, String? name})
IAMPermission.fromJson(Map json_)

Properties

granted ↔ bool?
Whether the permission is granted.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the permission.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited