ListRulesResponse class

Response message for the ListRules RPC.

Constructors

ListRulesResponse({List<Rule>? rules})
ListRulesResponse.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
rules List<Rule>?
All rules in response.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited