createCommsFirewall property
Create firewall.
If true, creates a firewall for the deployment. This field provides an option to not always create a firewall for the deployment.
Optional.
Implementation
core.bool? createCommsFirewall;
Create firewall.
If true, creates a firewall for the deployment. This field provides an option to not always create a firewall for the deployment.
Optional.
core.bool? createCommsFirewall;