ResourceFilter class
Resource filter for an evaluation defining the scope of resources to be evaluated.
Constructors
-
ResourceFilter({GceInstanceFilter? gceInstanceFilter, Map<
String, String> ? inclusionLabels, List<String> ? resourceIdPatterns, List<String> ? scopes}) - ResourceFilter.fromJson(Map json_)
Properties
- gceInstanceFilter ↔ GceInstanceFilter?
-
Filter compute engine resources.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inclusionLabels
↔ Map<
String, String> ? -
Labels to filter resources by.
getter/setter pair
-
resourceIdPatterns
↔ List<
String> ? -
The pattern to filter resources by their id For example, a pattern of
".prod-cluster." will match all resources that contain "prod-cluster" in
their ID.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
↔ List<
String> ? -
The scopes of evaluation resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited