Rule class

Message represent a rule

Constructors

Rule({String? description, String? displayName, String? errorMessage, String? name, String? primaryCategory, String? remediation, String? revisionId, String? ruleType, String? secondaryCategory, String? severity, List<String>? tags, String? uri})
Rule.fromJson(Map json_)

Properties

description ↔ String?
descrite rule in plain language
getter/setter pair
displayName ↔ String?
the name display in UI
getter/setter pair
errorMessage ↔ String?
the message template for rule
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
rule name
getter/setter pair
primaryCategory ↔ String?
the primary category
getter/setter pair
remediation ↔ String?
the remediation for the rule
getter/setter pair
revisionId ↔ String?
the version of the rule
getter/setter pair
ruleType ↔ String?
The type of the rule. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryCategory ↔ String?
the secondary category
getter/setter pair
severity ↔ String?
the severity of the rule
getter/setter pair
tags ↔ List<String>?
List of user-defined tags
getter/setter pair
uri ↔ String?
the docuement url for the rule
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited