SapDiscovery class

The schema of SAP system discovery data.

Constructors

SapDiscovery({SapDiscoveryComponent? applicationLayer, SapDiscoveryComponent? databaseLayer, SapDiscoveryMetadata? metadata, String? projectNumber, String? systemId, String? updateTime, bool? useDrReconciliation, SapDiscoveryWorkloadProperties? workloadProperties})
SapDiscovery.fromJson(Map json_)

Properties

applicationLayer ↔ SapDiscoveryComponent?
An SAP system may run without an application layer.
getter/setter pair
databaseLayer ↔ SapDiscoveryComponent?
An SAP System must have a database.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ SapDiscoveryMetadata?
The metadata for SAP system discovery data.
getter/setter pair
projectNumber ↔ String?
The GCP project number that this SapSystem belongs to.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemId ↔ String?
A combination of database SID, database instance URI and tenant DB name to make a unique identifier per-system.
getter/setter pair
updateTime ↔ String?
Unix timestamp this system has been updated last.
getter/setter pair
useDrReconciliation ↔ bool?
Whether to use DR reconciliation or not.
getter/setter pair
workloadProperties ↔ SapDiscoveryWorkloadProperties?
The properties of the workload.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited