SapDiscoveryComponentApplicationProperties class

A set of properties describing an SAP Application layer.

Constructors

SapDiscoveryComponentApplicationProperties({bool? abap, String? appInstanceNumber, String? applicationType, String? ascsInstanceNumber, String? ascsUri, String? ersInstanceNumber, String? kernelVersion, String? nfsUri})
SapDiscoveryComponentApplicationProperties.fromJson(Map json_)

Properties

abap ↔ bool?
Deprecated: ApplicationType now tells you whether this is ABAP or Java.
getter/setter pair
appInstanceNumber ↔ String?
Instance number of the SAP application instance.
getter/setter pair
applicationType ↔ String?
Type of the application.
getter/setter pair
ascsInstanceNumber ↔ String?
Instance number of the ASCS instance.
getter/setter pair
ascsUri ↔ String?
Resource URI of the recognized ASCS host of the application.
getter/setter pair
ersInstanceNumber ↔ String?
Instance number of the ERS instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kernelVersion ↔ String?
Kernel version for Netweaver running in the system.
getter/setter pair
nfsUri ↔ String?
Resource URI of the recognized shared NFS of the application.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited