SapDiscoveryMetadata class

Message describing SAP discovery system metadata

Constructors

SapDiscoveryMetadata({String? customerRegion, String? definedSystem, String? environmentType, String? sapProduct})
SapDiscoveryMetadata.fromJson(Map json_)

Properties

customerRegion ↔ String?
Customer region string for customer's use.
getter/setter pair
definedSystem ↔ String?
Customer defined, something like "E-commerce pre prod"
getter/setter pair
environmentType ↔ String?
Should be "prod", "QA", "dev", "staging", etc.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sapProduct ↔ String?
This SAP product name
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited