SapDiscoveryResourceInstanceProperties class

A set of properties only present for an instance type resource

Properties

appInstances ↔ List<SapDiscoveryResourceInstancePropertiesAppInstance>?
App server instances on the host
getter/setter pair
clusterInstances ↔ List<String>?
A list of instance URIs that are part of a cluster with this one.
getter/setter pair
diskMounts ↔ List<SapDiscoveryResourceInstancePropertiesDiskMount>?
Disk mounts on the instance.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceNumber ↔ String?
The VM's instance number.
getter/setter pair
instanceRole ↔ String?
Bitmask of instance role, a resource may have multiple roles at once.
getter/setter pair
isDrSite ↔ bool?
Instance is part of a DR site.
getter/setter pair
osKernelVersion ↔ SapDiscoveryResourceInstancePropertiesKernelVersion?
The kernel version of the instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
virtualHostname ↔ String?
A virtual hostname of the instance if it has one.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited