SapDiscoveryResourceInstancePropertiesAppInstance class

Fields to describe an SAP application server instance.

Properties

hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Instance name of the SAP application instance.
getter/setter pair
number ↔ String?
Instance number of the SAP application instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited