SapDiscoveryResourceInstancePropertiesKernelVersionVersion class

Version is reported as Major.Minor.Build.Patch.

Properties

build ↔ int?
The build version number.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
major ↔ int?
The major version number.
getter/setter pair
minor ↔ int?
The minor version number.
getter/setter pair
patch ↔ int?
The patch version number.
getter/setter pair
remainder ↔ String?
A catch-all for any unparsed version components.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited