ansibleRunnerServiceAccount property
Ansible runner service account.
Let customers bring their own service account for the Ansible runner.
Implementation
core.String? ansibleRunnerServiceAccount;
Ansible runner service account.
Let customers bring their own service account for the Ansible runner.
core.String? ansibleRunnerServiceAccount;