gcpProjectId property
The project that infrastructure is deployed in.
Currently only supports the same project where the deployment resource exists.
Implementation
core.String? gcpProjectId;
The project that infrastructure is deployed in.
Currently only supports the same project where the deployment resource exists.
core.String? gcpProjectId;