SapWorkload class

The body of sap workload

Constructors

SapWorkload({SapComponent? application, String? architecture, SapComponent? database, Map<String, String>? metadata, List<SapDiscoveryWorkloadPropertiesProductVersion>? products})
SapWorkload.fromJson(Map json_)

Properties

application ↔ SapComponent?
the acsc componment
getter/setter pair
architecture ↔ String?
the architecture
getter/setter pair
database ↔ SapComponent?
the database componment
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, String>?
The metadata for SAP workload.
getter/setter pair
products ↔ List<SapDiscoveryWorkloadPropertiesProductVersion>?
the products on this workload.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited