ShellCommand class
A ShellCommand is invoked via the agent's command line executor.
Constructors
- ShellCommand({String? args, String? command, int? timeoutSeconds})
- ShellCommand.fromJson(Map json_)
Properties
- args ↔ String?
-
Arguments to be passed to the command.
getter/setter pair
- command ↔ String?
-
The name of the command to be executed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeoutSeconds ↔ int?
-
If not specified, the default timeout is 60 seconds.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited