SqlLocationDetails class

Location and networking details for configuring SQL server workload.

Constructors

SqlLocationDetails({String? dnsZone, String? gcpProjectId, String? internetAccess, String? network, String? primaryZone, String? region, String? secondaryZone, String? subnetwork, String? tertiaryZone})
SqlLocationDetails.fromJson(Map json_)

Properties

dnsZone String?
Create a new DNS zone when the field is empty.
getter/setter pair
gcpProjectId String?
The project that infrastructure is deployed in.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internetAccess String?
Internet Access.
getter/setter pair
network String?
Network name.
getter/setter pair
primaryZone String?
Primary zone.
getter/setter pair
region String?
Region name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryZone String?
Secondary zone cannot be the same as primary_zone and is only for High Availability deployment mode.
getter/setter pair
subnetwork String?
Subnetwork name.
getter/setter pair
tertiaryZone String?
Tertiary zone cannot be the same as primary_zone and secondary_zone, and it is only for High Availability deployment mode.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited