tertiaryZone property
Tertiary zone cannot be the same as primary_zone and secondary_zone, and it is only for High Availability deployment mode.
Optional.
Implementation
core.String? tertiaryZone;
Tertiary zone cannot be the same as primary_zone and secondary_zone, and it is only for High Availability deployment mode.
Optional.
core.String? tertiaryZone;