SqlserverValidationValidationDetail class

Message describing the Sqlserver validation metrics.

Properties

details ↔ List<SqlserverValidationDetails>?
Details wraps map that represents collected data names and values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
The Sqlserver system that the validation data is from.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited