UpcomingMaintenanceEvent class

Maintenance Event

Constructors

UpcomingMaintenanceEvent({String? endTime, String? maintenanceStatus, String? onHostMaintenance, String? startTime, String? type})
UpcomingMaintenanceEvent.fromJson(Map json_)

Properties

endTime ↔ String?
End time
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maintenanceStatus ↔ String?
Maintenance status
getter/setter pair
onHostMaintenance ↔ String?
Instance maintenance behavior.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime ↔ String?
Start time
getter/setter pair
type ↔ String?
Type
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited