workloadmanager/v1 library
Workload Manager API - v1
Workload Manager is a service that provides tooling for enterprise workloads to automate the deployment and validation of your workloads against best practices and recommendations.
For more information, see cloud.google.com/workload-manager/docs
Create an instance of WorkloadManagerApi to access these resources:
Classes
- ActiveDirectory
- Active Directory details.
- Actuation
- The Actuation object represents the bootstrap state and output results of deployed infrastructure and software.
- ActuationOutput
- Message for output of actuation.
- AgentCommand
- An AgentCommand specifies a one-time executable program for the agent to run.
- AgentStates
- Agent status.
- AgentStatus
- The schema of agent status data.
- AgentStatusConfigValue
- The configuration value.
- AgentStatusIAMPermission
- The IAM permission status.
- AgentStatusReference
- The reference to public documentation.
- AgentStatusServiceStatus
- The status of a service (process metrics, host metrics, etc.).
- AppDetails
- Message for SAP instance details.
- BackupProperties
- Backup properties.
- BigQueryDestination
- BigQuery destination for evaluation results.
- CloudResource
- The resource on GCP
- Command
- Command specifies the type of command to execute.
- ComponentHealth
- HealthCondition contains the detailed health check of each component.
- Database
- Database details.
- DatabaseDetails
- Message for SAP instance details.
- DatabaseProperties
- Database Properties.
- Deployment
- The Deployment object represents user intent for deploying a specific type of workload.
- DeploymentOutput
- Message for output of deployment resource.
- Evaluation
- Represents a Workload Manager Evaluation configuration.
- Execution
- Execution that represents a single run of an Evaluation.
- ExecutionResult
- The result of an execution.
- ExternalDataSources
- External data sources for an execution.
- GceInstanceFilter
- A filter for matching Compute Engine instances.
- HealthCheck
- HealthCheck contains the detailed health check of a component based on asource.
- IAMPermission
- The IAM permission status.
- Insight
- A presentation of host resource usage where the workload runs.
- InstanceProperties
- Instance Properties.
- ListActuationsResponse
-
The response object from
ListActuations. - ListDeploymentsResponse
- Message for response to listing deployments.
- ListDiscoveredProfilesResponse
- List discovered profile Response returns discovered profiles from agents
- ListEvaluationsResponse
- Response message for the ListEvaluations RPC.
- ListExecutionResultsResponse
- Response message for the ListExecutionResults RPC.
- ListExecutionsResponse
- Response message for the ListExecutions RPC.
- ListLocationsResponse
- The response message for Locations.ListLocations.
- ListOperationsResponse
- The response message for Operations.ListOperations.
- ListRulesResponse
- Response message for the ListRules RPC.
- ListScannedResourcesResponse
- Response message for the ListScannedResources RPC.
- LocationDetails
- Message for SAP instance details.
- Notice
- Additional information generated by an execution.
- OpenShiftValidation
- A presentation of OpenShift workload insight.
- Operation
- This resource represents a long-running operation that is the result of a network API call.
- Pacemaker
- Pacemaker configuration.
- ProjectsLocationsDeploymentsActuationsResource
- ProjectsLocationsDeploymentsResource
- ProjectsLocationsDiscoveredprofilesHealthResource
- ProjectsLocationsDiscoveredprofilesResource
- ProjectsLocationsEvaluationsExecutionsResource
- ProjectsLocationsEvaluationsExecutionsResultsResource
- ProjectsLocationsEvaluationsExecutionsScannedResourcesResource
- ProjectsLocationsEvaluationsResource
- ProjectsLocationsInsightsResource
- ProjectsLocationsOperationsResource
- ProjectsLocationsResource
- ProjectsLocationsRulesResource
- ProjectsResource
- Resource
- Resource in execution result.
- ResourceFilter
- Resource filter for an evaluation defining the scope of resources to be evaluated.
- ResourceStatus
- The lifecycle status of an Evaluation resource.
- Rule
- A rule to be evaluated.
- RuleExecutionResult
- Execution result summary per rule.
- RuleOutput
- The rule output of the violation.
- RunEvaluationRequest
- Request message for the RunEvaluation RPC.
- SapComponent
- The component of sap workload
- SapDiscovery
- The schema of SAP system discovery data.
- SapDiscoveryComponent
- Message describing the system component.
- SapDiscoveryComponentApplicationProperties
- A set of properties describing an SAP Application layer.
- SapDiscoveryComponentDatabaseProperties
- A set of properties describing an SAP Database layer.
- SapDiscoveryComponentReplicationSite
- A replication site used in Disaster Recovery (DR) configurations.
- SapDiscoveryMetadata
- Message describing SAP discovery system metadata
- SapDiscoveryResource
- Message describing a resource.
- SapDiscoveryResourceInstanceProperties
- A set of properties only present for an instance type resource
- SapDiscoveryResourceInstancePropertiesAppInstance
- Fields to describe an SAP application server instance.
- SapDiscoveryResourceInstancePropertiesDiskMount
- Disk mount on the instance.
- SapDiscoveryResourceInstancePropertiesKernelVersion
- KernelVersion encapsulates the kernel version data for the system.
- SapDiscoveryResourceInstancePropertiesKernelVersionVersion
- Version is reported as Major.Minor.Build.Patch.
- SapDiscoveryWorkloadProperties
- A set of properties describing an SAP workload.
- SapDiscoveryWorkloadPropertiesSoftwareComponentProperties
- A SAP software component name, version, and type.
- SapInstanceProperties
- SAP instance properties.
- SapSystemS4Config
- Message for SAP system workload.
- SapValidation
- A presentation of SAP workload insight.
- SapValidationValidationDetail
- Message describing the SAP validation metrics.
- SapWorkload
- The body of sap workload
- ScannedResource
- A scanned resource.
- ServiceStates
- The state of the service.
- ShellCommand
- A ShellCommand is invoked via the agent's command line executor.
- SqlLocationDetails
- Location and networking details for configuring SQL server workload.
- SqlserverValidation
- A presentation of SQLServer workload insight.
- SqlserverValidationDetails
- Message containing collected data names and values.
- SqlserverValidationValidationDetail
- Message describing the Sqlserver validation metrics.
- SqlServerWorkload
- Message for MS SQL workload.
- Summary
- Execution summary.
- TorsoValidation
- The schema of torso workload validation data.
- UpcomingMaintenanceEvent
- Maintenance Event
- ViolationDetails
- The violation in an evaluation result.
- WorkloadManagerApi
- Workload Manager is a service that provides tooling for enterprise workloads to automate the deployment and validation of your workloads against best practices and recommendations.
- WorkloadProfile
- Workload resource.
- WorkloadProfileHealth
- WorkloadProfileHealth contains the detailed health check of workload.
- WriteInsightRequest
- Request for sending the data insights.
Typedefs
- CancelOperationRequest = $Empty
- The request message for Operations.CancelOperation.
- Empty = $Empty
- A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
- Location = $Location00
- A resource that represents a Google Cloud location.
- Product = $Shared33
- Contains the details of a product.
- SapDiscoveryWorkloadPropertiesProductVersion = $Shared33
- A product name and version.
- Status = $Status00
-
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. - TerraformVariable = $TerraformVariable
- In order to align with the Infra Manager dependency, we create the same TerraformVariable message to represent a Terraform input variable, by following Infra Manager's API documentation: https://cloud.google.com/infrastructure-manager/docs/reference/rest.
- WriteInsightResponse = $Empty
- The response for write insights request.
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.