DataPart class

DataPart represents a structured blob.

This is most commonly a JSON payload.

Constructors

DataPart({Map<String, Object?>? data})
DataPart.fromJson(Map json_)

Properties

data ↔ Map<String, Object?>?
The values for Object must be JSON objects. It can consist of num, String, bool and null as well as Map and List values.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited