PayloadOptions class

Options about what data to include in the event payload.

Only supported for Google Chat and Google Drive events.

Constructors

PayloadOptions({String? fieldMask, bool? includeResource})
PayloadOptions.fromJson(Map json_)

Properties

fieldMask ↔ String?
If include_resource is set to true, the list of fields to include in the event payload.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
includeResource ↔ bool?
Whether the event payload includes data about the resource that changed.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited