SendMessageRequest class

/////////// Request Messages ///////////

Constructors

SendMessageRequest({SendMessageConfiguration? configuration, Message? message, Map<String, Object?>? metadata, String? tenant})
SendMessageRequest.fromJson(Map json_)

Properties

configuration ↔ SendMessageConfiguration?
Configuration for the send request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ Message?
The message to send to the agent.
getter/setter pair
metadata ↔ Map<String, Object?>?
Optional metadata for the request.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenant ↔ String?
Optional tenant, provided as a path parameter.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited