StreamResponse class

The stream response for a message.

The stream should be one of the following sequences: If the response is a message, the stream should contain one, and only one, message and then close If the response is a task lifecycle, the first response should be a Task object followed by zero or more TaskStatusUpdateEvents and TaskArtifactUpdateEvents. The stream should complete when the Task if in an interrupted or terminal state. A stream that ends before these conditions are met are

Constructors

StreamResponse({TaskArtifactUpdateEvent? artifactUpdate, Message? message, TaskStatusUpdateEvent? statusUpdate, Task? task})
StreamResponse.fromJson(Map json_)

Properties

artifactUpdate ↔ TaskArtifactUpdateEvent?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ Message?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusUpdate ↔ TaskStatusUpdateEvent?
getter/setter pair
task ↔ Task?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited