Subscription class

A subscription to receive events about a Google Workspace resource.

To learn more about subscriptions, see the Google Workspace Events API overview.

Constructors

Subscription({String? authority, String? createTime, DriveOptions? driveOptions, String? etag, List<String>? eventTypes, String? expireTime, String? name, NotificationEndpoint? notificationEndpoint, PayloadOptions? payloadOptions, bool? reconciling, String? serviceAccountAuthority, String? state, String? suspensionReason, String? targetResource, String? ttl, String? uid, String? updateTime, String? userAuthority})
Subscription.fromJson(Map json_)

Properties

authority ↔ String?
The user who authorized the creation of the subscription.
getter/setter pair
createTime ↔ String?
The time when the subscription is created.
getter/setter pair
driveOptions ↔ DriveOptions?
Features that are supported only for subscriptions on Drive resources.
getter/setter pair
etag ↔ String?
This checksum is computed by the server based on the value of other fields, and might be sent on update requests to ensure the client has an up-to-date value before proceeding.
getter/setter pair
eventTypes ↔ List<String>?
Unordered list.
getter/setter pair
expireTime ↔ String?
Non-empty default.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
notificationEndpoint ↔ NotificationEndpoint?
The endpoint where the subscription delivers events, such as a Pub/Sub topic.
getter/setter pair
payloadOptions ↔ PayloadOptions?
Options about what data to include in the event payload.
getter/setter pair
reconciling ↔ bool?
If true, the subscription is in the process of being updated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountAuthority ↔ String?
The service account that was used to authorize the creation of the subscription.
getter/setter pair
state ↔ String?
The state of the subscription.
getter/setter pair
suspensionReason ↔ String?
The error that suspended the subscription.
getter/setter pair
targetResource ↔ String?
The Google Workspace resource that's monitored for events, formatted as the full resource name.
getter/setter pair
ttl ↔ String?
Input only.
getter/setter pair
uid ↔ String?
System-assigned unique identifier for the subscription.
getter/setter pair
updateTime ↔ String?
The last time that the subscription is updated.
getter/setter pair
userAuthority ↔ String?
The user who authorized the creation of the subscription.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited