driveOptions property
Features that are supported only for subscriptions on Drive resources.
Optional.
Implementation
DriveOptions? driveOptions;
Features that are supported only for subscriptions on Drive resources.
Optional.
DriveOptions? driveOptions;