userAuthority property

String? userAuthority
getter/setter pair

The user who authorized the creation of the subscription.

The user must be able to view the target_resource. For Google Workspace users, the {user} value is the [user.id](https://developers.google.com/workspace/admin/directory/reference/rest/v1/users#User.FIELDS.id) field from the Directory API. Format: users/{user}

Output only.

Implementation

core.String? userAuthority;