reactivate method
- ReactivateSubscriptionRequest request,
- String name, {
- String? $fields,
Reactivates a suspended Google Workspace subscription.
This method resets your subscription's State field to ACTIVE. Before
you use this method, you must fix the error that suspended the
subscription. This method will ignore or reject any subscription that
isn't currently in a suspended state. To learn how to use this method, see
Reactivate a Google Workspace subscription.
For a subscription on a
Chat target resource,
you can reactivate a subscription as: - A Chat app subscribing to space
events where the app is a member by specifying an authorization scope that
begins with chat.app and getting one-time administrator approval. To
learn more, see
Authorize as a Chat app with administrator approval.
- Developer Preview: A
Chat app subscribing to all events in a Google Workspace organization by
specifying an authorization scope that begins with
chat.app.alland getting one-time administrator approval. To learn more, see Subscribe to all Google Chat events in a Workspace organization . - A user by specifying an authorization scope that doesn't include
appin its name. To learn more, see Authorize as a Chat user.
request - The metadata request object.
Request parameters:
name - Required. Resource name of the subscription. Format:
subscriptions/{subscription}
Value must have pattern ^subscriptions/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Operation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Operation> reactivate(
ReactivateSubscriptionRequest request,
core.String name, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':reactivate';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}