TaskArtifactUpdateEvent class

TaskArtifactUpdateEvent represents a task delta where an artifact has been generated.

Constructors

TaskArtifactUpdateEvent({bool? append, Artifact? artifact, String? contextId, bool? lastChunk, Map<String, Object?>? metadata, String? taskId})
TaskArtifactUpdateEvent.fromJson(Map json_)

Properties

append ↔ bool?
Whether this should be appended to a prior one produced
getter/setter pair
artifact ↔ Artifact?
The artifact itself
getter/setter pair
contextId ↔ String?
The id of the context that this task belongs too
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastChunk ↔ bool?
Whether this represents the last part of an artifact
getter/setter pair
metadata ↔ Map<String, Object?>?
Optional metadata associated with the artifact update.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
taskId ↔ String?
The id of the task for this artifact
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited