TaskStatusUpdateEvent class

TaskStatusUpdateEvent is a delta even on a task indicating that a task has changed.

Constructors

TaskStatusUpdateEvent({String? contextId, bool? final_, Map<String, Object?>? metadata, TaskStatus? status, String? taskId})
TaskStatusUpdateEvent.fromJson(Map json_)

Properties

contextId ↔ String?
The id of the context that the task belongs to
getter/setter pair
final_ ↔ bool?
Whether this is the last status update expected for this task.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, Object?>?
Optional metadata to associate with the task update.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ TaskStatus?
The new status of the task.
getter/setter pair
taskId ↔ String?
The id of the task that is changed
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited