TasksResource class

Constructors

TasksResource(ApiRequester client)

Properties

hashCode → int
The hash code for this object.
no setterinherited
pushNotificationConfigs → TasksPushNotificationConfigsResource
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel(CancelTaskRequest request, String name, {String? $fields}) → Future<Task>
Cancel a task from the agent.
get(String name, {int? historyLength, String? tenant, String? $fields}) → Future<Task>
Get the current state of a task from the agent.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subscribe(String name, {String? tenant, String? $fields}) → Future<StreamResponse>
TaskSubscription is a streaming call that will return a stream of task update events.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited