WorkspaceEventsApi class

The Google Workspace Events API lets you subscribe to events and manage change notifications across Google Workspace applications.

Constructors

WorkspaceEventsApi(Client client, {String rootUrl = 'https://workspaceevents.googleapis.com/', String servicePath = ''})

Properties

hashCode int
The hash code for this object.
no setterinherited
message MessageResource
no setter
operations OperationsResource
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptions SubscriptionsResource
no setter
tasks TasksResource
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

chatAppAllMembershipsReadonlyScope → const String
On their own behalf, apps in Google Chat can see all members in Google Chat spaces and conversations throughout your Workspace organization, even when the Chat app isn't a member
chatAppAllMessagesReadonlyScope → const String
On their own behalf, apps in Google Chat can see all messages and reactions throughout your Workspace organization, even when the Chat app isn't a member of a space or conversation
chatAppAllSpacesReadonlyScope → const String
On their own behalf, apps in Google Chat can see metadata about all spaces and conversations in Google Chat throughout your Workspace organization, even when the Chat app isn't a member
chatAppAllUsersReadstateReadonlyScope → const String
On their own behalf, apps in Google Chat can see the last read time for all users in all spaces and conversations throughout your Workspace organization, even when the Chat app isn't a member.
chatAppMembershipsReadonlyScope → const String
On their own behalf, apps in Google Chat can see members of conversations and spaces
chatAppMembershipsScope → const String
On their own behalf, apps in Google Chat can see, add, update, and remove members from conversations and spaces
chatAppMessagesReadonlyScope → const String
On their own behalf, apps in Google Chat can see all messages and their associated reactions and message content
chatAppSpacesReadonlyScope → const String
On their own behalf, apps in Google Chat can see conversations and spaces and their metadata (including history settings and access settings)
chatAppSpacesScope → const String
On their own behalf, apps in Google Chat can create conversations and spaces and see or update their metadata (including history settings and access settings)
chatBotScope → const String
Private Service: https://www.googleapis.com/auth/chat.bot
chatMembershipsReadonlyScope → const String
View members in Google Chat conversations.
chatMembershipsScope → const String
See, add, update, and remove members from conversations and spaces in Google Chat
chatMessagesReactionsReadonlyScope → const String
View reactions as well as their reaction content to messages in Google Chat
chatMessagesReactionsScope → const String
See, add, and delete reactions as well as their reaction content to messages in Google Chat
chatMessagesReadonlyScope → const String
See messages as well as their reactions and message content in Google Chat
chatMessagesScope → const String
See, compose, send, update, and delete messages as well as their message content; add, see, and delete reactions to messages.
chatSpacesReadonlyScope → const String
View chat and spaces in Google Chat
chatSpacesScope → const String
Create conversations and spaces and see or update metadata (including history settings and access settings) in Google Chat
chatUsersAvailabilityReadonlyScope → const String
See your availability status in Google Chat.
chatUsersAvailabilityScope → const String
See and change your availability status in Google Chat.
chatUsersReadstateReadonlyScope → const String
View last read time for Google Chat conversations
chatUsersReadstateScope → const String
View and modify last read time for Google Chat conversations
driveFileScope → const String
See, edit, create, and delete only the specific Google Drive files you use with this app
driveMetadataReadonlyScope → const String
See information about your Google Drive files
driveMetadataScope → const String
View and manage metadata of files in your Google Drive
driveReadonlyScope → const String
See and download all your Google Drive files
driveScope → const String
See, edit, create, and delete all of your Google Drive files
meetingsSpaceCreatedScope → const String
Create, edit, and see information about your Google Meet conferences created by the app.
meetingsSpaceReadonlyScope → const String
Read information about any of your Google Meet conferences