BoostConfig class

A boost configuration is a set of resources that a workstation can use to increase its performance.

If you specify a boost configuration, upon startup, workstation users can choose to use a VM provisioned under the boost config by passing the boost config ID in the start request. If the workstation user does not provide a boost config ID in the start request, the system will choose a VM from the pool provisioned under the default config.

Constructors

BoostConfig({List<Accelerator>? accelerators, int? bootDiskSizeGb, bool? enableNestedVirtualization, String? id, String? machineType, int? poolSize})
BoostConfig.fromJson(Map json_)

Properties

accelerators ↔ List<Accelerator>?
A list of the type and count of accelerator cards attached to the boost instance.
getter/setter pair
bootDiskSizeGb ↔ int?
The size of the boot disk for the VM in gigabytes (GB).
getter/setter pair
enableNestedVirtualization ↔ bool?
Whether to enable nested virtualization on boosted Cloud Workstations VMs running using this boost configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID to be used for the boost configuration.
getter/setter pair
machineType ↔ String?
The type of machine that boosted VM instances will use—for example, e2-standard-4.
getter/setter pair
poolSize ↔ int?
The number of boost VMs that the system should keep idle so that workstations can be boosted quickly.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited