GceInstance class

A runtime using a Compute Engine instance.

Constructors

GceInstance({List<Accelerator>? accelerators, List<BoostConfig>? boostConfigs, int? bootDiskSizeGb, GceConfidentialInstanceConfig? confidentialInstanceConfig, bool? disablePublicIpAddresses, bool? disableSsh, bool? enableNestedVirtualization, Map<String, String>? instanceMetadata, String? machineType, int? poolSize, int? pooledInstances, String? serviceAccount, List<String>? serviceAccountScopes, GceShieldedInstanceConfig? shieldedInstanceConfig, String? startupScriptUri, List<String>? tags, Map<String, String>? vmTags})
GceInstance.fromJson(Map json_)

Properties

accelerators ↔ List<Accelerator>?
A list of the type and count of accelerator cards attached to the instance.
getter/setter pair
boostConfigs ↔ List<BoostConfig>?
A list of the boost configurations that workstations created using this workstation configuration are allowed to use.
getter/setter pair
bootDiskSizeGb ↔ int?
The size of the boot disk for the VM in gigabytes (GB).
getter/setter pair
confidentialInstanceConfig ↔ GceConfidentialInstanceConfig?
A set of Compute Engine Confidential VM instance options.
getter/setter pair
disablePublicIpAddresses ↔ bool?
When set to true, disables public IP addresses for VMs.
getter/setter pair
disableSsh ↔ bool?
Whether to disable SSH access to the VM.
getter/setter pair
enableNestedVirtualization ↔ bool?
Whether to enable nested virtualization on Cloud Workstations VMs created using this workstation configuration.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instanceMetadata ↔ Map<String, String>?
Custom metadata to apply to Compute Engine instances.
getter/setter pair
machineType ↔ String?
The type of machine to use for VM instances—for example, "e2-standard-4".
getter/setter pair
pooledInstances ↔ int?
Number of instances currently available in the pool for faster workstation startup.
getter/setter pair
poolSize ↔ int?
The number of VMs that the system should keep idle so that new workstations can be started quickly for new users.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAccount ↔ String?
The email address of the service account for Cloud Workstations VMs created with this configuration.
getter/setter pair
serviceAccountScopes ↔ List<String>?
Scopes to grant to the service_account.
getter/setter pair
shieldedInstanceConfig ↔ GceShieldedInstanceConfig?
A set of Compute Engine Shielded instance options.
getter/setter pair
startupScriptUri ↔ String?
Link to the startup script stored in Cloud Storage.
getter/setter pair
tags ↔ List<String>?
Network tags to add to the Compute Engine VMs backing the workstations.
getter/setter pair
vmTags ↔ Map<String, String>?
Resource manager tags to be bound to this instance.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited