GceRegionalPersistentDisk class

A Persistent Directory backed by a Compute Engine regional persistent disk.

The persistent_directories field is repeated, but it may contain only one entry. It creates a persistent disk that mounts to the workstation VM at /home when the session starts and detaches when the session ends. If this field is empty, workstations created with this configuration do not have a persistent home directory.

Constructors

GceRegionalPersistentDisk({String? archiveTimeout, String? diskType, String? fsType, int? maxSizeGb, String? reclaimPolicy, int? sizeGb, String? sourceSnapshot})
GceRegionalPersistentDisk.fromJson(Map json_)

Properties

archiveTimeout String?
Number of seconds to wait after initially creating or subsequently shutting down the workstation before converting its disk into a snapshot.
getter/setter pair
diskType String?
The type of the persistent disk for the home directory.
getter/setter pair
fsType String?
Type of file system that the disk should be formatted with.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxSizeGb int?
Maximum size in GB to which this persistent directory can be resized.
getter/setter pair
reclaimPolicy String?
Whether the persistent disk should be deleted when the workstation is deleted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeGb int?
The GB capacity of a persistent home directory for each workstation created with this configuration.
getter/setter pair
sourceSnapshot String?
Name of the snapshot to use as the source for the disk.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited