GenerateAccessTokenRequest class

Request message for GenerateAccessToken.

Constructors

GenerateAccessTokenRequest({String? expireTime, int? port, String? ttl})
GenerateAccessTokenRequest.fromJson(Map json_)

Properties

expireTime ↔ String?
Desired expiration time of the access token.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
port ↔ int?
Port for which the access token should be generated.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ttl ↔ String?
Desired lifetime duration of the access token.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited