GenerateAccessTokenResponse class

Response message for GenerateAccessToken.

Constructors

GenerateAccessTokenResponse({String? accessToken, String? expireTime})
GenerateAccessTokenResponse.fromJson(Map json_)

Properties

accessToken ↔ String?
The generated bearer access token.
getter/setter pair
expireTime ↔ String?
Time at which the generated token will expire.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited