ListWorkstationClustersResponse class

Response message for ListWorkstationClusters.

Constructors

ListWorkstationClustersResponse({String? nextPageToken, List<String>? unreachable, List<WorkstationCluster>? workstationClusters})
ListWorkstationClustersResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextPageToken ↔ String?
Token to retrieve the next page of results, or empty if there are no more results in the list.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unreachable ↔ List<String>?
Unreachable resources.
getter/setter pair
workstationClusters ↔ List<WorkstationCluster>?
The requested workstation clusters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited