PrivateClusterConfig class

Configuration options for private workstation clusters.

Constructors

PrivateClusterConfig({List<String>? allowedProjects, String? clusterHostname, bool? enablePrivateEndpoint, String? serviceAttachmentUri})
PrivateClusterConfig.fromJson(Map json_)

Properties

allowedProjects ↔ List<String>?
Additional projects that are allowed to attach to the workstation cluster's service attachment.
getter/setter pair
clusterHostname ↔ String?
Hostname for the workstation cluster.
getter/setter pair
enablePrivateEndpoint ↔ bool?
Whether Workstations endpoint is private.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serviceAttachmentUri ↔ String?
Service attachment URI for the workstation cluster.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited