StartWorkstationRequest class

Request message for StartWorkstation.

Constructors

StartWorkstationRequest({String? boostConfig, String? etag, bool? validateOnly})
StartWorkstationRequest.fromJson(Map json_)

Properties

boostConfig ↔ String?
If set, the workstation starts using the boost configuration with the specified ID.
getter/setter pair
etag ↔ String?
If set, the request will be rejected if the latest version of the workstation on the server does not have this ETag.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
validateOnly ↔ bool?
If set, validate the request and preview the result, but do not actually apply it.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited