Workstation class

A single instance of a developer workstation with its own persistent storage.

Constructors

Workstation({Map<String, String>? annotations, String? createTime, String? deleteTime, String? displayName, Map<String, String>? env, String? etag, String? host, String? kmsKey, Map<String, String>? labels, String? name, List<WorkstationPersistentDirectory>? persistentDirectories, bool? reconciling, RuntimeHost? runtimeHost, String? sourceWorkstation, String? startTime, String? state, String? uid, String? updateTime})
Workstation.fromJson(Map json_)

Properties

annotations ↔ Map<String, String>?
Client-specified annotations.
getter/setter pair
createTime ↔ String?
Time when this workstation was created.
getter/setter pair
deleteTime ↔ String?
Time when this workstation was soft-deleted.
getter/setter pair
displayName ↔ String?
Human-readable name for this workstation.
getter/setter pair
env ↔ Map<String, String>?
Environment variables passed to the workstation container's entrypoint.
getter/setter pair
etag ↔ String?
Checksum computed by the server.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
Host to which clients can send HTTPS traffic that will be received by the workstation.
getter/setter pair
kmsKey ↔ String?
The name of the Google Cloud KMS encryption key used to encrypt this workstation.
getter/setter pair
labels ↔ Map<String, String>?
Labels that are applied to the workstation and that are also propagated to the underlying Compute Engine resources.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
persistentDirectories ↔ List<WorkstationPersistentDirectory>?
Directories to persist across workstation sessions.
getter/setter pair
reconciling ↔ bool?
Indicates whether this workstation is currently being updated to match its intended state.
getter/setter pair
runtimeHost ↔ RuntimeHost?
Runtime host for the workstation when in STATE_RUNNING.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceWorkstation ↔ String?
The source workstation from which this workstation's persistent directories were cloned on creation.
getter/setter pair
startTime ↔ String?
Time when this workstation was most recently successfully started, regardless of the workstation's initial state.
getter/setter pair
state ↔ String?
Current state of the workstation.
getter/setter pair
uid ↔ String?
A system-assigned unique identifier for this workstation.
getter/setter pair
updateTime ↔ String?
Time when this workstation was most recently updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited