workstationAuthorizationUrl property

String? workstationAuthorizationUrl
getter/setter pair

Specifies the redirect URL for unauthorized requests received by workstation VMs in this cluster.

Redirects to this endpoint will send a base64 encoded state query param containing the target workstation name and original request hostname. The endpoint is responsible for retrieving a token using GenerateAccessToken and redirecting back to the original hostname with the token.

Optional.

Implementation

core.String? workstationAuthorizationUrl;