WorkstationConfig class

A workstation configuration resource in the Cloud Workstations API.

Workstation configurations act as templates for workstations. The workstation configuration defines details such as the workstation virtual machine (VM) instance type, persistent storage, container image defining environment, which IDE or Code Editor to use, and more. Administrators and platform teams can also use [Identity and Access Management (IAM)](https://cloud.google.com/iam/docs/overview) rules to grant access to teams or to individual developers.

Constructors

WorkstationConfig({List<PortRange>? allowedPorts, Map<String, String>? annotations, List<Status>? conditions, Container? container, String? createTime, bool? degraded, String? deleteTime, bool? disableTcpConnections, String? displayName, bool? enableAuditAgent, CustomerEncryptionKey? encryptionKey, List<EphemeralDirectory>? ephemeralDirectories, String? etag, bool? grantWorkstationAdminRoleOnCreate, Host? host, String? idleTimeout, Map<String, String>? labels, int? maxUsableWorkstations, String? name, List<PersistentDirectory>? persistentDirectories, List<ReadinessCheck>? readinessChecks, bool? reconciling, List<String>? replicaZones, String? runningTimeout, String? uid, String? updateTime})
WorkstationConfig.fromJson(Map json_)

Properties

allowedPorts ↔ List<PortRange>?
A list of PortRanges specifying single ports or ranges of ports that are externally accessible in the workstation.
getter/setter pair
annotations ↔ Map<String, String>?
Client-specified annotations.
getter/setter pair
conditions ↔ List<Status>?
Status conditions describing the workstation configuration's current state.
getter/setter pair
container ↔ Container?
Container that runs upon startup for each workstation using this workstation configuration.
getter/setter pair
createTime ↔ String?
Time when this workstation configuration was created.
getter/setter pair
degraded ↔ bool?
Whether this workstation configuration is in degraded mode, in which case it may require user action to restore full functionality.
getter/setter pair
deleteTime ↔ String?
Time when this workstation configuration was soft-deleted.
getter/setter pair
disableTcpConnections ↔ bool?
Disables support for plain TCP connections in the workstation.
getter/setter pair
displayName ↔ String?
Human-readable name for this workstation configuration.
getter/setter pair
enableAuditAgent ↔ bool?
Whether to enable Linux auditd logging on the workstation.
getter/setter pair
encryptionKey ↔ CustomerEncryptionKey?
Encrypts resources of this workstation configuration using a customer-managed encryption key (CMEK).
getter/setter pair
ephemeralDirectories ↔ List<EphemeralDirectory>?
Ephemeral directories which won't persist across workstation sessions.
getter/setter pair
etag ↔ String?
Checksum computed by the server.
getter/setter pair
grantWorkstationAdminRoleOnCreate ↔ bool?
Grant creator of a workstation roles/workstations.policyAdmin role along with roles/workstations.user role on the workstation created by them.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ Host?
Runtime host for the workstation.
getter/setter pair
idleTimeout ↔ String?
Number of seconds to wait before automatically stopping a workstation after it last received user traffic.
getter/setter pair
labels ↔ Map<String, String>?
Labels that are applied to the workstation configuration and that are also propagated to the underlying Compute Engine resources.
getter/setter pair
maxUsableWorkstations ↔ int?
Maximum number of workstations under this configuration a user can have workstations.workstation.use permission on.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
persistentDirectories ↔ List<PersistentDirectory>?
Directories to persist across workstation sessions.
getter/setter pair
readinessChecks ↔ List<ReadinessCheck>?
Readiness checks to perform when starting a workstation using this workstation configuration.
getter/setter pair
reconciling ↔ bool?
Indicates whether this workstation configuration is currently being updated to match its intended state.
getter/setter pair
replicaZones ↔ List<String>?
Specifies the zones used to replicate the VM and disk resources within the region.
getter/setter pair
runningTimeout ↔ String?
Number of seconds to wait before automatically stopping a workstation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uid ↔ String?
A system-assigned unique identifier for this workstation configuration.
getter/setter pair
updateTime ↔ String?
Time when this workstation configuration was most recently updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited