runningTimeout property
Number of seconds to wait before automatically stopping a workstation.
We recommend that workstations be stopped daily so that security updates
can be applied upon restart. The idle_timeout and running_timeout fields
are independent of each other. Note that the running_timeout field stops
workstations after the specified time, regardless of whether or not the
workstations are idle. Provide duration terminated by s for seconds—for
example, "54000s" (15 hours). Defaults to "43200s" (12 hours). A value
of "0s" indicates that workstations using this configuration should
never time out. If encryption_key is set, it must be greater than "0s"
and less than "86400s" (24 hours). Warning: A value of "0s" indicates
that Cloud Workstations VMs created with this configuration have no
maximum running time. This is strongly discouraged because you incur costs
and will not pick up security updates.
Optional.
Implementation
core.String? runningTimeout;