sizeGb property
Size of the persistent directory in GB.
If specified in an update request, this is the desired size of the directory.
Optional.
Implementation
core.int? sizeGb;
Size of the persistent directory in GB.
If specified in an update request, this is the desired size of the directory.
Optional.
core.int? sizeGb;