Activity class
An activity resource contains information about an action that a
particular channel, or user, has taken on YouTube.
The actions reported in activity feeds include sharing a video, uploading a
video, and so forth. Each activity resource identifies the type of action,
the channel associated with the action, and the resource(s) associated with
the action, such as the video that was rated or uploaded.
Constructors
- Activity({ActivityContentDetails? contentDetails, String? etag, String? id, String? kind, ActivitySnippet? snippet})
- Activity.fromJson(Map json_)
Properties
- contentDetails ↔ ActivityContentDetails?
-
The
contentDetailsobject contains information about the content associated with the activity.getter/setter pair - etag ↔ String?
-
Etag of this resource
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID that YouTube uses to uniquely identify the activity.
getter/setter pair
- kind ↔ String?
-
Identifies what kind of resource this is.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snippet ↔ ActivitySnippet?
-
The
snippetobject contains basic details about the activity, including the activity's type and group ID.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited