ActivityContentDetailsSubscription class
Information about a channel that a user subscribed to.
Deprecated: This resource is no longer returned.
Constructors
- ActivityContentDetailsSubscription({ResourceId? resourceId})
- ActivityContentDetailsSubscription.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceId ↔ ResourceId?
-
The
resourceIdobject contains information that identifies the resource that the user subscribed to.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited