AvailabilityConfig class
Common proto for Live and VOD geo-restrictions
Constructors
- AvailabilityConfig({AvailabilityConfigGlobalConfig? globalConfig, AvailabilityConfigRegionsConfig? regionsConfig})
- AvailabilityConfig.fromJson(Map json_)
Properties
- globalConfig ↔ AvailabilityConfigGlobalConfig?
-
Video is available in all regions except the ones specified in the config.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- regionsConfig ↔ AvailabilityConfigRegionsConfig?
-
Video is available in the specified regions only.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited