AvailabilityConfigGlobalConfig class

Video is available in all regions except the ones specified in the excluded_region_codes list.

Constructors

AvailabilityConfigGlobalConfig({List<String>? excludedRegionCodes, Interval? interval})
AvailabilityConfigGlobalConfig.fromJson(Map json_)

Properties

excludedRegionCodes List<String>?
Regions where video is blocked
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval Interval?
Default time window where video is available for all non-blocked regions Not supported for upcoming / active live broadcasts.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited