BatchGetStatsResponse class

Response for the Videos.stats API.

Returns VideoStat information about a batch of videos. VideoStat contains a subset of the information in Video that is relevant to statistics and content details. BatchGetStats is intentionally not atomic to provide a better user experience. BatchGetStatsResponse returns a summary to help users understand the outcome of the operation.

Constructors

BatchGetStatsResponse({String? etag, List<VideoStat>? items, String? kind})
BatchGetStatsResponse.fromJson(Map json_)

Properties

etag String?
Etag of this resource.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
items List<VideoStat>?
The videos' stats information.
getter/setter pair
kind String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited