BrandPartner class
Details about the brand partner linked to the video for Creator Initiated Linking (CIL).
Next ID: 6
Constructors
- BrandPartner({String? channelHandle, String? channelId})
- BrandPartner.fromJson(Map json_)
Properties
- channelHandle ↔ String?
-
Channel handle, must begin with "@"
getter/setter pair
- channelId ↔ String?
-
External Channel ID, must begin with "UC"
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited