ChannelSection class

Constructors

ChannelSection({ChannelSectionContentDetails? contentDetails, String? etag, String? id, String? kind, Map<String, ChannelSectionLocalization>? localizations, ChannelSectionSnippet? snippet, ChannelSectionTargeting? targeting})
ChannelSection.fromJson(Map json_)

Properties

contentDetails ↔ ChannelSectionContentDetails?
The contentDetails object contains details about the channel section content, such as a list of playlists or channels featured in the section.
getter/setter pair
etag ↔ String?
Etag of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID that YouTube uses to uniquely identify the channel section.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
localizations ↔ Map<String, ChannelSectionLocalization>?
Localizations for different languages
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet ↔ ChannelSectionSnippet?
The snippet object contains basic details about the channel section, such as its type, style and title.
getter/setter pair
targeting ↔ ChannelSectionTargeting?
The targeting object contains basic targeting settings about the channel section.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited