ChannelStatistics class

Statistics about a channel: number of subscribers, number of videos in the channel, etc.

Constructors

ChannelStatistics({String? commentCount, bool? hiddenSubscriberCount, String? subscriberCount, String? videoCount, String? viewCount})
ChannelStatistics.fromJson(Map json_)

Properties

commentCount ↔ String?
The number of comments for the channel.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hiddenSubscriberCount ↔ bool?
Whether or not the number of subscribers is shown for this user.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriberCount ↔ String?
The number of subscribers that the channel has.
getter/setter pair
videoCount ↔ String?
The number of videos uploaded to the channel.
getter/setter pair
viewCount ↔ String?
The number of times the channel has been viewed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited