ChannelStatus class

JSON template for the status part of a channel.

Constructors

ChannelStatus({bool? isChannelMonetizationEnabled, bool? isLinked, String? longUploadsStatus, bool? madeForKids, String? privacyStatus, bool? selfDeclaredMadeForKids})
ChannelStatus.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
isChannelMonetizationEnabled ↔ bool?
Whether the channel is considered ypp monetization enabled.
getter/setter pair
isLinked ↔ bool?
If true, then the user is linked to either a YouTube username or G+ account.
getter/setter pair
longUploadsStatus ↔ String?
The long uploads status of this channel.
getter/setter pair
madeForKids ↔ bool?
getter/setter pair
privacyStatus ↔ String?
Privacy status of the channel. Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfDeclaredMadeForKids ↔ bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited