ChannelToAffiliateProgramLinkDetails class

Information specific to a creator in an affiliate program linked to a YouTube channel.

Constructors

ChannelToAffiliateProgramLinkDetails({String? merchantId, String? programStatus, String? statusUpdateReason, String? statusUpdateTime})
ChannelToAffiliateProgramLinkDetails.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
merchantId String?
Google Merchant Center ID of the partner.
getter/setter pair
programStatus String?
Affiliate program status.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusUpdateReason String?
Reason for the last update of the affiliate program status.
getter/setter pair
statusUpdateTime String?
Timestamp when the affiliate program status was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited