statusUpdateReason property
Reason for the last update of the affiliate program status.
Optional.
Implementation
core.String? statusUpdateReason;
Reason for the last update of the affiliate program status.
Optional.
core.String? statusUpdateReason;