CommentThread class

A comment thread represents information that applies to a top level comment and all its replies.

It can also include the top level comment itself and some of the replies.

Constructors

CommentThread({String? etag, String? id, String? kind, CommentThreadReplies? replies, CommentThreadSnippet? snippet})
CommentThread.fromJson(Map json_)

Properties

etag ↔ String?
Etag of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID that YouTube uses to uniquely identify the comment thread.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
replies ↔ CommentThreadReplies?
The replies object contains a limited number of replies (if any) to the top level comment found in the snippet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet ↔ CommentThreadSnippet?
The snippet object contains basic details about the comment thread and also the top level comment.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited