CommentThreadListResponse class

Constructors

CommentThreadListResponse({String? etag, String? eventId, List<CommentThread>? items, String? kind, String? nextPageToken, PageInfo? pageInfo, TokenPagination? tokenPagination, String? visitorId})
CommentThreadListResponse.fromJson(Map json_)

Properties

etag ↔ String?
Etag of this resource.
getter/setter pair
eventId ↔ String?
Serialized EventId of the request which produced this response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<CommentThread>?
A list of comment threads that match the request criteria.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
nextPageToken ↔ String?
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
getter/setter pair
pageInfo ↔ PageInfo?
General pagination information.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenPagination ↔ TokenPagination?
getter/setter pair
visitorId ↔ String?
The visitorId identifies the visitor.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited