LiveChatMessageListResponse class

Constructors

LiveChatMessageListResponse({LiveChatMessage? activePollItem, String? etag, String? eventId, List<LiveChatMessage>? items, String? kind, String? nextPageToken, DateTime? offlineAt, PageInfo? pageInfo, int? pollingIntervalMillis, TokenPagination? tokenPagination, String? visitorId})
LiveChatMessageListResponse.fromJson(Map json_)

Properties

activePollItem ↔ LiveChatMessage?
Set when there is an active poll.
getter/setter pair
etag ↔ String?
Etag of this resource.
getter/setter pair
eventId ↔ String?
Serialized EventId of the request which produced this response.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<LiveChatMessage>?
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
nextPageToken ↔ String?
getter/setter pair
offlineAt ↔ DateTime?
The date and time when the underlying stream went offline.
getter/setter pair
pageInfo ↔ PageInfo?
General pagination information.
getter/setter pair
pollingIntervalMillis ↔ int?
The amount of time the client should wait before polling again.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tokenPagination ↔ TokenPagination?
getter/setter pair
visitorId ↔ String?
The visitorId identifies the visitor.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited