LiveStreamConfigurationIssue class

Constructors

LiveStreamConfigurationIssue({String? description, String? reason, String? severity, String? type})
LiveStreamConfigurationIssue.fromJson(Map json_)

Properties

description ↔ String?
The long-form description of the issue and how to resolve it.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
reason ↔ String?
The short-form reason for this issue.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
severity ↔ String?
How severe this issue is to the stream. Possible string values are:
getter/setter pair
type ↔ String?
The kind of error happening. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited