LiveStreamHealthStatus class

Constructors

LiveStreamHealthStatus({List<LiveStreamConfigurationIssue>? configurationIssues, String? lastUpdateTimeSeconds, String? status})
LiveStreamHealthStatus.fromJson(Map json_)

Properties

configurationIssues ↔ List<LiveStreamConfigurationIssue>?
The configurations issues on this stream
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastUpdateTimeSeconds ↔ String?
The last time this status was updated (in seconds)
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ String?
The status code of this stream Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited