LiveStreamSnippet class

Constructors

LiveStreamSnippet({String? channelId, String? description, bool? isDefaultStream, DateTime? publishedAt, String? title})
LiveStreamSnippet.fromJson(Map json_)

Properties

channelId ↔ String?
The ID that YouTube uses to uniquely identify the channel that is transmitting the stream.
getter/setter pair
description ↔ String?
The stream's description.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDefaultStream ↔ bool?
getter/setter pair
publishedAt ↔ DateTime?
The date and time that the stream was created.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
The stream's title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited