MonitorStreamInfo class

Settings and Info of the monitor stream

Constructors

MonitorStreamInfo({int? broadcastStreamDelayMs, String? embedHtml, bool? enableMonitorStream})
MonitorStreamInfo.fromJson(Map json_)

Properties

broadcastStreamDelayMs ↔ int?
If you have set the enableMonitorStream property to true, then this property determines the length of the live broadcast delay.
getter/setter pair
embedHtml ↔ String?
HTML code that embeds a player that plays the monitor stream.
getter/setter pair
enableMonitorStream ↔ bool?
This value determines whether the monitor stream is enabled for the broadcast.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited