Subscription class

A subscription resource contains information about a YouTube user subscription.

A subscription notifies a user when new videos are added to a channel or when another user takes one of several actions on YouTube, such as uploading a video, rating a video, or commenting on a video.

Constructors

Subscription({SubscriptionContentDetails? contentDetails, String? etag, String? id, String? kind, SubscriptionSnippet? snippet, SubscriptionSubscriberSnippet? subscriberSnippet})
Subscription.fromJson(Map json_)

Properties

contentDetails ↔ SubscriptionContentDetails?
The contentDetails object contains basic statistics about the subscription.
getter/setter pair
etag ↔ String?
Etag of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID that YouTube uses to uniquely identify the subscription.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet ↔ SubscriptionSnippet?
The snippet object contains basic details about the subscription, including its title and the channel that the user subscribed to.
getter/setter pair
subscriberSnippet ↔ SubscriptionSubscriberSnippet?
The subscriberSnippet object contains basic details about the subscriber.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited