SuperStickerMetadata class

Constructors

SuperStickerMetadata({String? altText, String? altTextLanguage, String? stickerId})
SuperStickerMetadata.fromJson(Map json_)

Properties

altText ↔ String?
Internationalized alt text that describes the sticker image and any animation associated with it.
getter/setter pair
altTextLanguage ↔ String?
Specifies the localization language in which the alt text is returned.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stickerId ↔ String?
Unique identifier of the Super Sticker.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited