Video class

A video resource represents a YouTube video.

Constructors

Video({VideoAgeGating? ageGating, BrandPartner? brandPartner, VideoContentDetails? contentDetails, String? etag, VideoFileDetails? fileDetails, String? id, String? kind, VideoLiveStreamingDetails? liveStreamingDetails, Map<String, VideoLocalization>? localizations, VideoMonetizationDetails? monetizationDetails, VideoPaidProductPlacementDetails? paidProductPlacementDetails, VideoPlayer? player, VideoProcessingDetails? processingDetails, VideoProjectDetails? projectDetails, VideoRecordingDetails? recordingDetails, VideoSnippet? snippet, VideoStatistics? statistics, VideoStatus? status, VideoSuggestions? suggestions, VideoTopicDetails? topicDetails})
Video.fromJson(Map json_)

Properties

ageGating ↔ VideoAgeGating?
Age restriction details related to a video.
getter/setter pair
brandPartner ↔ BrandPartner?
getter/setter pair
contentDetails ↔ VideoContentDetails?
The contentDetails object contains information about the video content, including the length of the video and its aspect ratio.
getter/setter pair
etag ↔ String?
Etag of this resource.
getter/setter pair
fileDetails ↔ VideoFileDetails?
The fileDetails object encapsulates information about the video file that was uploaded to YouTube, including the file's resolution, duration, audio and video codecs, stream bitrates, and more.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID that YouTube uses to uniquely identify the video.
getter/setter pair
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
liveStreamingDetails ↔ VideoLiveStreamingDetails?
The liveStreamingDetails object contains metadata about a live video broadcast.
getter/setter pair
localizations ↔ Map<String, VideoLocalization>?
The localizations object contains localized versions of the basic details about the video, such as its title and description.
getter/setter pair
monetizationDetails ↔ VideoMonetizationDetails?
The monetizationDetails object encapsulates information about the monetization status of the video.
getter/setter pair
paidProductPlacementDetails ↔ VideoPaidProductPlacementDetails?
getter/setter pair
player ↔ VideoPlayer?
The player object contains information that you would use to play the video in an embedded player.
getter/setter pair
processingDetails ↔ VideoProcessingDetails?
The processingDetails object encapsulates information about YouTube's progress in processing the uploaded video file.
getter/setter pair
projectDetails ↔ TokenPagination?
The projectDetails object contains information about the project specific video metadata.
getter/setter pair
recordingDetails ↔ VideoRecordingDetails?
The recordingDetails object encapsulates information about the location, date and address where the video was recorded.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet ↔ VideoSnippet?
The snippet object contains basic details about the video, such as its title, description, and category.
getter/setter pair
statistics ↔ VideoStatistics?
The statistics object contains statistics about the video.
getter/setter pair
status ↔ VideoStatus?
The status object contains information about the video's uploading, processing, and privacy statuses.
getter/setter pair
suggestions ↔ VideoSuggestions?
The suggestions object encapsulates suggestions that identify opportunities to improve the video quality or the metadata for the uploaded video.
getter/setter pair
topicDetails ↔ VideoTopicDetails?
The topicDetails object encapsulates information about Freebase topics associated with the video.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited