VideoFileDetailsAudioStream class

Information about an audio stream.

Constructors

VideoFileDetailsAudioStream({String? bitrateBps, int? channelCount, String? codec, String? vendor})
VideoFileDetailsAudioStream.fromJson(Map json_)

Properties

bitrateBps ↔ String?
The audio stream's bitrate, in bits per second.
getter/setter pair
channelCount ↔ int?
The number of audio channels that the stream contains.
getter/setter pair
codec ↔ String?
The audio codec that the stream uses.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vendor ↔ String?
A value that uniquely identifies a video vendor.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited