VideoLocalization class

Localized versions of certain video properties (e.g. title).

Constructors

VideoLocalization({String? description, String? title})
VideoLocalization.fromJson(Map json_)

Properties

description ↔ String?
Localized version of the video's description.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Localized version of the video's title.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited