VideoPlayer class

Player to be used for a video playback.

Constructors

VideoPlayer({String? embedHeight, String? embedHtml, String? embedWidth})
VideoPlayer.fromJson(Map json_)

Properties

embedHeight ↔ String?
getter/setter pair
embedHtml ↔ String?
An <iframe> tag that embeds a player that will play the video.
getter/setter pair
embedWidth ↔ String?
The embed width
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited