VideoProcessingDetailsProcessingProgress class

Video processing progress and completion time estimate.

Properties

hashCode → int
The hash code for this object.
no setterinherited
partsProcessed ↔ String?
The number of parts of the video that YouTube has already processed.
getter/setter pair
partsTotal ↔ String?
An estimate of the total number of parts that need to be processed for the video.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeLeftMs ↔ String?
An estimate of the amount of time, in millseconds, that YouTube needs to finish processing the video.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited