contentDetails property
The VideoStatsContentDetails object contains information about the video content, including the length of the video.
Output only.
Implementation
VideoStatsContentDetails? contentDetails;
The VideoStatsContentDetails object contains information about the video content, including the length of the video.
Output only.
VideoStatsContentDetails? contentDetails;