VideoStatistics class

Statistics about the video, such as the number of times the video was viewed or liked.

Constructors

VideoStatistics({String? commentCount, String? dislikeCount, String? favoriteCount, String? likeCount, String? viewCount})
VideoStatistics.fromJson(Map json_)

Properties

commentCount ↔ String?
The number of comments for the video.
getter/setter pair
dislikeCount ↔ String?
The number of users who have indicated that they disliked the video by giving it a negative rating.
getter/setter pair
favoriteCount ↔ String?
The number of users who currently have the video marked as a favorite video.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
likeCount ↔ String?
The number of users who have indicated that they liked the video by giving it a positive rating.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewCount ↔ String?
The number of times the video has been viewed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited