VideoStatsContentDetails class
Details about the content of a YouTube Video.
This is a subset of the information in VideoContentDetails specifically for the Videos.stats API.
Constructors
- VideoStatsContentDetails({String? duration})
- VideoStatsContentDetails.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited