likeCount property
The number of users who have indicated that they liked the video by giving it a positive rating.
Output only.
Implementation
core.String? likeCount;
The number of users who have indicated that they liked the video by giving it a positive rating.
Output only.
core.String? likeCount;