VideoStatus class

Basic details about a video category, such as its localized title.

Next Id: 19

Constructors

VideoStatus({bool? containsSyntheticMedia, bool? embeddable, String? failureReason, String? license, bool? madeForKids, String? privacyStatus, bool? publicStatsViewable, DateTime? publishAt, String? rejectionReason, bool? selfDeclaredMadeForKids, String? uploadStatus})
VideoStatus.fromJson(Map json_)

Properties

containsSyntheticMedia ↔ bool?
Indicates if the video contains altered or synthetic media.
getter/setter pair
embeddable ↔ bool?
This value indicates if the video can be embedded on another website.
getter/setter pair
failureReason ↔ String?
This value explains why a video failed to upload.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
license ↔ String?
The video's license.
getter/setter pair
madeForKids ↔ bool?
getter/setter pair
privacyStatus ↔ String?
The video's privacy status. Possible string values are:
getter/setter pair
publicStatsViewable ↔ bool?
This value indicates if the extended video statistics on the watch page can be viewed by everyone.
getter/setter pair
publishAt ↔ DateTime?
The date and time when the video is scheduled to publish.
getter/setter pair
rejectionReason ↔ String?
This value explains why YouTube rejected an uploaded video.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selfDeclaredMadeForKids ↔ bool?
getter/setter pair
uploadStatus ↔ String?
The status of the uploaded video. Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited