VideoTrainability class

Specifies who is allowed to train on the video.

Constructors

VideoTrainability({String? etag, String? kind, List<String>? permitted, String? videoId})
VideoTrainability.fromJson(Map json_)

Properties

etag ↔ String?
Etag of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Identifies what kind of resource this is.
getter/setter pair
permitted ↔ List<String>?
Specifies who is allowed to train on the video.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoId ↔ String?
The ID of the video.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited