batchGetStats method
Retrieves a batch of VideoStat resources, possibly filtered.
BatchGetStats is intentionally not atomic to provide a better user experience.
Request parameters:
id - Required. Return videos with the given ids. The number of IDs
specified cannot exceed 50.
onBehalfOfContentOwner - Optional. Note: This parameter is intended
exclusively for YouTube content partners. The onBehalfOfContentOwner
parameter indicates that the request's authorization credentials identify
a YouTube CMS user who is acting on behalf of the content owner specified
in the parameter value. This parameter is intended for YouTube content
partners that own and manage many different YouTube channels. It allows
content owners to authenticate once and get access to all their video and
channel data, without having to provide authentication credentials for
each individual channel. The CMS account that the user authenticates with
must be linked to the specified YouTube content owner.
part - Required. The **part** parameter specifies a comma-separated
list of one or more videoStat resource properties that the API response
will include. If the parameter identifies a property that contains child
properties, the child properties will be included in the response. For
example, in a videoStat resource, the statistics property contains
view_count and like_count. As such, if you set **part=snippet**, the
API response will contain all of those properties.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a BatchGetStatsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<BatchGetStatsResponse> batchGetStats({
core.List<core.String>? id,
core.String? onBehalfOfContentOwner,
core.List<core.String>? part,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'id': ?id,
'onBehalfOfContentOwner': ?onBehalfOfContentOwner == null
? null
: [onBehalfOfContentOwner],
'part': ?part,
'fields': ?$fields == null ? null : [$fields],
};
const url_ = 'youtube/v3/videos:batchGetStats';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return BatchGetStatsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}