ErrorProto class

Describes one specific error.

Constructors

ErrorProto({List<String>? argument, String? code, String? debugInfo, String? domain, String? externalErrorMessage, String? location, String? locationType})
ErrorProto.fromJson(Map json_)

Properties

argument ↔ List<String>?
Error arguments, to be used when building user-friendly error messages given the error domain and code.
getter/setter pair
code ↔ String?
Error code in the error domain.
getter/setter pair
debugInfo ↔ String?
Debugging information, which should not be shared externally.
getter/setter pair
domain ↔ String?
Error domain.
getter/setter pair
externalErrorMessage ↔ String?
A short explanation for the error, which can be shared outside Google.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
Location of the error, as specified by the location type.
getter/setter pair
locationType ↔ String?
Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited