Errors class

Request Error information.

The presence of an error field signals that the operation has failed.

Constructors

Errors({String? code, List<ErrorProto>? error, String? requestId})
Errors.fromJson(Map json_)

Properties

code ↔ String?
Global error code.
getter/setter pair
error ↔ List<ErrorProto>?
Specific error description and codes
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
requestId ↔ String?
Request identifier generated by the service, which can be used to identify the error in the logs
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited