Group class

A group.

Constructors

Group({GroupContentDetails? contentDetails, Errors? errors, String? etag, String? id, String? kind, GroupSnippet? snippet})
Group.fromJson(Map json_)

Properties

contentDetails ↔ GroupContentDetails?
The contentDetails object contains additional information about the group, such as the number and type of items that it contains.
getter/setter pair
errors ↔ Errors?
Apiary error details
getter/setter pair
etag ↔ String?
The Etag of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID that YouTube uses to uniquely identify the group.
getter/setter pair
kind ↔ String?
Identifies the API resource's type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet ↔ GroupSnippet?
The snippet object contains basic information about the group, including its creation date and name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited