GroupItem class

A group item.

Constructors

GroupItem({Errors? errors, String? etag, String? groupId, String? id, String? kind, GroupItemResource? resource})
GroupItem.fromJson(Map json_)

Properties

errors ↔ Errors?
Apiary error details
getter/setter pair
etag ↔ String?
The Etag of this resource.
getter/setter pair
groupId ↔ String?
The ID that YouTube uses to uniquely identify the group that contains the item.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The ID that YouTube uses to uniquely identify the channel, video, playlist, or asset resource that is included in the group.
getter/setter pair
kind ↔ String?
Identifies the API resource's type.
getter/setter pair
resource ↔ GroupItemResource?
The resource object contains information that identifies the item being added to the group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited