GroupItemResource class

Constructors

GroupItemResource({String? id, String? kind})
GroupItemResource.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The channel, video, playlist, or asset ID that YouTube uses to uniquely identify the item that is being added to the group.
getter/setter pair
kind ↔ String?
Identifies the type of resource being added to the group.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited