ListGroupsResponse class

Response message for GroupsService.ListGroups.

Constructors

ListGroupsResponse({Errors? errors, String? etag, List<Group>? items, String? kind, String? nextPageToken})
ListGroupsResponse.fromJson(Map json_)

Properties

errors ↔ Errors?
Apiary error details
getter/setter pair
etag ↔ String?
The Etag of this resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
items ↔ List<Group>?
A list of groups that match the API request parameters.
getter/setter pair
kind ↔ String?
Identifies the API resource's type.
getter/setter pair
nextPageToken ↔ String?
The token that can be used as the value of the pageToken parameter to retrieve the next page in the result set.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited