QueryResponse class

Response message for TargetedQueriesService.Query.

Constructors

QueryResponse({List<ResultTableColumnHeader>? columnHeaders, Errors? errors, String? kind, List<List<Object?>>? rows})
QueryResponse.fromJson(Map json_)

Properties

columnHeaders ↔ List<ResultTableColumnHeader>?
This value specifies information about the data returned in the rows fields.
getter/setter pair
errors ↔ Errors?
When set, indicates that the operation failed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
This value specifies the type of data included in the API response.
getter/setter pair
rows ↔ List<List<Object?>>?
The list contains all rows of the result table.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited