restrictedClientApplications property
- @Deprecated('Not supported. Member documentation may have more information.')
getter/setter pair
Deprecated: Use scoped_access_settings instead.
A list of applications that are subject to this binding's restrictions. If the list is empty, the binding restrictions will universally apply to all applications.
Optional.
Implementation
@core.Deprecated(
'Not supported. Member documentation may have more information.',
)
core.List<Application>? restrictedClientApplications;