pscEndpoint property
A PrivateServiceConnectEndpoint that is allowed to access the perimeter.
The Private Service Connect endpoint may be in any organization, not just the organization that the perimeter is defined in.
Implementation
PrivateServiceConnectEndpoint? pscEndpoint;