federatedPrincipal property
The IAM principal identifier of the federated workforce or workload to assign the policy to.
Examples include the following: * Single principal:
principal://iam.googleapis.com/projects/{project_number}/locations/global/workloadIdentityPools/{pool_id}/subject/{subject_attribute_value}
- All workloads in a workload identity pool:
principalSet://iam.googleapis.com/projects/{project_number}/locations/global/workloadIdentityPools/{pool_id} / ** All Workforce Pools in a Google Cloud organization:principalSet://cloudresourcemanager.googleapis.com/organizations/{organization_id}/type/WorkforcePoolBindings created for all Workforce Pools in a Google Cloud organization support onlyscoped_access_settingswith therestricted_projectclient scope and activesession_settings. No other configurations are allowed.
Immutable.
Implementation
core.String? federatedPrincipal;