VpcAccessibleServices class
Specifies how APIs are allowed to communicate within the Service Perimeter.
Constructors
-
VpcAccessibleServices({List<
ServicePattern> ? allowedServicePatterns, List<String> ? allowedServices, bool? enableRestriction, List<String> ? servicePatternsEnforcementScopes}) - VpcAccessibleServices.fromJson(Map json_)
Properties
-
allowedServicePatterns
↔ List<
ServicePattern> ? -
Specifies which Google services are allowed to be accessed from VPC
networks in the service perimeter.
getter/setter pair
-
allowedServices
↔ List<
String> ? -
The list of APIs usable within the Service Perimeter.
getter/setter pair
- enableRestriction ↔ bool?
-
Whether to restrict API calls within the Service Perimeter to the list of
APIs specified in 'allowed_services'.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
servicePatternsEnforcementScopes
↔ List<
String> ? -
Defines the enforcement scopes of service patterns.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited