externalIds property
The list of external IDs for the group, such as an immutable identifier from an external identity provider or directory sync client.
Each entry contains a namespace and an ID value.
Optional.
Implementation
core.List<ExternalId>? externalIds;