OwnerDetails class
Details of the owner of the resource.
Constructors
-
OwnerDetails({List<
OwnerIdentity> ? ownerIdentity, String? ownerType}) - OwnerDetails.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ownerIdentity
↔ List<
OwnerIdentity> ? -
Identity details of the owner(s) of the resource.
getter/setter pair
- ownerType ↔ String?
-
Type of the owner of the resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited