admin/reports_v1 library
Admin SDK API - reports_v1
Admin SDK lets administrators of enterprise domains to view and manage resources like user, groups etc. It also provides audit and usage reports of domain.
For more information, see developers.google.com/workspace/admin/
Create an instance of ReportsApi to access these resources:
Classes
- Activities
- JSON template for a collection of activities.
- ActivitiesResource
- Activity
- JSON template for the activity resource.
- ActivityActor
- User doing the action.
- ActivityActorApplicationInfo
- Details of the application that was the actor for the activity.
- ActivityEvents
- ActivityEventsParameters
- ActivityEventsParametersMessageValue
- Nested parameter value pairs associated with this parameter.
- ActivityEventsParametersMultiMessageValue
- ActivityEventsSensitiveParameters
- ActivityEventsSensitiveParametersMessageValue
- Nested parameter value pairs associated with this parameter.
- ActivityEventsSensitiveParametersMultiMessageValue
- ActivityEventsStatus
- Status of the event.
- ActivityId
- Unique identifier for each activity record.
- ActivityNetworkInfo
- Network information of the user doing the action.
- ActivityUserDeviceInfo
- Device details of the user doing the action.
- AgentAttributionInfo
- Details of the AI agent that was the actor for the activity.
- AgentAttributionInfoAgentOwner
- Details of the owner of the AI agent.
- AppliedLabel
- Details of the label applied on the resource.
- Channel
- A notification channel used to watch for resource changes.
- ChannelsResource
- CustomerIdentity
- Identity of the Google Workspace customer who owns the resource.
- CustomerUsageReportsResource
- EntityUsageReportsResource
- FieldValue
- Details of the field value set by the user for the particular label.
- FieldValueSelectionListValue
- Setting a selection list value by selecting multiple values from a dropdown.
- FieldValueSelectionValue
- Setting a selection value by selecting a single value from a dropdown.
- FieldValueUserListValue
- Setting a user list value by selecting multiple users.
- FieldValueUserValue
- Setting a user value by selecting a single user.
- GroupIdentity
- Identity of the group who owns the resource.
- NestedParameter
- JSON template for a parameter used in various reports.
- OwnerDetails
- Details of the owner of the resource.
- OwnerIdentity
- Identity details of the owner of the resource.
- Reason
- The reason why the label/field was applied.
- ReportsApi
- Admin SDK lets administrators of enterprise domains to view and manage resources like user, groups etc.
- ResourceDetails
- Details of the resource on which the action was performed.
- Identity of the shared drive who owns the resource.
- UsageReport
- JSON template for a usage report.
- UsageReportEntity
- Information about the type of the item.
- UsageReportParameters
- UsageReports
- UsageReportsWarnings
- UsageReportsWarningsData
- UserIdentity
- Identity of the user who owns the resource.
- UserUsageReportResource
Typedefs
- Date = $Date
- Represents a whole or partial calendar date, such as a birthday.
- FieldValueTextListValue = $Shared12
- Setting a text list value.
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.