allowedScopes property
List of scopes that are allowed to be requested for this auth_provider.
If this list is non-empty, only scopes within this list may be requested.
If this list is empty, all scopes may be requested. Scopes appearing in
blocked_scopes are disallowed even if they appear in allowed_scopes.
The number of allowed scopes is limited to 200.
Optional.
Implementation
core.List<core.String>? allowedScopes;