AuthProviderTypeParams class

AuthProvider type specific parameters.

Required when creating an auth_provider.

Constructors

AuthProviderTypeParams({ApiKeyParams? apiKey, GeminiEnterpriseAuthProviderParams? geAuthProvider, ThreeLeggedOAuth? threeLeggedOauth, TwoLeggedOAuth? twoLeggedOauth})
AuthProviderTypeParams.fromJson(Map json_)

Properties

apiKey ApiKeyParams?
ApiKey AuthProvider type parameters.
getter/setter pair
geAuthProvider GeminiEnterpriseAuthProviderParams?
GeminiEnterprise auth_provider type parameters.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threeLeggedOauth ThreeLeggedOAuth?
ThreeLeggedOAuth AuthProvider type parameters.
getter/setter pair
twoLeggedOauth TwoLeggedOAuth?
TwoLeggedOAuth AuthProvider type parameters.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited