list method
Lists AuthProviders in a given project and location.
Request parameters:
parent - Required. The parent resource where the search is performed.
Format: projects/{project}/locations/{location}
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
filter - Optional. Filter results. This field is currently ignored.
orderBy - Optional. Currently ignored. Defaults to ordering by
auth_provider_id in ascending order.
pageSize - Optional. Requested page size. Server may return fewer items
than requested. If unspecified, server will pick an appropriate default.
pageToken - Optional. A token, which can be sent as page_token to
retrieve the next page. If this field is omitted, the first page is
returned.
showDeleted - Optional. Deleted auth_providers will be kept with a
soft-delete for 30 days before being purged. If this field is set to true,
deleted auth_providers will also be returned.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ListAuthProvidersResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ListAuthProvidersResponse> list(
core.String parent, {
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.bool? showDeleted,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'showDeleted': ?showDeleted == null ? null : ['${showDeleted}'],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/authProviders';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ListAuthProvidersResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}