query method
Queries what all auth_providers are used by a given workload_id.
Request parameters:
parent - Required. The parent resource where the search is performed.
Format: projects/{project}/locations/{location}
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
pageSize - Optional. Requested page size. Server may return fewer items
than requested. If unspecified, server will pick an appropriate default.
The maximum page size is 1000.
pageToken - Optional. A token, which can be sent as page_token to
retrieve the next page. If this field is omitted, the first page is
returned. A page token, received from a previous QueryAuthProviders call.
Provide this to retrieve the subsequent page. When paginating, all other
parameters provided to QueryAuthProviders must match the call that
provided the page token.
workloadId - Required. The workload identifier to filter by.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a QueryAuthProvidersResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<QueryAuthProvidersResponse> query(
core.String parent, {
core.int? pageSize,
core.String? pageToken,
core.String? workloadId,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'workloadId': ?workloadId == null ? null : [workloadId],
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'v1/' + core.Uri.encodeFull('$parent') + '/authProviders:query';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return QueryAuthProvidersResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}