queryWorkloads method
Queries what all workloads are using a given auth_provider.
Request parameters:
name - Required. The name of the auth_provider to query. Format:
projects/{project}/locations/{location}/authProviders/{auth_provider}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/authProviders/\[^/\]+$.
pageSize - Optional. Requested page size. Server may return fewer items
than requested. If unspecified, server will pick an appropriate default.
pageToken - Optional. A token, which can be sent as page_token to
retrieve the next page. When paginating, all other parameters provided to
QueryWorkloads must match the call that provided the page token. If this
field is omitted, the first page is returned.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a QueryWorkloadsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<QueryWorkloadsResponse> queryWorkloads(
core.String name, {
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name') + ':queryWorkloads';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return QueryWorkloadsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}