ThreeLeggedOAuth class
Message describing ThreeLeggedOAuth object.
Constructors
- ThreeLeggedOAuth({String? authorizationUrl, String? clientId, String? clientSecret, String? defaultContinueUri, bool? enablePkce, String? redirectUrl, String? tokenUrl})
- ThreeLeggedOAuth.fromJson(Map json_)
Properties
-
The authorization endpoint to send users to for consenting to delegate to
the agent.
getter/setter pair
- clientId ↔ String?
-
The client ID of the OAuth client.
getter/setter pair
- clientSecret ↔ String?
-
Input only.
getter/setter pair
- defaultContinueUri ↔ String?
-
The default continue URI for 3LO flow and it will be used when no continue
URI is provided in the RetrieveCredentials request.
getter/setter pair
- enablePkce ↔ bool?
-
Enables Proof Key for Code Exchange (PKCE) for the OAuth flow to prevent
authorization code interception attacks.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- redirectUrl ↔ String?
-
The redirect URL this auth_provider uses for the OAuth exchange.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tokenUrl ↔ String?
-
The token endpoint for requesting tokens on behalf of an end user.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited