ProjectsLocationsAuthProvidersCredentialsResource class
Constructors
- ProjectsLocationsAuthProvidersCredentialsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
finalize(
GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsRequest request, String authProvider, {String? $fields}) → Future< GoogleCloudAgentidentitycredentialsV1FinalizeCredentialsResponse> - Finalizes the credentials after a successful consent flow.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
retrieve(
GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsRequest request, String authProvider, {String? $fields}) → Future< GoogleCloudAgentidentitycredentialsV1RetrieveCredentialsResponse> - Retrieves authorization credentials for an auth provider, or indicates what action needs to be taken to obtain credentials.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited