agentregistry/v1 library
Agent Registry API - v1
Agent Registry is a centralized, unified catalog that lets you store, discover, and govern Model Context Protocol (MCP) servers, tools, and AI agents within Google Cloud.
For more information, see docs.cloud.google.com/agent-registry/overview
Create an instance of AgentRegistryApi to access these resources:
Classes
- A2ASkill
- Represents the skills of an Agent.
- Agent
- Represents an Agent.
- AgentRegistryApi
- Agent Registry is a centralized, unified catalog that lets you store, discover, and govern Model Context Protocol (MCP) servers, tools, and AI agents within Google Cloud.
- AgentSpec
- The spec of the agent.
- Annotations
- Annotations describing the characteristics and behavior of a tool or operation.
- AuthProviderBinding
- The AuthProvider of the Binding.
- Binding
- Represents a user-defined Binding.
- Card
- Full Agent Card payload, often obtained from the A2A Agent Card.
- Endpoint
- Represents an Endpoint.
- EndpointSpec
- The spec of the endpoint.
- FetchAvailableBindingsResponse
- Message for response to fetching available Bindings.
- Interface
- Represents the connection details for an Agent or MCP Server.
- ListAgentsResponse
- Message for response to listing Agents
- ListBindingsResponse
- Message for response to listing Bindings
- ListEndpointsResponse
- Message for response to listing Endpoints
- ListLocationsResponse
- The response message for Locations.ListLocations.
- ListMcpServersResponse
- Message for response to listing McpServers
- ListOperationsResponse
- The response message for Operations.ListOperations.
- ListServicesResponse
- Message for response to listing Services
- McpServer
- Represents an MCP (Model Context Protocol) Server.
- McpServerSpec
- The spec of the MCP Server.
- Operation
- This resource represents a long-running operation that is the result of a network API call.
- ProjectsLocationsAgentsResource
- ProjectsLocationsBindingsResource
- ProjectsLocationsEndpointsResource
- ProjectsLocationsMcpServersResource
- ProjectsLocationsOperationsResource
- ProjectsLocationsResource
- ProjectsLocationsServicesResource
- ProjectsResource
- Protocol
- Represents the protocol of an Agent.
- SearchAgentsRequest
- Message for searching Agents
- SearchAgentsResponse
- Message for response to searching Agents
- SearchMcpServersRequest
- Message for searching MCP Servers
- SearchMcpServersResponse
- Message for response to searching MCP Servers
- Service
- Represents a user-defined Service.
- Source
- The source of the Binding.
- Target
- The target of the Binding.
- Tool
- Represents a single tool provided by an MCP Server.
Typedefs
- CancelOperationRequest = $Empty
- The request message for Operations.CancelOperation.
- Empty = $Empty
- A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
- Location = $Location00
- A resource that represents a Google Cloud location.
- Status = $Status00
-
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs.
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.