Agent class
Represents an Agent.
"A2A" below refers to the Agent-to-Agent protocol.
Constructors
-
Agent({String? agentId, Map<
String, Map< ? attributes, Card? card, String? createTime, String? description, String? displayName, String? location, String? name, List<String, Object?> >Protocol> ? protocols, List<A2ASkill> ? skills, String? uid, String? updateTime, String? version}) - Agent.fromJson(Map json_)
Properties
- agentId ↔ String?
-
A stable, globally unique identifier for agents.
getter/setter pair
-
attributes
↔ Map<
String, Map< ?String, Object?> > -
Attributes of the Agent.
getter/setter pair
- card ↔ Card?
-
Full Agent Card payload, when available.
getter/setter pair
- createTime ↔ String?
-
Create time.
getter/setter pair
- description ↔ String?
-
The description of the Agent, often obtained from the A2A Agent Card.
getter/setter pair
- displayName ↔ String?
-
The display name of the agent, often obtained from the A2A Agent Card.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- location ↔ String?
-
The location where agent is hosted.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
-
protocols
↔ List<
Protocol> ? -
The connection details for the Agent.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
skills
↔ List<
A2ASkill> ? -
Skills the agent possesses, often obtained from the A2A Agent Card.
getter/setter pair
- uid ↔ String?
-
A universally unique identifier for the Agent.
getter/setter pair
- updateTime ↔ String?
-
Update time.
getter/setter pair
- version ↔ String?
-
The version of the Agent, often obtained from the A2A Agent Card.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited