version property
The version of the Agent, often obtained from the A2A Agent Card.
Empty if Agent Card has no version or agent is not an A2A Agent.
Output only.
Implementation
core.String? version;
The version of the Agent, often obtained from the A2A Agent Card.
Empty if Agent Card has no version or agent is not an A2A Agent.
Output only.
core.String? version;