Binding class

Represents a user-defined Binding.

Constructors

Binding({AuthProviderBinding? authProviderBinding, String? createTime, String? description, String? displayName, String? name, Source? source, Target? target, String? updateTime})
Binding.fromJson(Map json_)

Properties

authProviderBinding AuthProviderBinding?
The binding for AuthProvider.
getter/setter pair
createTime String?
Timestamp when this binding was created.
getter/setter pair
description String?
User-defined description of a Binding.
getter/setter pair
displayName String?
User-defined display name for the Binding.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source Source?
The target Agent of the Binding.
getter/setter pair
target Target?
The target Agent Registry Resource of the Binding.
getter/setter pair
updateTime String?
Timestamp when this binding was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited