Endpoint class
Represents an Endpoint.
Constructors
Properties
-
attributes
↔ Map<
String, Map< ?String, Object?> > -
Attributes of the Endpoint.
getter/setter pair
- createTime ↔ String?
-
Create time.
getter/setter pair
- description ↔ String?
-
Description of an Endpoint.
getter/setter pair
- displayName ↔ String?
-
Display name for the Endpoint.
getter/setter pair
- endpointId ↔ String?
-
A stable, globally unique identifier for Endpoint.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interfaces
↔ List<
Interface> ? -
The connection details for the Endpoint.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateTime ↔ String?
-
Update time.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited