McpServer class
Represents an MCP (Model Context Protocol) Server.
Constructors
Properties
-
attributes
↔ Map<
String, Map< ?String, Object?> > -
Attributes of the MCP Server.
getter/setter pair
- createTime ↔ String?
-
Create time.
getter/setter pair
- description ↔ String?
-
The description of the MCP Server.
getter/setter pair
- displayName ↔ String?
-
The display name of the MCP Server.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
interfaces
↔ List<
Interface> ? -
The connection details for the MCP Server.
getter/setter pair
- mcpServerId ↔ String?
-
A stable, globally unique identifier for MCP Servers.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tools
↔ List<
Tool> ? -
Tools provided by the MCP Server.
getter/setter pair
- updateTime ↔ String?
-
Update time.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited