McpServerSpec class

The spec of the MCP Server.

Constructors

McpServerSpec({Map<String, Object?>? content, String? type})
McpServerSpec.fromJson(Map json_)

Properties

content Map<String, Object?>?
The content of the MCP Server spec.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The type of the MCP Server spec content.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited