content property
The content of the MCP Server spec.
This payload is validated against the schema for the specified type. The
content size is limited to 10KB.
Optional.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Object?>? content;