SearchAgentsRequest class

Message for searching Agents

Constructors

SearchAgentsRequest({int? pageSize, String? pageToken, String? searchString})
SearchAgentsRequest.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
pageSize int?
The maximum number of search results to return per page.
getter/setter pair
pageToken String?
If present, retrieve the next batch of results from the preceding call to this method.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchString String?
Search criteria used to select the Agents to return.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited