searchString property
Search criteria used to select the Agents to return.
If no search criteria is specified then all accessible Agents will be
returned. Search expressions can be used to restrict results based upon
searchable fields, where the operators can be used along with the suffix
wildcard symbol *. See
instructions
for more details. Allowed operators: =, :, NOT, AND, OR, and
(). Searchable fields: | Field | = | : | * | Keyword Search |
|--------------------|-----|-----|-----|----------------| | agentId | Yes
| Yes | Yes | Included | | name | No | Yes | Yes | Included | |
displayName | No | Yes | Yes | Included | | description | No | Yes | No |
Included | | skills | No | Yes | No | Included | | skills.id | No | Yes |
No | Included | | skills.name | No | Yes | No | Included | |
skills.description | No | Yes | No | Included | | skills.tags | No | Yes |
No | Included | | skills.examples | No | Yes | No | Included | Examples: *
agentId="urn:agent:projects-123:projects:123:locations:us-central1:reasoningEngines:1234"
to find the agent with the specified agent ID. * name:important to find
agents whose name contains important as a word. * displayName:works*
to find agents whose display name contains words that start with works.
skills.tags:testto find agents whose skills tags containtest. *planner OR bookingto find agents whose metadata contains the wordsplannerorbooking.
Optional.
Implementation
core.String? searchString;