inputGcsUri property
Input Cloud Storage URI for the Async query.
If you are not bringing your own container (BYOC), the content of the file
should be a JSON object with an input field matching the input field
of QueryReasoningEngineRequest (e.g. { "input": { "user_id": "hello", "message":"$QUERY"} }). For BYOC, the content of the file depends on the
the agent application.
Optional.
Implementation
core.String? inputGcsUri;