GoogleCloudAiplatformV1Chunk class
Container for bytes-encoded data such as video frame, audio sample, or a complete binary/text data.
Constructors
- GoogleCloudAiplatformV1Chunk({String? data, GoogleCloudAiplatformV1Metadata? metadata, String? mimeType})
- GoogleCloudAiplatformV1Chunk.fromJson(Map json_)
Properties
- data ↔ String?
-
The data in the chunk.
getter/setter pair
-
dataAsBytes
↔ List<
int> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- metadata ↔ GoogleCloudAiplatformV1Metadata?
-
Metadata that is associated with the data in the payload.
getter/setter pair
- mimeType ↔ String?
-
Mime type of the chunk data.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited