GoogleCloudAiplatformV1EmbedContentRequest class
Request message for PredictionService.EmbedContent.
Constructors
- GoogleCloudAiplatformV1EmbedContentRequest({bool? autoTruncate, GoogleCloudAiplatformV1Content? content, int? outputDimensionality, String? taskType, String? title})
- GoogleCloudAiplatformV1EmbedContentRequest.fromJson(Map json_)
Properties
- autoTruncate ↔ bool?
-
Whether to silently truncate the input content if it's longer than the
maximum sequence length.
getter/setter pair
- content ↔ GoogleCloudAiplatformV1Content?
-
Input content to be embedded.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputDimensionality ↔ int?
-
Optional reduced dimension for the output embedding.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskType ↔ String?
-
The task type of the embedding.
getter/setter pair
- title ↔ String?
-
An optional title for the text.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited