GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig class
Configurations for the EmbedContent API.
Constructors
- GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig({bool? audioTrackExtraction, bool? autoTruncate, bool? documentOcr, int? outputDimensionality, String? taskType, String? title})
- GoogleCloudAiplatformV1EmbedContentRequestEmbedContentConfig.fromJson(Map json_)
Properties
- audioTrackExtraction ↔ bool?
-
Whether to extract audio from video content.
getter/setter pair
- autoTruncate ↔ bool?
-
Whether to silently truncate the input content if it's longer than the
maximum sequence length.
getter/setter pair
- documentOcr ↔ bool?
-
Whether to enable OCR for document content.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- outputDimensionality ↔ int?
-
Reduced dimension for the output embedding.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskType ↔ String?
-
The task type of the embedding.
getter/setter pair
- title ↔ String?
-
The title for the text.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited