GoogleCloudAiplatformV1EvaluationRunInferenceConfigAgentRunConfigUserSimulatorConfig class
Used for multi-turn agent scraping.
Contains configuration for a user simulator that uses an LLM to generate messages on behalf of the user.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxTurn ↔ int?
-
Maximum number of invocations allowed by the multi-turn agent scraping.
getter/setter pair
- modelConfig ↔ GoogleCloudAiplatformV1GenerationConfig?
-
The configuration for the model.
getter/setter pair
- modelName ↔ String?
-
The model name to use for multi-turn agent scraping to get next user
message, e.g. "gemini-3-flash-preview".
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited