partial property
Indicates whether the text content is part of a unfinished text stream.
Only used for streaming mode and when the content is plain text.
Optional.
Implementation
core.bool? partial;
Indicates whether the text content is part of a unfinished text stream.
Only used for streaming mode and when the content is plain text.
Optional.
core.bool? partial;