GoogleCloudAiplatformV1ExecutableCode class
Code generated by the model that is meant to be executed, and the result returned to the model.
Generated when using the CodeExecution tool, in which the code will be
automatically executed, and a corresponding CodeExecutionResult will also be
generated.
Constructors
- GoogleCloudAiplatformV1ExecutableCode({String? code, String? id, String? language})
- GoogleCloudAiplatformV1ExecutableCode.fromJson(Map json_)
Properties
- code ↔ String?
-
The code to be executed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
Unique identifier of the
ExecutableCodepart.getter/setter pair - language ↔ String?
-
Programming language of the
code.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited