GoogleCloudAiplatformV1FeatureOnlineStoreBigtable class
Constructors
- GoogleCloudAiplatformV1FeatureOnlineStoreBigtable({GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling? autoScaling, GoogleCloudAiplatformV1FeatureOnlineStoreBigtableBigtableMetadata? bigtableMetadata, bool? enableDirectBigtableAccess, String? zone})
- GoogleCloudAiplatformV1FeatureOnlineStoreBigtable.fromJson(Map json_)
Properties
- autoScaling ↔ GoogleCloudAiplatformV1FeatureOnlineStoreBigtableAutoScaling?
-
Autoscaling config applied to Bigtable Instance.
getter/setter pair
- bigtableMetadata ↔ GoogleCloudAiplatformV1FeatureOnlineStoreBigtableBigtableMetadata?
-
Metadata of the Bigtable instance.
getter/setter pair
- enableDirectBigtableAccess ↔ bool?
-
It true, enable direct access to the Bigtable instance.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zone ↔ String?
-
The zone where the underlying Bigtable cluster for the primary Bigtable
instance will be provisioned.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited