GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSources class
The sources that were used to generate the place answer.
This includes review snippets and photos that were used to generate the answer, as well as URIs to flag content.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
reviewSnippets
↔ List<
GoogleCloudAiplatformV1GroundingChunkMapsPlaceAnswerSourcesReviewSnippet> ? -
Snippets of reviews that were used to generate the answer.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited