GoogleCloudAiplatformV1GroundingMetadata class
Information about the sources that support the content of a response.
When grounding is enabled, the model returns citations for claims in the response. This object contains the retrieved sources.
Constructors
-
GoogleCloudAiplatformV1GroundingMetadata({String? googleMapsWidgetContextToken, List<
GoogleCloudAiplatformV1GroundingChunk> ? groundingChunks, List<GoogleCloudAiplatformV1GroundingSupport> ? groundingSupports, GoogleCloudAiplatformV1RetrievalMetadata? retrievalMetadata, GoogleCloudAiplatformV1SearchEntryPoint? searchEntryPoint, List<GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri> ? sourceFlaggingUris, List<String> ? webSearchQueries}) - GoogleCloudAiplatformV1GroundingMetadata.fromJson(Map json_)
Properties
- googleMapsWidgetContextToken ↔ String?
-
A token that can be used to render a Google Maps widget with the
contextual data.
getter/setter pair
-
groundingChunks
↔ List<
GoogleCloudAiplatformV1GroundingChunk> ? -
A list of supporting references retrieved from the grounding source.
getter/setter pair
-
groundingSupports
↔ List<
GoogleCloudAiplatformV1GroundingSupport> ? -
A list of grounding supports that connect the generated content to the
grounding chunks.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- retrievalMetadata ↔ GoogleCloudAiplatformV1RetrievalMetadata?
-
Metadata related to the retrieval grounding source.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchEntryPoint ↔ GoogleCloudAiplatformV1SearchEntryPoint?
-
A web search entry point that can be used to display search results.
getter/setter pair
-
sourceFlaggingUris
↔ List<
GoogleCloudAiplatformV1GroundingMetadataSourceFlaggingUri> ? -
A list of URIs that can be used to flag a place or review for
inappropriate content.
getter/setter pair
-
webSearchQueries
↔ List<
String> ? -
The web search queries that were used to generate the content.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited