GoogleCloudAiplatformV1GroundingSupport class
A collection of supporting references for a segment of the model's response.
Constructors
-
GoogleCloudAiplatformV1GroundingSupport({List<
double> ? confidenceScores, List<int> ? groundingChunkIndices, GoogleCloudAiplatformV1Segment? segment}) - GoogleCloudAiplatformV1GroundingSupport.fromJson(Map json_)
Properties
-
confidenceScores
↔ List<
double> ? -
The confidence scores for the support references.
getter/setter pair
-
groundingChunkIndices
↔ List<
int> ? -
A list of indices into the
grounding_chunksfield of theGroundingMetadatamessage.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segment ↔ GoogleCloudAiplatformV1Segment?
-
The content segment that this support message applies to.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited