GoogleCloudAiplatformV1ImageConfig class
Configuration for image generation.
This message allows you to control various aspects of image generation, such as the output format, aspect ratio, and whether the model can generate images of people.
Constructors
- GoogleCloudAiplatformV1ImageConfig({String? aspectRatio, GoogleCloudAiplatformV1ImageConfigImageOutputOptions? imageOutputOptions, String? imageSize, String? personGeneration})
- GoogleCloudAiplatformV1ImageConfig.fromJson(Map json_)
Properties
- aspectRatio ↔ String?
-
The desired aspect ratio for the generated images.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageOutputOptions ↔ GoogleCloudAiplatformV1ImageConfigImageOutputOptions?
-
The image output format for generated images.
getter/setter pair
- imageSize ↔ String?
-
Specifies the size of generated images.
getter/setter pair
- personGeneration ↔ String?
-
Controls whether the model can generate people.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited