scope property
The scope of the memories that should be generated from the stream.
Memories will be consolidated across memories with the same scope. Scope values cannot contain the wildcard character '*'.
Required.
Implementation
core.Map<core.String, core.String>? scope;