GoogleCloudAiplatformV1LogprobsResult class
The log probabilities of the tokens generated by the model.
This is useful for understanding the model's confidence in its predictions and for debugging. For example, you can use log probabilities to identify when the model is making a less confident prediction or to explore alternative responses that the model considered. A low log probability can also indicate that the model is "hallucinating" or generating factually incorrect information.
Constructors
-
GoogleCloudAiplatformV1LogprobsResult({List<
GoogleCloudAiplatformV1LogprobsResultCandidate> ? chosenCandidates, List<GoogleCloudAiplatformV1LogprobsResultTopCandidates> ? topCandidates}) - GoogleCloudAiplatformV1LogprobsResult.fromJson(Map json_)
Properties
-
chosenCandidates
↔ List<
GoogleCloudAiplatformV1LogprobsResultCandidate> ? -
A list of the chosen candidate tokens at each decoding step.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
topCandidates
↔ List<
GoogleCloudAiplatformV1LogprobsResultTopCandidates> ? -
A list of the top candidate tokens at each decoding step.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited