GoogleCloudAiplatformV1MemoryGenerationTriggerConfigGenerationTriggerRule class

Represents the active rule that determines when to flush the buffer.

Properties

eventCount int?
Specifies to trigger generation when the event count reaches this limit.
getter/setter pair
fixedInterval String?
Specifies to trigger generation at a fixed interval.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
idleDuration String?
Specifies to trigger generation if the stream is inactive for the specified duration after the most recent event.
getter/setter pair
overlapEventCount int?
Re-include the last N already-processed events in the next window.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited