GoogleCloudAiplatformV1MemoryMetadataValue class
Memory metadata.
Constructors
- GoogleCloudAiplatformV1MemoryMetadataValue({bool? boolValue, double? doubleValue, String? stringValue, String? timestampValue})
- GoogleCloudAiplatformV1MemoryMetadataValue.fromJson(Map json_)
Properties
- boolValue ↔ bool?
-
Boolean value.
getter/setter pair
- doubleValue ↔ double?
-
Double value.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringValue ↔ String?
-
String value.
getter/setter pair
- timestampValue ↔ String?
-
Timestamp value.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited