GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntime class
Configuration for a Workbench Instances-based environment.
Constructors
- GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntime({GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntimeContainerImage? customContainerImage, GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntimeVmImage? vmImage})
- GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntime.fromJson(Map json_)
Properties
- customContainerImage ↔ GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntimeContainerImage?
-
A user-provided container image.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vmImage ↔ GoogleCloudAiplatformV1NotebookExecutionJobWorkbenchRuntimeVmImage?
-
A specific Compute Engine VM image to run the notebook on.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited