defaultTtl property
The default TTL duration of the memories in the Memory Bank.
This applies to all operations that create or update a memory.
Optional.
Implementation
core.String? defaultTtl;
The default TTL duration of the memories in the Memory Bank.
This applies to all operations that create or update a memory.
Optional.
core.String? defaultTtl;