GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig class
Configuration for TTL of the memories in the Memory Bank based on the action that created or updated the memory.
Constructors
- GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig({String? createTtl, String? generateCreatedTtl, String? generateUpdatedTtl})
- GoogleCloudAiplatformV1ReasoningEngineContextSpecMemoryBankConfigTtlConfigGranularTtlConfig.fromJson(Map json_)
Properties
- createTtl ↔ String?
-
The TTL duration for memories uploaded via CreateMemory.
getter/setter pair
- generateCreatedTtl ↔ String?
-
The TTL duration for memories newly generated via GenerateMemories
(GenerateMemoriesResponse.GeneratedMemory.Action.CREATED).
getter/setter pair
- generateUpdatedTtl ↔ String?
-
The TTL duration for memories updated via GenerateMemories
(GenerateMemoriesResponse.GeneratedMemory.Action.UPDATED).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited