keepAliveProbe property
Specifies the configuration for keep-alive probe.
Contains configuration on a specified endpoint that a deployment host should use to keep the container alive based on the probe settings.
Optional.
Implementation
GoogleCloudAiplatformV1KeepAliveProbe? keepAliveProbe;