GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpec class

Specification for deploying from source code.

Properties

agentConfigSource GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecAgentConfigSource?
Source code is generated from the agent config.
getter/setter pair
developerConnectSource GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecDeveloperConnectSource?
Source code is in a Git repository managed by Developer Connect.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageSpec GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecImageSpec?
Configuration for building an image with custom config file.
getter/setter pair
inlineSource GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecInlineSource?
Source code is provided directly in the request.
getter/setter pair
pythonSpec GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecPythonSpec?
Configuration for a Python application.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited