GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecAgentConfigSource class

Specification for the deploying from agent config.

Properties

adkConfig GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecAgentConfigSourceAdkConfig?
The ADK configuration.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
inlineSource GoogleCloudAiplatformV1ReasoningEngineSpecSourceCodeSpecInlineSource?
Any additional files needed to interpret the config.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited