GoogleCloudAiplatformV1SafetySetting class
A safety setting that affects the safety-blocking behavior.
A SafetySetting consists of a harm category and a threshold for that category.
Constructors
- GoogleCloudAiplatformV1SafetySetting({String? category, String? method, String? threshold})
- GoogleCloudAiplatformV1SafetySetting.fromJson(Map json_)
Properties
- category ↔ String?
-
The harm category to be blocked.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- method ↔ String?
-
The method for blocking content.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threshold ↔ String?
-
The threshold for blocking content.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited