GoogleCloudAiplatformV1Schema class
Defines the schema of input and output data.
This is a subset of the OpenAPI 3.0 Schema Object.
Constructors
-
GoogleCloudAiplatformV1Schema({Object? additionalProperties, List<
GoogleCloudAiplatformV1Schema> ? anyOf, Object? default_, Map<String, GoogleCloudAiplatformV1Schema> ? defs, String? description, List<String> ? enum_, Object? example, String? format, GoogleCloudAiplatformV1Schema? items, String? maxItems, String? maxLength, String? maxProperties, double? maximum, String? minItems, String? minLength, String? minProperties, double? minimum, bool? nullable, String? pattern, Map<String, GoogleCloudAiplatformV1Schema> ? properties, List<String> ? propertyOrdering, String? ref, List<String> ? required, String? title, String? type}) - GoogleCloudAiplatformV1Schema.fromJson(Map json_)
Properties
- additionalProperties ↔ Object?
-
If
typeisOBJECT, specifies how to handle properties not defined inproperties.getter/setter pair -
anyOf
↔ List<
GoogleCloudAiplatformV1Schema> ? -
The instance must be valid against any (one or more) of the subschemas
listed in
any_of.getter/setter pair - default_ ↔ Object?
-
Default value to use if the field is not specified.
getter/setter pair
-
defs
↔ Map<
String, GoogleCloudAiplatformV1Schema> ? -
defsprovides a map of schema definitions that can be reused byrefelsewhere in the schema.getter/setter pair - description ↔ String?
-
Description of the schema.
getter/setter pair
-
enum_
↔ List<
String> ? -
Possible values of the field.
getter/setter pair
- example ↔ Object?
-
Example of an instance of this schema.
getter/setter pair
- format ↔ String?
-
The format of the data.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- items ↔ GoogleCloudAiplatformV1Schema?
-
If type is
ARRAY,itemsspecifies the schema of elements in the array.getter/setter pair - maximum ↔ double?
-
If type is
INTEGERorNUMBER,maximumspecifies the maximum allowed value.getter/setter pair - maxItems ↔ String?
-
If type is
ARRAY,max_itemsspecifies the maximum number of items in an array.getter/setter pair - maxLength ↔ String?
-
If type is
STRING,max_lengthspecifies the maximum length of the string.getter/setter pair - maxProperties ↔ String?
-
If type is
OBJECT,max_propertiesspecifies the maximum number of properties that can be provided.getter/setter pair - minimum ↔ double?
-
If type is
INTEGERorNUMBER,minimumspecifies the minimum allowed value.getter/setter pair - minItems ↔ String?
-
If type is
ARRAY,min_itemsspecifies the minimum number of items in an array.getter/setter pair - minLength ↔ String?
-
If type is
STRING,min_lengthspecifies the minimum length of the string.getter/setter pair - minProperties ↔ String?
-
If type is
OBJECT,min_propertiesspecifies the minimum number of properties that can be provided.getter/setter pair - nullable ↔ bool?
-
Indicates if the value of this field can be null.
getter/setter pair
- pattern ↔ String?
-
If type is
STRING,patternspecifies a regular expression that the string must match.getter/setter pair -
properties
↔ Map<
String, GoogleCloudAiplatformV1Schema> ? -
If type is
OBJECT,propertiesis a map of property names to schema definitions for each property of the object.getter/setter pair -
propertyOrdering
↔ List<
String> ? -
Order of properties displayed or used where order matters.
getter/setter pair
- ref ↔ String?
-
Allows referencing another schema definition to use in place of this
schema.
getter/setter pair
-
required
↔ List<
String> ? -
If type is
OBJECT,requiredlists the names of properties that must be present.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
Title for the schema.
getter/setter pair
- type ↔ String?
-
Data type of the schema field.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited