GoogleCloudAiplatformV1Session class
A session contains a set of actions between users and Vertex agents.
Constructors
Properties
- createTime ↔ String?
-
Timestamp when the session was created.
getter/setter pair
- displayName ↔ String?
-
The display name of the session.
getter/setter pair
- expireTime ↔ String?
-
Timestamp of when this session is considered expired.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
The labels with user-defined metadata to organize your Sessions.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sessionState
↔ Map<
String, Object?> ? -
Session specific memory which stores key conversation points.
getter/setter pair
- ttl ↔ String?
-
Input only.
getter/setter pair
- updateTime ↔ String?
-
Timestamp when the session was updated.
getter/setter pair
- userId ↔ String?
-
String id provided by the user
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited