GoogleCloudAiplatformV1SessionEvent class
An event represents a message from either the user or agent.
Constructors
- GoogleCloudAiplatformV1SessionEvent({GoogleCloudAiplatformV1EventActions? actions, String? author, GoogleCloudAiplatformV1Content? content, String? errorCode, String? errorMessage, GoogleCloudAiplatformV1EventMetadata? eventMetadata, String? invocationId, String? name, String? timestamp})
- GoogleCloudAiplatformV1SessionEvent.fromJson(Map json_)
Properties
- actions ↔ GoogleCloudAiplatformV1EventActions?
-
Actions executed by the agent.
getter/setter pair
-
The name of the agent that sent the event, or user.
getter/setter pair
- content ↔ GoogleCloudAiplatformV1Content?
-
Content of the event provided by the author.
getter/setter pair
- errorCode ↔ String?
-
Error code if the response is an error.
getter/setter pair
- errorMessage ↔ String?
-
Error message if the response is an error.
getter/setter pair
- eventMetadata ↔ GoogleCloudAiplatformV1EventMetadata?
-
Metadata relating to this event.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- invocationId ↔ String?
-
The invocation id of the event, multiple events can have the same
invocation id.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ String?
-
Timestamp when the event was created on client side.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited