GoogleCloudAiplatformV1UrlContextMetadata class
Metadata returned when the model uses the url_context tool to get
information from a user-provided URL.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
urlMetadata
↔ List<
GoogleCloudAiplatformV1UrlMetadata> ? -
A list of URL metadata, with one entry for each URL retrieved by the tool.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited