getSemanticGovernancePolicyEngine method
Gets a SemanticGovernancePolicyEngine.
A SemanticGovernancePolicyEngine is a singleton resource that is created when its parent is created, and deleted when its parent is deleted. This method retrieves the current state of the Semantic Governance Policy Engine.
Request parameters:
name - Required. The resource name of the SemanticGovernancePolicyEngine
to retrieve. Format:
projects/{project}/locations/{location}/semanticGovernancePolicyEngine
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/semanticGovernancePolicyEngine$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudAiplatformV1SemanticGovernancePolicyEngine.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleCloudAiplatformV1SemanticGovernancePolicyEngine>
getSemanticGovernancePolicyEngine(
core.String name, {
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleCloudAiplatformV1SemanticGovernancePolicyEngine.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}