ConnectionPoolConfig class

Configuration for Managed Connection Pool (MCP).

Constructors

ConnectionPoolConfig({bool? enabled, Map<String, String>? flags, int? poolerCount})
ConnectionPoolConfig.fromJson(Map json_)

Properties

enabled ↔ bool?
Whether to enable Managed Connection Pool (MCP).
getter/setter pair
flags ↔ Map<String, String>?
Connection Pool flags, as a list of "key": "value" pairs.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
poolerCount ↔ int?
The number of running poolers per instance.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited