authproxyPoolerScalingType property
The scaling type of the AuthProxy pooler.
Optional. Possible string values are:
- "POOLER_SCALING_TYPE_UNSPECIFIED" : The scaling type is not specified.
- "POOLER_NONE" : No pooler is enabled.
- "POOLER_MACHINE_SIZED" : The number of poolers is automatically determined by the service based on the VM size.
- "POOLER_MANUAL_OVERRIDE" : The number of poolers is kept unchanged no matter the machine size.
Implementation
core.String? authproxyPoolerScalingType;