PackageRegistrationStatus class
Resource message PackageRegistrationStatus.
Constructors
- PackageRegistrationStatus({String? certificateFingerprint, String? name, String? state})
- PackageRegistrationStatus.fromJson(Map json_)
Properties
- certificateFingerprint ↔ String?
-
The SHA-256 fingerprint of the public certificate represented as a
64-character lowercase hexadecimal string without any colons or separators
(e.g.,
d6ac89ed1d0a805aad4b087d06d5f41645b814480b133fbc867ef7498d069e06).getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
Registration state of the package, or pair.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited