AppStoreAppActiveApkSet class
An installable set of active APKs.
A set of APKs might only contain 1 APK if the app in question publishes using APKs. If the app uses app bundles (or a similar technology), this set should contain all APKs (even optional ones) that might be installed for this app. A set of APKs should be installable together. If certain APKs are exclusive to one another and cannot be installed together, then a separate AppStoreAppActiveApkSet should be created.
Constructors
-
AppStoreAppActiveApkSet({String? baseApkId, List<
String> ? splitApkId}) - AppStoreAppActiveApkSet.fromJson(Map json_)
Properties
- baseApkId ↔ String?
-
The ID for the main base application module.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
splitApkId
↔ List<
String> ? -
IDs for split modules that might be installed in combination with the base
APK.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited