AppStoreAppStoreListing class
A localized store listing.
These are the details about the app as shown in your app store.
Constructors
Properties
- appIconId ↔ String?
-
Image ID generated from UploadImage for the main app icon.
getter/setter pair
- appName ↔ String?
-
The title of the app.
getter/setter pair
- fullDescription ↔ String?
-
Comprehensive description text about the app.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode ↔ String?
-
Language code (e.g., "en-US") of the listing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
screenshotId
↔ List<
String> ? -
Multiple image IDs for screenshot galleries.
getter/setter pair
- shortDescription ↔ String?
-
Quick summary about the app.
getter/setter pair
- videoLink ↔ String?
-
Link to a video about the app.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited