CatalogAppView class
LINT.IfChange A view of a Google Play app within the Catalog Export for app stores.
Constructors
-
CatalogAppView({List<
String> ? activeVersionNames, String? appCategory, AppContactInformation? appContactInformation, String? appSubcategory, String? deliveryToken, DeveloperDetails? developerDetails, List<DeviceCompatibilityRequirements> ? deviceCompatibilityRequirements, List<DeviceIdentifier> ? excludedDevicesByIdentifier, List<CatalogDeviceSelector> ? excludedDevicesBySelector, Date? firstReleaseDate, bool? hasInAppAds, bool? hasInAppPurchases, String? iarcCertificateId, bool? isAdultOnlyAudience, String? lastPublishTime, LocalizedStoreListings? localizedStoreListings, String? packageName, List<CatalogPermission> ? permissions, List<CatalogPermission> ? permissionsSdk23, Money? priceInTheUnitedStates, String? privacyPolicyUrl, Money? salePriceInTheUnitedStates}) - CatalogAppView.fromJson(Map json_)
Properties
-
activeVersionNames
↔ List<
String> ? -
Active versions of the app mapped from
android:versionNamemanifest attributes.getter/setter pair - appCategory ↔ String?
-
The category of the app.
Possible string values are:
getter/setter pair
- appContactInformation ↔ AppContactInformation?
-
Developer-provided contact information for the app.
getter/setter pair
- appSubcategory ↔ String?
-
The subcategory of the app e.g. "GAME_ACTION".
getter/setter pair
- deliveryToken ↔ String?
-
The token used for delivery of the app with the Google Play Inline Install
API.
getter/setter pair
- developerDetails ↔ DeveloperDetails?
-
The developer details of the app.
getter/setter pair
-
deviceCompatibilityRequirements
↔ List<
DeviceCompatibilityRequirements> ? -
The app may specify multiple sets of device compatibility requirements,
and a device is considered compatible with the app if it satisfies at
least one of
DeviceCompatibilityRequirements.getter/setter pair -
excludedDevicesByIdentifier
↔ List<
DeviceIdentifier> ? -
List of devices excluded from the app's distribution even if they are
otherwise compatible with the requirements from
device_compatibility_requirements.
getter/setter pair
-
excludedDevicesBySelector
↔ List<
CatalogDeviceSelector> ? -
List of devices excluded from the app's distribution even if they are
otherwise compatible with the requirements from
device_compatibility_requirements.
getter/setter pair
- firstReleaseDate ↔ Date?
-
The date when the app was first released.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasInAppAds ↔ bool?
-
Whether the app has ads.
getter/setter pair
- hasInAppPurchases ↔ bool?
-
Whether the app has in-app purchases through Google Play.
getter/setter pair
- iarcCertificateId ↔ String?
-
The IARC certificate ID for the app.
getter/setter pair
- isAdultOnlyAudience ↔ bool?
-
Whether the app is targeted to an adult-only (18+) audience.
getter/setter pair
- lastPublishTime ↔ String?
-
The timestamp when the app was last published.
getter/setter pair
- localizedStoreListings ↔ LocalizedStoreListings?
-
The localized store listings of the app which are shown on Google Play.
getter/setter pair
- packageName ↔ String?
-
The package name of the app.
getter/setter pair
-
permissions
↔ List<
CatalogPermission> ? -
Required permissions declared by the app which apply for all Android SDK
versions.
getter/setter pair
-
permissionsSdk23
↔ List<
CatalogPermission> ? -
Required permissions declared by the app which apply for Android SDK
versions SDK 23 and above.
getter/setter pair
- priceInTheUnitedStates ↔ Money?
-
The price of the app in the United States.
getter/setter pair
- privacyPolicyUrl ↔ String?
-
The URL of the app's privacy policy.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- salePriceInTheUnitedStates ↔ Money?
-
The sale price of the app in the United States.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited