excludedDevicesByIdentifier property
List of devices excluded from the app's distribution even if they are otherwise compatible with the requirements from device_compatibility_requirements.
These are OR-ed, i.e. a device is excluded if it matches any of the identifiers.
Implementation
core.List<DeviceIdentifier>? excludedDevicesByIdentifier;