excludedDevicesBySelector property
List of devices excluded from the app's distribution even if they are otherwise compatible with the requirements from device_compatibility_requirements.
A device is excluded if it matches any of given the selectors.
Implementation
core.List<CatalogDeviceSelector>? excludedDevicesBySelector;