cryptoKeyVersionResource property
Resource identifier of the private key hosted in Google Cloud KMS.
The Google Play service account must be granted Decrypt and Sign permissions on this resource. Format: projects//locations//keyRings//cryptoKeys//cryptoKeyVersions/
Required.
Implementation
core.String? cryptoKeyVersionResource;