productTaxCategoryCode property
Product tax category code in context.
Product tax category determines the transaction tax rates applied to the product that will be factored into the price calculation. If not set, tax rates for the default product tax category will be used. Refer to the Help Center article for more information.
Optional.
Implementation
core.String? productTaxCategoryCode;