DeviceCompatibilityRequirements class
Defines a set of device compatibility requirements for the app.
A device must satisfy all of the requirements in a set to be considered compatible with the app.
Constructors
-
DeviceCompatibilityRequirements({List<
CompatibleScreen> ? compatibleScreens, int? glEsVersion, bool? isScreenRequired, List<String> ? nativePlatforms, List<String> ? requiredSoftwareLibraries, List<String> ? requiredSystemFeatures, String? requiresSmallestWidthDp, CatalogSdkVersion? sdkVersion, List<String> ? supportedGlTextures, List<String> ? supportedScreens, String? use32BitAbi, List<UsesConfiguration> ? usesConfigurations}) - DeviceCompatibilityRequirements.fromJson(Map json_)
Properties
-
compatibleScreens
↔ List<
CompatibleScreen> ? -
Compatible screens as listed in the
compatible-screensManifest tag.getter/setter pair - glEsVersion ↔ int?
-
Required version of OpenGL ES.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isScreenRequired ↔ bool?
-
Specifies if the app requires a screen.
getter/setter pair
-
nativePlatforms
↔ List<
String> ? -
List of required ABIs (Application Binary Interface), e.g.
armeabiorx86.getter/setter pair -
requiredSoftwareLibraries
↔ List<
String> ? -
List of required libraries as declared in the
uses-librarymanifest tag.getter/setter pair -
requiredSystemFeatures
↔ List<
String> ? -
The system features that the app requires.
getter/setter pair
- requiresSmallestWidthDp ↔ String?
-
Specifies the minimum smallest width required of the screen.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkVersion ↔ CatalogSdkVersion?
-
Defines a range of SDK versions that the app is compatible with.
getter/setter pair
-
supportedGlTextures
↔ List<
String> ? -
Supported gl textures as specified by the
supported-gl-textureManifest tag.getter/setter pair -
supportedScreens
↔ List<
String> ? -
Compatible screens as listed in the
supports-screensManifest tag.getter/setter pair - use32BitAbi ↔ String?
-
Value of
android:use32BitAbiflag retrieved from the Manifest. Possible string values are:getter/setter pair -
usesConfigurations
↔ List<
UsesConfiguration> ? -
Lists all configurations marked as required by use of the
uses-configurationmanifest tag.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited