enrollNewApp property
Changes the signing key of a new app to an external Cloud KMS key.
The app must not have published to Open testing or Production tracks.
Implementation
EnrollNewApp? enrollNewApp;
Changes the signing key of a new app to an external Cloud KMS key.
The app must not have published to Open testing or Production tracks.
EnrollNewApp? enrollNewApp;