ItemExpiryTimeDetails class
Expiry time details of a subscription item.
Constructors
- ItemExpiryTimeDetails({String? expiryTime, String? productId})
- ItemExpiryTimeDetails.fromJson(Map json_)
Properties
- expiryTime ↔ String?
-
The new expiry time for this subscription item.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- productId ↔ String?
-
The product ID of the subscription item (for example, 'premium_plan').
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited