LocalizedStoreListing class
A localized store listings of the app.
Constructors
- LocalizedStoreListing({String? appName, ImageAsset? featureGraphic, String? fullDescription, ImageAsset? icon, String? languageCode, ScreenshotSet? phoneScreenshots, String? shortDescription, ScreenshotSet? tabletRegularScreenshots, ScreenshotSet? tabletSmallScreenshots, VideoAsset? video})
- LocalizedStoreListing.fromJson(Map json_)
Properties
- appName ↔ String?
-
The name of the app in this localization.
getter/setter pair
- featureGraphic ↔ ImageAsset?
-
The feature graphic of the app.
getter/setter pair
- fullDescription ↔ String?
-
A longer description of the app in this localization.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ ImageAsset?
-
The icon of the app.
getter/setter pair
- languageCode ↔ String?
-
The BCP-47 language code for this localization.
getter/setter pair
- phoneScreenshots ↔ ScreenshotSet?
-
The phone screenshots of the app.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortDescription ↔ String?
-
A short description of the app in this localization.
getter/setter pair
- tabletRegularScreenshots ↔ ScreenshotSet?
-
The regular tablet screenshots of the app.
getter/setter pair
- tabletSmallScreenshots ↔ ScreenshotSet?
-
The small tablet screenshots of the app.
getter/setter pair
- video ↔ VideoAsset?
-
The video of the app.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited