consumptionUsageEvents property
List of events, each representing an instance where the user consumed or used the purchased item or service.
Lists with over 1000 items will be rejected.
Optional.
Implementation
core.List<ConsumptionUsageEvent>? consumptionUsageEvents;