refundPreference property
Indicates your preference, based on your operational logic, as to whether the Play Store should grant the refund.
Required. Possible string values are:
- "REFUND_PREFERENCE_UNSPECIFIED" : Refund preference unspecified. This value is not used.
- "DECLINE" : Developer prefers that Play declines the refund.
- "APPROVE" : Developer prefers that Play grants the refund in full.
- "NEUTRAL" : Developer has no preference about Google Play's decision to issue a refund
Implementation
core.String? refundPreference;