PolicyDocumentResponse class
An uploaded document.
Must be a single logical document (e.g. a financial license).
Constructors
- PolicyDocumentResponse({String? documentId, Date? expiryDate, bool? nonExpiring})
- PolicyDocumentResponse.fromJson(Map json_)
Properties
- documentId ↔ String?
-
ID of the uploaded document.
getter/setter pair
- expiryDate ↔ Date?
-
Expiry date for the document.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonExpiring ↔ bool?
-
True if confirmed that the document does not have an expiry date.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited