RotatedCloudKmsKey class
Message representing rotated Cloud KMS key.
Consists of the Cloud KMS key and its associated proof of rotation.
Constructors
- RotatedCloudKmsKey({CloudKmsKeyAndCert? cloudKmsKeyAndCert, String? signingCertificateLineage})
- RotatedCloudKmsKey.fromJson(Map json_)
Properties
- cloudKmsKeyAndCert ↔ CloudKmsKeyAndCert?
-
Cloud KMS key and the certificate associated with the key.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signingCertificateLineage ↔ String?
-
Proof-of-rotation.
getter/setter pair
-
signingCertificateLineageAsBytes
↔ List<
int> -
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited