etag property
Entity tag representing the current state of the subscription.
The developer will provide this etag for subscription actions. This etag is always present for auto-renewing and prepaid subscriptions.
Implementation
core.String? etag;
Entity tag representing the current state of the subscription.
The developer will provide this etag for subscription actions. This etag is always present for auto-renewing and prepaid subscriptions.
core.String? etag;