publishState property
The new publish state for the hosted app.
Required. Possible string values are:
- "APP_STORE_APP_PUBLISH_STATE_UNSPECIFIED" : Unspecified publish state. Do not use.
- "APP_STORE_APP_PUBLISH_STATE_PUBLISHED" : The app is published and available on the third-party app store.
- "APP_STORE_APP_PUBLISH_STATE_UNPUBLISHED" : The app is unpublished and no longer available on the third-party app store.
Implementation
core.String? publishState;