UpdateAppStoreHostedAppRequest class

Request to update an app record for an app store hosted app.

Constructors

UpdateAppStoreHostedAppRequest({AppStoreAppActiveApks? activeApks, List<AppStoreAppStoreListing>? activeLocalizedStoreListings, AppStoreAppDetails? appDetails, String? packageName, List<AppStoreAppPolicyDeclaration>? policyDeclarations})
UpdateAppStoreHostedAppRequest.fromJson(Map json_)

Properties

activeApks AppStoreAppActiveApks?
Actively distributed APKs of the app.
getter/setter pair
activeLocalizedStoreListings List<AppStoreAppStoreListing>?
Localized store listings details of the update.
getter/setter pair
appDetails AppStoreAppDetails?
General developer details for the app.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
packageName String?
Package name of the app.
getter/setter pair
policyDeclarations List<AppStoreAppPolicyDeclaration>?
Policy declarations provided for the app.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited