UsesConfiguration class
Represents all configurations marked as required by use of the uses-configuration manifest tag.
Constructors
- UsesConfiguration({String? requiredKeyboardType, String? requiredTouchscreenType, bool? requiresHardwareKeyboard})
- UsesConfiguration.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requiredKeyboardType ↔ String?
-
The type of keyboard required.
Possible string values are:
getter/setter pair
-
The navigation device required.
Possible string values are:
getter/setter pair
- requiredTouchscreenType ↔ String?
-
The type of touchscreen required.
Possible string values are:
getter/setter pair
-
Whether or not the application requires a five-way navigation control.
getter/setter pair
- requiresHardwareKeyboard ↔ bool?
-
Whether or not the application requires a hardware keyboard.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited