GoogleCloudApigeeV1LlmOperationConfig class
Binds the resources in an API proxy or remote service with the allowed REST methods and associated quota enforcement.
Constructors
-
GoogleCloudApigeeV1LlmOperationConfig({String? apiSource, List<
GoogleCloudApigeeV1Attribute> ? attributes, List<GoogleCloudApigeeV1LlmOperation> ? llmOperations, GoogleCloudApigeeV1LlmTokenQuota? llmTokenQuota}) - GoogleCloudApigeeV1LlmOperationConfig.fromJson(Map json_)
Properties
- apiSource ↔ String?
-
Name of the API proxy or remote service with which the resources, methods,
and quota are associated.
getter/setter pair
-
attributes
↔ List<
GoogleCloudApigeeV1Attribute> ? -
Custom attributes associated with the operation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
llmOperations
↔ List<
GoogleCloudApigeeV1LlmOperation> ? -
List of resource/method/model for the API proxy to which quota will
applied.
getter/setter pair
- llmTokenQuota ↔ GoogleCloudApigeeV1LlmTokenQuota?
-
LLM token Quota parameters to be enforced for the resources, methods, and
API source & LLM model combination.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited