severityLevel property
The severity level for the logs.
Logs will be generated if their severity level is >= than the value of the severity level mentioned here.
Optional. Possible string values are:
- "SEVERITY_LEVEL_UNSPECIFIED" : No severity level specified, meaning everything is being logged.
- "DEBUG" : Debug or trace information.
- "INFO" : Routine information, such as ongoing status or performance.
- "NOTICE" : Normal but significant events, such as start up, shut down, or a configuration change.
- "WARNING" : Warning events that might cause problems.
- "ERROR" : Error events that are likely to cause problems.
- "CRITICAL" : Critical events that cause more severe problems or outages.
- "ALERT" : Alert events that require a person must take an action immediately.
- "EMERGENCY" : One or more systems are unusable.
Implementation
core.String? severityLevel;