PrewarmPlatform class
The platform (architecture and OS) of the image.
This is a sub-message.
Constructors
- PrewarmPlatform({String? architecture, String? os})
- PrewarmPlatform.fromJson(Map json_)
Properties
- architecture ↔ String?
-
The architecture of the image or tag.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- os ↔ String?
-
The OS of the image or tag.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited