GoogleCloudAssuredworkloadsV1ArchiveResourceEventsRequest class
Request for archiving resource events.
Constructors
- GoogleCloudAssuredworkloadsV1ArchiveResourceEventsRequest({String? archiveTime, int? batchSize, String? eventCutoffTime, int? maxEventsMove, String? organizationId, String? region})
- GoogleCloudAssuredworkloadsV1ArchiveResourceEventsRequest.fromJson(Map json_)
Properties
- archiveTime ↔ String?
-
Time to set as ArchiveTime in the archive table.
getter/setter pair
- batchSize ↔ int?
-
The number of events to process in a single transaction batch.
getter/setter pair
- eventCutoffTime ↔ String?
-
Only events with EventTime earlier than this cutoff will be archived.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxEventsMove ↔ int?
-
The maximum total number of events to move in this request.
getter/setter pair
- organizationId ↔ String?
-
The organization ID for which to archive events.
getter/setter pair
- region ↔ String?
-
The region of the workload(s) whose events should be archived.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited