GoogleCloudAssuredworkloadsV1CloudControlReport class
The cloud control report.
Constructors
-
GoogleCloudAssuredworkloadsV1CloudControlReport({List<
String> ? categories, String? cloudControl, GoogleCloudAssuredworkloadsV1CloudControlAssessmentDetails? cloudControlAssessmentDetails, String? cloudControlDeployment, String? cloudControlType, String? description, String? displayName, String? enforcementMode, String? findingCategory, String? findingSeverity, List<String> ? frameworkMajorRevisionIds, String? majorRevisionId, GoogleCloudAssuredworkloadsV1ManualCloudControlAssessmentDetails? manualCloudControlAssessmentDetails, String? minorRevisionId, List<GoogleCloudAssuredworkloadsV1Rule> ? rules, List<GoogleCloudAssuredworkloadsV1SimilarControls> ? similarControls}) - GoogleCloudAssuredworkloadsV1CloudControlReport.fromJson(Map json_)
Properties
-
categories
↔ List<
String> ? -
The list of categories for the cloud control.
getter/setter pair
- cloudControl ↔ String?
-
The name of the cloud control.
getter/setter pair
- cloudControlAssessmentDetails ↔ GoogleCloudAssuredworkloadsV1CloudControlAssessmentDetails?
-
The details of a cloud control assessment.
getter/setter pair
- cloudControlDeployment ↔ String?
-
The name of the cloud control deployment.
getter/setter pair
- cloudControlType ↔ String?
-
The type of the cloud control.
Possible string values are:
getter/setter pair
- description ↔ String?
-
The description of the cloud control.
getter/setter pair
- displayName ↔ String?
-
The display name of the cloud control.
getter/setter pair
- enforcementMode ↔ String?
-
The enforcement mode of the cloud control.
Possible string values are:
getter/setter pair
- findingCategory ↔ String?
-
The category of the finding.
getter/setter pair
- findingSeverity ↔ String?
-
The severity of the finding.
Possible string values are:
getter/setter pair
-
frameworkMajorRevisionIds
↔ List<
String> ? -
The major revision IDs of the frameworks that the cloud control belongs
to.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- majorRevisionId ↔ String?
-
The major revision ID of the cloud control.
getter/setter pair
- manualCloudControlAssessmentDetails ↔ GoogleCloudAssuredworkloadsV1ManualCloudControlAssessmentDetails?
-
The details of a manual cloud control assessment.
getter/setter pair
- minorRevisionId ↔ String?
-
The minor revision ID of the cloud control.
getter/setter pair
-
rules
↔ List<
GoogleCloudAssuredworkloadsV1Rule> ? -
The list of rules that correspond to the cloud control.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
similarControls
↔ List<
GoogleCloudAssuredworkloadsV1SimilarControls> ? -
The list of similar controls.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited