GoogleCloudAssuredworkloadsV1Rule class
A rule in the cloud control.
Constructors
-
GoogleCloudAssuredworkloadsV1Rule({GoogleCloudAssuredworkloadsV1CELExpression? celExpression, String? description, List<
String> ? ruleActionTypes}) - GoogleCloudAssuredworkloadsV1Rule.fromJson(Map json_)
Properties
- celExpression ↔ GoogleCloudAssuredworkloadsV1CELExpression?
-
The rule's logic expression in Common Expression Language (CEL).
getter/setter pair
- description ↔ String?
-
The rule description.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ruleActionTypes
↔ List<
String> ? -
The functionality that's enabled by the rule.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited