list method
Lists the finding summary by category for a given scope.
Request parameters:
parent - Required. The parent scope for the framework overview page.
Formats: - projects/{project}/locations/{location} -
folders/{folder}/locations/{location} -
organizations/{organization}/locations/{location}
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
filter - Optional. The filtering results.
pageSize - Optional. The requested page size. The server might return
fewer items than requested. If unspecified, the server picks an
appropriate default.
pageToken - Optional. A token that identifies the page of results that
the server should return.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse>
list(
core.String parent, {
core.String? filter,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/dbFindingSummaries';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleCloudAssuredworkloadsV1ListDbFindingSummariesResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}