ComputeInstanceBackupPlanProperties class

Properties for a compute instance backup plan.

Constructors

ComputeInstanceBackupPlanProperties({bool? bootDiskOnly, DiskExclusionLabels? diskExclusionLabels, bool? guestFlush})
ComputeInstanceBackupPlanProperties.fromJson(Map json_)

Properties

bootDiskOnly bool?
If true, only the boot disk will be backed up.
getter/setter pair
diskExclusionLabels DiskExclusionLabels?
Labels used to identify disks for exclusion from the backup.
getter/setter pair
guestFlush bool?
Indicates whether to perform a guest flush operation before taking a compute backup.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited