guestFlush property
Indicates whether to perform a guest flush operation before taking a compute backup.
When set to false, the system will create crash-consistent backups. Default value is false.
Optional.
Implementation
core.bool? guestFlush;
Indicates whether to perform a guest flush operation before taking a compute backup.
When set to false, the system will create crash-consistent backups. Default value is false.
Optional.
core.bool? guestFlush;