labels property
Labels used to identify disks for exclusion from the backup.
If a disk carries any of these labels, it will be excluded (OR logic).
Optional.
Implementation
core.List<LabelKeyValPair>? labels;
Labels used to identify disks for exclusion from the backup.
If a disk carries any of these labels, it will be excluded (OR logic).
Optional.
core.List<LabelKeyValPair>? labels;