InitializeServiceRequest class

Request message for initializing the service.

Constructors

InitializeServiceRequest({String? backupPlanLocation, CloudSqlInstanceInitializationConfig? cloudSqlInstanceInitializationConfig, String? requestId, String? resourceType, bool? validateOnly})
InitializeServiceRequest.fromJson(Map json_)

Properties

backupPlanLocation String?
The location where the BackupPlan will be created.
getter/setter pair
cloudSqlInstanceInitializationConfig CloudSqlInstanceInitializationConfig?
The configuration for initializing a Cloud SQL instance.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
requestId String?
An optional request ID to identify requests.
getter/setter pair
resourceType String?
The resource type to which the default service config will be applied.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validateOnly bool?
If set, validates the request and returns the result, but does not actually run it.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited