RestoreDiskFromInstanceOptions class
Options for creating a disk from a source Compute Instance backup.
Constructors
- RestoreDiskFromInstanceOptions({bool? bootDisk, String? sourceDeviceName})
- RestoreDiskFromInstanceOptions.fromJson(Map json_)
Properties
- bootDisk ↔ bool?
-
Specifies that the boot disk should be restored from the instance backup.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceDeviceName ↔ String?
-
The device name of the disk to restore from the VM backup.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited