bootDisk property
Specifies that the boot disk should be restored from the instance backup.
This field should only be set to true if selected.
Implementation
core.bool? bootDisk;
Specifies that the boot disk should be restored from the instance backup.
This field should only be set to true if selected.
core.bool? bootDisk;