allowedLocations property
A list of location names that are allowed for the job's VMs formatted as URLs.
Each location can be a region or a zone, but you can only specify one
region or multiple zones in one region per job. For example,
["regions/us-central1"] allow VMs in any zones in region us-central1,
and ["zones/us-central1-a", "zones/us-central1-c"] only allow VMs in
zones us-central1-a and us-central1-c. However,
["regions/us-central1", "zones/us-central1-a", "zones/us-central1-b", "zones/us-west1-a"] causes an error because it contains multiple regions
(us-central1 and us-west1). The specified region or zones must be in
the same region in which the job is created starting on the following
dates: + For projects that have successfully submitted before July 31,
2026 at least one job that uses the allowedLocations[] field with any
region or zones outside of the job's location, the changes are starting on
June 30, 2027. + For all other projects, the changes are starting on
July 31, 2026. For example, for job
projects/123/locations/us-central1/jobs/jobid, the specified region or
zones must be in us-central1. Using a different region (e.g.
regions/us-west1) or a zone not in us-central1 (e.g.
zones/us-west1-a) causes an error.
Implementation
core.List<core.String>? allowedLocations;