GenAiFunctionStats class

Provides statistics for each Ai function call within a query.

Constructors

GenAiFunctionStats({GenAiFunctionCacheStats? cacheStats, GenAiFunctionCostOptimizationStats? costOptimizationStats, GenAiFunctionErrorStats? errorStats, String? functionName, String? numProcessedRows, String? prompt})
GenAiFunctionStats.fromJson(Map json_)

Properties

cacheStats GenAiFunctionCacheStats?
Cache stats for the function.
getter/setter pair
costOptimizationStats GenAiFunctionCostOptimizationStats?
Cost optimization stats if applied on the rows processed by the function.
getter/setter pair
errorStats GenAiFunctionErrorStats?
Error stats for the function.
getter/setter pair
functionName String?
Name of the function.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
numProcessedRows String?
Number of rows processed by this GenAi function.
getter/setter pair
prompt String?
User input prompt of the function (truncated to 20 chars).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited