GenAiStats class
GenAi stats for the query job.
Constructors
-
GenAiStats({GenAiErrorStats? errorStats, List<
GenAiFunctionStats> ? functionStats}) - GenAiStats.fromJson(Map json_)
Properties
- errorStats ↔ GenAiErrorStats?
-
Job level error stats across all GenAi functions
getter/setter pair
-
functionStats
↔ List<
GenAiFunctionStats> ? -
Function level stats for GenAI Functions.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited