IncrementalResultStats class
Statistics related to Incremental Query Results.
Populated as part of JobStatistics2. This feature is not yet available.
Constructors
- IncrementalResultStats({String? disabledReason, String? disabledReasonDetails, String? firstIncrementalRowTime, String? incrementalRowCount, String? lastIncrementalRowTime, String? resultSetLastModifyTime, String? resultSetLastReplaceTime})
- IncrementalResultStats.fromJson(Map json_)
Properties
- disabledReason ↔ String?
-
Reason why incremental query results are/were not written by the query.
getter/setter pair
- disabledReasonDetails ↔ String?
-
Additional human-readable clarification, if available, for DisabledReason.
getter/setter pair
- firstIncrementalRowTime ↔ String?
-
The time at which the first incremental result was written.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- incrementalRowCount ↔ String?
-
Number of rows that were in the latest result set before query completion.
getter/setter pair
- lastIncrementalRowTime ↔ String?
-
The time at which the last incremental result was written.
getter/setter pair
- resultSetLastModifyTime ↔ String?
-
The time at which the result table's contents were modified.
getter/setter pair
- resultSetLastReplaceTime ↔ String?
-
The time at which the result table's contents were completely replaced.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited