firstIncrementalRowTime property
The time at which the first incremental result was written.
If the query needed to restart internally, this only describes the final attempt.
Output only.
Implementation
core.String? firstIncrementalRowTime;
The time at which the first incremental result was written.
If the query needed to restart internally, this only describes the final attempt.
Output only.
core.String? firstIncrementalRowTime;