MetadataCacheStalenessInsight class
Column Metadata Index staleness detailed infnormation.
Constructors
- MetadataCacheStalenessInsight({String? avgPreviousStalenessMs, double? stalenessPercentageIncrease})
- MetadataCacheStalenessInsight.fromJson(Map json_)
Properties
- avgPreviousStalenessMs ↔ String?
-
Average column metadata index staleness of previous runs with the same
query hash.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stalenessPercentageIncrease ↔ double?
-
The percent increase in staleness between the current job and the average
staleness of previous jobs with the same query hash.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited