stalenessPercentageIncrease property
The percent increase in staleness between the current job and the average staleness of previous jobs with the same query hash.
Output only.
Implementation
core.double? stalenessPercentageIncrease;
The percent increase in staleness between the current job and the average staleness of previous jobs with the same query hash.
Output only.
core.double? stalenessPercentageIncrease;