queryResultsFormat property
The query results format.
If the value is anything other than STRUCT_ENCODING or unspecified: *
The schema of the results will be provided in
QueryResponse.results_schema field. * The results of the first page will
be provided in QueryResponse.results field. * The QueryResponse.rows
will not be populated. * The QueryResponse.schema for
QueryResponse.rows will also not be populated since it is the schema of
the QueryResponse.rows. This feature is not yet available.
Optional. Possible string values are:
- "QUERY_RESULTS_FORMAT_UNSPECIFIED" : If unspecified it will default to
struct
QueryResponse.rows(STRUCT_ENCODING) - "STRUCT_ENCODING" : Default encoding of results as struct in
QueryResponse.rows - "ARROW" : Arrow is a standard open source column-based message format. See https://arrow.apache.org/ for more details.
Implementation
core.String? queryResultsFormat;