RoutineBuildStatus class
The status of a routine build.
Constructors
- RoutineBuildStatus({String? buildDuration, String? buildState, String? buildStateUpdateTime, ErrorProto? errorResult, String? imageSizeBytes})
- RoutineBuildStatus.fromJson(Map json_)
Properties
- buildDuration ↔ String?
-
The time taken for the image build.
getter/setter pair
- buildState ↔ String?
-
The current build state of the routine.
getter/setter pair
- buildStateUpdateTime ↔ String?
-
The time when the build state was updated last.
getter/setter pair
- errorResult ↔ ErrorProto?
-
A result object that will be present only if the build has failed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageSizeBytes ↔ String?
-
The size of the image in bytes.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited