TableChangeInsight class

Table-level performance insights compared to previous runs.

These insights don't apply to specific query stages, rather they apply to the whole table.

Constructors

TableChangeInsight({bool? metadataCacheNotUsedButUsedPreviously, MetadataCacheStalenessInsight? metadataCacheStalenessInsight, TableReference? tableReference})
TableChangeInsight.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
metadataCacheNotUsedButUsedPreviously bool?
True if the table's column metadata index was not used in the current job, but was used in a previous job with the same query hash.
getter/setter pair
metadataCacheStalenessInsight MetadataCacheStalenessInsight?
If present, indicates that the table's metadata column index staleness has increased significantly compared to previous jobs with the same query hash.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tableReference TableReference?
The table that was queried.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited