metadataCacheNotUsedButUsedPreviously property
True if the table's column metadata index was not used in the current job, but was used in a previous job with the same query hash.
Output only.
Implementation
core.bool? metadataCacheNotUsedButUsedPreviously;