metadataCacheStalenessInsight property
If present, indicates that the table's metadata column index staleness has increased significantly compared to previous jobs with the same query hash.
Output only.
Implementation
MetadataCacheStalenessInsight? metadataCacheStalenessInsight;