TableFieldSchemaDataGovernanceTagsInfo class
Specifies the data governance tags on this field.
This field works with other column-level security fields as follows: *
Precedence: If a data governance tag is attached to a column, it takes
precedence over the policy tag attached to the column. However, if a data
policy is attached to a column, it takes precedence over the data governance
tag. * Patching behavior: Describes how this field behaves during a
Table.patch schema update: * Unset: If the data_governance_tags_info
field is omitted from the update request, the existing tags on the column
are preserved. * Empty Field: To clear data governance tags from a
column, send the data_governance_tags_info field as an empty object. This
removes all tags from the column. * Updating tags: To replace an
existing tag, send the field with the new tag.
Optional.
Constructors
-
TableFieldSchemaDataGovernanceTagsInfo({Map<
String, String> ? dataGovernanceTags}) - TableFieldSchemaDataGovernanceTagsInfo.fromJson(Map json_)
Properties
-
dataGovernanceTags
↔ Map<
String, String> ? -
The data governance tags added to this field are used for field-level
access control.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited