ConnectorConfigurationParameterValue class

Represents a value for a connector parameter.

Constructors

ConnectorConfigurationParameterValue({bool? boolValue, double? doubleValue, int? int32Value, ConnectorConfigurationSecret? secretValue, String? stringValue})
ConnectorConfigurationParameterValue.fromJson(Map json_)

Properties

boolValue bool?
A boolean parameter value.
getter/setter pair
doubleValue double?
A double parameter value.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
int32Value int?
An int32 parameter value.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretValue ConnectorConfigurationSecret?
A secret parameter value.
getter/setter pair
stringValue String?
A string parameter value.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited