HierarchyDetail class
Details about the hierarchy.
Constructors
- HierarchyDetail({PartitionDetail? partitionDetail, TableDetail? tableDetail})
- HierarchyDetail.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- partitionDetail ↔ PartitionDetail?
-
Partition details related to hierarchy.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableDetail ↔ TableDetail?
-
Table details related to hierarchy.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited