TransferResource class

Resource (table/partition) that is being transferred.

Constructors

TransferResource({String? destination, HierarchyDetail? hierarchyDetail, TransferRunBrief? lastSuccessfulRun, TransferRunBrief? latestRun, TransferResourceStatusDetail? latestStatusDetail, String? name, String? type, String? updateTime})
TransferResource.fromJson(Map json_)

Properties

destination String?
Resource destination.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hierarchyDetail HierarchyDetail?
Details about the hierarchy.
getter/setter pair
lastSuccessfulRun TransferRunBrief?
Run details for the last successful run.
getter/setter pair
latestRun TransferRunBrief?
Run details for the latest run.
getter/setter pair
latestStatusDetail TransferResourceStatusDetail?
Status details for the latest run.
getter/setter pair
name String?
Identifier.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
Resource type.
getter/setter pair
updateTime String?
Time when the resource was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited