TransferResourceStatusDetail class
Status details of the resource being transferred.
Constructors
- TransferResourceStatusDetail({double? completedPercentage, Status? error, String? state, TransferStatusSummary? summary})
- TransferResourceStatusDetail.fromJson(Map json_)
Properties
- completedPercentage ↔ double?
-
Percentage of the transfer completed.
getter/setter pair
- error ↔ Status?
-
Transfer error details for the resource.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
Transfer state of the resource.
getter/setter pair
- summary ↔ TransferStatusSummary?
-
Transfer status summary of the resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited