concurrency property
If present and > 0, the reservation will attempt to limit the concurrency of jobs running for any particular project within it to the given value.
This feature is not yet generally available.
Optional.
Implementation
core.String? concurrency;