locations property
A list of Cloud Bigtable zones where automated backups are allowed to be created.
If empty, automated backups will be created in all zones of the instance.
Locations are in the format projects/{project}/locations/{zone}. You can
set this field only for tables in Enterprise Plus instances.
Optional.
Implementation
core.List<core.String>? locations;