GoogleBigtableAdminV2TypeInt32EncodingOrderedCodeBytes typedef
GoogleBigtableAdminV2TypeInt32EncodingOrderedCodeBytes = $Empty
Encodes the value in a variable length binary format of up to 5 bytes.
Values that are closer to zero use fewer bytes. Sorted mode: all values are supported. Distinct mode: all values are supported.
Implementation
typedef GoogleBigtableAdminV2TypeInt32EncodingOrderedCodeBytes = $Empty;