edition property
The edition of the instance.
See Edition for details.
Optional. Possible string values are:
- "EDITION_UNSPECIFIED" : The edition is unspecified. This is treated as
ENTERPRISE. - "ENTERPRISE" : The Enterprise edition. This is the default offering that is designed to meet the needs of most enterprise workloads.
- "ENTERPRISE_PLUS" : The Enterprise Plus edition. This is a premium tier that is designed for demanding, multi-tenant workloads requiring the highest levels of performance, scale, and global availability. The nodes in the Enterprise Plus tier come at a higher cost than the Enterprise tier. Any Enterprise Plus features must be disabled before downgrading to Enterprise.
Implementation
core.String? edition;