MemoryLayer class
The memory layer of a cluster.
A memory layer serves reads from memory without hitting the backing persistent data store.
Constructors
- MemoryLayer({String? etag, GoogleBigtableAdminV2MemoryLayerMemoryConfig? memoryConfig, String? name, String? state})
- MemoryLayer.fromJson(Map json_)
Properties
- etag ↔ String?
-
The etag for this memory layer.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- memoryConfig ↔ GoogleBigtableAdminV2MemoryLayerMemoryConfig?
-
The configuration of this memory layer.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
The current state of the memory layer.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited