EventLabel class
Constructors
- EventLabel({String? backgroundColor, String? id, String? name})
- EventLabel.fromJson(Map json_)
Properties
- backgroundColor ↔ String?
-
Background color of the label in hexadecimal format, such as "#039be5".
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID of the label.
getter/setter pair
- name ↔ String?
-
Name of the label.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited