backgroundColor property
Background color of the label in hexadecimal format, such as "#039be5".
Events with this label are displayed in this color. Required.
Implementation
core.String? backgroundColor;
Background color of the label in hexadecimal format, such as "#039be5".
Events with this label are displayed in this color. Required.
core.String? backgroundColor;