ManagedIdentityCertificate class
Configuration and state of a Managed Identity Certificate.
Certificate Manager provisions and renews Managed Identity Certificates automatically, for as long as it's authorized to do so.
Constructors
- ManagedIdentityCertificate({String? identity, ProvisioningIssue? provisioningIssue, String? state})
- ManagedIdentityCertificate.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- identity ↔ String?
-
SPIFFE ID of the Managed Identity used for this certificate.
getter/setter pair
- provisioningIssue ↔ ProvisioningIssue?
-
Information about issues with provisioning a managed certificate.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
State of the managed certificate resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited