Troubleshooting class
Troubleshooting information for the authorization attempt.
Constructors
-
Troubleshooting({CNAME? cname, IPs? ips, List<
String> ? issues}) - Troubleshooting.fromJson(Map json_)
Properties
- cname ↔ CNAME?
-
CNAME troubleshooting information.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ips ↔ IPs?
-
IPs troubleshooting information.
getter/setter pair
-
issues
↔ List<
String> ? -
The list of issues discovered during the authorization attempt.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited