Action class
Configuration of an Action for the tool to use.
Note: This can be either an Action or an Operation. See https://cloud.google.com/integration-connectors/docs/entities-operation-action for details.
Constructors
-
Action({String? connectionActionId, ActionEntityOperation? entityOperation, List<
String> ? inputFields, List<String> ? outputFields}) - Action.fromJson(Map json_)
Properties
- connectionActionId ↔ String?
-
ID of a Connection action for the tool to use.
getter/setter pair
- entityOperation ↔ ActionEntityOperation?
-
Entity operation configuration for the tool to use.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputFields
↔ List<
String> ? -
Entity fields to use as inputs for the operation.
getter/setter pair
-
outputFields
↔ List<
String> ? -
Entity fields to return from the operation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited