ActionEntityOperation class

Entity CRUD operation specification.

Constructors

ActionEntityOperation({String? entityId, String? operation})
ActionEntityOperation.fromJson(Map json_)

Properties

entityId String?
ID of the entity.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
operation String?
Operation to perform on the entity.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited