beforeAgentCallbacks property
The callbacks to execute before the agent is called.
The provided callbacks are executed sequentially in the exact order they are given in the list. If a callback returns an overridden response, execution stops and any remaining callbacks are skipped.
Optional.
Implementation
core.List<Callback>? beforeAgentCallbacks;