skills property
Skills represent a unit of ability an agent can perform.
This may somewhat abstract but represents a more focused set of actions that the agent is highly likely to succeed at.
Required.
Implementation
core.List<AgentSkill>? skills;
Skills represent a unit of ability an agent can perform.
This may somewhat abstract but represents a more focused set of actions that the agent is highly likely to succeed at.
Required.
core.List<AgentSkill>? skills;