AgentLlmAgent typedef
AgentLlmAgent = $Empty
Default agent type.
The agent uses instructions and callbacks specified in the agent to perform the task using a large language model.
Implementation
typedef AgentLlmAgent = $Empty;