AgentRemoteDialogflowAgent class
The agent which will transfer execution to a remote Dialogflow CX agent.
The Dialogflow agent will process subsequent user queries until the session ends or flow ends, and the control is transferred back to the parent CES agent.
Constructors
Properties
- agent ↔ String?
-
The
Dialogflow
agent resource name.
getter/setter pair
- environmentId ↔ String?
-
The environment ID of the Dialogflow agent to be used for the agent
execution.
getter/setter pair
- flowId ↔ String?
-
The flow ID of the flow in the Dialogflow agent.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
inputVariableMapping
↔ Map<
String, String> ? -
The mapping of the app variables names to the Dialogflow session
parameters names to be sent to the Dialogflow agent as input.
getter/setter pair
- languageCodeVariable ↔ String?
-
The name of the variable that contains the language code to be used for
the Dialogflow session.
getter/setter pair
-
outputVariableMapping
↔ Map<
String, String> ? -
The mapping of the Dialogflow session parameters names to the app
variables names to be sent back to the CES agent after the Dialogflow
agent execution ends.
getter/setter pair
- respectResponseInterruptionSettings ↔ bool?
-
Indicates whether to respect the message-level interruption settings
configured in the Dialogflow agent.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited