AgentTool class
Represents a tool that allows the agent to call another agent.
Constructors
Properties
- agent ↔ String?
-
The resource name of the agent that is the entry point of the tool.
getter/setter pair
- description ↔ String?
-
Description of the tool's purpose.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
The name of the agent tool.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited