AmbientSoundConfig class

Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.

Constructors

AmbientSoundConfig({String? gcsUri, String? prebuiltAmbientNoise, String? prebuiltAmbientSound, double? volumeGainDb})
AmbientSoundConfig.fromJson(Map json_)

Properties

gcsUri String?
Ambient noise as a mono-channel, 16kHz WAV file stored in Cloud Storage.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
prebuiltAmbientNoise String?
Deprecated: prebuilt_ambient_noise is deprecated in favor of prebuilt_ambient_sound.
getter/setter pair
prebuiltAmbientSound String?
Name of the prebuilt ambient sound.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
volumeGainDb double?
Volume gain (in dB) of the normal native volume supported by ambient noise, in the range [-96.0, 16.0].
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited