App class
An app serves as a top-level container for a group of agents, including the root agent and its sub-agents, along with their associated configurations.
These agents work together to achieve specific goals within the app's context.
Constructors
-
App({AudioProcessingConfig? audioProcessingConfig, ClientCertificateSettings? clientCertificateSettings, String? createTime, DataStoreSettings? dataStoreSettings, ChannelProfile? defaultChannelProfile, int? deploymentCount, String? description, String? displayName, ErrorHandlingSettings? errorHandlingSettings, String? etag, EvaluationMetricsThresholds? evaluationMetricsThresholds, String? globalInstruction, List<
String> ? guardrails, LanguageSettings? languageSettings, bool? locked, LoggingSettings? loggingSettings, Map<String, String> ? metadata, ModelSettings? modelSettings, String? name, bool? pinned, List<AppVariableDeclaration> ? predefinedVariableDeclarations, String? rootAgent, TimeZoneSettings? timeZoneSettings, String? toolExecutionMode, String? updateTime, List<String> ? validationErrors, List<AppVariableDeclaration> ? variableDeclarations, VpcScSettings? vpcScSettings}) - App.fromJson(Map json_)
Properties
- audioProcessingConfig ↔ AudioProcessingConfig?
-
Audio processing configuration of the app.
getter/setter pair
- clientCertificateSettings ↔ ClientCertificateSettings?
-
The default client certificate settings for the app.
getter/setter pair
- createTime ↔ String?
-
Timestamp when the app was created.
getter/setter pair
- dataStoreSettings ↔ DataStoreSettings?
-
The data store settings for the app.
getter/setter pair
- defaultChannelProfile ↔ ChannelProfile?
-
The default channel profile used by the app.
getter/setter pair
- deploymentCount ↔ int?
-
Number of deployments in the app.
getter/setter pair
- description ↔ String?
-
Human-readable description of the app.
getter/setter pair
- displayName ↔ String?
-
Display name of the app.
getter/setter pair
- errorHandlingSettings ↔ ErrorHandlingSettings?
-
Error handling settings of the app.
getter/setter pair
- etag ↔ String?
-
Etag used to ensure the object hasn't changed during a read-modify-write
operation.
getter/setter pair
- evaluationMetricsThresholds ↔ EvaluationMetricsThresholds?
-
The evaluation thresholds for the app.
getter/setter pair
- globalInstruction ↔ String?
-
Instructions for all the agents in the app.
getter/setter pair
-
guardrails
↔ List<
String> ? -
List of guardrails for the app.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageSettings ↔ LanguageSettings?
-
Language settings of the app.
getter/setter pair
- locked ↔ bool?
-
Indicates whether the app is locked for changes.
getter/setter pair
- loggingSettings ↔ LoggingSettings?
-
Logging settings of the app.
getter/setter pair
-
metadata
↔ Map<
String, String> ? -
Metadata about the app.
getter/setter pair
- modelSettings ↔ ModelSettings?
-
The default LLM model settings for the app.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- pinned ↔ bool?
-
Whether the app is pinned in the app list.
getter/setter pair
-
predefinedVariableDeclarations
↔ List<
AppVariableDeclaration> ? -
The declarations of predefined variables for the app.
getter/setter pair
- rootAgent ↔ String?
-
The root agent is the entry point of the app.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeZoneSettings ↔ TimeZoneSettings?
-
TimeZone settings of the app.
getter/setter pair
- toolExecutionMode ↔ String?
-
The tool execution mode for the app.
getter/setter pair
- updateTime ↔ String?
-
Timestamp when the app was last updated.
getter/setter pair
-
validationErrors
↔ List<
String> ? -
Misconfigurations or warnings in the app.
getter/setter pair
-
variableDeclarations
↔ List<
AppVariableDeclaration> ? -
The declarations of the variables.
getter/setter pair
- vpcScSettings ↔ VpcScSettings?
-
VPC-SC settings for the app.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited