toolExecutionMode property
The tool execution mode for the app.
If not provided, will default to PARALLEL.
Optional. Possible string values are:
- "TOOL_EXECUTION_MODE_UNSPECIFIED" : Unspecified tool execution mode. Default to PARALLEL.
- "PARALLEL" : If there are multiple tools being selected, they will be executed in parallel, with the same ToolContext.
- "SEQUENTIAL" : If there are multiple tools being selected, they will be executed sequentially. The next tool will only be executed after the previous tool completes and it can see updated ToolContext from the previous tool.
Implementation
core.String? toolExecutionMode;