AppSnapshot class

A snapshot of the app.

Constructors

AppSnapshot({List<Agent>? agents, App? app, List<Example>? examples, List<Guardrail>? guardrails, List<Tool>? tools, List<Toolset>? toolsets})
AppSnapshot.fromJson(Map json_)

Properties

agents List<Agent>?
List of agents in the app.
getter/setter pair
app App?
The basic settings for the app.
getter/setter pair
examples List<Example>?
List of examples in the app.
getter/setter pair
guardrails List<Guardrail>?
List of guardrails in the app.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tools List<Tool>?
List of tools in the app.
getter/setter pair
toolsets List<Toolset>?
List of toolsets in the app.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited