AppVersion class
In Customer Engagement Suite (CES), an app version is a snapshot of the app at a specific point in time.
It is immutable and cannot be modified once created.
Constructors
- AppVersion({String? createTime, String? creator, String? description, String? displayName, String? etag, String? name, AppSnapshot? snapshot})
- AppVersion.fromJson(Map json_)
Properties
- createTime ↔ String?
-
Timestamp when the app version was created.
getter/setter pair
- creator ↔ String?
-
Email of the user who created the app version.
getter/setter pair
- description ↔ String?
-
The description of the app version.
getter/setter pair
- displayName ↔ String?
-
The display name of the app version.
getter/setter pair
- etag ↔ String?
-
Etag used to ensure the object hasn't changed during a read-modify-write
operation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshot ↔ AppSnapshot?
-
The snapshot of the app when the version is created.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited