ambientSoundConfig property
Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.
Optional.
Implementation
AmbientSoundConfig? ambientSoundConfig;
Configuration for the ambient sound to be played with the synthesized agent response, to enhance the naturalness of the conversation.
Optional.
AmbientSoundConfig? ambientSoundConfig;