AudioRecordingConfig class

Configuration for how the audio interactions should be recorded.

Constructors

AudioRecordingConfig({String? gcsBucket, String? gcsPathPrefix})
AudioRecordingConfig.fromJson(Map json_)

Properties

gcsBucket String?
The Cloud Storage bucket to store the session audio recordings.
getter/setter pair
gcsPathPrefix String?
The Cloud Storage path prefix for audio recordings.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited