BargeInConfig class
Configuration for how the user barge-in activities should be handled.
Constructors
- BargeInConfig({bool? bargeInAwareness, bool? disableBargeIn})
- BargeInConfig.fromJson(Map json_)
Properties
- bargeInAwareness ↔ bool?
-
If enabled, the agent will adapt its next response based on the assumption
that the user hasn't heard the full preceding agent message.
getter/setter pair
- disableBargeIn ↔ bool?
-
Deprecated:
disable_barge_inis deprecated in favor ofdisable_barge_in_controlin ChannelProfile.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited