Callback class

A callback defines the custom logic to be executed at various stages of agent interaction.

Constructors

Callback({String? description, bool? disabled, bool? proactiveExecutionEnabled, String? pythonCode})
Callback.fromJson(Map json_)

Properties

description String?
Human-readable description of the callback.
getter/setter pair
disabled bool?
Whether the callback is disabled.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
proactiveExecutionEnabled bool?
If enabled, the callback will also be executed on intermediate model outputs.
getter/setter pair
pythonCode String?
The python code to execute for the callback.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited