Changelog class
Changelogs represent a change made to the app or to an resource within the app.
Constructors
-
Changelog({String? action, String? author, String? createTime, List<
Map< ? dependentResources, String? description, String? displayName, String? name, Map<String, Object?> >String, Object?> ? newResource, Map<String, Object?> ? originalResource, String? resource, String? resourceType, String? sequenceNumber}) - Changelog.fromJson(Map json_)
Properties
- action ↔ String?
-
The action that was performed on the resource.
getter/setter pair
-
Email address of the change author.
getter/setter pair
- createTime ↔ String?
-
The time when the change was made.
getter/setter pair
-
dependentResources
↔ List<
Map< ?String, Object?> > -
The dependent resources that were changed.
getter/setter pair
- description ↔ String?
-
Description of the change.
getter/setter pair
- displayName ↔ String?
-
Display name of the change.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
-
newResource
↔ Map<
String, Object?> ? -
The new resource after the change.
getter/setter pair
-
originalResource
↔ Map<
String, Object?> ? -
The original resource before the change.
getter/setter pair
- resource ↔ String?
-
The resource that was changed.
getter/setter pair
- resourceType ↔ String?
-
The type of the resource that was changed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sequenceNumber ↔ String?
-
The monotonically increasing sequence number of the changelog.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited