ChannelProfile class
A ChannelProfile configures the agent's behavior for a specific communication channel, such as web UI or telephony.
Constructors
- ChannelProfile({String? channelType, bool? disableBargeInControl, bool? disableDtmf, ChannelProfileInstagramConfig? instagramConfig, String? noiseSuppressionLevel, ChannelProfilePersonaProperty? personaProperty, String? profileId, ChannelProfileWebWidgetConfig? webWidgetConfig, ChannelProfileWhatsAppConfig? whatsappConfig})
- ChannelProfile.fromJson(Map json_)
Properties
- channelType ↔ String?
-
The type of the channel profile.
getter/setter pair
- disableBargeInControl ↔ bool?
-
Whether to disable user barge-in control in the conversation.
getter/setter pair
- disableDtmf ↔ bool?
-
Whether to disable DTMF (dual-tone multi-frequency).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- instagramConfig ↔ ChannelProfileInstagramConfig?
-
Configuration specific to Instagram deployments.
getter/setter pair
- noiseSuppressionLevel ↔ String?
-
The noise suppression level of the channel profile.
getter/setter pair
- personaProperty ↔ ChannelProfilePersonaProperty?
-
The persona property of the channel profile.
getter/setter pair
- profileId ↔ String?
-
The unique identifier of the channel profile.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- webWidgetConfig ↔ ChannelProfileWebWidgetConfig?
-
The configuration for the web widget.
getter/setter pair
- whatsappConfig ↔ ChannelProfileWhatsAppConfig?
-
Configuration specific to WhatsApp deployments.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited