enableOriginCheck property
Indicates whether origin check for the web widget is enabled.
If true, the web widget will check the origin of the website that loads
the web widget and only allow it to be loaded in the same origin or any of
the allowed origins.
Optional.
Implementation
core.bool? enableOriginCheck;