Chunk class
A chunk of content within a message.
Constructors
Properties
- agentTransfer ↔ AgentTransfer?
-
Agent transfer event.
getter/setter pair
- blob ↔ Blob?
-
Blob data.
getter/setter pair
-
defaultVariables
↔ Map<
String, Object?> ? -
A struct represents default variables at the start of the conversation,
keyed by variable names.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- image ↔ Image?
-
Image data.
getter/setter pair
-
payload
↔ Map<
String, Object?> ? -
Custom payload data.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String?
-
Text data.
getter/setter pair
- toolCall ↔ ToolCall?
-
Tool execution request.
getter/setter pair
- toolResponse ↔ ToolResponse?
-
Tool execution response.
getter/setter pair
- transcript ↔ String?
-
Transcript associated with the audio.
getter/setter pair
-
updatedVariables
↔ Map<
String, Object?> ? -
A struct represents variables that were updated in the conversation, keyed
by variable names.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited