Citations class

Citations associated with the agent response.

Constructors

Citations({List<CitationsCitedChunk>? citedChunks})
Citations.fromJson(Map json_)

Properties

citedChunks List<CitationsCitedChunk>?
List of cited pieces of information.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited