CitationsCitedChunk class
Piece of cited information.
Constructors
- CitationsCitedChunk({bool? requiresAttribution, String? text, String? title, String? uri})
- CitationsCitedChunk.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requiresAttribution ↔ bool?
-
Whether this citation requires attribution to be shown to the end users.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String?
-
Text used for citation.
getter/setter pair
- title ↔ String?
-
Title of the cited document.
getter/setter pair
- uri ↔ String?
-
URI used for citation.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited