ClientFunction class

Represents a client-side function that the agent can invoke.

When the tool is chosen by the agent, control is handed off to the client. The client is responsible for executing the function and returning the result as a ToolResponse to continue the interaction with the agent.

Constructors

ClientFunction({String? description, String? name, Schema? parameters, Schema? response})
ClientFunction.fromJson(Map json_)

Properties

description String?
The function description.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The function name.
getter/setter pair
parameters Schema?
The schema of the function parameters.
getter/setter pair
response Schema?
The schema of the function response.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited