ConnectorTool class

A ConnectorTool allows connections to different integrations.

See: https://cloud.google.com/integration-connectors/docs/overview.

Constructors

ConnectorTool({Action? action, EndUserAuthConfig? authConfig, String? connection, String? description, String? name})
ConnectorTool.fromJson(Map json_)

Properties

action Action?
Action for the tool to use.
getter/setter pair
authConfig EndUserAuthConfig?
Configures how authentication is handled in Integration Connectors.
getter/setter pair
connection String?
The full resource name of the referenced Integration Connectors Connection.
getter/setter pair
description String?
The description of the tool that can be used by the Agent to decide whether to call this ConnectorTool.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the tool that can be used by the Agent to decide whether to call this ConnectorTool.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited