description property
The description of the tool that can be used by the Agent to decide whether to call this ConnectorTool.
Optional.
Implementation
core.String? description;
The description of the tool that can be used by the Agent to decide whether to call this ConnectorTool.
Optional.
core.String? description;