ConnectorToolset class

A toolset that generates tools from an Integration Connectors Connection.

Constructors

ConnectorToolset({EndUserAuthConfig? authConfig, String? connection, List<Action>? connectorActions})
ConnectorToolset.fromJson(Map json_)

Properties

authConfig EndUserAuthConfig?
Configures how authentication is handled in Integration Connectors.
getter/setter pair
connection String?
The full resource name of the referenced Integration Connectors Connection.
getter/setter pair
connectorActions List<Action>?
The list of connector actions/entity operations to generate tools for.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited