channelType property
- @Deprecated('Not supported. Member documentation may have more information.')
getter/setter pair
Please use input_types instead.
Deprecated. Possible string values are:
- "CHANNEL_TYPE_UNSPECIFIED" : Unspecified channel type.
- "TEXT" : The conversation only contains text messages between the end user and the agent.
- "AUDIO" : The conversation contains audio messages between the end user and the agent.
- "MULTIMODAL" : The conversation multi-modal messages (e.g. image) between the end user and the agent.
Implementation
@core.Deprecated(
'Not supported. Member documentation may have more information.',
)
core.String? channelType;