source property
Indicate the source of the conversation.
Output only. Possible string values are:
- "SOURCE_UNSPECIFIED" : Unspecified source.
- "LIVE" : The conversation is from the live end user.
- "SIMULATOR" : The conversation is from the simulator.
- "EVAL" : The conversation is from the evaluation.
- "AGENT_TOOL" : The conversation is from an agent tool. Agent tool runs the agent in a separate session, which is persisted for testing and debugging purposes.
Implementation
core.String? source;