ConversationLoggingSettings class

Settings to describe the conversation logging behaviors for the app.

Constructors

ConversationLoggingSettings({bool? disableConversationLogging, String? retentionWindow})
ConversationLoggingSettings.fromJson(Map json_)

Properties

disableConversationLogging ↔ bool?
Whether to disable conversation logging for the sessions.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
retentionWindow ↔ String?
Controls the retention window for the conversation.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited