ConversationTurn class
All information about a single turn in the conversation.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
messages
↔ List<
Message> ? -
List of messages in the conversation turn, including user input, agent
responses and intermediate events during the processing.
getter/setter pair
- resolvedDeveloperInstruction ↔ String?
-
The full dynamically resolved developer instruction generated from
templates.
getter/setter pair
- rootSpan ↔ Span?
-
The root span of the action processing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
templateAttributes
↔ Map<
String, Object?> ? -
Variables or configurations referenced by the template engine during
dynamic prompt generation.
getter/setter pair
- userIntendedText ↔ String?
-
The intended ground-truth text from the Simulated Caller (Polysynth).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited