type property
The type of the data store.
This field is readonly and populated by the server.
Output only. Possible string values are:
- "DATA_STORE_TYPE_UNSPECIFIED" : Not specified. This value indicates that the data store type is not specified, so it will not be used during search.
- "PUBLIC_WEB" : A data store that contains public web content.
- "UNSTRUCTURED" : A data store that contains unstructured private data.
- "FAQ" : A data store that contains structured data used as FAQ.
- "CONNECTOR" : A data store that is a connector to a first-party or a third-party service.
Implementation
core.String? type;