DataStoreConnectorConfig class
The connector config for the data store connection.
Constructors
- DataStoreConnectorConfig({String? collection, String? collectionDisplayName, String? dataSource})
- DataStoreConnectorConfig.fromJson(Map json_)
Properties
- collection ↔ String?
-
Resource name of the collection the data store belongs to.
getter/setter pair
- collectionDisplayName ↔ String?
-
Display name of the collection the data store belongs to.
getter/setter pair
- dataSource ↔ String?
-
The name of the data source.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited