type property
The type of the engine.
Output only. Possible string values are:
- "TYPE_UNSPECIFIED" : Unspecified engine type.
- "ENGINE_TYPE_SEARCH" : The SOLUTION_TYPE_SEARCH engine for the app. All connector data stores added to the app will be added to this engine.
- "ENGINE_TYPE_CHAT" : Chat engine type. The SOLUTION_TYPE_CHAT engine for the app. All connector data stores added to the app will be added to this engine.
Implementation
core.String? type;