condition property
An expression which specifies a boost condition.
The syntax is the same as filter expression syntax. Currently, the only supported condition is a list of BCP-47 lang codes. Example: To boost suggestions in languages en or fr: (lang_code: ANY("en", "fr"))
Required.
Implementation
core.String? condition;