groundingLevel property
The groundedness threshold of the answer based on the retrieved sources.
The value has a configurable range of [1, 5]. The level is used to threshold the groundedness of the answer, meaning that all responses with a groundedness score below the threshold will fall back to returning relevant snippets only. For example, a level of 3 means that the groundedness score must be 3 or higher for the response to be returned.
Optional.
Implementation
core.double? groundingLevel;