EndSession typedef
EndSession = $EndSession
Indicates the session has terminated, due to either successful completion (e.g. user says "Good bye!" ) or an agent escalation.
The agent will not process any further inputs after session is terminated and the client should half-close and disconnect after receiving all remaining responses from the agent.
Implementation
typedef EndSession = $EndSession;