EndUserAuthConfig class

End-user authentication configuration used for Connection calls.

The field values must be the names of context variables in the format $context.variables..

Properties

hashCode int
The hash code for this object.
no setterinherited
oauth2AuthCodeConfig EndUserAuthConfigOauth2AuthCodeConfig?
Oauth 2.0 Authorization Code authentication.
getter/setter pair
oauth2JwtBearerConfig EndUserAuthConfigOauth2JwtBearerConfig?
JWT Profile Oauth 2.0 Authorization Grant authentication.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited