EndUserAuthConfigOauth2AuthCodeConfig class
Oauth 2.0 Authorization Code authentication configuration.
Constructors
- EndUserAuthConfigOauth2AuthCodeConfig({String? oauthToken})
- EndUserAuthConfigOauth2AuthCodeConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- oauthToken ↔ String?
-
Oauth token parameter name to pass through.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited