errorHandlingStrategy property
The strategy to use for error handling.
Optional. Possible string values are:
- "ERROR_HANDLING_STRATEGY_UNSPECIFIED" : Unspecified error handling strategy.
- "NONE" : No specific handling is enabled.
- "FALLBACK_RESPONSE" : A fallback message will be returned to the user in case of system errors (e.g. LLM errors).
- "END_SESSION" : An EndSession signal will be emitted in case of system errors (e.g. LLM errors).
Implementation
core.String? errorHandlingStrategy;