ErrorHandlingSettingsFallbackResponseConfig class
Configuration for handling fallback responses.
Constructors
-
ErrorHandlingSettingsFallbackResponseConfig({Map<
String, String> ? customFallbackMessages, int? maxFallbackAttempts}) - ErrorHandlingSettingsFallbackResponseConfig.fromJson(Map json_)
Properties
-
customFallbackMessages
↔ Map<
String, String> ? -
The fallback messages in case of system errors (e.g. LLM errors), mapped
by
supported language code.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxFallbackAttempts ↔ int?
-
The maximum number of fallback attempts to make before the agent emitting
EndSession Signal.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited