EvaluationMetricsThresholds class
Threshold settings for metrics in an Evaluation.
Constructors
- EvaluationMetricsThresholds({EvaluationMetricsThresholdsGoldenEvaluationMetricsThresholds? goldenEvaluationMetricsThresholds, String? goldenHallucinationMetricBehavior, String? hallucinationMetricBehavior, String? scenarioHallucinationMetricBehavior})
- EvaluationMetricsThresholds.fromJson(Map json_)
Properties
- goldenEvaluationMetricsThresholds ↔ EvaluationMetricsThresholdsGoldenEvaluationMetricsThresholds?
-
The golden evaluation metrics thresholds.
getter/setter pair
- goldenHallucinationMetricBehavior ↔ String?
-
The hallucination metric behavior for golden evaluations.
getter/setter pair
- hallucinationMetricBehavior ↔ String?
-
Deprecated: Use
golden_hallucination_metric_behaviorinstead.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scenarioHallucinationMetricBehavior ↔ String?
-
The hallucination metric behavior for scenario evaluations.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited