Example class
An example represents a sample conversation between the user and the agent(s).
Constructors
Properties
- createTime ↔ String?
-
Timestamp when the example was created.
getter/setter pair
- description ↔ String?
-
Human-readable description of the example.
getter/setter pair
- displayName ↔ String?
-
Display name of the example.
getter/setter pair
- entryAgent ↔ String?
-
The agent that initially handles the conversation.
getter/setter pair
- etag ↔ String?
-
Etag used to ensure the object hasn't changed during a read-modify-write
operation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- invalid ↔ bool?
-
The example may become invalid if referencing resources are deleted.
getter/setter pair
-
messages
↔ List<
Message> ? -
The collection of messages that make up the conversation.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateTime ↔ String?
-
Timestamp when the example was last updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited