ExecuteToolRequest class

Request message for ToolService.ExecuteTool.

Constructors

ExecuteToolRequest({Map<String, Object?>? args, Map<String, Object?>? context, MockConfig? mockConfig, String? tool, ToolsetTool? toolsetTool, Map<String, Object?>? variables})
ExecuteToolRequest.fromJson(Map json_)

Properties

args Map<String, Object?>?
The input parameters and values for the tool in JSON object format.
getter/setter pair
context Map<String, Object?>?
The [ToolCallContext](https://docs.cloud.google.com/customer-engagement-ai/conversational-agents/ps/tool/python#environment for details) to be passed to the Python tool.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mockConfig MockConfig?
Mock configuration for the tool execution.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tool String?
The name of the tool to execute.
getter/setter pair
toolsetTool ToolsetTool?
The toolset tool to execute.
getter/setter pair
variables Map<String, Object?>?
The variables that are available for the tool execution.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited