mockConfig property
Mock configuration for the tool execution.
If this field is set, tools that call other tools will be mocked based on the provided patterns and responses.
Optional.
Implementation
MockConfig? mockConfig;
Mock configuration for the tool execution.
If this field is set, tools that call other tools will be mocked based on the provided patterns and responses.
Optional.
MockConfig? mockConfig;