googleSearchSuggestions property
The suggestions returned from Google Search as a result of invoking the Google Search Tool during the tool execution.
Implementation
GoogleSearchSuggestions? googleSearchSuggestions;
The suggestions returned from Google Search as a result of invoking the Google Search Tool during the tool execution.
GoogleSearchSuggestions? googleSearchSuggestions;