ExportAppRequest class
Request message for AgentService.ExportApp.
Constructors
- ExportAppRequest({String? appVersion, String? exportFormat, String? gcsUri})
- ExportAppRequest.fromJson(Map json_)
Properties
- appVersion ↔ String?
-
The resource name of the app version to export.
getter/setter pair
- exportFormat ↔ String?
-
The format to export the app in.
getter/setter pair
- gcsUri ↔ String?
-
The Google Cloud Storage URI to
which to export the app.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited