FileSearchTool class

The file search tool allows the agent to search across the files uploaded by the app/agent developer.

It has presets to give relatively good quality search over the uploaded files and summarization of the retrieved results.

Constructors

FileSearchTool({String? corpusType, String? description, String? fileCorpus, String? name})
FileSearchTool.fromJson(Map json_)

Properties

corpusType String?
The type of the corpus.
getter/setter pair
description String?
The tool description.
getter/setter pair
fileCorpus String?
The corpus where files are stored.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The tool name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited