GenerateChatTokenRequest class
Request message for WidgetService.GenerateChatToken.
Constructors
- GenerateChatTokenRequest({String? deployment, bool? liveHandoffEnabled, String? recaptchaToken})
- GenerateChatTokenRequest.fromJson(Map json_)
Properties
- deployment ↔ String?
-
The deployment of the app to use for the session.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- liveHandoffEnabled ↔ bool?
-
Indicates if live handoff is enabled for the session.
getter/setter pair
- recaptchaToken ↔ String?
-
The reCAPTCHA token generated by the client-side chat widget.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited