GoogleSearchTool class
Represents a tool to perform Google web searches for grounding.
See https://cloud.google.com/customer-engagement-ai/conversational-agents/ps/tool#google-search.
Constructors
-
GoogleSearchTool({List<
String> ? contextUrls, String? description, List<String> ? excludeDomains, String? name, List<String> ? preferredDomains, GoogleSearchToolPromptConfig? promptConfig}) - GoogleSearchTool.fromJson(Map json_)
Properties
-
contextUrls
↔ List<
String> ? -
Content will be fetched directly from these URLs for context and
grounding.
getter/setter pair
- description ↔ String?
-
Description of the tool's purpose.
getter/setter pair
-
excludeDomains
↔ List<
String> ? -
List of domains to be excluded from the search results.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
The name of the tool.
getter/setter pair
-
preferredDomains
↔ List<
String> ? -
Specifies domains to restrict search results to.
getter/setter pair
- promptConfig ↔ GoogleSearchToolPromptConfig?
-
Prompt instructions passed to planner on how the search results should be
processed for text and voice.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited