GoogleSearchToolPromptConfig class
Prompt settings used by the model when processing or summarizing the google search results.
Constructors
- GoogleSearchToolPromptConfig({String? textPrompt, String? voicePrompt})
- GoogleSearchToolPromptConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textPrompt ↔ String?
-
Defines the prompt used for the system instructions when interacting with
the agent in chat conversations.
getter/setter pair
- voicePrompt ↔ String?
-
Defines the prompt used for the system instructions when interacting with
the agent in voice conversations.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited