GuardrailCodeCallback class
Guardrail that blocks the conversation based on the code callbacks provided.
Constructors
- GuardrailCodeCallback({Callback? afterAgentCallback, Callback? afterModelCallback, Callback? beforeAgentCallback, Callback? beforeModelCallback})
- GuardrailCodeCallback.fromJson(Map json_)
Properties
- afterAgentCallback ↔ Callback?
-
The callback to execute after the agent is called.
getter/setter pair
- afterModelCallback ↔ Callback?
-
The callback to execute after the model is called.
getter/setter pair
- beforeAgentCallback ↔ Callback?
-
The callback to execute before the agent is called.
getter/setter pair
- beforeModelCallback ↔ Callback?
-
The callback to execute before the model is called.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited