GuardrailContentFilter class
Guardrail that bans certain content from being used in the conversation.
Constructors
Properties
-
bannedContents
↔ List<
String> ? -
List of banned phrases.
getter/setter pair
-
bannedContentsInAgentResponse
↔ List<
String> ? -
List of banned phrases.
getter/setter pair
-
bannedContentsInUserInput
↔ List<
String> ? -
List of banned phrases.
getter/setter pair
- disregardDiacritics ↔ bool?
-
If true, diacritics are ignored during matching.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- matchType ↔ String?
-
Match type for the content filter.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited