failOpen property
Determines the behavior when the guardrail encounters an LLM error.
- If true: the guardrail is bypassed. - If false (default): the guardrail triggers/blocks. Note: If a custom policy is provided, this field is ignored in favor of the policy's 'fail_open' configuration.
Optional.
Implementation
core.bool? failOpen;