ImportAppRequestImportOptions class
Configuration options for the app import process.
These options control how the import behaves, particularly when conflicts arise with existing app data.
Constructors
- ImportAppRequestImportOptions({String? conflictResolutionStrategy, bool? validateOnly})
- ImportAppRequestImportOptions.fromJson(Map json_)
Properties
- conflictResolutionStrategy ↔ String?
-
The strategy to use when resolving conflicts during import.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validateOnly ↔ bool?
-
Flag for dry-running the import process.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited