conflictResolutionStrategy property
The strategy to use when resolving conflicts during import.
Optional. Possible string values are:
- "CONFLICT_RESOLUTION_STRATEGY_UNSPECIFIED" : The conflict resolution strategy is unspecified.
- "REPLACE" : Replace existing data with imported data. If an app with the
same
app_idalready exists, its content will be updated based on the imported app. - Resources (App, Agents, Tools, Examples, Guardrails, Toolsets) in the imported app that have the same display name as existing resources will overwrite the existing ones. - Imported resources with new display names will be created. - Existing resources that do not have a matching display name in the imported app will remain untouched. - "OVERWRITE" : Overwrite existing data with imported data. If an app with
the same
app_idalready exists, its content will be overwritten with the imported app. - Existing resources (Agents, Tools, Examples, Guardrails, Toolsets) in the app will be deleted. - Imported resources will be created as new resources.
Implementation
core.String? conflictResolutionStrategy;