validateOnly property
Flag for dry-running the import process.
If set to true, the import process will only perform validations and will not make any changes to the existing app or create a new one.
Optional.
Implementation
core.bool? validateOnly;
Flag for dry-running the import process.
If set to true, the import process will only perform validations and will not make any changes to the existing app or create a new one.
Optional.
core.bool? validateOnly;