InputAudioConfig class
InputAudioConfig configures how the CES agent should interpret the incoming audio data.
Constructors
- InputAudioConfig({String? audioEncoding, String? noiseSuppressionLevel, int? sampleRateHertz})
- InputAudioConfig.fromJson(Map json_)
Properties
- audioEncoding ↔ String?
-
The encoding of the input audio data.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- noiseSuppressionLevel ↔ String?
-
Whether to enable noise suppression on the input audio.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRateHertz ↔ int?
-
The sample rate (in Hertz) of the input audio data.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited