InstagramCredentials class

Ephemeral Meta credentials for Instagram native integration.

Constructors

InstagramCredentials({String? authCode, String? conversationProfileId})
InstagramCredentials.fromJson(Map json_)

Properties

authCode String?
The Meta auth code provided by the embedded signup flow.
getter/setter pair
conversationProfileId String?
The Conversation Profile ID to use for the deployment.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited