LanguageSettings class

Language settings of the app.

Constructors

LanguageSettings({String? defaultLanguageCode, bool? enableMultilingualSupport, String? fallbackAction, List<String>? supportedLanguageCodes})
LanguageSettings.fromJson(Map json_)

Properties

defaultLanguageCode String?
The default language code of the app.
getter/setter pair
enableMultilingualSupport bool?
Enables multilingual support.
getter/setter pair
fallbackAction String?
Deprecated: This feature is no longer supported.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
supportedLanguageCodes List<String>?
List of languages codes supported by the app, in addition to the default_language_code.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited