LfA2aV1AgentCard class
A self-describing manifest for an agent.
It provides essential metadata including the agent's identity, capabilities, skills, supported communication methods, and security requirements. Next ID: 20
Constructors
-
LfA2aV1AgentCard({LfA2aV1AgentCapabilities? capabilities, List<
String> ? defaultInputModes, List<String> ? defaultOutputModes, String? description, String? documentationUrl, String? iconUrl, String? name, LfA2aV1AgentProvider? provider, List<LfA2aV1SecurityRequirement> ? securityRequirements, Map<String, LfA2aV1SecurityScheme> ? securitySchemes, List<LfA2aV1AgentCardSignature> ? signatures, List<LfA2aV1AgentSkill> ? skills, List<LfA2aV1AgentInterface> ? supportedInterfaces, String? version}) - LfA2aV1AgentCard.fromJson(Map json_)
Properties
- capabilities ↔ LfA2aV1AgentCapabilities?
-
A2A Capability set supported by the agent.
getter/setter pair
-
defaultInputModes
↔ List<
String> ? -
protolint:enable REPEATED_FIELD_NAMES_PLURALIZED The set of interaction
modes that the agent supports across all skills.
getter/setter pair
-
defaultOutputModes
↔ List<
String> ? -
The media types supported as outputs from this agent.
getter/setter pair
- description ↔ String?
-
A human-readable description of the agent, assisting users and other
agents in understanding its purpose.
getter/setter pair
- documentationUrl ↔ String?
-
A URL providing additional documentation about the agent.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconUrl ↔ String?
-
A URL to an icon for the agent.
getter/setter pair
- name ↔ String?
-
A human readable name for the agent.
getter/setter pair
- provider ↔ LfA2aV1AgentProvider?
-
The service provider of the agent.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
securityRequirements
↔ List<
LfA2aV1SecurityRequirement> ? -
Security requirements for contacting the agent.
getter/setter pair
-
securitySchemes
↔ Map<
String, LfA2aV1SecurityScheme> ? -
The security scheme details used for authenticating with this agent.
getter/setter pair
-
signatures
↔ List<
LfA2aV1AgentCardSignature> ? -
JSON Web Signatures computed for this
AgentCard.getter/setter pair -
skills
↔ List<
LfA2aV1AgentSkill> ? -
Skills represent the abilities of an agent.
getter/setter pair
-
supportedInterfaces
↔ List<
LfA2aV1AgentInterface> ? -
Ordered list of supported interfaces.
getter/setter pair
- version ↔ String?
-
The version of the agent.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited