role property
Identifies the sender of the message.
Required. Possible string values are:
- "ROLE_UNSPECIFIED" : The role is unspecified.
- "ROLE_USER" : The message is from the client to the server.
- "ROLE_AGENT" : The message is from the server to the client.
Implementation
core.String? role;