LfA2aV1Part class

Part represents a container for a section of communication content.

Parts can be purely textual, some sort of file (image, video, etc) or a structured data blob (i.e. JSON).

Constructors

LfA2aV1Part({Object? data, String? filename, String? mediaType, Map<String, Object?>? metadata, String? raw, String? text, String? url})
LfA2aV1Part.fromJson(Map json_)

Properties

data Object?
Arbitrary structured data as a JSON value (object, array, string, number, boolean, or null).
getter/setter pair
filename String?
An optional filename for the file (e.g., "document.pdf").
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
mediaType String?
The media_type (MIME type) of the part content (e.g., "text/plain", "application/json", "image/png").
getter/setter pair
metadata Map<String, Object?>?
metadata associated with this part.
getter/setter pair
raw String?
The raw byte content of a file.
getter/setter pair
rawAsBytes List<int>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The string content of the text part.
getter/setter pair
url String?
A url pointing to the file's content.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited