LfA2aV1SecurityScheme class
Defines a security scheme that can be used to secure an agent's endpoints.
This is a discriminated union type based on the OpenAPI 3.2 Security Scheme Object. See: https://spec.openapis.org/oas/v3.2.0.html#security-scheme-object
Constructors
- LfA2aV1SecurityScheme({LfA2aV1APIKeySecurityScheme? apiKeySecurityScheme, LfA2aV1HTTPAuthSecurityScheme? httpAuthSecurityScheme, LfA2aV1MutualTlsSecurityScheme? mtlsSecurityScheme, LfA2aV1OAuth2SecurityScheme? oauth2SecurityScheme, LfA2aV1OpenIdConnectSecurityScheme? openIdConnectSecurityScheme})
- LfA2aV1SecurityScheme.fromJson(Map json_)
Properties
- apiKeySecurityScheme ↔ LfA2aV1APIKeySecurityScheme?
-
API key-based authentication.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpAuthSecurityScheme ↔ LfA2aV1HTTPAuthSecurityScheme?
-
HTTP authentication (Basic, Bearer, etc.).
getter/setter pair
- mtlsSecurityScheme ↔ LfA2aV1MutualTlsSecurityScheme?
-
Mutual TLS authentication.
getter/setter pair
- oauth2SecurityScheme ↔ LfA2aV1OAuth2SecurityScheme?
-
OAuth 2.0 authentication.
getter/setter pair
- openIdConnectSecurityScheme ↔ LfA2aV1OpenIdConnectSecurityScheme?
-
OpenID Connect authentication.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited