LfA2aV1SendMessageConfiguration class

Configuration of a send message request.

Constructors

LfA2aV1SendMessageConfiguration({List<String>? acceptedOutputModes, int? historyLength, bool? returnImmediately, LfA2aV1TaskPushNotificationConfig? taskPushNotificationConfig})
LfA2aV1SendMessageConfiguration.fromJson(Map json_)

Properties

acceptedOutputModes List<String>?
A list of media types the client is prepared to accept for response parts.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
historyLength int?
The maximum number of most recent messages from the task's history to retrieve in the response.
getter/setter pair
returnImmediately bool?
If true, the operation returns immediately after creating the task, even if processing is still in progress.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
taskPushNotificationConfig LfA2aV1TaskPushNotificationConfig?
Configuration for the agent to send push notifications for task updates.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited