historyLength property
The maximum number of most recent messages from the task's history to retrieve in the response.
An unset value means the client does not impose any limit. A value of zero is a request to not include any messages. The server MUST NOT return more messages than the provided value, but MAY apply a lower limit.
Implementation
core.int? historyLength;