taskPushNotificationConfig property
Configuration for the agent to send push notifications for task updates.
Task id should be empty when sending this configuration in a SendMessage
request.
Implementation
LfA2aV1TaskPushNotificationConfig? taskPushNotificationConfig;