LfA2aV1SendMessageRequest class

Represents a request for the SendMessage method.

Properties

configuration ↔ LfA2aV1SendMessageConfiguration?
Configuration for the send request.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
message ↔ LfA2aV1Message?
The message to send to the agent.
getter/setter pair
metadata ↔ Map<String, Object?>?
A flexible key-value map for passing additional context or parameters.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited