LfA2aV1TaskPushNotificationConfig class
A container associating a push notification configuration with a specific task.
Constructors
- LfA2aV1TaskPushNotificationConfig({LfA2aV1AuthenticationInfo? authentication, String? id, String? taskId, String? tenant, String? token, String? url})
- LfA2aV1TaskPushNotificationConfig.fromJson(Map json_)
Properties
- authentication ↔ LfA2aV1AuthenticationInfo?
-
Authentication information required to send the notification.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The push notification configuration details.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- taskId ↔ String?
-
The ID of the task this configuration is associated with.
getter/setter pair
- tenant ↔ String?
-
Opaque routing identifier.
getter/setter pair
- token ↔ String?
-
A token unique for this task or session.
getter/setter pair
- url ↔ String?
-
The URL where the notification should be sent.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited