ListChangelogsResponse class
Response message for AgentService.ListChangelogs.
Constructors
-
ListChangelogsResponse({List<
Changelog> ? changelogs, String? nextPageToken}) - ListChangelogsResponse.fromJson(Map json_)
Properties
-
changelogs
↔ List<
Changelog> ? -
The list of changelogs.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
A token that can be sent as ListChangelogsRequest.page_token to retrieve
the next page.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited