LoggingSettings class

Settings to describe the logging behaviors for the app.

Constructors

LoggingSettings({AudioRecordingConfig? audioRecordingConfig, BigQueryExportSettings? bigqueryExportSettings, CloudLoggingSettings? cloudLoggingSettings, ConversationLoggingSettings? conversationLoggingSettings, AudioRecordingConfig? evaluationAudioRecordingConfig, MetricAnalysisSettings? metricAnalysisSettings, RedactionConfig? redactionConfig, AudioRecordingConfig? unredactedAudioRecordingConfig, BigQueryExportSettings? unredactedBigqueryExportSettings})
LoggingSettings.fromJson(Map json_)

Properties

audioRecordingConfig ↔ AudioRecordingConfig?
Configuration for how audio interactions should be recorded.
getter/setter pair
bigqueryExportSettings ↔ BigQueryExportSettings?
Configures the BigQuery export behaviors for the app.
getter/setter pair
cloudLoggingSettings ↔ CloudLoggingSettings?
Settings to describe the Cloud Logging behaviors for the app.
getter/setter pair
conversationLoggingSettings ↔ ConversationLoggingSettings?
Settings to describe the conversation logging behaviors for the app.
getter/setter pair
evaluationAudioRecordingConfig ↔ AudioRecordingConfig?
Configuration for how audio interactions should be recorded for the evaluation.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
metricAnalysisSettings ↔ MetricAnalysisSettings?
Settings to describe the conversation data collection behaviors for the LLM analysis pipeline for the app.
getter/setter pair
redactionConfig ↔ RedactionConfig?
Configuration for how sensitive data should be redacted.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unredactedAudioRecordingConfig ↔ AudioRecordingConfig?
Configures an additional recording of unredacted audio.
getter/setter pair
unredactedBigqueryExportSettings ↔ BigQueryExportSettings?
Configures the BigQuery export behaviors for the app.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited