McpToolDefinition class
Container for a tool's core definition elements that are snapshot.
Schemas in the snapshot are used as-is and cannot be overridden.
Constructors
- McpToolDefinition({String? description, Schema? inputSchema, Schema? outputSchema})
- McpToolDefinition.fromJson(Map json_)
Properties
- description ↔ String?
-
The description of the MCP tool.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputSchema ↔ Schema?
-
The schema of the input arguments of the MCP tool.
getter/setter pair
- outputSchema ↔ Schema?
-
The schema of the output arguments of the MCP tool.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited