llmMetricsOptedOut property
Whether to collect conversation data for llm analysis metrics.
If true, conversation data will not be collected for llm analysis metrics; otherwise, conversation data will be collected.
Optional.
Implementation
core.bool? llmMetricsOptedOut;