MockedToolCall class
A mocked tool call.
Expresses the target tool + a pattern to match against that tool's args / inputs. If the pattern matches, then the mock response will be returned.
Constructors
-
MockedToolCall({Map<
String, Object?> ? expectedArgsPattern, Map<String, Object?> ? mockResponse, String? tool, String? toolId, ToolsetTool? toolset}) - MockedToolCall.fromJson(Map json_)
Properties
-
expectedArgsPattern
↔ Map<
String, Object?> ? -
A pattern to match against the args / inputs of all dispatched tool calls.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mockResponse
↔ Map<
String, Object?> ? -
The mock response / output to return if the tool call args / inputs match
the pattern.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tool ↔ String?
-
Use tool_identifier instead.
getter/setter pair
- toolId ↔ String?
-
The name of the tool to mock.
getter/setter pair
- toolset ↔ ToolsetTool?
-
The toolset to mock.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited