OpenApiToolset class

A toolset that contains a list of tools that are defined by an OpenAPI schema.

Constructors

OpenApiToolset({ApiAuthentication? apiAuthentication, bool? ignoreUnknownFields, String? openApiSchema, ServiceDirectoryConfig? serviceDirectoryConfig, TlsConfig? tlsConfig, String? url})
OpenApiToolset.fromJson(Map json_)

Properties

apiAuthentication ApiAuthentication?
Authentication information required by the API.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
ignoreUnknownFields bool?
If true, the agent will ignore unknown fields in the API response for all operations defined in the OpenAPI schema.
getter/setter pair
openApiSchema String?
The OpenAPI schema of the toolset.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceDirectoryConfig ServiceDirectoryConfig?
Service Directory configuration.
getter/setter pair
tlsConfig TlsConfig?
The TLS configuration.
getter/setter pair
url String?
The server URL of the Open API schema.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited