ProjectsLocationsAppsConversationsResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchDelete(BatchDeleteConversationsRequest request, String parent, {String? $fields})
→ Future<Operation>
-
Batch deletes the specified conversations.
-
delete(String name, {String? source, String? $fields})
→ Future<Empty>
-
Deletes the specified conversation.
-
get(String name, {String? source, String? view, String? $fields})
→ Future<Conversation>
-
Gets details of the specified conversation.
-
list(String parent, {String? filter, int? pageSize, String? pageToken, String? source, List<String>? sources, String? $fields})
→ Future<ListConversationsResponse>
-
Lists conversations in the given app.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited