get method
Gets details of the specified conversation.
Request parameters:
name - Required. The resource name of the conversation to retrieve.
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+/conversations/\[^/\]+$.
source - Optional. Indicate the source of the conversation. If not set,
all source will be searched.
Possible string values are:
- "SOURCE_UNSPECIFIED" : Unspecified source.
- "LIVE" : The conversation is from the live end user.
- "SIMULATOR" : The conversation is from the simulator.
- "EVAL" : The conversation is from the evaluation.
- "AGENT_TOOL" : The conversation is from an agent tool. Agent tool runs the agent in a separate session, which is persisted for testing and debugging purposes.
view - Optional. The view specifying which fields in the response should
be populated.
Possible string values are:
- "CONVERSATION_VIEW_UNSPECIFIED" : Not specified, defaults to CONVERSATION_VIEW_BASIC.
- "CONVERSATION_VIEW_BASIC" : The basic view. Returns everything except resolved instructions.
- "CONVERSATION_VIEW_FULL" : The full view. Includes resolved instructions dynamically per turn.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Conversation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Conversation> get(
core.String name, {
core.String? source,
core.String? view,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'source': ?source == null ? null : [source],
'view': ?view == null ? null : [view],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return Conversation.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}