ProjectsLocationsAppsExamplesResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(Example request, String parent, {String? exampleId, String? $fields})
→ Future<Example>
-
Creates a new example in the given app.
-
delete(String name, {String? etag, String? $fields})
→ Future<Empty>
-
Deletes the specified example.
-
get(String name, {String? $fields})
→ Future<Example>
-
Gets details of the specified example.
-
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields})
→ Future<ListExamplesResponse>
-
Lists examples in the given app.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(Example request, String name, {String? updateMask, String? $fields})
→ Future<Example>
-
Updates the specified example.
-
toString()
→ String
-
A string representation of this object.
inherited