delete method
Deletes the specified example.
Request parameters:
name - Required. The resource name of the example to delete.
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+/examples/\[^/\]+$.
etag - Optional. The current etag of the example. If an etag is not
provided, the deletion will overwrite any concurrent changes. If an etag
is provided and does not match the current etag of the example, deletion
will be blocked and an ABORTED error will be returned.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Empty.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Empty> delete(
core.String name, {
core.String? etag,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'etag': ?etag == null ? null : [etag],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'DELETE',
queryParams: queryParams_,
);
return Empty.fromJson(response_ as core.Map<core.String, core.dynamic>);
}