ProjectsLocationsAppsSessionsResource class
Constructors
- ProjectsLocationsAppsSessionsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
generateChatToken(
GenerateChatTokenRequest request, String name, {String? $fields}) → Future< GenerateChatTokenResponse> - Generates a session scoped token for chat widget to authenticate with Session APIs.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
runSession(
RunSessionRequest request, String session, {String? $fields}) → Future< RunSessionResponse> - Initiates a single-turn interaction with the CES agent within a session.
-
streamRunSession(
RunSessionRequest request, String session, {String? $fields}) → Future< RunSessionResponse> - Initiates a single-turn interaction with the CES agent.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited