patch method
Updates the specified tool.
request - The metadata request object.
Request parameters:
name - Identifier. The resource name of the tool. Format: *
projects/{project}/locations/{location}/apps/{app}/tools/{tool} for
standalone tools. *
projects/{project}/locations/{location}/apps/{app}/toolsets/{toolset}/tools/{tool}
for tools retrieved from a toolset. These tools are dynamic and
output-only; they cannot be referenced directly where a tool is expected.
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/apps/\[^/\]+/tools/\[^/\]+$.
updateMask - Optional. Field mask is used to control which fields get
updated. If the mask is not present, all fields will be updated.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Tool.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Tool> patch(
Tool request,
core.String name, {
core.String? updateMask,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'updateMask': ?updateMask == null ? null : [updateMask],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'PATCH',
body: body_,
queryParams: queryParams_,
);
return Tool.fromJson(response_ as core.Map<core.String, core.dynamic>);
}