RetrieveToolSchemaResponse class
Response message for ToolService.RetrieveToolSchema.
Constructors
- RetrieveToolSchemaResponse({Schema? inputSchema, Schema? outputSchema, String? tool, ToolsetTool? toolsetTool})
- RetrieveToolSchemaResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputSchema ↔ Schema?
-
The schema of the tool input parameters.
getter/setter pair
- outputSchema ↔ Schema?
-
The schema of the tool output parameters.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tool ↔ String?
-
The name of the tool that the schema is for.
getter/setter pair
- toolsetTool ↔ ToolsetTool?
-
The toolset tool that the schema is for.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited