RetrieveToolsRequest class

Request message for ToolService.RetrieveTools.

Constructors

RetrieveToolsRequest({bool? bypassPersistenceConfig, List<String>? toolIds})
RetrieveToolsRequest.fromJson(Map json_)

Properties

bypassPersistenceConfig bool?
If true, the returned tools will contain raw descriptions and schemas directly from the server, bypassing any stored persistence configurations (overrides/snapshots).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolIds List<String>?
The identifiers of the tools to retrieve from the toolset.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited