bypassPersistenceConfig property
If true, the returned tools will contain raw descriptions and schemas directly from the server, bypassing any stored persistence configurations (overrides/snapshots).
Optional.
Implementation
core.bool? bypassPersistenceConfig;