ServiceAccountAuthConfig class
Configurations for authentication using a custom service account.
Constructors
-
ServiceAccountAuthConfig({List<
String> ? scopes, String? serviceAccount}) - ServiceAccountAuthConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
↔ List<
String> ? -
The OAuth scopes to grant.
getter/setter pair
- serviceAccount ↔ String?
-
The email address of the service account used for authentication.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited