serviceAccount property
The email address of the service account used for authentication.
CES uses this service account to exchange an access token and the access
token is then sent in the Authorization header of the request. The
service account must have the roles/iam.serviceAccountTokenCreator role
granted to the CES service agent
service-@gcp-sa-ces.iam.gserviceaccount.com.
Required.
Implementation
core.String? serviceAccount;