enableTextStreaming property
Whether to enable streaming text outputs from the model.
By default, text outputs from the model are collected before sending to the client. NOTE: This is only supported for text (non-voice) sessions via StreamRunSession or BidiRunSession.
Optional.
Implementation
core.bool? enableTextStreaming;