historicalContexts property
The historical context of the session, including user inputs, agent responses, and other messages.
Typically, CES agent would manage session automatically so client doesn't need to explicitly populate this field. However, client can optionally override the historical contexts to force the session start from certain state.
Optional.
Implementation
core.List<Message>? historicalContexts;