useToolFakes property
Whether to use tool fakes for the session.
If this field is set, the agent will attempt use tool fakes instead of calling the real tools.
Optional.
Implementation
core.bool? useToolFakes;
Whether to use tool fakes for the session.
If this field is set, the agent will attempt use tool fakes instead of calling the real tools.
Optional.
core.bool? useToolFakes;