SessionInput class

Input for the session.

Constructors

SessionInput({String? audio, Blob? blob, String? dtmf, Event? event, Image? image, String? text, ToolResponses? toolResponses, Map<String, Object?>? variables, bool? willContinue})
SessionInput.fromJson(Map json_)

Properties

audio String?
Audio data from the end user.
getter/setter pair
audioAsBytes List<int>
getter/setter pair
blob Blob?
Blob data from the end user.
getter/setter pair
dtmf String?
DTMF digits from the end user.
getter/setter pair
event Event?
Event input.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image Image?
Image data from the end user.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
Text data from the end user.
getter/setter pair
toolResponses ToolResponses?
Execution results for the tool calls from the client.
getter/setter pair
variables Map<String, Object?>?
Contextual variables for the session, keyed by name.
getter/setter pair
willContinue bool?
A flag to indicate if the current message is a fragment of a larger input in the bidi streaming session.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited