willContinue property
A flag to indicate if the current message is a fragment of a larger input in the bidi streaming session.
When set to true, the agent defers processing until it receives a
subsequent message where will_continue is false, or until the system
detects an endpoint in the audio input. NOTE: This field does not apply to
audio and DTMF inputs, as they are always processed automatically based on
the endpointing signal.
Optional.
Implementation
core.bool? willContinue;