SessionOutput class
Output for the session.
Constructors
-
SessionOutput({String? audio, Citations? citations, List<
Map< ? context, SessionOutputDiagnosticInfo? diagnosticInfo, EndSession? endSession, GoogleSearchSuggestions? googleSearchSuggestions, Map<String, Object?> >String, Object?> ? payload, String? text, ToolCalls? toolCalls, bool? turnCompleted, int? turnIndex}) - SessionOutput.fromJson(Map json_)
Properties
- audio ↔ String?
-
Output audio from the CES agent.
getter/setter pair
-
audioAsBytes
↔ List<
int> -
getter/setter pair
- citations ↔ Citations?
-
Citations that provide the source information for the agent's generated
text.
getter/setter pair
-
context
↔ List<
Map< ?String, Object?> > -
Context messages for external supervision guardrails.
getter/setter pair
- diagnosticInfo ↔ SessionOutputDiagnosticInfo?
-
Diagnostic information contains execution details during the processing of
the input.
getter/setter pair
- endSession ↔ EndSession?
-
Indicates the session has ended.
getter/setter pair
- googleSearchSuggestions ↔ GoogleSearchSuggestions?
-
The suggestions returned from Google Search as a result of invoking the
GoogleSearchTool.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
payload
↔ Map<
String, Object?> ? -
Custom payload with structured output from the CES agent.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text ↔ String?
-
Output text from the CES agent.
getter/setter pair
- toolCalls ↔ ToolCalls?
-
Request for the client to execute the tools.
getter/setter pair
- turnCompleted ↔ bool?
-
If true, the CES agent has detected the end of the current conversation
turn and will provide no further output for this turn.
getter/setter pair
- turnIndex ↔ int?
-
Indicates the sequential order of conversation turn to which this output
belongs to, starting from 1.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited