Span class

A span is a unit of work or a single operation during the request processing.

Constructors

Span({Map<String, Object?>? attributes, List<Span>? childSpans, String? duration, String? endTime, String? name, String? startTime})
Span.fromJson(Map json_)

Properties

attributes Map<String, Object?>?
Key-value attributes associated with the span.
getter/setter pair
childSpans List<Span>?
The child spans that are nested under this span.
getter/setter pair
duration String?
The duration of the span.
getter/setter pair
endTime String?
The end time of the span.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the span.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String?
The start time of the span.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited