SynthesizeSpeechConfig class
Configuration for how the agent response should be synthesized.
Constructors
- SynthesizeSpeechConfig({String? consentAudioGcsUri, String? instruction, String? model, double? speakingRate, String? voice, String? voiceSampleGcsUri})
- SynthesizeSpeechConfig.fromJson(Map json_)
Properties
- consentAudioGcsUri ↔ String?
-
Deprecated: Use
custom_voice_samplesin AudioProcessingConfig instead.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- instruction ↔ String?
-
The instruction used to synthesize speech when using a generative model.
getter/setter pair
- model ↔ String?
-
The model used to synthesize audio.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speakingRate ↔ double?
-
The speaking rate/speed in the range [0.25, 2.0].
getter/setter pair
- voice ↔ String?
-
The name of the voice.
getter/setter pair
- voiceSampleGcsUri ↔ String?
-
Deprecated: Use
custom_voice_samplesin AudioProcessingConfig instead.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited