Tool class
A tool represents an action that the CES agent can take to achieve certain goals.
Constructors
- Tool({AgentTool? agentTool, ClientFunction? clientFunction, ConnectorTool? connectorTool, String? createTime, DataStoreTool? dataStoreTool, String? displayName, String? etag, String? executionType, FileSearchTool? fileSearchTool, String? generatedSummary, GoogleSearchTool? googleSearchTool, McpTool? mcpTool, String? name, OpenApiTool? openApiTool, PythonFunction? pythonFunction, RemoteAgentTool? remoteAgentTool, SystemTool? systemTool, String? timeout, ToolFakeConfig? toolFakeConfig, String? updateTime, WidgetTool? widgetTool})
- Tool.fromJson(Map json_)
Properties
- agentTool ↔ AgentTool?
-
The agent tool.
getter/setter pair
- clientFunction ↔ ClientFunction?
-
The client function.
getter/setter pair
- connectorTool ↔ ConnectorTool?
-
The Integration Connector tool.
getter/setter pair
- createTime ↔ String?
-
Timestamp when the tool was created.
getter/setter pair
- dataStoreTool ↔ DataStoreTool?
-
The data store tool.
getter/setter pair
- displayName ↔ String?
-
The display name of the tool, derived based on the tool's type.
getter/setter pair
- etag ↔ String?
-
Etag used to ensure the object hasn't changed during a read-modify-write
operation.
getter/setter pair
- executionType ↔ String?
-
The execution type of the tool.
getter/setter pair
- fileSearchTool ↔ FileSearchTool?
-
The file search tool.
getter/setter pair
- generatedSummary ↔ String?
-
If the tool is generated by the LLM assistant, this field contains a
descriptive summary of the generation.
getter/setter pair
- googleSearchTool ↔ GoogleSearchTool?
-
The google search tool.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mcpTool ↔ McpTool?
-
The MCP tool.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- openApiTool ↔ OpenApiTool?
-
The open API tool.
getter/setter pair
- pythonFunction ↔ PythonFunction?
-
The python function tool.
getter/setter pair
- remoteAgentTool ↔ RemoteAgentTool?
-
The remote agent tool.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- systemTool ↔ SystemTool?
-
The system tool.
getter/setter pair
- timeout ↔ String?
-
The timeout for the tool execution.
getter/setter pair
- toolFakeConfig ↔ ToolFakeConfig?
-
Configuration for tool behavior in fake mode.
getter/setter pair
- updateTime ↔ String?
-
Timestamp when the tool was last updated.
getter/setter pair
- widgetTool ↔ WidgetTool?
-
The widget tool.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited