ToolCall class
Request for the client or the agent to execute the specified tool.
Constructors
-
ToolCall({Map<
String, Object?> ? args, String? displayName, String? id, String? tool, ToolsetTool? toolsetTool}) - ToolCall.fromJson(Map json_)
Properties
-
args
↔ Map<
String, Object?> ? -
The input parameters and values for the tool in JSON object format.
getter/setter pair
- displayName ↔ String?
-
Display name of the tool.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The unique identifier of the tool call.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tool ↔ String?
-
The name of the tool to execute.
getter/setter pair
- toolsetTool ↔ ToolsetTool?
-
The toolset tool to execute.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited