ToolResponse class
The execution result of a specific tool from the client or the agent.
Constructors
-
ToolResponse({String? displayName, String? id, Map<
String, Object?> ? response, String? tool, ToolsetTool? toolsetTool}) - ToolResponse.fromJson(Map json_)
Properties
- displayName ↔ String?
-
Display name of the tool.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The matching ID of the tool call the response is for.
getter/setter pair
-
response
↔ Map<
String, Object?> ? -
The tool execution result in JSON object format.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tool ↔ String?
-
The name of the tool to execute.
getter/setter pair
- toolsetTool ↔ ToolsetTool?
-
The toolset tool that got executed.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited