Toolset class
A toolset represents a group of dynamically managed tools that can be used by the agent.
Constructors
- Toolset({ConnectorToolset? connectorToolset, String? createTime, String? description, String? displayName, String? etag, String? executionType, McpToolset? mcpToolset, String? name, OpenApiToolset? openApiToolset, String? timeout, ToolFakeConfig? toolFakeConfig, String? updateTime})
- Toolset.fromJson(Map json_)
Properties
- connectorToolset ↔ ConnectorToolset?
-
A toolset that generates tools from an Integration Connectors Connection.
getter/setter pair
- createTime ↔ String?
-
Timestamp when the toolset was created.
getter/setter pair
- description ↔ String?
-
The description of the toolset.
getter/setter pair
- displayName ↔ String?
-
The display name of the toolset.
getter/setter pair
- etag ↔ String?
-
ETag used to ensure the object hasn't changed during a read-modify-write
operation.
getter/setter pair
- executionType ↔ String?
-
The execution type of the tools in the toolset.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mcpToolset ↔ McpToolset?
-
A toolset that contains a list of tools that are offered by the MCP
server.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- openApiToolset ↔ OpenApiToolset?
-
A toolset that contains a list of tools that are defined by an OpenAPI
schema.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeout ↔ String?
-
The timeout for the toolset execution.
getter/setter pair
- toolFakeConfig ↔ ToolFakeConfig?
-
Configuration for tools behavior in fake mode.
getter/setter pair
- updateTime ↔ String?
-
Timestamp when the toolset was last updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited