TransferRule class
Rule for transferring to a specific agent.
Constructors
- TransferRule({String? childAgent, TransferRuleDeterministicTransfer? deterministicTransfer, String? direction, TransferRuleDisablePlannerTransfer? disablePlannerTransfer})
- TransferRule.fromJson(Map json_)
Properties
- childAgent ↔ String?
-
The resource name of the child agent the rule applies to.
getter/setter pair
- deterministicTransfer ↔ TransferRuleDeterministicTransfer?
-
A rule that immediately transfers to the target agent when the condition
is met.
getter/setter pair
- direction ↔ String?
-
The direction of the transfer.
getter/setter pair
- disablePlannerTransfer ↔ TransferRuleDisablePlannerTransfer?
-
Rule that prevents the planner from transferring to the target agent.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited