direction property
The direction of the transfer.
Required. Possible string values are:
- "DIRECTION_UNSPECIFIED" : Unspecified direction.
- "PARENT_TO_CHILD" : Transfer from the parent agent to the child agent.
- "CHILD_TO_PARENT" : Transfer from the child agent to the parent agent.
Implementation
core.String? direction;