TransferRuleDeterministicTransfer class

Deterministic transfer rule.

When the condition evaluates to true, the transfer occurs.

Properties

expressionCondition ExpressionCondition?
A rule that evaluates a session state condition.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
pythonCodeCondition PythonCodeCondition?
A rule that uses Python code block to evaluate the conditions.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited