pythonCodeCondition property
A rule that uses Python code block to evaluate the conditions.
If the condition evaluates to true, the transfer occurs.
Optional.
Implementation
PythonCodeCondition? pythonCodeCondition;
A rule that uses Python code block to evaluate the conditions.
If the condition evaluates to true, the transfer occurs.
Optional.
PythonCodeCondition? pythonCodeCondition;