expressionCondition property
If the condition evaluates to true, planner will not be allowed to transfer to the target agent.
Required.
Implementation
ExpressionCondition? expressionCondition;
If the condition evaluates to true, planner will not be allowed to transfer to the target agent.
Required.
ExpressionCondition? expressionCondition;