TriggerAction class
Action that is taken when a certain precondition is met.
Constructors
- TriggerAction({TriggerActionGenerativeAnswer? generativeAnswer, TriggerActionRespondImmediately? respondImmediately, TriggerActionTransferAgent? transferAgent})
- TriggerAction.fromJson(Map json_)
Properties
- generativeAnswer ↔ TriggerActionGenerativeAnswer?
-
Respond with a generative answer.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- respondImmediately ↔ TriggerActionRespondImmediately?
-
Immediately respond with a preconfigured response.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- transferAgent ↔ TriggerActionTransferAgent?
-
Transfer the conversation to a different agent.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited