VpcScSettings class
VPC-SC settings for the app.
Constructors
-
VpcScSettings({List<
String> ? allowedOrigins}) - VpcScSettings.fromJson(Map json_)
Properties
-
allowedOrigins
↔ List<
String> ? -
The allowed HTTP(s) origins that OpenAPI tools in the App are able to
directly call when VPC Service Controls are enabled.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited