WidgetTool class

Represents a widget tool that the agent can invoke.

When the tool is chosen by the agent, agent will return the widget to the client. The client is responsible for processing the widget and generating the next user query to continue the interaction with the agent.

Constructors

WidgetTool({WidgetToolDataMapping? dataMapping, String? description, String? name, Schema? parameters, WidgetToolTextResponseConfig? textResponseConfig, Map<String, Object?>? uiConfig, String? widgetType})
WidgetTool.fromJson(Map json_)

Properties

dataMapping WidgetToolDataMapping?
The mapping that defines how data from a source tool is mapped to the widget's input parameters.
getter/setter pair
description String?
The description of the widget tool.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The display name of the widget tool.
getter/setter pair
parameters Schema?
The input parameters of the widget tool.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textResponseConfig WidgetToolTextResponseConfig?
Configuration for always-included text responses.
getter/setter pair
uiConfig Map<String, Object?>?
Configuration for rendering the widget.
getter/setter pair
widgetType String?
The type of the widget tool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited