WidgetToolDataMapping class
Configuration for mapping data from a source tool to the widget's input parameters.
Constructors
-
WidgetToolDataMapping({Map<
String, String> ? fieldMappings, String? mode, PythonFunction? pythonFunction, String? pythonScript, String? sourceToolName}) - WidgetToolDataMapping.fromJson(Map json_)
Properties
-
fieldMappings
↔ Map<
String, String> ? -
A map of widget input parameter fields to the corresponding output fields
of the source tool.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode ↔ String?
-
The mode of the data mapping.
getter/setter pair
- pythonFunction ↔ PythonFunction?
-
Configuration for a Python function used to transform the source tool's
output into the widget's input format.
getter/setter pair
- pythonScript ↔ String?
-
Deprecated: Use
python_functioninstead.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceToolName ↔ String?
-
The resource name of the tool that provides the data for the widget (e.g.,
a search tool or a custom function).
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited