WidgetToolTextResponseConfig class
Configuration for the text response returned with the widget.
Constructors
- WidgetToolTextResponseConfig({String? staticText, String? textResponseInstruction, String? type})
- WidgetToolTextResponseConfig.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staticText ↔ String?
-
The static text response to return when type is STATIC.
getter/setter pair
- textResponseInstruction ↔ String?
-
Instruction for the LLM on how to generate the text response.
getter/setter pair
- type ↔ String?
-
The strategy for providing the text response.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited