CardWithId class

A card in a Google Chat message.

Only Chat apps can create cards. If your Chat app authenticates as a user, the message can't contain cards. Card builder

Constructors

CardWithId({GoogleAppsCardV1Card? card, String? cardId})
CardWithId.fromJson(Map json_)

Properties

card ↔ GoogleAppsCardV1Card?
A card.
getter/setter pair
cardId ↔ String?
Required if the message contains multiple cards.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited