GoogleAppsCardV1ExpressionDataCondition class

Represents a condition that is evaluated using CEL.

Only supported by Google Workspace Workflow, but not Google Chat apps or Google Workspace add-ons.

Properties

conditionType ↔ String?
The type of the condition. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited