GoogleChatV1Section class
Represents a section in Google Chat.
Sections help users organize their spaces. There are two types of sections:
- System Sections: These are predefined sections managed by Google
Chat. Their resource names are fixed, and they cannot be created, deleted,
or have their
display_namemodified. Examples include: *users/{user}/sections/default-direct-messages*users/{user}/sections/default-spaces*users/{user}/sections/default-apps2. Custom Sections: These are sections created and managed by the user. Creating a custom section usingCreateSectionrequires adisplay_name. Custom sections can be updated usingUpdateSectionand deleted usingDeleteSection.
Constructors
- GoogleChatV1Section({String? displayName, String? name, int? sortOrder, String? type})
- GoogleChatV1Section.fromJson(Map json_)
Properties
- displayName ↔ String?
-
The section's display name.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sortOrder ↔ int?
-
The order of the section in relation to other sections.
getter/setter pair
- type ↔ String?
-
The type of the section.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited