affiliation property
A user's relationship to the Workspace organization that owns the space.
In spaces owned by consumer accounts, the affiliation of all members is
EXTERNAL.
Output only. Possible string values are:
- "AFFILIATION_UNSPECIFIED" : Default value. This value is unused.
- "INTERNAL" : An account managed by the same Google Workspace organization that owns the space.
- "EXTERNAL" : An account external to the Google Workspace organization that owns the space (e.g., a consumer account, or an account managed by a different Workspace organization).
- "MANAGED_EXTERNAL" : An account managed by the Workspace organization that owns the space, but provisioned for a user who is external to the organization (e.g., a Guest user). To learn more about guests, see https://support.google.com/chat/answer/16997417.
Implementation
core.String? affiliation;