spaceMuteSetting property
The mute setting of the calling user for the space where the message is posted.
The caller app can use this information to decide how to process the
message depending on whether the space is muted for the user or not. Only
returned if the request view is SEARCH_MESSAGES_VIEW_FULL and the
calling credentials include the following
authorization scope:
https://www.googleapis.com/auth/chat.users.spacesettingsPossible string values are:- "MUTE_SETTING_UNSPECIFIED" : Reserved.
- "UNMUTED" : The user will receive notifications for the space based on the notification setting.
- "MUTED" : The user will not receive any notifications for the space, regardless of the notification setting.
Implementation
core.String? spaceMuteSetting;