failureStartTime property
Field recording time of the earliest failure since the last success event.
This field is only set when the state is DISABLED_BY_FAILURES.
Output only.
Implementation
core.String? failureStartTime;
Field recording time of the earliest failure since the last success event.
This field is only set when the state is DISABLED_BY_FAILURES.
Output only.
core.String? failureStartTime;