updateTime property
Field recording time of most recent modification of the status.
For ENABLED, this is the time the status was changed to ENABLED. For
DISABLED_BY_FAILURES, this is the time of the most recent failed attempt
to send an event to this config.
Output only.
Implementation
core.String? updateTime;