PublishItemRequest class
Request message for PublishItem.
Constructors
-
PublishItemRequest({List<
DeployInfo> ? deployInfos, String? publishType, bool? skipReview}) - PublishItemRequest.fromJson(Map json_)
Properties
-
deployInfos
↔ List<
DeployInfo> ? -
Additional deploy information including the desired initial percentage
rollout.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- publishType ↔ String?
-
Use this to control if the item is published immediately on approval or
staged for publishing in the future.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipReview ↔ bool?
-
Whether to attempt to skip item review.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited