PublishItemResponse class
Response message for PublishItem.
Constructors
- PublishItemResponse({String? itemId, String? name, String? state})
- PublishItemResponse.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemId ↔ String?
-
The ID of the item.
getter/setter pair
- name ↔ String?
-
The name of the item that was submitted
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
The current state of the submission.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited