PublishersItemsResource class
Constructors
- PublishersItemsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancelSubmission(
CancelSubmissionRequest request, String name, {String? $fields}) → Future< CancelSubmissionResponse> - Cancel the current active submission of an item if present.
-
fetchStatus(
String name, {String? $fields}) → Future< FetchItemStatusResponse> - Fetch the status of an item.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
publish(
PublishItemRequest request, String name, {String? $fields}) → Future< PublishItemResponse> - Submit the item to be published in the store.
-
setPublishedDeployPercentage(
SetPublishedDeployPercentageRequest request, String name, {String? $fields}) → Future< SetPublishedDeployPercentageResponse> - Set a higher target deploy percentage for the item's published revision.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited