crxVersion property
The extension version provided in the manifest of the uploaded package.
This will not be set if the upload is still in progress (upload_state is
UPLOAD_IN_PROGRESS).
Implementation
core.String? crxVersion;
The extension version provided in the manifest of the uploaded package.
This will not be set if the upload is still in progress (upload_state is
UPLOAD_IN_PROGRESS).
core.String? crxVersion;