description property
A description of the warning.
Developers should use this message to understand the warning and take appropriate action to resolve the issue.
Implementation
core.String? description;
A description of the warning.
Developers should use this message to understand the warning and take appropriate action to resolve the issue.
core.String? description;