oci property
A list of OCI images to be uploaded to Artifact Registry upon successful completion of all build steps.
OCI images in the specified paths will be uploaded to the specified Artifact Registry repository using the builder service account's credentials. If any images fail to be pushed, the build is marked FAILURE.
Optional.
Implementation
core.List<Oci>? oci;