GenericArtifact class
Generic artifact to upload to Artifact Registry upon successful completion of all build steps.
Constructors
- GenericArtifact({String? folder, String? registryPath})
- GenericArtifact.fromJson(Map json_)
Properties
- folder ↔ String?
-
Path to the generic artifact in the build's workspace to be uploaded to
Artifact Registry.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- registryPath ↔ String?
-
Registry path to upload the generic artifact to, in the form
projects/$PROJECT/locations/$LOCATION/repositories/$REPO/packages/$PACKAGE/versions/$VERSION
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited