StepResult class

StepResult is the declaration of a result for a build step.

Constructors

StepResult({String? attestationContent, String? attestationType, String? name})
StepResult.fromJson(Map json_)

Properties

attestationContent String?
The content of the attestation to be generated.
getter/setter pair
attestationType String?
The type of attestation to be generated.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the result.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited