UploadedGenericArtifact class
A generic artifact uploaded to Artifact Registry using the GenericArtifact directive.
Constructors
-
UploadedGenericArtifact({FileHashes? artifactFingerprint, String? artifactRegistryPackage, Map<
String, FileHashes> ? fileHashes, TimeSpan? pushTiming, String? uri}) - UploadedGenericArtifact.fromJson(Map json_)
Properties
- artifactFingerprint ↔ FileHashes?
-
The hash of the whole artifact.
getter/setter pair
- artifactRegistryPackage ↔ String?
-
Path to the artifact in Artifact Registry.
getter/setter pair
-
fileHashes
↔ Map<
String, FileHashes> ? -
The file hashes that make up the generic artifact.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pushTiming ↔ TimeSpan?
-
Stores timing information for pushing the specified artifact.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri ↔ String?
-
URI of the uploaded artifact.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited