AlertPolicyCheck class
AlertPolicyCheck configures a set of Cloud Monitoring alerting policies that will be periodically polled for alerts.
If any of the listed policies have an active alert, the analysis check will fail.
Constructors
-
AlertPolicyCheck({List<
String> ? alertPolicies, String? id, Map<String, String> ? labels}) - AlertPolicyCheck.fromJson(Map json_)
Properties
-
alertPolicies
↔ List<
String> ? -
The Cloud Monitoring Alert Policies to check for active alerts.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID of the analysis check.
getter/setter pair
-
labels
↔ Map<
String, String> ? -
A set of labels to filter active alerts.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited