failedAlertPolicies property
The alert policies that were found to be firing during this check.
This will be empty if no incidents were found.
Output only.
Implementation
core.List<FailedAlertPolicy>? failedAlertPolicies;
The alert policies that were found to be firing during this check.
This will be empty if no incidents were found.
Output only.
core.List<FailedAlertPolicy>? failedAlertPolicies;