Analysis class
Analysis contains the configuration for the set of analyses to be performed on the target.
Constructors
-
Analysis({List<
CustomCheck> ? customChecks, String? duration, GoogleCloudAnalysis? googleCloud}) - Analysis.fromJson(Map json_)
Properties
-
customChecks
↔ List<
CustomCheck> ? -
Custom analysis checks from 3P metric providers.
getter/setter pair
- duration ↔ String?
-
The amount of time in minutes the analysis on the target will last.
getter/setter pair
- googleCloud ↔ GoogleCloudAnalysis?
-
Google Cloud - based analysis checks.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited