AnalysisJobRun class
AnalysisJobRun contains information specific to an analysis JobRun.
Constructors
-
AnalysisJobRun({List<
AlertPolicyCheckStatus> ? alertPolicyAnalyses, List<CustomCheckStatus> ? customCheckAnalyses, String? failedCheckId}) - AnalysisJobRun.fromJson(Map json_)
Properties
-
alertPolicyAnalyses
↔ List<
AlertPolicyCheckStatus> ? -
The status of the running alert policy checks configured for this
analysis.
getter/setter pair
-
customCheckAnalyses
↔ List<
CustomCheckStatus> ? -
The status of the running custom checks configured for this analysis.
getter/setter pair
- failedCheckId ↔ String?
-
The ID of the configured check that failed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited