CloudRunRenderMetadata class

CloudRunRenderMetadata contains Cloud Run information associated with a Release render.

Constructors

CloudRunRenderMetadata({String? job, String? revision, String? service, String? workerPool})
CloudRunRenderMetadata.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
job String?
The name of the Cloud Run Job in the rendered manifest.
getter/setter pair
revision String?
The name of the Cloud Run Revision in the rendered manifest.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String?
The name of the Cloud Run Service in the rendered manifest.
getter/setter pair
workerPool String?
The name of the Cloud Run Worker Pool in the rendered manifest.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited