ContainerTask class

This task is represented by a container that is executed in the Cloud Build execution environment.

Constructors

ContainerTask({List<String>? args, List<String>? command, Map<String, String>? env, String? image})
ContainerTask.fromJson(Map json_)

Properties

args List<String>?
Args is the container arguments to use.
getter/setter pair
command List<String>?
Command is the container entrypoint to use.
getter/setter pair
env Map<String, String>?
Environment variables that are set in the container.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image String?
Image is the container image to use.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited