CustomCheck class
CustomCheck configures a third-party metric provider to run the analysis, via a Task that runs at a specified frequency.
Constructors
- CustomCheck({String? frequency, String? id, Task? task})
- CustomCheck.fromJson(Map json_)
Properties
- frequency ↔ String?
-
The frequency at which the custom check will be run, with a minimum and
default of 5 minutes.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID of the custom Analysis check.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task ↔ Task?
-
The Task to be run for this custom check.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited