CustomCheckStatus class
CustomCheckStatus contains information specific to a single iteration of a custom analysis job.
Constructors
- CustomCheckStatus({String? failureCause, String? failureMessage, String? frequency, String? id, String? latestBuild, CustomMetadata? metadata, Task? task})
- CustomCheckStatus.fromJson(Map json_)
Properties
- failureCause ↔ String?
-
The reason the analysis failed.
getter/setter pair
- failureMessage ↔ String?
-
Additional information about the analysis failure, if available.
getter/setter pair
- frequency ↔ String?
-
The frequency in minutes at which the custom check is run.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID of the custom check.
getter/setter pair
- latestBuild ↔ String?
-
The resource name of the Cloud Build
Buildobject that was used to execute the latest run of this custom action check.getter/setter pair - metadata ↔ CustomMetadata?
-
Custom metadata provided by the user-defined custom check operation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- task ↔ Task?
-
The task that ran for this custom check.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited