CustomTargetType class
A CustomTargetType resource in the Cloud Deploy API.
A CustomTargetType defines a type of custom target that can be referenced
in a Target in order to facilitate deploying to other systems besides the
supported runtimes.
Constructors
-
CustomTargetType({Map<
String, String> ? annotations, String? createTime, CustomTargetSkaffoldActions? customActions, String? customTargetTypeId, String? description, String? etag, Map<String, String> ? labels, String? name, CustomTargetTasks? tasks, String? uid, String? updateTime}) - CustomTargetType.fromJson(Map json_)
Properties
-
annotations
↔ Map<
String, String> ? -
User annotations.
getter/setter pair
- createTime ↔ String?
-
Time at which the
CustomTargetTypewas created.getter/setter pair - customActions ↔ CustomTargetSkaffoldActions?
-
Configures render and deploy for the
CustomTargetTypeusing Skaffold custom actions.getter/setter pair - customTargetTypeId ↔ String?
-
Resource id of the
CustomTargetType.getter/setter pair - description ↔ String?
-
Description of the
CustomTargetType.getter/setter pair - etag ↔ String?
-
This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client
has an up-to-date value before proceeding.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
Labels are attributes that can be set and used by both the user and by
Cloud Deploy.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tasks ↔ CustomTargetTasks?
-
Configures render and deploy for the
CustomTargetTypeusing tasks.getter/setter pair - uid ↔ String?
-
Unique identifier of the
CustomTargetType.getter/setter pair - updateTime ↔ String?
-
Most recent time at which the
CustomTargetTypewas updated.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited