FailedAlertPolicy class
FailedAlertPolicy contains information about an alert policy that was found to be firing during an alert policy check.
Constructors
-
FailedAlertPolicy({String? alertPolicy, List<
String> ? alerts}) - FailedAlertPolicy.fromJson(Map json_)
Properties
- alertPolicy ↔ String?
-
The name of the alert policy that was found to be firing.
getter/setter pair
-
alerts
↔ List<
String> ? -
Open alerts for the alerting policies that matched the alert policy check
configuration.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited