canaryDeployment property
Name of the canary version of the Kubernetes Deployment that will be applied to the GKE cluster.
Only set if a canary deployment strategy was configured.
Output only.
Implementation
core.String? canaryDeployment;
Name of the canary version of the Kubernetes Deployment that will be applied to the GKE cluster.
Only set if a canary deployment strategy was configured.
Output only.
core.String? canaryDeployment;