deployment property
Name of the Kubernetes Deployment that will be applied to the GKE cluster.
Only set if a single Deployment was provided in the rendered manifest.
Output only.
Implementation
core.String? deployment;
Name of the Kubernetes Deployment that will be applied to the GKE cluster.
Only set if a single Deployment was provided in the rendered manifest.
Output only.
core.String? deployment;