RenderMetadata class
RenderMetadata includes information associated with a Release render.
Constructors
- RenderMetadata({CloudRunRenderMetadata? cloudRun, CustomMetadata? custom, KubernetesRenderMetadata? kubernetes})
- RenderMetadata.fromJson(Map json_)
Properties
- cloudRun ↔ CloudRunRenderMetadata?
-
Metadata associated with rendering for Cloud Run.
getter/setter pair
- custom ↔ CustomMetadata?
-
Custom metadata provided by user-defined render operation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- kubernetes ↔ KubernetesRenderMetadata?
-
Metadata associated with rendering for a Kubernetes cluster (GKE or GKE
Enterprise target).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited