FailurePolicy class
Describes the policy in case of function's execution failure.
If empty, then defaults to ignoring failures (i.e. not retrying them).
Constructors
- FailurePolicy({Retry? retry})
- FailurePolicy.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- retry ↔ AutomaticUpdatePolicy?
-
If specified, then the function will be retried in case of a failure.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited