DirectVpcNetworkInterface class
The Direct VPC network interface.
This is mutually exclusive with VPC Connector.
Constructors
-
DirectVpcNetworkInterface({String? network, String? subnetwork, List<
String> ? tags}) - DirectVpcNetworkInterface.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- network ↔ String?
-
The name of the VPC network to which the function will be connected.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subnetwork ↔ String?
-
The name of the VPC subnetwork that the Cloud Function resource will get
IPs from.
getter/setter pair
-
Network tags applied to this Cloud Function resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited