AllowlistedDomain class
This resource object defines a domain that has been designated as allowlisted.
Constructors
- AllowlistedDomain({String? domain, String? name})
- AllowlistedDomain.fromJson(Map json_)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited