AllowlistedDomainsResource class
Constructors
- AllowlistedDomainsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
AllowlistedDomain request, {String? $fields}) → Future< Operation> - Adds a domain to the allowlist.
-
delete(
String name, {String? $fields}) → Future< Operation> - Removes a domain from the allowlist.
-
get(
String name, {String? $fields}) → Future< AllowlistedDomain> - Retrieves a specific domain from the allowlist.
-
list(
{String? filter, int? pageSize, String? pageToken, String? $fields}) → Future< ListAllowlistedDomainsResponse> - Lists the domains in the allowlist.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited