keyAccessJustificationsPolicy property
The policy used for Key Access Justifications Policy Enforcement.
If this field is present and this key is enrolled in Key Access
Justifications Policy Enforcement, the policy will be evaluated in
encrypt, decrypt, and sign operations, and the operation will fail if
rejected by the policy. The policy is defined by specifying zero or more
allowed justification codes.
https://cloud.google.com/assured-workloads/key-access-justifications/docs/justification-codes
By default, this field is absent, and all justification codes are allowed.
If the key_access_justifications_policy.allowed_access_reasons is empty
(zero allowed justification code), all encrypt, decrypt, and sign
operations will fail.
Optional.
Implementation
KeyAccessJustificationsPolicy? keyAccessJustificationsPolicy;