hsmTrusted property
Field indicating that the key wrapping key is trusted.
This field is only valid for key purpose AES_256_WRAPPING, and protection level HSM_SINGLE_TENANT.
Output only.
Implementation
core.bool? hsmTrusted;
Field indicating that the key wrapping key is trusted.
This field is only valid for key purpose AES_256_WRAPPING, and protection level HSM_SINGLE_TENANT.
Output only.
core.bool? hsmTrusted;