ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse class
Represents a response message for KeyAccessJustificationsConfig.ShowEffectiveKeyAccessJustificationsEnrollmentConfig
Constructors
- ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse({KeyAccessJustificationsEnrollmentConfig? externalConfig, KeyAccessJustificationsEnrollmentConfig? hardwareConfig, KeyAccessJustificationsEnrollmentConfig? softwareConfig})
- ShowEffectiveKeyAccessJustificationsEnrollmentConfigResponse.fromJson(Map json_)
Properties
- externalConfig ↔ KeyAccessJustificationsEnrollmentConfig?
-
Contains the effective KeyAccessJustificationsEnrollmentConfig for
external keys.
getter/setter pair
- hardwareConfig ↔ KeyAccessJustificationsEnrollmentConfig?
-
Contains the effective KeyAccessJustificationsEnrollmentConfig for
hardware keys.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- softwareConfig ↔ KeyAccessJustificationsEnrollmentConfig?
-
Contains the effective KeyAccessJustificationsEnrollmentConfig for
software keys.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited