UpgradeKeyTrust class
Promotes a key with the AES_WRAPPING purpose to a trusted wrapping key.
The key must be in the ACTIVE state to perform this operation.
Constructors
- UpgradeKeyTrust({String? name, String? twoFactorPublicKeyPem})
- UpgradeKeyTrust.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
The name of the CryptoKeyVersion to promote.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- twoFactorPublicKeyPem ↔ String?
-
The public key associated with the 2FA key that will sign the login nonce
for this operation.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited