WrappingPublicKey class

The public key component of the wrapping key.

For details of the type of key this public key corresponds to, see the ImportMethod.

Properties

hashCode → int
The hash code for this object.
no setterinherited
pem ↔ String?
The public key, encoded in PEM format.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited