cloudproductregistry/v1 library
Cloud Product Registry API - v1
Cloud Product Registry API provides capabilities to access all first Google Cloud products.
For more information, see docs.cloud.google.com/product-registry
Create an instance of CloudProductRegistryApi to access these resources:
Classes
- CloudProductRegistryApi
- Cloud Product Registry API provides capabilities to access all first Google Cloud products.
- ListLogicalProductsResponse
- Response message for ListLogicalProducts.
- ListLogicalProductVariantsResponse
- Response message for ListLogicalProductVariants.
- ListProductSuitesResponse
- Response message for ListProductSuites.
- LogicalProduct
- Represents an independent service offering that can be provisioned by a customer.
- LogicalProductsResource
- LogicalProductsVariantsResource
- LogicalProductVariant
- Represents a distinct offering derived from a primary product that retains core functionalities but offers specialized features for a specific market segment.
- LookupEntityResponse
- Response message for LookupEntity.
- ProductSuite
- Represents a unified grouping of products sharing a common brand and market positioning.
- ProductSuitesResource
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.