LogicalProductVariant class
Represents a distinct offering derived from a primary product that retains core functionalities but offers specialized features for a specific market segment.
Constructors
- LogicalProductVariant({String? lifecycleState, String? name, bool? replaced, String? replacement, String? title})
- LogicalProductVariant.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lifecycleState ↔ String?
-
Current Lifecycle state of the logical product variant.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- replaced ↔ bool?
-
Indicates whether the logical product variant has been replaced.
getter/setter pair
- replacement ↔ String?
-
The resource name of the Logical Entity that the logical product variant
is replaced by.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
Display name of the LogicalProductVariant.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited