replacement property
The resource name of the Logical Entity that the logical product variant is replaced by.
This field is only populated when this logical product variant is replaced by some other type. Eg: logicalProducts/{logical_product}, productSuites/{product_suite}, etc.
Output only.
Implementation
core.String? replacement;