QuerySuggestion class
Constructors
- QuerySuggestion({String? lastQueryTime, String? sourceCorpus})
- QuerySuggestion.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastQueryTime ↔ String?
-
Last query time of the suggestion for query history suggestions.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceCorpus ↔ String?
-
Source corpus of the suggestion.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited