networkingType property
Networking type for the environment, either private or public.
Optional. Possible string values are:
- "NETWORKING_TYPE_UNSPECIFIED" : Default networking type.
- "PRIVATE" : Private IP Cloud Composer environment with no access to the internet.
- "PUBLIC" : Cloud Composer environment with access to the internet.
Implementation
core.String? networkingType;