serviceLbPolicy property
URL to networkservices.ServiceLbPolicy resource.
Can only be set if load balancing scheme is EXTERNAL_MANAGED, INTERNAL_MANAGED or INTERNAL_SELF_MANAGED for a global backend service, and EXTERNAL_MANAGED or INTERNAL_MANAGED for a regional backend service.
For a global backend service, the service lb policy must be global. For a regional backend service, the service lb policy must be regional and in the same region.
Implementation
core.String? serviceLbPolicy;