BackendServiceOrchestrationInfo class

A message containing information about the resource or system that manages the backend service.

Properties

hashCode int
The hash code for this object.
no setterinherited
resourceUri String?
The resource URI of the resource or system that manages the backend service.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited