cacheKeyPolicy property
The cache key configuration.
If not specified, the default behavior depends on the backend type: for Backend Services, the complete request URI is used; for Backend Buckets, the request URI is used without the protocol or host, and only query parameters known to Cloud Storage are included.
Implementation
CachePolicyCacheKeyPolicy? cacheKeyPolicy;