maxTtl property
Specifies the maximum allowed TTL for cached content.
Cache directives that
attempt to set a max-age or s-maxage higher than this, or an Expires
header
more than maxTtl seconds in the future will be capped at the value of
maxTtl, as if it were the value of an s-maxage Cache-Control directive.
Headers sent to the client will not be modified. Setting a TTL of "0"
means
"always revalidate". The maximum allowed value is 31,622,400s (1 year).
Infrequently accessed objects may be evicted from the cache before the
defined TTL. If not specified, Cloud CDN uses 86400s (1 day) for
CACHE_ALL_STATIC mode. Can be specified only for CACHE_ALL_STATIC
cache
mode.
Implementation
Duration? maxTtl;