CachePolicyCacheKeyPolicy class

Message containing what to include in the cache key for a request for Cache Policy defined on Route Action.

Constructors

CachePolicyCacheKeyPolicy({List<String>? excludedQueryParameters, bool? includeHost, bool? includeProtocol, bool? includeQueryString, List<String>? includedCookieNames, List<String>? includedHeaderNames, List<String>? includedQueryParameters})
CachePolicyCacheKeyPolicy.fromJson(Map json_)

Properties

excludedQueryParameters List<String>?
Names of query string parameters to exclude in cache keys.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
includedCookieNames List<String>?
Allows HTTP cookies (by name) to be used in the cache key. The name=value pair will be used in the cache key Cloud CDN generates.
getter/setter pair
includedHeaderNames List<String>?
Allows HTTP request headers (by name) to be used in the cache key.
getter/setter pair
includedQueryParameters List<String>?
Names of query string parameters to include in cache keys.
getter/setter pair
includeHost bool?
If true, requests to different hosts will be cached separately.
getter/setter pair
includeProtocol bool?
If true, http and https requests will be cached separately.
getter/setter pair
includeQueryString bool?
If true, include query string parameters in the cache key according to includedQueryParameters and excludedQueryParameters.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited