includeHost property
If true, requests to different hosts will be cached separately.
Note: This setting is only applicable to routes that use a Backend Service.
It does not affect requests served by a Backend Bucket, as the host is never included in a Backend Bucket's cache key. Attempting to set it on a route that points exclusively to Backend Buckets will result in a configuration error.
Implementation
core.bool? includeHost;