includeQueryString property
If true, include query string parameters in the cache key according to
includedQueryParameters and excludedQueryParameters.
If neither is set, the entire query string will be included. If false, the query string will be excluded from the cache key entirely.
Note: This field applies to routes that use backend services. Attempting
to set it on a route that points exclusively to Backend Buckets will
result in a configuration error. For routes that point to a Backend
Bucket, use includedQueryParameters to define which parameters should
be part of the cache key.
Implementation
core.bool? includeQueryString;