CompositeHealthCheckHealth class
Response message for RegionCompositeHealthChecks.GetHealth
Constructors
-
CompositeHealthCheckHealth({List<
CompositeHealthChecksGetHealthResponseHealthSourceHealth> ? healthSources, String? healthState, String? kind}) - CompositeHealthCheckHealth.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
healthSources
↔ List<
CompositeHealthChecksGetHealthResponseHealthSourceHealth> ? -
Health sources and their corresponding health states.
getter/setter pair
- healthState ↔ String?
-
Health state of the CompositeHealthCheck.
Possible string values are:
getter/setter pair
- kind ↔ String?
-
Type of resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited