backendService property
Identifies the backend service to which the forwarding rule sends traffic.
It is a required field for the following load balancers:
- Internal passthrough Network Load Balancers
- Backend service-based regional external passthrough Network Load Balancers
- Global external passthrough Network Load Balancers
It cannot be set by other load balancer types and protocol forwarding rules.
Implementation
core.String? backendService;