FutureReservationStoragePoolProperties class

Storage pool properties for the future reservation.

Constructors

FutureReservationStoragePoolProperties({StoragePoolExapoolProvisionedCapacityGb? requestedExapoolProvisionedCapacityGb, FutureReservationStoragePoolProvisionedCapacity? requestedStoragePoolProvisionedCapacity, String? storagePoolType})
FutureReservationStoragePoolProperties.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
requestedExapoolProvisionedCapacityGb StoragePoolExapoolProvisionedCapacityGb?
Requested exapool provisioned capacity in GiB.
getter/setter pair
requestedStoragePoolProvisionedCapacity FutureReservationStoragePoolProvisionedCapacity?
Requested storage pool provisioned capacity.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storagePoolType String?
Type of the storage pool.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited