FutureReservationStoragePoolProvisionedCapacity class
Storage pool provisioned capacities for each SKU type.
Constructors
- FutureReservationStoragePoolProvisionedCapacity({String? poolProvisionedCapacityGb, String? poolProvisionedIops, String? poolProvisionedThroughput})
- FutureReservationStoragePoolProvisionedCapacity.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- poolProvisionedCapacityGb ↔ String?
-
Size of the storage pool in GiB.
getter/setter pair
- poolProvisionedIops ↔ String?
-
Provisioned IOPS of the storage pool.
getter/setter pair
- poolProvisionedThroughput ↔ String?
-
Provisioned throughput of the storage pool in MiB/s.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited