GlobalVmExtensionPolicy class
Message describing GlobalVmExtensionPolicy object.
Constructors
-
GlobalVmExtensionPolicy({String? creationTimestamp, String? description, Map<
String, GlobalVmExtensionPolicyExtensionPolicy> ? extensionPolicies, String? id, List<GlobalVmExtensionPolicyInstanceSelector> ? instanceSelectors, String? kind, String? name, int? priority, GlobalVmExtensionPolicyRolloutOperation? rolloutOperation, String? scopedResourceStatus, String? selfLink, String? selfLinkWithId, String? updateTimestamp}) - GlobalVmExtensionPolicy.fromJson(Map json_)
Properties
- creationTimestamp ↔ String?
-
Creation timestamp inRFC3339
text format.
getter/setter pair
- description ↔ String?
-
An optional description of this resource.
getter/setter pair
-
extensionPolicies
↔ Map<
String, GlobalVmExtensionPolicyExtensionPolicy> ? -
Map from extension (eg: "cloudops") to its policy configuration.
The key is the name of the extension.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The unique identifier for the resource.
getter/setter pair
-
instanceSelectors
↔ List<
GlobalVmExtensionPolicyInstanceSelector> ? -
Selector to target VMs for a policy.
There is a logical "AND" between instance_selectors.
getter/setter pair
- kind ↔ String?
-
Type of the resource.
getter/setter pair
- name ↔ String?
-
Name of the resource.
getter/setter pair
- priority ↔ int?
-
Used to resolve conflicts when multiple policies are active for the same
extension.
getter/setter pair
- rolloutOperation ↔ GlobalVmExtensionPolicyRolloutOperation?
-
The rollout strategy and status.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scopedResourceStatus ↔ String?
-
The scoped resource status.
getter/setter pair
- selfLink ↔ String?
-
Server-defined fully-qualified URL for this resource.
getter/setter pair
- selfLinkWithId ↔ String?
-
Server-defined URL for this resource's resource id.
getter/setter pair
- updateTimestamp ↔ String?
-
Update timestamp inRFC3339
text format.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited