GlobalVmExtensionPolicyExtensionPolicy class
Policy for a single extension.
Constructors
- GlobalVmExtensionPolicyExtensionPolicy({String? pinnedVersion, String? stringConfig})
- GlobalVmExtensionPolicyExtensionPolicy.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- pinnedVersion ↔ String?
-
The version pinning for the extension.
If empty, the extension will be installed with the latest version
released by the extension producer.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringConfig ↔ String?
-
String configuration.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited