GlobalVmExtensionPolicyLabelSelector class

A LabelSelector is applicable for a VM only if it matches all labels in the LabelSelector.

Properties

hashCode int
The hash code for this object.
no setterinherited
inclusionLabels Map<String, String>?
Labels as key value pairs. A VM should contain all the pairs specified in this map to be selected; Labels within the LabelSelector are OR'ed.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited