HttpRedirectAction class

Specifies settings for an HTTP redirect.

Constructors

HttpRedirectAction({String? hostRedirect, bool? httpsRedirect, String? pathRedirect, String? prefixRedirect, String? redirectResponseCode, bool? stripQuery})
HttpRedirectAction.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostRedirect ↔ String?
The host that is used in the redirect response instead of the one that was supplied in the request.
getter/setter pair
httpsRedirect ↔ bool?
If set to true, the URL scheme in the redirected request is set to HTTPS.
getter/setter pair
pathRedirect ↔ String?
The path that is used in the redirect response instead of the one that was supplied in the request.
getter/setter pair
prefixRedirect ↔ String?
The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request.
getter/setter pair
redirectResponseCode ↔ String?
The HTTP Status code to use for this RedirectAction.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stripQuery ↔ bool?
If set to true, any accompanying query portion of the original URL is removed before redirecting the request.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited