source property
The full Google Cloud Storage URL or Artifact Registry path where the raw disk image archive is stored. The following are valid formats:
https://storage.googleapis.com/bucket_name/folder_name/image_archive_name
projects/project/locations/location/repositories/repo/packages/package/versions/version_id
projects/project/locations/location/repositories/repo/packages/package/versions/version_id@dirsum_sha256:hex_value
In order to create an image, you must provide the full or partial URL of one of the following:
- The rawDisk.source URL
- The sourceDisk URL
- The sourceImage URL
- The sourceSnapshot URL
Implementation
core.String? source;