localSsdEncryptionMode property
Specifies which method should be used for encrypting the Local SSDs attached to the VM. Possible string values are:
- "EPHEMERAL_KEY_ENCRYPTION" : The given VM will opt-in for using ephemeral key for encryption of Local SSDs. The Local SSDs will not be able to recover data in case of VM crash.
- "LOCAL_SSD_ENCRYPTION_MODE_UNSPECIFIED" : The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
- "STANDARD_ENCRYPTION" : The given VM will be encrypted using keys managed by the cloud infrastructure and the keys will be deleted when the VM is deleted.
Implementation
core.String? localSsdEncryptionMode;