InstanceGroupManagerInstanceLifecyclePolicy class

Properties

defaultActionOnFailure String?
The action that a MIG performs on a failed VM.
getter/setter pair
forceUpdateOnRepair String?
A bit indicating whether to forcefully apply the group's latest configuration when repairing a VM.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onFailedHealthCheck String?
The action that a MIG performs on an unhealthy VM.
getter/setter pair
onRepair InstanceGroupManagerInstanceLifecyclePolicyOnRepair?
Configuration for VM repairs in the MIG.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited