InstanceGroupManagerInstanceLifecyclePolicyOnRepair class
Configuration for VM repairs in the MIG.
Constructors
- InstanceGroupManagerInstanceLifecyclePolicyOnRepair({String? allowChangingZone})
- InstanceGroupManagerInstanceLifecyclePolicyOnRepair.fromJson(Map json_)
Properties
- allowChangingZone ↔ String?
-
Specifies whether the MIG can change a VM's zone during a repair.
Valid values are:
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited