currentInstanceStatuses property
The list of instance statuses and the number of instances in this managed instance group that have the status.
Currently only shown for TPU MIGs
Output only.
Implementation
InstanceGroupManagerStatusInstanceStatusSummary? currentInstanceStatuses;