InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheck class
Constructors
Properties
- error ↔ InstanceGroupManagerStatusBulkInstanceOperationLastProgressCheckError?
-
Errors encountered during bulk instance operation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp ↔ String?
-
Timestamp of the last progress check of bulk instance
operation.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited