InstanceGroupManagerStatusInstanceStatusSummary class

The list of instance statuses and the number of instances in this managed instance group that have the status.

For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.

Constructors

InstanceGroupManagerStatusInstanceStatusSummary({int? deprovisioning, int? nonExistent, int? pending, int? pendingStop, int? provisioning, int? repairing, int? running, int? staging, int? stopped, int? stopping, int? suspended, int? suspending, int? terminated})
InstanceGroupManagerStatusInstanceStatusSummary.fromJson(Map json_)

Properties

deprovisioning int?
The number of instances in the managed instance group that have DEPROVISIONING status.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nonExistent int?
The number of instances that have not been created yet or have been deleted.
getter/setter pair
pending int?
The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources.
getter/setter pair
pendingStop int?
The number of instances in the managed instance group that have PENDING_STOP status.
getter/setter pair
provisioning int?
The number of instances in the managed instance group that have PROVISIONING status.
getter/setter pair
repairing int?
The number of instances in the managed instance group that have REPAIRING status.
getter/setter pair
running int?
The number of instances in the managed instance group that have RUNNING status.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
staging int?
The number of instances in the managed instance group that have STAGING status.
getter/setter pair
stopped int?
The number of instances in the managed instance group that have STOPPED status.
getter/setter pair
stopping int?
The number of instances in the managed instance group that have STOPPING status.
getter/setter pair
suspended int?
The number of instances in the managed instance group that have SUSPENDED status.
getter/setter pair
suspending int?
The number of instances in the managed instance group that have SUSPENDING status.
getter/setter pair
terminated int?
The number of instances in the managed instance group that have TERMINATED status.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited