effectiveLocation property
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
By default it will be the same as the location field.
Output only.
Implementation
core.String? effectiveLocation;
URL of the InterconnectLocation object that represents where this connection is to be provisioned.
By default it will be the same as the location field.
Output only.
core.String? effectiveLocation;