LicenseCode class
Represents a License Code resource.
A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Constructors
-
LicenseCode({List<
String> ? allowedReplacementLicenses, bool? appendableToDisk, String? creationTimestamp, String? description, String? id, List<String> ? incompatibleLicenses, String? kind, List<LicenseCodeLicenseAlias> ? licenseAlias, Duration? minimumRetention, bool? multiTenantOnly, String? name, bool? osLicense, bool? removableFromDisk, List<String> ? requiredCoattachedLicenses, String? selfLink, bool? soleTenantOnly, String? state, bool? transferable, String? updateTimestamp}) - LicenseCode.fromJson(Map json_)
Properties
-
allowedReplacementLicenses
↔ List<
String> ? -
Specifies licenseCodes of licenses that can replace this license.
getter/setter pair
- appendableToDisk ↔ bool?
-
If true, this license can be appended to an existing disk's set of
licenses.
getter/setter pair
- creationTimestamp ↔ String?
-
Creation timestamp inRFC3339
text format.
getter/setter pair
- description ↔ String?
-
Description of this License Code.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The unique identifier for the resource.
getter/setter pair
-
incompatibleLicenses
↔ List<
String> ? -
Specifies licenseCodes of licenses that are incompatible with this
license.
If a license is incompatible with this license, it cannot be attached to
the same disk or image.
getter/setter pair
- kind ↔ String?
-
Type of resource.
getter/setter pair
-
licenseAlias
↔ List<
LicenseCodeLicenseAlias> ? -
URL and description aliases of Licenses with the same
License Code.
getter/setter pair
- minimumRetention ↔ Duration?
-
If set, this license will be unable to be removed or replaced once
attached
to a disk until the minimum_retention period has passed.
getter/setter pair
- multiTenantOnly ↔ bool?
-
If true, this license can only be used on VMs on multi tenant nodes.
getter/setter pair
- name ↔ String?
-
Name of the resource.
getter/setter pair
- osLicense ↔ bool?
-
If true, indicates this is an OS license.
getter/setter pair
- removableFromDisk ↔ bool?
-
If true, this license can be removed from a disk's set of licenses, with
no
replacement license needed.
getter/setter pair
-
requiredCoattachedLicenses
↔ List<
String> ? -
Specifies the set of permissible coattached licenseCodes of licenses that
satisfy the coattachment requirement of this license.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink ↔ String?
-
Server-defined URL for the resource.
getter/setter pair
- soleTenantOnly ↔ bool?
-
If true, this license can only be used on VMs on sole tenant nodes.
getter/setter pair
- state ↔ String?
-
Current state of this License Code.
getter/setter pair
- transferable ↔ bool?
-
If true, the license will remain attached when creating
images or snapshots from disks.
getter/setter pair
- updateTimestamp ↔ String?
-
Last update timestamp inRFC3339
text format.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited