Returns the specified License resource.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
Create a License resource in the specified project.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
Sets the access control policy on the specified resource.
Replaces any existing policy.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
Returns permissions that a caller has on the specified resource.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.
Updates a License resource in the specified project.
Caution This resource is intended
for use only by third-party partners who are creatingCloud Marketplace
images.