gracefulShutdownTimestamp property
The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured.
This is in RFC3339 text format.
Output only.
Implementation
core.String? gracefulShutdownTimestamp;
The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured.
This is in RFC3339 text format.
Output only.
core.String? gracefulShutdownTimestamp;