ManagedInstanceShutdownDetails class
Constructors
- ManagedInstanceShutdownDetails({Duration? maxDuration, String? requestTimestamp})
- ManagedInstanceShutdownDetails.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxDuration ↔ Duration?
-
The duration for graceful shutdown.
getter/setter pair
- requestTimestamp ↔ String?
-
Past timestamp indicating the beginning of
PENDING_STOPstate of instance in RFC3339 text format.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited