NodeGroup class

Represents a sole-tenant Node Group resource.

A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, read Sole-tenant nodes.

Constructors

NodeGroup({NodeGroupAutoscalingPolicy? autoscalingPolicy, String? creationTimestamp, String? description, String? fingerprint, String? id, String? kind, String? locationHint, String? maintenanceInterval, String? maintenancePolicy, NodeGroupMaintenanceWindow? maintenanceWindow, String? name, String? nodeTemplate, String? selfLink, ShareSettings? shareSettings, int? size, String? status, String? zone})
NodeGroup.fromJson(Map json_)

Properties

autoscalingPolicy ↔ NodeGroupAutoscalingPolicy?
Specifies how autoscaling should behave.
getter/setter pair
creationTimestamp ↔ String?
Creation timestamp in RFC3339 text format.
getter/setter pair
description ↔ String?
An optional description of this resource.
getter/setter pair
fingerprint ↔ String?
getter/setter pair
fingerprintAsBytes ↔ List<int>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
id ↔ String?
The unique identifier for the resource.
getter/setter pair
kind ↔ String?
The type of the resource.
getter/setter pair
locationHint ↔ String?
An opaque location hint used to place the Node close to other resources.
getter/setter pair
maintenanceInterval ↔ String?
Specifies the frequency of planned maintenance events.
getter/setter pair
maintenancePolicy ↔ String?
Specifies how to handle instances when a node in the group undergoes maintenance.
getter/setter pair
maintenanceWindow ↔ NodeGroupMaintenanceWindow?
getter/setter pair
name ↔ String?
The name of the resource, provided by the client when initially creating the resource.
getter/setter pair
nodeTemplate ↔ String?
URL of the node template to create the node group from.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Server-defined URL for the resource.
getter/setter pair
shareSettings ↔ ShareSettings?
Share-settings for the node group
getter/setter pair
size ↔ int?
The total number of nodes in the node group.
getter/setter pair
status ↔ String?
Possible string values are:
getter/setter pair
zone ↔ String?
The name of the zone where the node group resides, such as us-central1-a.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited