status property
The status of the operation, which can be one of the
following:
PENDING, RUNNING, or DONE.
Output only. Possible string values are:
- "DONE" : The operation has completed processing successfully or with an error.
- "PENDING" : The operation is waiting to be processed.
- "RUNNING" : The operation is actively being processed.
Implementation
core.String? status;