PeriodicPartialMaintenanceSchedule class
The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)
Constructors
- PeriodicPartialMaintenanceSchedule({String? subType, String? targetResource, String? type, DateTime? windowEndTime, DateTime? windowStartTime})
- PeriodicPartialMaintenanceSchedule.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subType ↔ String?
-
The maintenance type in which the zone is during the given window.
Possible string values are:
getter/setter pair
- targetResource ↔ String?
-
The target resource that the maintenance window is for.
For example, "projects/my-project/zones/us-central1-a".
getter/setter pair
- type ↔ String?
-
Possible string values are:
getter/setter pair
- windowEndTime ↔ DateTime?
-
The end civil timestamp of the window (not inclusive).
This contains a time zone.
getter/setter pair
- windowStartTime ↔ DateTime?
-
The start civil timestamp of the window.
This contains a time zone.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited