PublicDelegatedPrefix class
A PublicDelegatedPrefix resource represents an IP block within a PublicAdvertisedPrefix that is configured within a single cloud scope (global or region).
IPs in the block can be allocated to resources within that scope. Public delegated prefixes may be further broken up into smaller IP blocks in the same scope as the parent block.
Constructors
-
PublicDelegatedPrefix({int? allocatablePrefixLength, String? byoipApiVersion, String? creationTimestamp, String? description, bool? enableEnhancedIpv4Allocation, String? fingerprint, String? id, String? ipCidrRange, String? ipv6AccessType, bool? isLiveMigration, String? kind, String? mode, String? name, String? parentPrefix, List<
PublicDelegatedPrefixPublicDelegatedSubPrefix> ? publicDelegatedSubPrefixs, String? region, String? selfLink, String? status}) - PublicDelegatedPrefix.fromJson(Map json_)
Properties
- allocatablePrefixLength ↔ int?
-
The allocatable prefix length supported by this public delegated prefix.
This field is optional and cannot be set for prefixes in DELEGATION mode.
It cannot be set for IPv4 prefixes either, and it always defaults to 32.
getter/setter pair
- byoipApiVersion ↔ String?
-
The version of BYOIP API.
getter/setter pair
- creationTimestamp ↔ String?
-
Creation timestamp inRFC3339
text format.
getter/setter pair
- description ↔ String?
-
An optional description of this resource.
getter/setter pair
- enableEnhancedIpv4Allocation ↔ bool?
-
Whether this PDP supports enhanced IPv4 allocations.
Applicable for IPv4 PDPs only.
getter/setter pair
- fingerprint ↔ String?
-
Fingerprint of this resource.
getter/setter pair
-
fingerprintAsBytes
↔ List<
int> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The unique identifier for the resource type.
getter/setter pair
- ipCidrRange ↔ String?
-
The IP address range, in CIDR format, represented by this public
delegated prefix.
getter/setter pair
- ipv6AccessType ↔ String?
-
The internet access type for IPv6 Public Delegated Prefixes.
Inherited from parent prefix.
getter/setter pair
- isLiveMigration ↔ bool?
-
If true, the prefix will be live migrated.
getter/setter pair
- kind ↔ String?
-
Type of the resource.
getter/setter pair
- mode ↔ String?
-
The public delegated prefix mode for IPv6 only.
Possible string values are:
getter/setter pair
- name ↔ String?
-
Name of the resource.
getter/setter pair
- parentPrefix ↔ String?
-
The URL of parent prefix.
getter/setter pair
-
publicDelegatedSubPrefixs
↔ List<
PublicDelegatedPrefixPublicDelegatedSubPrefix> ? -
The list of sub public delegated prefixes that exist for this public
delegated prefix.
getter/setter pair
- region ↔ String?
-
URL of the region where the public delegated prefix resides.
This field applies only to the region resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink ↔ String?
-
Server-defined URL for the resource.
getter/setter pair
- status ↔ String?
-
The status of the public delegated prefix, which can be one
of following values:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited