RegexRewrite class

The spec for modifying the path using a regular expression.

Constructors

RegexRewrite({String? pathPattern, String? pathSubstitution})
RegexRewrite.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
pathPattern String?
The regular expression used to match against the URL path. It uses RE2 syntax with the following constraints:
getter/setter pair
pathSubstitution String?
Required when path pattern is specified.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited