pathPattern property
The regular expression used to match against the URL path. It uses RE2 syntax with the following constraints:
- Any single character operators
- Groups are allowed to have only submatch operator inside
- Groups are allowed only without any char repetition, e.g.
.*
- Any char repetition, e.g. .*, is
only allowed to be used in a single regex together with:
- Empty string operators
- Other repetitions
- Ranges
- Repetitions of ranges
- Ranges are only allowed to have:
- Character range
- Digits range
- Symbols listed in characters allowed for ranges
Required.
Implementation
core.String? pathPattern;