ResourceStatusScheduling class

Constructors

ResourceStatusScheduling({int? availabilityDomain, String? gracefulShutdownTimestamp, String? terminationTimestamp})
ResourceStatusScheduling.fromJson(Map json_)

Properties

availabilityDomain int?
Specifies the availability domain to place the instance in.
getter/setter pair
gracefulShutdownTimestamp String?
Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminationTimestamp String?
Time in future when the instance will be terminated inRFC3339 text format.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited