RiskDetails class
Detailed insights and metrics about a detected reliability risk.
Constructors
- RiskDetails({String? duration, RiskDetailsGlobalDnsInsight? globalDnsInsight, String? lastUpdateTimestamp, String? severity, String? type})
- RiskDetails.fromJson(Map json_)
Properties
- duration ↔ String?
-
The duration of the risk since it was detected.
getter/setter pair
- globalDnsInsight ↔ RiskDetailsGlobalDnsInsight?
-
Insight details for global DNS risk.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastUpdateTimestamp ↔ String?
-
The last time the risk was updated.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity ↔ String?
-
The severity of the risk.
Possible string values are:
getter/setter pair
- type ↔ String?
-
The type of risk.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited