RiskDetailsGlobalDnsInsight class
Detailed insights for a global DNS reliability risk.
Constructors
- RiskDetailsGlobalDnsInsight({bool? projectDefaultIsGlobalDns, String? queryObservationWindow, String? riskyQueryCount, String? totalQueryCount})
- RiskDetailsGlobalDnsInsight.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- projectDefaultIsGlobalDns ↔ bool?
-
Indicates whether the project's default DNS setting is global DNS.
getter/setter pair
- queryObservationWindow ↔ String?
-
The observation window for the query counts.
getter/setter pair
- riskyQueryCount ↔ String?
-
The number of queries that are risky.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalQueryCount ↔ String?
-
The total number of queries in the observation window.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited