state property
The current state of the Rollout.
Output only. Possible string values are:
- "CANCELLED" : The rollout is in a failure terminal state.
- "CANCELLING" : The rollout is being cancelled.
- "CANCEL_FAILED" : An attempted cancel operation was unsuccessful.
- "COMPLETED" : The rollout is in a successful terminal state.
- "COMPLETE_FAILED" : An attempted complete operation was unsuccessful.
- "COMPLETING" : The rollout is being marked as completed.
- "FAILED" : The rollout completed with failures.
- "PAUSED" : The rollout is paused.
- "PAUSE_FAILED" : An attempted pause operation was unsuccessful.
- "PAUSING" : The rollout is being paused.
- "PROCESSING" : A wave is being processed by the product.
- "READY" : The rollout has been successfully initialized and is ready to start.
- "RESUMING" : The rollout is being resumed after being paused.
- "ROLLBACK_WAVE_FAILED" : An attempted rollback operation failed to complete successfully.
- "ROLLING_BACK" : A wave rollback is in progress for this rollout.
- "STATE_UNSPECIFIED" : Undefined default state. Should never be exposed to users.
- "UNINITIALIZED" : The rollout has been created but is not yet ready to be started.
- "WAVE_FAILED" : The product failed to process the wave.
Implementation
core.String? state;