selectors property
The selectors for this wave.
There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave.
Required.
Implementation
core.List<RolloutPlanWaveSelector>? selectors;