RolloutPlanWaveOrchestrationOptions class
Options to control the pace of orchestration of a wave.
These options are required only if the resource being rolled out follows the Orchestrated pattern.
Constructors
-
RolloutPlanWaveOrchestrationOptions({List<
RolloutPlanWaveOrchestrationOptionsDelay> ? delays, String? maxConcurrentLocations, String? maxConcurrentResourcesPerLocation}) - RolloutPlanWaveOrchestrationOptions.fromJson(Map json_)
Properties
-
delays
↔ List<
RolloutPlanWaveOrchestrationOptionsDelay> ? -
Delays, if any, to be added between batches of projects.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrentLocations ↔ String?
-
Maximum number of locations to be orchestrated in parallel.
getter/setter pair
- maxConcurrentResourcesPerLocation ↔ String?
-
Maximum number of resources to be orchestrated per location in
parallel.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited