RolloutPlanWaveOrchestrationOptionsDelay class
Options to control the delay, if any, between batches of projects.
Constructors
- RolloutPlanWaveOrchestrationOptionsDelay({String? delimiter, String? duration, String? type})
- RolloutPlanWaveOrchestrationOptionsDelay.fromJson(Map json_)
Properties
- delimiter ↔ String?
-
Controls whether the delay should only be added between batches of
projects corresponding to different locations, or also between
batches of projects corresponding to the same location.
getter/setter pair
- duration ↔ String?
-
The duration of the delay, if any, to be added between batches of
projects.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Controls whether the specified duration is to be added at the end of
each batch, or if the total processing time for each batch will be
padded if needed to meet the specified duration.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited