waitDuration property
The duration that the system waits in between waves.
This wait starts after all changes in the wave are rolled out.
Optional.
Implementation
core.String? waitDuration;
The duration that the system waits in between waves.
This wait starts after all changes in the wave are rolled out.
Optional.
core.String? waitDuration;