RolloutRolloutEntityOrchestratedEntity class
This message is used if the resource type follows the Orchestrated integration model with ProgressiveRollout.
Constructors
- RolloutRolloutEntityOrchestratedEntity({String? conflictBehavior, String? orchestrationAction, String? orchestrationSource})
- RolloutRolloutEntityOrchestratedEntity.fromJson(Map json_)
Properties
- conflictBehavior ↔ String?
-
Specifies the behavior of the Rollout if an out of band update is
detected in a project during a Rollout.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- orchestrationAction ↔ String?
-
Orchestration action during the Rollout.
getter/setter pair
- orchestrationSource ↔ String?
-
Fully qualified resource name of the resource which contains the source
of truth of the configuration being rolled out across
locations/projects.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited