SubnetworkSecondaryRange class

Represents a secondary IP range of a subnetwork.

Constructors

SubnetworkSecondaryRange({String? ipCidrRange, String? ipCollection, String? ipVersion, String? rangeName, String? reservedInternalRange})
SubnetworkSecondaryRange.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
ipCidrRange String?
The range of IP addresses belonging to this subnetwork secondary range. Provide this property when you create the subnetwork.
getter/setter pair
ipCollection String?
Reference to a Public Delegated Prefix (PDP) for BYOIP. This field should be specified for configuring BYOGUA internal IPv6 secondary range. When specified along with the ip_cidr_range, the ip_cidr_range must lie within the PDP referenced by the ipCollection field. When specified without the ip_cidr_range, the range is auto-allocated from the PDP referenced by the ipCollection field.
getter/setter pair
ipVersion String?
Possible string values are:
getter/setter pair
rangeName String?
The name associated with this subnetwork secondary range, used when adding an alias IP/IPv6 range to a VM instance. The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the subnetwork.
getter/setter pair
reservedInternalRange String?
The URL of the reserved internal range.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited