VmExtensionPolicy class
Represents a VM extension policy.
Constructors
-
VmExtensionPolicy({String? creationTimestamp, String? description, Map<
String, VmExtensionPolicyExtensionPolicy> ? extensionPolicies, String? globalResourceLink, String? id, List<VmExtensionPolicyInstanceSelector> ? instanceSelectors, String? kind, bool? managedByGlobal, String? name, int? priority, String? selfLink, String? selfLinkWithId, String? state, String? updateTimestamp}) - VmExtensionPolicy.fromJson(Map json_)
Properties
- creationTimestamp ↔ String?
-
Creation timestamp inRFC3339
text format.
getter/setter pair
- description ↔ String?
-
An optional description of this resource.
getter/setter pair
-
extensionPolicies
↔ Map<
String, VmExtensionPolicyExtensionPolicy> ? -
A map of extension names (for example, "ops-agent") to their corresponding
policy configurations.
getter/setter pair
- globalResourceLink ↔ String?
-
Link to the global policy that manages this zone policy, if
applicable.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The unique identifier for the resource.
getter/setter pair
-
instanceSelectors
↔ List<
VmExtensionPolicyInstanceSelector> ? -
Selectors to target VMs for this policy.
getter/setter pair
- kind ↔ String?
-
Type of the resource.
getter/setter pair
- managedByGlobal ↔ bool?
-
Indicates if this policy is managed by a global policy.
getter/setter pair
- name ↔ String?
-
Name of the resource.
getter/setter pair
- priority ↔ int?
-
Priority of this policy.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink ↔ String?
-
Server-defined fully-qualified URL for this resource.
getter/setter pair
- selfLinkWithId ↔ String?
-
Server-defined URL for this resource's resource id.
getter/setter pair
- state ↔ String?
-
Current state of the policy: ACTIVE or DELETING.
getter/setter pair
- updateTimestamp ↔ String?
-
Update timestamp inRFC3339
text format.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited