state property
Current state of the policy: ACTIVE or DELETING.
Optional. Output only. Possible string values are:
- "ACTIVE" : The policy is active and applied to matching VMs. Newly created VMs that match the policy will also receive the extension policy.
- "DELETING" : The policy is in the process of being deleted. After the extension is removed from all matching VMs, the policy will be deleted.
- "STATE_UNSPECIFIED" : Default value. Do not use.
Implementation
core.String? state;