VmExtensionPolicyLabelSelector class

A LabelSelector is applied to a VM only if it matches all the specified labels.

Properties

hashCode int
The hash code for this object.
no setterinherited
inclusionLabels Map<String, String>?
A map of key-value pairs representing VM labels. VMs must have all of the labels specified in this map to be selected (logical AND).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited