VpnTunnel class
Represents a Cloud VPN Tunnel resource.
For more information about VPN, read the the Cloud VPN Overview.
Constructors
-
VpnTunnel({VpnTunnelCipherSuite? cipherSuite, String? creationTimestamp, String? description, String? detailedStatus, String? id, int? ikeVersion, String? kind, String? labelFingerprint, Map<
String, String> ? labels, List<String> ? localTrafficSelector, String? name, String? peerExternalGateway, int? peerExternalGatewayInterface, String? peerGcpGateway, String? peerIp, String? region, List<String> ? remoteTrafficSelector, String? router, String? selfLink, String? status, String? targetVpnGateway, String? vpnGateway, int? vpnGatewayInterface}) - VpnTunnel.fromJson(Map json_)
Properties
- cipherSuite ↔ VpnTunnelCipherSuite?
-
User specified list of ciphers to use for the phase 1 and phase 2 of the
IKE protocol.
getter/setter pair
- creationTimestamp ↔ String?
-
Creation timestamp inRFC3339
text format.
getter/setter pair
- description ↔ String?
-
An optional description of this resource.
getter/setter pair
- detailedStatus ↔ String?
-
Detailed status message for the VPN tunnel.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The unique identifier for the resource.
getter/setter pair
- ikeVersion ↔ int?
-
IKE protocol version to use when establishing the VPN tunnel with the peer
VPN gateway.
getter/setter pair
- kind ↔ String?
-
Type of resource.
getter/setter pair
- labelFingerprint ↔ String?
-
A fingerprint for the labels being applied to this VpnTunnel, which is
essentially a hash of the labels set used for optimistic locking.
getter/setter pair
-
labelFingerprintAsBytes
↔ List<
int> -
getter/setter pair
-
labels
↔ Map<
String, String> ? -
Labels for this resource.
getter/setter pair
-
localTrafficSelector
↔ List<
String> ? -
Local traffic selector to use when establishing the VPN tunnel with the
peer VPN gateway.
getter/setter pair
- name ↔ String?
-
Name of the resource.
getter/setter pair
- peerExternalGateway ↔ String?
-
URL of the peer side external VPN gateway to which this VPN tunnel is
connected.
Provided by the client when the VPN tunnel is created.
This field is exclusive with the field peerGcpGateway.
getter/setter pair
- peerExternalGatewayInterface ↔ int?
-
The interface ID of the external VPN gateway to which this VPN tunnel is
connected.
getter/setter pair
- peerGcpGateway ↔ String?
-
URL of the peer side HA VPN gateway to which this VPN tunnel
is connected.
getter/setter pair
- peerIp ↔ String?
-
IP address of the peer VPN gateway.
getter/setter pair
- region ↔ String?
-
URL of the region where the VPN tunnel resides.
You must specify this field as part of the HTTP request URL.
getter/setter pair
-
remoteTrafficSelector
↔ List<
String> ? -
Remote traffic selectors to use when establishing the VPN tunnel with
the peer VPN gateway.
getter/setter pair
- router ↔ String?
-
URL of the router resource to be used for dynamic routing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfLink ↔ String?
-
Server-defined URL for the resource.
getter/setter pair
-
Shared secret used to set the secure session between the Cloud VPN gateway
and the peer VPN gateway.
getter/setter pair
-
Hash of the shared secret.
getter/setter pair
- status ↔ String?
-
The status of the VPN tunnel, which can be one of the
following:
getter/setter pair
- targetVpnGateway ↔ String?
-
URL of the Target VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created.
This field can be set only for Classic VPN tunnels.
getter/setter pair
- vpnGateway ↔ String?
-
URL of the VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created.
getter/setter pair
- vpnGatewayInterface ↔ int?
-
The interface ID of the VPN gateway with which this VPN tunnel is
associated.
Possible values are:
0,1.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited