DeploymentGroup class

A DeploymentGroup is a collection of DeploymentUnits that in a DAG-like structure.

Constructors

DeploymentGroup({Map<String, String>? annotations, String? createTime, List<DeploymentUnit>? deploymentUnits, Map<String, String>? labels, String? name, Status? provisioningError, String? provisioningState, String? provisioningStateDescription, String? state, String? stateDescription, String? updateTime})
DeploymentGroup.fromJson(Map json_)

Properties

annotations Map<String, String>?
Arbitrary key-value metadata storage e.g. to help client tools identify deployment group during automation.
getter/setter pair
createTime String?
Time when the deployment group was created.
getter/setter pair
deploymentUnits List<DeploymentUnit>?
The deployment units of the deployment group in a DAG like structure.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
labels Map<String, String>?
User-defined metadata for the deployment group.
getter/setter pair
name String?
Identifier.
getter/setter pair
provisioningError Status?
The error status of the deployment group provisioning or deprovisioning.
getter/setter pair
provisioningState String?
The provisioning state of the deployment group.
getter/setter pair
provisioningStateDescription String?
Additional information regarding the current provisioning state.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state String?
Current state of the deployment group.
getter/setter pair
stateDescription String?
Additional information regarding the current state.
getter/setter pair
updateTime String?
Time when the deployment group was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited