deploymentUnits property
The deployment units of the deployment group in a DAG like structure.
When a deployment group is being provisioned, the deployment units are deployed in a DAG order. The provided units must be in a DAG order, otherwise an error will be returned.
Implementation
core.List<DeploymentUnit>? deploymentUnits;