deployment property
The resource name of the source Deployment to import the output from.
Format: projects/{project}/locations/{location}/deployments/{deployment} The source deployment must be in the same project and location.
Required.
Implementation
core.String? deployment;