force property
If set to true, this option is propagated to the deletion of each deployment in the group.
This corresponds to the 'force' field in DeleteDeploymentRequest.
Optional.
Implementation
core.bool? force;
If set to true, this option is propagated to the deletion of each deployment in the group.
This corresponds to the 'force' field in DeleteDeploymentRequest.
Optional.
core.bool? force;