delete method
Deletes a DeploymentGroup
Request parameters:
name - Required. The name of DeploymentGroup in the format
projects/{project_id}/locations/{location_id}/deploymentGroups/{deploymentGroup}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/deploymentGroups/\[^/\]+$.
deploymentReferencePolicy - Optional. Policy on how to handle referenced
deployments when deleting the DeploymentGroup. If unspecified, the default
behavior is to fail the deletion if any deployments currently referenced
in the deployment_units of the DeploymentGroup or in the latest revision
are not deleted.
Possible string values are:
- "DEPLOYMENT_REFERENCE_POLICY_UNSPECIFIED" : The default behavior. If
unspecified, the system will act as if
FAIL_IF_ANY_REFERENCES_EXISTis specified. - "FAIL_IF_ANY_REFERENCES_EXIST" : Fail the deletion if any deployments
currently referenced in the
deployment_unitsof the DeploymentGroup or in the latest revision are not deleted. - "FAIL_IF_METADATA_REFERENCES_EXIST" : Fail the deletion only if any
deployments currently referenced in the
deployment_unitsof the DeploymentGroup are not deleted. The deletion will proceed even if the deployments in the latest revision of the DeploymentGroup are not deleted. - "IGNORE_DEPLOYMENT_REFERENCES" : Ignore any deployments currently
referenced in the
deployment_unitsof the DeploymentGroup or in the latest revision.
force - Optional. If set to true, any revisions for this deployment
group will also be deleted. (Otherwise, the request will only work if the
deployment group has no revisions.)
requestId - Optional. An optional request ID to identify requests.
Specify a unique request ID so that if you must retry your request, the
server will know to ignore the request if it has already been completed.
The server will guarantee that for at least 60 minutes after the first
request. For example, consider a situation where you make an initial
request and the request times out. If you make the request again with the
same request ID, the server can check if original operation with the same
request ID was received, and if so, will ignore the second request. This
prevents clients from accidentally creating duplicate commitments. The
request ID must be a valid UUID with the exception that zero UUID is not
supported (00000000-0000-0000-0000-000000000000).
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Operation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Operation> delete(
core.String name, {
core.String? deploymentReferencePolicy,
core.bool? force,
core.String? requestId,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'deploymentReferencePolicy': ?deploymentReferencePolicy == null
? null
: [deploymentReferencePolicy],
'force': ?force == null ? null : ['${force}'],
'requestId': ?requestId == null ? null : [requestId],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'DELETE',
queryParams: queryParams_,
);
return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}