ToolspecOverride class
Toolspec overrides for a connection only holds the information that is to be displayed in the UI for admins.
Constructors
-
ToolspecOverride({String? baseVersion, String? createTime, List<
Map< ? tools, String? updateTime})String, Object?> > - ToolspecOverride.fromJson(Map json_)
Properties
- baseVersion ↔ String?
-
Represents the base version of the toolspec for which admin has added
overrides.
getter/setter pair
- createTime ↔ String?
-
Created time.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
tools
↔ List<
Map< ?String, Object?> > -
List of tools defined in the tool spec.
getter/setter pair
- updateTime ↔ String?
-
Updated time.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited