ExecuteHttpRequestResponse class

Constructors

ExecuteHttpRequestResponse({String? body, List<HttpHeader>? headers, String? reason, int? statusCode})
ExecuteHttpRequestResponse.fromJson(Map json_)

Properties

body String?
The raw response body.
getter/setter pair
bodyAsBytes List<int>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
headers List<HttpHeader>?
HTTP headers received in the response.
getter/setter pair
reason String?
The HTTP status reason phrase received from the backend (e.g., "Not Found").
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int?
The HTTP status code received from the backend.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited