reason property
The HTTP status reason phrase received from the backend (e.g., "Not Found").
May be empty if the backend did not provide one.
Implementation
core.String? reason;
The HTTP status reason phrase received from the backend (e.g., "Not Found").
May be empty if the backend did not provide one.
core.String? reason;