CustomImageConfig class

CustomImageConfig contains the information r

Constructors

CustomImageConfig({String? image, String? imageProject})
CustomImageConfig.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
image String?
The name of the image to use for this node.
getter/setter pair
imageProject String?
The project containing the image to use for this node.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited