state property
The desired state of etcd encryption. Possible string values are:
- "UNKNOWN" : Should never be set
- "ENCRYPTED" : Secrets in etcd are encrypted.
- "DECRYPTED" : Secrets in etcd are stored in plain text (at etcd level) - this is unrelated to Compute Engine level full disk encryption.
- "ALL_OBJECTS_ENCRYPTION_ENABLED" : Encryption of all objects in the storage is enabled. There is no guarantee that all objects in the storage are encrypted, but eventually they will be.
Implementation
core.String? state;