DiskIoScheduler class
DiskIoScheduler contains the configuration for the disk IO scheduler.
Constructors
- DiskIoScheduler({String? nodeAttachedDiskIoScheduler, String? nodeSystemIoScheduler})
- DiskIoScheduler.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodeAttachedDiskIoScheduler ↔ String?
-
Configures the IO scheduler for the attached disks.
getter/setter pair
- nodeSystemIoScheduler ↔ String?
-
Configures the IO scheduler for the boot disk or ephemeral lssd that runs
node system workloads.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited