NodeDrainConfig class
NodeDrainConfig contains the node drain related configurations for this node pool.
Constructors
- NodeDrainConfig({String? graceTerminationDuration, String? pdbTimeoutDuration, bool? respectPdbDuringNodePoolDeletion})
- NodeDrainConfig.fromJson(Map json_)
Properties
- graceTerminationDuration ↔ String?
-
The duration of the grace termination period for node drain.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- pdbTimeoutDuration ↔ String?
-
The duration of the PDB timeout period for node drain.
getter/setter pair
- respectPdbDuringNodePoolDeletion ↔ bool?
-
Whether to respect PDB during node pool deletion.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited