acceleratorNetworkProfile property
The accelerator network profile for the node pool.
For now the only valid value is "auto". If specified, the network configuration of the nodes in this node pool will be managed by this profile for the supported machine types, zone, etc.
Immutable.
Implementation
core.String? acceleratorNetworkProfile;