NodeVfioConfig class
Configuration settings for VFIO (Virtual Function I/O) on a node.
VFIO allows safe, unprivileged, userspace drivers to access I/O devices.
Constructors
- NodeVfioConfig({int? dmaEntryLimit})
- NodeVfioConfig.fromJson(Map json_)
Properties
- dmaEntryLimit ↔ int?
-
Specifies the maximum number of DMA entries (pages) that can be mapped by
the VFIO IOMMU type 1 driver for a container.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited