RecurringMaintenanceWindow class
Represents an arbitrary window of time that recurs.
Will replace RecurringTimeWindow.
Constructors
- RecurringMaintenanceWindow({Date? delayUntil, String? recurrence, String? windowDuration, TimeOfDay? windowStartTime})
- RecurringMaintenanceWindow.fromJson(Map json_)
Properties
- delayUntil ↔ Date?
-
Specifies the date before which will not be scheduled.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- recurrence ↔ String?
-
An RRULE (https://tools.ietf.org/html/rfc5545#section-3.8.5.3) for how
this window recurs.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- windowDuration ↔ String?
-
Duration of the window.
getter/setter pair
- windowStartTime ↔ TimeOfDay?
-
Start time of the window on days that it is scheduled, assuming UTC
timezone.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited