lineNumber property
Line number in the file where the package was found.
Optional field that only applies to source repository scanning.
Implementation
core.int? lineNumber;
Line number in the file where the package was found.
Optional field that only applies to source repository scanning.
core.int? lineNumber;