rating property
Average rating score of the product.
The value must be within the range of [min_rating, max_rating],
inclusive. When displayed on the product page, this rating is normalized
to a scale of [1, 5] with one decimal place. If provided,
review_count, min_rating, and max_rating are also required. This
field is for an upcoming feature and is not yet used.
Implementation
core.double? rating;