GcsRepositorySnapshotMetadata class
Metadata about a repository snapshot stored in Google Cloud Storage.
Constructors
- GcsRepositorySnapshotMetadata({String? crc32cChecksum, String? generation, String? repositorySnapshotUri})
- GcsRepositorySnapshotMetadata.fromJson(Map json_)
Properties
- crc32cChecksum ↔ String?
-
The crc32c checksum of the repository snapshot, big-endian base64 encoded.
getter/setter pair
- generation ↔ String?
-
The generation number of the Cloud Storage object.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- repositorySnapshotUri ↔ String?
-
The Google Cloud Storage URI of the repository snapshot.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited