effectiveDefaultBranch property
The Git remote's effective default branch name.
This is the default branch name of the Git remote if it is set, otherwise
it is main.
Output only.
Implementation
core.String? effectiveDefaultBranch;
The Git remote's effective default branch name.
This is the default branch name of the Git remote if it is set, otherwise
it is main.
Output only.
core.String? effectiveDefaultBranch;