path property
The relative path within the Git repository where the pipeline is defined.
For example, for a Dataform pipeline, it is a path to the folder where
workflow_settings.yaml or dataform.json is located.
Required.
Implementation
core.String? path;