ProjectsLocationsTeamFoldersResource class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(TeamFolder request, String parent, {String? $fields})
→ Future<TeamFolder>
-
Creates a new TeamFolder in a given project and location.
-
delete(String name, {String? $fields})
→ Future<Empty>
-
Deletes a single TeamFolder.
-
deleteTree(DeleteTeamFolderTreeRequest request, String name, {String? $fields})
→ Future<Operation>
-
Deletes a TeamFolder with its contents (Folders, Repositories, Workspaces,
ReleaseConfigs, and WorkflowConfigs).
-
get(String name, {String? $fields})
→ Future<TeamFolder>
-
Fetches a single TeamFolder.
-
getIamPolicy(String resource, {int? options_requestedPolicyVersion, String? $fields})
→ Future<Policy>
-
Gets the access control policy for a resource.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(TeamFolder request, String name, {String? updateMask, String? $fields})
→ Future<TeamFolder>
-
Updates a single TeamFolder.
-
queryContents(String teamFolder, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields})
→ Future<QueryTeamFolderContentsResponse>
-
Returns the contents of a given TeamFolder.
-
search(String location, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields})
→ Future<SearchTeamFoldersResponse>
-
Returns all TeamFolders in a given location that the caller has access to
and match the provided filter.
-
setIamPolicy(SetIamPolicyRequest request, String resource, {String? $fields})
→ Future<Policy>
-
Sets the access control policy on the specified resource.
-
testIamPermissions(TestIamPermissionsRequest request, String resource, {String? $fields})
→ Future<TestIamPermissionsResponse>
-
Returns permissions that a caller has on the specified resource.
-
toString()
→ String
-
A string representation of this object.
inherited