containingFolder property
The name of the containing folder of the repository.
The field is immutable and it can be modified via a MoveRepository
operation. Format: projects / * /locations / * /folders / * . or
projects / * /locations / * /teamFolders / * .
Optional.
Implementation
core.String? containingFolder;