datalineage/v1 library
Data Lineage API - v1
For more information, see cloud.google.com/data-catalog
Create an instance of DatalineageApi to access these resources:
Classes
- DatalineageApi
- FoldersLocationsConfigResource
- FoldersLocationsResource
- FoldersResource
- GoogleCloudDatacatalogLineageConfigmanagementV1Config
- Configuration for Data Lineage.
- GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestion
- Defines how Lineage should be ingested for a given resource.
- GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRule
- Ingestion rule for Data Lineage ingestion.
- GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRuleIntegrationSelector
- Integration selector of the rule.
- GoogleCloudDatacatalogLineageConfigmanagementV1ConfigIngestionIngestionRuleLineageEnablement
- Lineage enablement configuration.
- GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesRequest
- Request message for BatchSearchLinkProcesses.
- GoogleCloudDatacatalogLineageV1BatchSearchLinkProcessesResponse
- Response message for BatchSearchLinkProcesses.
- GoogleCloudDatacatalogLineageV1DependencyInfo
- Dependency info describes how one entity depends on another.
- GoogleCloudDatacatalogLineageV1EntityReference
- The soft reference to everything you can attach a lineage event to.
- GoogleCloudDatacatalogLineageV1EventLink
- A lineage between source and target entities.
- GoogleCloudDatacatalogLineageV1LineageEvent
- A lineage event represents an operation on assets.
- GoogleCloudDatacatalogLineageV1LineageLink
- Lineage link between two entities.
- GoogleCloudDatacatalogLineageV1LineageLinkLineageProcess
- Process metadata for the link.
- GoogleCloudDatacatalogLineageV1Link
- Links represent the data flow between source (upstream) and target (downstream) assets in transformation pipelines.
- GoogleCloudDatacatalogLineageV1ListLineageEventsResponse
- Response message for ListLineageEvents.
- GoogleCloudDatacatalogLineageV1ListProcessesResponse
- Response message for ListProcesses.
- GoogleCloudDatacatalogLineageV1ListRunsResponse
- Response message for ListRuns.
- GoogleCloudDatacatalogLineageV1MultipleEntityReference
- Multiple entity reference for SearchLinksRequest.
- GoogleCloudDatacatalogLineageV1Origin
- Origin of a process.
- GoogleCloudDatacatalogLineageV1Process
- A process is the definition of a data transformation operation.
- GoogleCloudDatacatalogLineageV1ProcessLinkInfo
- Link details.
- GoogleCloudDatacatalogLineageV1ProcessLinks
- Links associated with a specific process.
- GoogleCloudDatacatalogLineageV1ProcessOpenLineageRunEventResponse
- Response message for ProcessOpenLineageRunEvent.
- GoogleCloudDatacatalogLineageV1Run
- A lineage run represents an execution of a process that creates lineage events.
- GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequest
- Request message for SearchLineageStreaming.
- GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestRootCriteria
- Criteria for the root of the search.
- GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestSearchFilters
- Filters for the search.
- GoogleCloudDatacatalogLineageV1SearchLineageStreamingRequestSearchLimits
- Limits for the search results.
- GoogleCloudDatacatalogLineageV1SearchLineageStreamingResponse
- Response message for SearchLineageStreaming.
- GoogleCloudDatacatalogLineageV1SearchLinksRequest
- Request message for SearchLinks.
- GoogleCloudDatacatalogLineageV1SearchLinksResponse
- Response message for SearchLinks.
- GoogleLongrunningListOperationsResponse
- The response message for Operations.ListOperations.
- GoogleLongrunningOperation
- This resource represents a long-running operation that is the result of a network API call.
- OrganizationsLocationsConfigResource
- OrganizationsLocationsResource
- OrganizationsResource
- ProjectsLocationsConfigResource
- ProjectsLocationsOperationsResource
- ProjectsLocationsProcessesResource
- ProjectsLocationsProcessesRunsLineageEventsResource
- ProjectsLocationsProcessesRunsResource
- ProjectsLocationsResource
- ProjectsResource
Typedefs
- GoogleCloudDatacatalogLineageV1LineageLinkDependencyInfo = $LinkDependencyInfo
- Dependency info describes how one entity is dependent on another.
- GoogleCloudDatacatalogLineageV1LinkDependencyInfo = $LinkDependencyInfo
- Dependency info describes how one entity depends on another.
- GoogleLongrunningCancelOperationRequest = $Empty
- The request message for Operations.CancelOperation.
- GoogleProtobufEmpty = $Empty
- A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
- GoogleRpcStatus = $Status00
-
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. - GoogleTypeInterval = $Interval
- Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.