AccountTypesAccountsPartnerLinksResource class
Constructors
- AccountTypesAccountsPartnerLinksResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
PartnerLink request, String parent, {String? $fields}) → Future< PartnerLink> - Creates a partner link for the given account.
-
delete(
String name, {String? $fields}) → Future< Empty> - Deletes a partner link for the given account.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
search(
String parent, {String? filter, int? pageSize, String? pageToken, String? $fields}) → Future< SearchPartnerLinksResponse> - Searches for all partner links to and from a given account.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited