AdEvent class
An ad event.
Constructors
- AdEvent({String? adFormat, String? adFormatString, String? adGroupId, int? adHeight, String? adId, String? adPlacement, String? adPlacementString, String? adType, String? adTypeString, int? adWidth, String? advertiserId, String? attributionHint, String? campaignId, String? campaignName, DeviceInfo? deviceInfo, String? eventId, String? eventSubtype, String? eventSubtypeString, String? eventType, bool? measurementAllowed, String? medium, String? mobileDeviceId, String? platform, String? platformString, String? platformType, String? platformTypeString, String? regionCode, String? source, String? targetingType, String? targetingTypeString, String? timestamp, UserData? userData, ViewabilityInfo? viewabilityInfo})
- AdEvent.fromJson(Map json_)
Properties
- adFormat ↔ String?
-
Enum value for ad format.
Possible string values are:
getter/setter pair
- adFormatString ↔ String?
-
String value for ad format.
getter/setter pair
- adGroupId ↔ String?
-
The ID of the associated ad group.
getter/setter pair
- adHeight ↔ int?
-
The height of the ad in pixels.
getter/setter pair
- adId ↔ String?
-
The ID of the associated ad within the group.
getter/setter pair
- adPlacement ↔ String?
-
Enum value for ad placement.
Possible string values are:
getter/setter pair
- adPlacementString ↔ String?
-
String value for ad placement.
getter/setter pair
- adType ↔ String?
-
Enum value for ad type.
Possible string values are:
getter/setter pair
- adTypeString ↔ String?
-
String value for ad type.
getter/setter pair
- advertiserId ↔ String?
-
The ID of the advertiser for the ad event.
getter/setter pair
- adWidth ↔ int?
-
The width of the ad in pixels.
getter/setter pair
- attributionHint ↔ String?
-
The partner-assumed attribution status for this ad event.
getter/setter pair
- campaignId ↔ String?
-
The ID of the associated campaign.
getter/setter pair
- campaignName ↔ String?
-
The name of the associated campaign.
getter/setter pair
- deviceInfo ↔ DeviceInfo?
-
Information gathered about the device being used when the ad event
happened.
getter/setter pair
- eventId ↔ String?
-
An ID created and managed by the caller that uniquely identifies this
event.
getter/setter pair
- eventSubtype ↔ String?
-
Enum value for event subtype.
Possible string values are:
getter/setter pair
- eventSubtypeString ↔ String?
-
String value for event subtype.
getter/setter pair
- eventType ↔ String?
-
The type of the event.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- measurementAllowed ↔ bool?
-
Represents if the row is allowed to be used for measurement purposes, as
governed by applicable privacy laws within regional jurisdiction.
getter/setter pair
- medium ↔ String?
-
The medium of the ad, akin to the Google Analytics medium.
getter/setter pair
- mobileDeviceId ↔ String?
-
The device ID of the device that the ad was served to.
getter/setter pair
- platform ↔ String?
-
Enum value for platform.
Possible string values are:
getter/setter pair
- platformString ↔ String?
-
String value for platform.
getter/setter pair
- platformType ↔ String?
-
Enum value for platform type.
Possible string values are:
getter/setter pair
- platformTypeString ↔ String?
-
String value for platform type.
getter/setter pair
- regionCode ↔ String?
-
The ISO 3166-2 country plus subdivision.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source ↔ String?
-
The platform source of the ad, akin to the Google Analytics source.
getter/setter pair
- targetingType ↔ String?
-
Enum value for targeting type.
Possible string values are:
getter/setter pair
- targetingTypeString ↔ String?
-
String value for targeting type.
getter/setter pair
- timestamp ↔ String?
-
The time the event occurred.
getter/setter pair
- userData ↔ UserData?
-
Multiple pieces of user-provided data, representing the user the event is
associated with.
getter/setter pair
- viewabilityInfo ↔ ViewabilityInfo?
-
Details of the viewability of the ad served.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited