AdIdentifiers class
Identifiers and other information used to match the conversion event with other online activity (such as ad clicks).
Constructors
-
AdIdentifiers({String? dclid, List<
EncryptedUserId> ? encryptedUserIds, String? gbraid, String? gclid, String? impressionId, DeviceInfo? landingPageDeviceInfo, String? matchId, String? mobileDeviceId, String? sessionAttributes, String? wbraid}) - AdIdentifiers.fromJson(Map json_)
Properties
- dclid ↔ String?
-
The display click ID associated with this event.
getter/setter pair
-
encryptedUserIds
↔ List<
EncryptedUserId> ? -
Any number of encrypted user IDs.
getter/setter pair
- gbraid ↔ String?
-
The click identifier for clicks associated with app events and originating
from iOS devices starting with iOS14.
getter/setter pair
- gclid ↔ String?
-
The Google click ID (gclid) associated with this event.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- impressionId ↔ String?
-
The impression ID associated with this event.
getter/setter pair
- landingPageDeviceInfo ↔ DeviceInfo?
-
Information gathered about the device being used (if any) at the time of
landing onto the advertiser’s site after interacting with the ad.
getter/setter pair
- matchId ↔ String?
-
The match ID field used to join this event with a previous event.
getter/setter pair
- mobileDeviceId ↔ String?
-
The mobile identifier for advertisers.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionAttributes ↔ String?
-
Session attributes for event attribution and modeling.
getter/setter pair
- wbraid ↔ String?
-
The click identifier for clicks associated with web events and originating
from iOS devices starting with iOS14.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited