ContactIdInfo class
Additional information when CONTACT_ID is one of the upload_key_types.
Constructors
- ContactIdInfo({String? dataSourceType, int? matchRatePercentage})
- ContactIdInfo.fromJson(Map json_)
Properties
- dataSourceType ↔ String?
-
Source of the upload data
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- matchRatePercentage ↔ int?
-
Match rate for customer match user lists.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited