reason property
The warning reason. Possible string values are:
- "WARNING_REASON_UNSPECIFIED" : Unspecified warning reason.
- "WARNING_REASON_CUSTOM_VARIABLE_NOT_ENABLED" : A custom variable in
custom_variablesis not enabled in the account. - "WARNING_REASON_CUSTOM_VARIABLE_NOT_PREDEFINED" : A custom variable
value in
custom_variablesis not among the predefined allowed values configured for the custom variable on the destination account. - "WARNING_REASON_CART_DATA_NOT_SUPPORTED_WITH_GBRAID_OR_WBRAID" : The
cart_datais not supported withgbraidorwbraid. - "WARNING_REASON_CART_DATA_ITEM_MERCHANT_PRODUCT_ID_MISSING" : The
merchant_product_idis missing in the cart item. - "WARNING_REASON_CART_DATA_ITEM_UNIT_PRICE_MISSING" : The
unit_priceis missing in the cart item. - "WARNING_REASON_GENERIC" : Generic warning reason for issues that do not fit into other specific categories.
- "WARNING_REASON_INVALID_CLIENT_ID" : The
client_idis invalid. - "WARNING_REASON_INVALID_SUBDIVISION_CODE" : The
subdivision_codeis invalid. - "WARNING_REASON_INVALID_REGION_CODE" : The
region_codeis invalid. - "WARNING_REASON_INVALID_SUBCONTINENT_CODE" : The
subcontinent_codeis invalid. - "WARNING_REASON_INVALID_CONTINENT_CODE" : The
continent_codeis invalid. - "WARNING_REASON_INVALID_DEVICE_CATEGORY" : The device
categoryis invalid. - "WARNING_REASON_INVALID_DEVICE_SCREEN_RESOLUTION" : The device
screen_heightorscreen_widthis invalid. - "WARNING_REASON_INVALID_MERCHANT_ID" : The
merchant_idis invalid.
Implementation
core.String? reason;