IngestAudienceMembersStatus class
The status of the ingest audience members request.
Constructors
- IngestAudienceMembersStatus({IngestCompositeDataStatus? compositeDataIngestionStatus, IngestGoogleUserIdDataStatus? googleUserIdDataIngestionStatus, IngestMobileDataStatus? mobileDataIngestionStatus, IngestPairDataStatus? pairDataIngestionStatus, IngestPartnerProvidedIdDataStatus? partnerProvidedIdDataIngestionStatus, IngestPpidDataStatus? ppidDataIngestionStatus, IngestUserDataStatus? userDataIngestionStatus, IngestUserIdDataStatus? userIdDataIngestionStatus})
- IngestAudienceMembersStatus.fromJson(Map json_)
Properties
- compositeDataIngestionStatus ↔ IngestCompositeDataStatus?
-
The status of the composite data ingestion to the destination.
getter/setter pair
- googleUserIdDataIngestionStatus ↔ IngestGoogleUserIdDataStatus?
-
The status of the google user id data ingestion to the destination.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mobileDataIngestionStatus ↔ IngestMobileDataStatus?
-
The status of the mobile data ingestion to the destination.
getter/setter pair
- pairDataIngestionStatus ↔ IngestPairDataStatus?
-
The status of the pair data ingestion to the destination.
getter/setter pair
- partnerProvidedIdDataIngestionStatus ↔ IngestPartnerProvidedIdDataStatus?
-
The status of the partner provided id data ingestion to the destination.
getter/setter pair
- ppidDataIngestionStatus ↔ IngestPpidDataStatus?
-
The status of the ppid data ingestion to the destination.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userDataIngestionStatus ↔ IngestUserDataStatus?
-
The status of the user data ingestion to the destination.
getter/setter pair
- userIdDataIngestionStatus ↔ IngestUserIdDataStatus?
-
The status of the user id data ingestion to the destination.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited