IngestEventsResponse class
Response from the IngestEventsRequest.
Constructors
-
IngestEventsResponse({List<
FieldWarning> ? fieldWarnings, String? requestId}) - IngestEventsResponse.fromJson(Map json_)
Properties
-
fieldWarnings
↔ List<
FieldWarning> ? -
Detailed row-level warnings with field paths.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId ↔ String?
-
The auto-generated ID of the request.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited