userIdCount property
The total count of user ids sent in the upload request for the destination.
Includes all user ids in the request, regardless of whether they were successfully ingested or not.
Implementation
core.String? userIdCount;
The total count of user ids sent in the upload request for the destination.
Includes all user ids in the request, regardless of whether they were successfully ingested or not.
core.String? userIdCount;