conversionValue property
The conversion value associated with this item within the event, for cases where the conversion value is different for each item.
Optional.
Implementation
core.double? conversionValue;
The conversion value associated with this item within the event, for cases where the conversion value is different for each item.
Optional.
core.double? conversionValue;