MobileData class
Mobile IDs for the audience.
At least one mobile ID is required.
Constructors
-
MobileData({List<
String> ? mobileIds}) - MobileData.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mobileIds
↔ List<
String> ? -
The list of mobile device IDs (Android advertising ID, iOS IDFA for
Customer Match user lists and Android advertising ID, iOS IDFA, Xbox or
Microsoft ID, Amazon Fire TV ID, Roku ID, Generic Device ID for basic user
lists).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited