MobileIdInfo class
Additional information when MOBILE_ID is one of the upload_key_types.
Constructors
- MobileIdInfo({String? appId, String? dataSourceType, String? keySpace})
- MobileIdInfo.fromJson(Map json_)
Properties
- appId ↔ String?
-
A string that uniquely identifies a mobile application from which the data
was collected.
getter/setter pair
- dataSourceType ↔ String?
-
Source of the upload data.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- keySpace ↔ String?
-
The key space of mobile IDs.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited