PairIdInfo class
Additional information when PAIR_ID is one of the upload_key_types.
This feature is only available to data partners.
Constructors
- PairIdInfo({String? advertiserIdentifierCount, String? cleanRoomIdentifier, int? matchRatePercentage, String? publisherId, String? publisherName})
- PairIdInfo.fromJson(Map json_)
Properties
- advertiserIdentifierCount ↔ String?
-
The count of the advertiser's first party data records that have been
uploaded to a clean room provider.
getter/setter pair
- cleanRoomIdentifier ↔ String?
-
Identifies a unique advertiser to publisher relationship with one clean
room provider or across multiple clean room providers.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- matchRatePercentage ↔ int?
-
This field denotes the percentage of membership match of this user list
with the corresponding publisher's first party data.
getter/setter pair
- publisherId ↔ String?
-
Identifies the publisher that the Publisher Advertiser Identity
Reconciliation user list is reconciled with.
getter/setter pair
- publisherName ↔ String?
-
Descriptive name of the publisher to be displayed in the UI for a better
targeting experience.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited