PartnerCustomerAccount class

Represents a customer account in the partner's system.

Constructors

PartnerCustomerAccount({String? accountId, String? accountName, String? accountType})
PartnerCustomerAccount.fromJson(Map json_)

Properties

accountId String?
The identifier of the customer account in the partner's ID space.
getter/setter pair
accountName String?
The name of the account.
getter/setter pair
accountType String?
The type of the account.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited