featureSet property
The set of features supported for the partner link.
If not specified, the system behavior defaults to FEATURE_SET_AUDIENCE_AND_EVENT_MANAGEMENT.
Optional. Immutable. Possible string values are:
- "FEATURE_SET_UNSPECIFIED" : Unspecified feature set. If unspecified, the system behavior defaults to FEATURE_SET_AUDIENCE_AND_EVENT_MANAGEMENT.
- "FEATURE_SET_AUDIENCE_AND_EVENT_MANAGEMENT" : Indicates a link used for audience and event management.
- "FEATURE_SET_AD_EVENT_MANAGEMENT" : Indicates a link used for ad event management.
Implementation
core.String? featureSet;