PartnerProvidedIdData class
Partner-provided data holding the partner-provided identifiers.
At least one partner-provided identifier is required.
Constructors
-
PartnerProvidedIdData({List<
String> ? partnerProvidedIds}) - PartnerProvidedIdData.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
partnerProvidedIds
↔ List<
String> ? -
The list of partner-provided identifiers.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited