syncStatus property
Sync status of the user list.
Output only. Possible string values are:
- "SYNC_STATUS_UNSPECIFIED" : Not specified.
- "CREATED" : The user list has been created as a placeholder. List contents and/or metadata are still being synced. The user list is not ready for use.
- "READY_FOR_USE" : The user list is ready for use. Contents and cookies have been synced correctly.
- "FAILED" : An error has occurred syncing user list contents and/or metadata. The user list cannot be used.
Implementation
core.String? syncStatus;