RemoveAllAudienceMembersRequest class
Request to remove all users from an audience in the provided destinations.
Returns a RemoveAllAudienceMembersResponse.
Constructors
-
RemoveAllAudienceMembersRequest({List<
Destination> ? destinations, String? removeAsOfTime, bool? validateOnly}) - RemoveAllAudienceMembersRequest.fromJson(Map json_)
Properties
-
destinations
↔ List<
Destination> ? -
The list of destinations to remove the users from.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- removeAsOfTime ↔ String?
-
The remove as of time.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validateOnly ↔ bool?
-
For testing purposes.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited