userIdCount property
The total count of user ids sent in the removal request.
Includes all user ids in the request, regardless of whether they were successfully removed or not.
Implementation
core.String? userIdCount;
The total count of user ids sent in the removal request.
Includes all user ids in the request, regardless of whether they were successfully removed or not.
core.String? userIdCount;