TargetNetworkInfo class
Eligibility information for different target networks.
Constructors
- TargetNetworkInfo({bool? eligibleForDisplay, bool? eligibleForSearch})
- TargetNetworkInfo.fromJson(Map json_)
Properties
- eligibleForDisplay ↔ bool?
-
Indicates this user list is eligible for Google Display Network.
getter/setter pair
- eligibleForSearch ↔ bool?
-
Indicates if this user list is eligible for Google Search Network.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited