accountAccessStatus property
Indicates if this share is still enabled.
When a user list is shared with the account this field is set to
ENABLED. Later the user list owner can decide to revoke the share and
make it DISABLED.
Optional. Possible string values are:
- "ACCESS_STATUS_UNSPECIFIED" : Not specified.
- "ENABLED" : The access is enabled.
- "DISABLED" : The access is disabled.
Implementation
core.String? accountAccessStatus;