membershipDuration property
The duration a user remains in the user list.
Valid durations are exact multiples of 24 hours (86400 seconds). Providing a value that is not an exact multiple of 24 hours will result in an INVALID_ARGUMENT error.
Optional.
Implementation
core.String? membershipDuration;