UserListDirectLicense class
A user list direct license.
This feature is only available to data partners.
Constructors
-
UserListDirectLicense({String? clientAccountDisplayName, String? clientAccountId, String? clientAccountType, List<
UserListLicensePricing> ? historicalPricings, UserListLicenseMetrics? metrics, String? name, UserListLicensePricing? pricing, String? status, String? userListDisplayName, String? userListId}) - UserListDirectLicense.fromJson(Map json_)
Properties
- clientAccountDisplayName ↔ String?
-
Name of client customer which the user list is being licensed to.
getter/setter pair
- clientAccountId ↔ String?
-
ID of client customer which the user list is being licensed to.
getter/setter pair
- clientAccountType ↔ String?
-
Account type of client customer which the user list is being licensed to.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
historicalPricings
↔ List<
UserListLicensePricing> ? -
Pricing history of this user list license.
getter/setter pair
- metrics ↔ UserListLicenseMetrics?
-
Metrics related to this license This field is read-only and only populated
if the start and end dates are set in the ListUserListDirectLicenses call
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- pricing ↔ UserListLicensePricing?
-
UserListDirectLicense pricing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
Status of UserListDirectLicense - ENABLED or DISABLED.
getter/setter pair
- userListDisplayName ↔ String?
-
Name of the user list being licensed.
getter/setter pair
- userListId ↔ String?
-
ID of the user list being licensed.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited