metrics property
Metrics related to this license This field is read-only and only populated if the start and end dates are set in the ListUserListDirectLicenses call
Output only.
Implementation
UserListLicenseMetrics? metrics;
Metrics related to this license This field is read-only and only populated if the start and end dates are set in the ListUserListDirectLicenses call
Output only.
UserListLicenseMetrics? metrics;