UserListGlobalLicense class
A user list global license.
This feature is only available to data partners.
Constructors
-
UserListGlobalLicense({List<
UserListLicensePricing> ? historicalPricings, String? licenseType, UserListLicenseMetrics? metrics, String? name, UserListLicensePricing? pricing, String? status, String? userListDisplayName, String? userListId}) - UserListGlobalLicense.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
historicalPricings
↔ List<
UserListLicensePricing> ? -
Pricing history of this user list license.
getter/setter pair
- licenseType ↔ String?
-
Product type of client customer which the user list is being licensed to.
getter/setter pair
- metrics ↔ UserListLicenseMetrics?
-
Metrics related to this license This field is read-only and only populated
if the start and end dates are set in the ListUserListGlobalLicenses call
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- pricing ↔ UserListLicensePricing?
-
UserListGlobalLicense pricing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ String?
-
Status of UserListGlobalLicense - ENABLED or DISABLED.
getter/setter pair
- userListDisplayName ↔ String?
-
Name of the user list being licensed.
getter/setter pair
- userListId ↔ String?
-
ID of the user list being licensed.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited