UserListLicenseMetrics class
Metrics related to a user list license.
Constructors
- UserListLicenseMetrics({String? clickCount, String? endDate, String? impressionCount, String? revenueUsdMicros, String? startDate})
- UserListLicenseMetrics.fromJson(Map json_)
Properties
- clickCount ↔ String?
-
The number of clicks for the user list license.
getter/setter pair
- endDate ↔ String?
-
The end date (inclusive) of the metrics in the format YYYYMMDD.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- impressionCount ↔ String?
-
The number of impressions for the user list license.
getter/setter pair
- revenueUsdMicros ↔ String?
-
The revenue for the user list license in USD micros.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startDate ↔ String?
-
The start date (inclusive) of the metrics in the format YYYYMMDD.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited