UserListLicensePricing class
A user list license pricing.
Constructors
Properties
- buyerApprovalState ↔ String?
-
The buyer approval state of this pricing.
getter/setter pair
- costMicros ↔ String?
-
The cost associated with the model, in micro units (10^-6), in the
currency specified by the currency_code field.
getter/setter pair
- costType ↔ String?
-
The cost type of this pricing.
getter/setter pair
- currencyCode ↔ String?
-
The currency in which cost and max_cost is specified.
getter/setter pair
- endTime ↔ String?
-
End time of the pricing.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxCostMicros ↔ String?
-
The maximum CPM a commerce audience can be charged when the MEDIA_SHARE
cost type is used.
getter/setter pair
- pricingActive ↔ bool?
-
Whether this pricing is active.
getter/setter pair
- pricingId ↔ String?
-
The ID of this pricing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime ↔ String?
-
Start time of the pricing.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited