GoogleCloudDataplexV1DataDiscoverySpecStorageConfigUnstructuredDataOptions class

Describes options for unstructured data discovery.

Properties

globalEndpointEnabled bool?
Whether to use the global model endpoint.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticInferenceEnabled bool?
Specifies whether deeper semantic inference over the objects' contents using GenAI is enabled.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited