GoogleCloudDataplexV1DataDomain class
A DataDomain is a logical grouping of data resources for governance, discovery, and management at scale.
Constructors
-
GoogleCloudDataplexV1DataDomain({GoogleCloudDataplexV1Contacts? contacts, String? createTime, String? description, String? displayName, Map<
String, String> ? labels, String? name, String? parentDataDomain, GoogleIamV1ResourcePolicyMember? policyMember, String? uid, String? updateTime}) - GoogleCloudDataplexV1DataDomain.fromJson(Map json_)
Properties
- contacts ↔ GoogleCloudDataplexV1Contacts?
-
Contact info for the Data Domains.
getter/setter pair
- createTime ↔ String?
-
The time at which the DataDomain was created.
getter/setter pair
- description ↔ String?
-
User-provided description of the DataDomain.
getter/setter pair
- displayName ↔ String?
-
User-friendly display name.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
User-defined labels for the DataDomain.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- parentDataDomain ↔ String?
-
The resource name of the parent DataDomain.
getter/setter pair
- policyMember ↔ GoogleIamV1ResourcePolicyMember?
-
Output-only policy member strings of this resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uid ↔ String?
-
System-generated globally unique ID for the DataDomain.
getter/setter pair
- updateTime ↔ String?
-
The time at which the DataDomain was last updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited