accessGroupDisplayName property
The display name of the access group defined in the Data Product for which access is being requested.
Output only.
Implementation
core.String? accessGroupDisplayName;
The display name of the access group defined in the Data Product for which access is being requested.
Output only.
core.String? accessGroupDisplayName;