templateReference property
Aggregate rule which references a rule template and provides the parameters to be substituted in the template.
If any rows are returned, this rule fails.
Implementation
GoogleCloudDataplexV1DataQualityRuleTemplateReference? templateReference;