GoogleCloudDataplexV1DataQualityRuleResultDebugQueryResult class
Contains a single result from the debug query.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Specifies the name of the result.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Indicates the data type of the result.
getter/setter pair
- value ↔ String?
-
Represents the value of the result as a string.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited