GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntryLinkSource class
Entry link source represents information about the entry link.
Constructors
Properties
- entryLink ↔ String?
-
The entry link name in the form of:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entryLinks/{entry_link_id}
getter/setter pair
- entryLinkType ↔ String?
-
The entry link type to represent the current relationship between the
entry and the next entry in the path.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited