entryLinkType property
The entry link type to represent the current relationship between the entry and the next entry in the path.
In the form of: projects/{project_id_or_number}/locations/{location_id}/entryLinkTypes/{entry_link_type_id}
Output only.
Implementation
core.String? entryLinkType;