GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource class
Entry source represents information about the related source entry.
Constructors
- GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource({String? displayName, String? entry, String? entryType})
- GoogleCloudDataplexV1DataQualityRuleRuleSourceRulePathElementEntrySource.fromJson(Map json_)
Properties
- displayName ↔ String?
-
The display name of the entry.
getter/setter pair
- entry ↔ String?
-
The entry name in the form of:
projects/{project_id_or_number}/locations/{location_id}/entryGroups/{entry_group_id}/entries/{entry_id}
getter/setter pair
- entryType ↔ String?
-
The entry type to represent the current characteristics of the entry in
the form of:
projects/{project_id_or_number}/locations/{location_id}/entryTypes/{entry-type-id}.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited