GoogleCloudDataplexV1EncryptionConfig class

A Resource designed to manage encryption configurations for customers to support Customer Managed Encryption Keys (CMEK).

Properties

createTime ↔ String?
The time when the Encryption configuration was created.
getter/setter pair
encryptionState ↔ String?
The state of encryption of the databases.
getter/setter pair
etag ↔ String?
Etag of the EncryptionConfig.
getter/setter pair
failureDetails ↔ GoogleCloudDataplexV1EncryptionConfigFailureDetails?
Details of the failure if anything related to Cmek db fails.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
If a key is chosen, it means that the customer is using CMEK.
getter/setter pair
name ↔ String?
Identifier.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
The time when the Encryption configuration was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited