aspects property
The aspects that are attached to the entry link.
The format of the aspect key has to be the following: {project_id_or_number}.{location_id}.{aspect_type_id} Currently, only a single aspect of a Dataplex-owned Aspect Type is allowed.
Optional.
Implementation
core.Map<core.String, GoogleCloudDataplexV1Aspect>? aspects;