GoogleCloudDataplexV1GraphProfileEdgeType class

Represents a type of edge (relationship) in the graph.

Properties

description String?
Description of the edge type.
getter/setter pair
extractionHints GoogleCloudDataplexV1GraphProfileEdgeTypeExtractionHints?
Extraction hints for the edge.
getter/setter pair
fields List<GoogleCloudDataplexV1GraphProfileField>?
Fields of the edge type.
getter/setter pair
foreignKeys List<GoogleCloudDataplexV1GraphProfileEdgeTypeForeignKey>?
Defines the Foreign Key constraints for the edge.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
name String?
Name of the edge type.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceNodeType String?
Source node type.
getter/setter pair
targetNodeType String?
Target node type.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited