GoogleCloudDataplexV1GraphProfileEdgeTypeForeignKey class
Represents a foreign key constraint.
Constructors
-
GoogleCloudDataplexV1GraphProfileEdgeTypeForeignKey({String? description, List<
GoogleCloudDataplexV1GraphProfileEdgeTypeForeignKeyFieldMapping> ? fieldMappings, String? name, String? referencedNodeType}) - GoogleCloudDataplexV1GraphProfileEdgeTypeForeignKey.fromJson(Map json_)
Properties
- description ↔ String?
-
Description of the foreign key.
getter/setter pair
-
fieldMappings
↔ List<
GoogleCloudDataplexV1GraphProfileEdgeTypeForeignKeyFieldMapping> ? -
Field Mappings.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Name of the foreign key constraint.
getter/setter pair
- referencedNodeType ↔ String?
-
The node type this constraint references.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited