GoogleCloudDataplexV1GraphProfileEdgeTypeForeignKeyFieldMapping class

Maps a local field to a referenced field.

Properties

field String?
Local field name forming part of the foreign key.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
referencedField String?
Field name in the referenced node type.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited