GoogleCloudDataplexV1GraphProfileField class

Represents a field in a node or edge type.

Properties

dataType String?
The data type of the field, e.g., STRING, INTEGER, DATE.
getter/setter pair
description String?
Description of the field.
getter/setter pair
extractionHints GoogleCloudDataplexV1GraphProfileFieldExtractionHints?
Extraction hints for the field.
getter/setter pair
fields List<GoogleCloudDataplexV1GraphProfileField>?
Sub-fields of this field (for STRUCT types).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadataType String?
The mapped metadata type.
getter/setter pair
mode String?
The mode of the field.
getter/setter pair
name String?
Name of the field.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited