GoogleCloudDataplexV1GraphProfileNodeType class
Represents a type of node in the graph.
Constructors
-
GoogleCloudDataplexV1GraphProfileNodeType({String? description, GoogleCloudDataplexV1GraphProfileNodeTypeExtractionHints? extractionHints, List<
GoogleCloudDataplexV1GraphProfileField> ? fields, String? name, List<String> ? primaryKeys}) - GoogleCloudDataplexV1GraphProfileNodeType.fromJson(Map json_)
Properties
- description ↔ String?
-
Description of the node type.
getter/setter pair
- extractionHints ↔ GoogleCloudDataplexV1GraphProfileNodeTypeExtractionHints?
-
Extraction hints for the node.
getter/setter pair
-
fields
↔ List<
GoogleCloudDataplexV1GraphProfileField> ? -
Fields of the node type.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Name of the node type.
getter/setter pair
-
primaryKeys
↔ List<
String> ? -
Field names forming the primary keys.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited