GoogleCloudDataplexV1ModifyEntryRequest class

Modify Entry request using permissions in the source system.

Properties

aspectKeys List<String>?
The aspect keys which the service should modify.
getter/setter pair
deleteMissingAspects bool?
If set to true, any aspects not specified in the request will be deleted.
getter/setter pair
entry GoogleCloudDataplexV1Entry?
The entry to modify.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updateMask String?
Mask of fields to update.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited