GoogleCloudDataplexV1UnstructuredDataProfileSpec class
Contains the specification for an unstructured data profile scan.
Constructors
- GoogleCloudDataplexV1UnstructuredDataProfileSpec({String? customizedPrompt, bool? globalEndpointEnabled, bool? graphProfilePublishingEnabled})
- GoogleCloudDataplexV1UnstructuredDataProfileSpec.fromJson(Map json_)
Properties
- customizedPrompt ↔ String?
-
Customized prompt for unstructured data profile.
getter/setter pair
- globalEndpointEnabled ↔ bool?
-
Whether to use the global model.
getter/setter pair
- graphProfilePublishingEnabled ↔ bool?
-
Whether to publish graph-profile as aspect on the catalog entry.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited