delete method
Deletes a ChangeRequest.Behavior depends on the caller's permissions and the resource's state: 1.
Callers with dataplex.changeRequests.delete can only delete ChangeRequests in the NEW state. 2. Callers with the dataplex.changeRequests.adminDelete permission can delete ChangeRequests regardless of their state.
Request parameters:
name - Required. The name of the ChangeRequest to delete. Format:
projects/{project_number}/locations/{location_id}/changeRequests/{change_request_id}
Value must have pattern
^projects/\[^/\]+/locations/\[^/\]+/changeRequests/\[^/\]+$.
etag - Optional. The etag of the ChangeRequest.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Empty.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Empty> delete(
core.String name, {
core.String? etag,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'etag': ?etag == null ? null : [etag],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'DELETE',
queryParams: queryParams_,
);
return Empty.fromJson(response_ as core.Map<core.String, core.dynamic>);
}