list method
Lists DataDomain resources in a project and location.
Request parameters:
parent - Required. The resource name of the parent location:
projects/{project_id_or_number}/locations/{location_id}
Value must have pattern ^projects/\[^/\]+/locations/\[^/\]+$.
filter - Optional. Filter request. Supports filter by
parent_data_domain.
orderBy - Optional. Order by fields for the result.
pageSize - Optional. Maximum number of DataDomains to return. The
service may return fewer. If unspecified, at most 50 domains will be
returned. The maximum value is 100; values above 100 will be coerced to
100.
pageToken - Optional. Page token received from a previous
ListDataDomains call.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleCloudDataplexV1ListDataDomainsResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleCloudDataplexV1ListDataDomainsResponse> list(
core.String parent, {
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/dataDomains';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleCloudDataplexV1ListDataDomainsResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}