ProjectsLocationsResource class
Methods
-
get(String name, {String? $fields})
→ Future<GoogleCloudLocationLocation>
-
Gets information about a location.
-
list(String name, {String? filter, int? pageSize, String? pageToken, String? $fields})
→ Future<GoogleCloudLocationListLocationsResponse>
-
Lists information about the supported locations for this service.This
method lists locations based on the resource scope provided in the
ListLocationsRequest.name field: Global locations: If name is empty, the
method lists the public locations available to all projects.
-
lookupContext(GoogleCloudDataplexV1LookupContextRequest request, String name, {String? $fields})
→ Future<GoogleCloudDataplexV1LookupContextResponse>
-
Looks up LLM Context for the specified resources.
-
lookupEntry(String name, {List<String>? aspectTypes_1, String? entry, List<String>? paths, String? view, String? $fields})
→ Future<GoogleCloudDataplexV1Entry>
-
Looks up an entry by name using the permission on the source system.
-
lookupEntryLinks(String name, {String? entry, List<String>? entryLinkTypes_1, String? entryMode, int? pageSize, String? pageToken, String? $fields})
→ Future<GoogleCloudDataplexV1LookupEntryLinksResponse>
-
Looks up Entry Links referencing the specified Entry.
-
modifyEntry(GoogleCloudDataplexV1ModifyEntryRequest request, String name, {String? $fields})
→ Future<GoogleCloudDataplexV1Entry>
-
Modifies an entry using the permission on the source system.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
searchEntries(String name, {String? orderBy, int? pageSize, String? pageToken, String? query, String? scope, bool? semanticSearch, String? $fields})
→ Future<GoogleCloudDataplexV1SearchEntriesResponse>
-
Searches for Entries matching the given query and scope.
-
toString()
→ String
-
A string representation of this object.
inherited