gkeClusterConfig property
- @Deprecated('Not supported. Member documentation may have more information.')
getter/setter pair
BETA.
The Kubernetes Engine config for clusters deployed to Kubernetes. These config settings are mutually exclusive with Compute Engine-based options, such as gce_cluster_config, master_config, worker_config, secondary_worker_config, and autoscaling_config.
Optional.
Implementation
@core.Deprecated(
'Not supported. Member documentation may have more information.',
)
GkeClusterConfig? gkeClusterConfig;