diskConfig property
Disk configuration to apply to the instances in this instance selection.
If specified on any entry in instanceSelectionList, then it must be specified on every entry in instanceSelectionList and the instanceGroupConfig must not specify any diskConfig.
Optional.
Implementation
DiskConfig? diskConfig;