PySparkNotebookBatch class
A configuration for running a PySpark Notebook batch workload.
Constructors
Properties
-
archiveUris
↔ List<
String> ? -
HCFS URIs of archives to be extracted into the working directory of each
executor.
getter/setter pair
-
fileUris
↔ List<
String> ? -
HCFS URIs of files to be placed in the working directory of each executor
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
jarFileUris
↔ List<
String> ? -
HCFS URIs of jar files to be added to the Spark CLASSPATH.
getter/setter pair
- notebookFileUri ↔ String?
-
The HCFS URI of the notebook file to execute.
getter/setter pair
-
params
↔ Map<
String, String> ? -
The parameters to pass to the notebook.
getter/setter pair
-
pythonFileUris
↔ List<
String> ? -
HCFS URIs of Python files to pass to the PySpark framework.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited