DataverseProfile class
Profile for connecting to a Dataverse source.
Constructors
- DataverseProfile({String? environmentUrl, OauthClientCredentials? oauthClientCredentials, String? tenantId})
- DataverseProfile.fromJson(Map json_)
Properties
- environmentUrl ↔ String?
-
Environment URL of the Microsoft Dataverse instance.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- oauthClientCredentials ↔ OauthClientCredentials?
-
Credentials for authenticating with the Dataverse API.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tenantId ↔ String?
-
Tenant id of the Microsoft Dataverse instance.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited