properties property
Source properties.
When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing.
Optional.
Implementation
core.List<SourceProperty>? properties;
Source properties.
When unspecified as part of include objects, includes everything, when unspecified as part of exclude objects, excludes nothing.
Optional.
core.List<SourceProperty>? properties;