gitProxyConfig property
Configuration for the git proxy feature.
Enabling the git proxy allows clients to perform git operations on the repositories linked in the connection. Learn more.
Optional.
Implementation
GitProxyConfig? gitProxyConfig;
Configuration for the git proxy feature.
Enabling the git proxy allows clients to perform git operations on the repositories linked in the connection. Learn more.
Optional.
GitProxyConfig? gitProxyConfig;