enabled property
Setting this to true allows the git and http proxies to perform actions on behalf of the user configured under the account connector.
Optional.
Implementation
core.bool? enabled;
Setting this to true allows the git and http proxies to perform actions on behalf of the user configured under the account connector.
Optional.
core.bool? enabled;