developerknowledge/v1 library
Developer Knowledge API - v1
The Developer Knowledge API provides access to Google's developer knowledge.
For more information, see developers.google.com/knowledge
Create an instance of DeveloperKnowledgeApi to access these resources:
Classes
- Answer
- An answer to a query.
- AnswerCitation
- Citation info for a segment.
- AnswerQueryRequest
- Request message for DeveloperKnowledge.AnswerQuery.
- AnswerQueryResponse
- Response message for DeveloperKnowledge.AnswerQuery.
- AnswerReference
- Represents a reference to a source.
- BatchGetDocumentsResponse
- Response message for DeveloperKnowledge.BatchGetDocuments.
- CitationSource
- Citation source.
- DeveloperKnowledgeApi
- The Developer Knowledge API provides access to Google's developer knowledge.
- Document
- A Document represents a page of documentation in the Developer Knowledge corpus, like the page at https://docs.cloud.google.com/storage/docs/creating-buckets.
- DocumentChunk
- A DocumentChunk represents a piece of content from a Document in the DeveloperKnowledge corpus.
- DocumentReference
- Represents a reference to a document.
- DocumentsResource
- SearchDocumentChunksResponse
- Response message for DeveloperKnowledge.SearchDocumentChunks.
- V1Resource
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.