startIndex property
Indicates the start of the segment, measured in bytes (UTF-8 unicode), inclusive.
If there are multi-byte characters, such as non-ASCII characters, the index measurement is longer than the string length.
Output only.
Implementation
core.int? startIndex;