document property
Represents metadata about the Document this chunk is from.
The DocumentView of this Document message will be set to
DOCUMENT_VIEW_BASIC. It is included here for convenience so that clients
do not need to call DeveloperKnowledge.GetDocument or
DeveloperKnowledge.BatchGetDocuments if they only need the metadata
fields. Otherwise, clients should use DeveloperKnowledge.GetDocument or
DeveloperKnowledge.BatchGetDocuments to fetch the full document content.
Output only.
Implementation
Document? document;