id property
Specifies the ID of this chunk within the document.
The chunk ID is unique within a document, but not globally unique across documents. The chunk ID is not stable and may change over time.
Output only.
Implementation
core.String? id;
Specifies the ID of this chunk within the document.
The chunk ID is unique within a document, but not globally unique across documents. The chunk ID is not stable and may change over time.
Output only.
core.String? id;