DocumentsResource class
Constructors
- DocumentsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
batchGet(
{List< String> ? names, String? view, String? $fields}) → Future<BatchGetDocumentsResponse> - Retrieves multiple documents, each with its full Markdown content.
-
get(
String name, {String? view, String? $fields}) → Future< Document> - Retrieves a single document with its full Markdown content.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
searchDocumentChunks(
{String? filter, int? pageSize, String? pageToken, String? query, String? $fields}) → Future< SearchDocumentChunksResponse> - Searches for developer knowledge across Google's developer documentation.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited