CustomValueField class
Contains custom value field information.
Constructors
- CustomValueField({int? fieldId, String? requestKey})
- CustomValueField.fromJson(Map json_)
Properties
- fieldId ↔ int?
-
Field ID in the element.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestKey ↔ String?
-
Custom key used to match for auto filtering.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited