ReportDataResponse class
Represents a response to report data request.
Constructors
-
ReportDataResponse({List<
ColumnHeader> ? columnHeaders, String? nextPageToken, List<ReportDataRow> ? rows, ReportDataRow? totalRow}) - ReportDataResponse.fromJson(Map json_)
Properties
-
columnHeaders
↔ List<
ColumnHeader> ? -
Ordered descriptors of the requested column fields.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nextPageToken ↔ String?
-
Token to retrieve the next page of rows, or empty if end of results.
getter/setter pair
-
rows
↔ List<
ReportDataRow> ? -
The resulting set of matching data rows.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalRow ↔ ReportDataRow?
-
Singular aggregate total row for the entire query matching the criteria.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited