totalRow property
Singular aggregate total row for the entire query matching the criteria.
Column headers apply in the exact same order as data rows. In the total_row: - All dimension columns contain an empty string (""), as aggregation does not apply. - Non-summable metric columns (e.g. Reach metrics) contain an empty string (""), as grand total aggregation cannot be mathematically/logically computed for them.
Output only.
Implementation
ReportDataRow? totalRow;