values property
A single sequential list of all cell values matching column_headers indices exactly.
- Metric cells that are suppressed due to Minimum Reporting Standard (MRS) privacy protection constraints return "-".
Output only.
Implementation
core.List<core.String>? values;