GoogleCloudDialogflowV2EntityType class

Each intent parameter has a type, called the entity type, which dictates exactly how data from an end-user expression is extracted.

Dialogflow provides predefined system entities that can match many common types of data. For example, there are system entities for matching dates, times, colors, email addresses, and so on. You can also create your own custom entities for matching custom data. For example, you could define a vegetable entity that can match the types of vegetables available for purchase with a grocery store agent. For more information, see the Entity guide.

Constructors

GoogleCloudDialogflowV2EntityType({String? autoExpansionMode, String? displayName, bool? enableFuzzyExtraction, List<GoogleCloudDialogflowV2EntityTypeEntity>? entities, String? kind, String? name})
GoogleCloudDialogflowV2EntityType.fromJson(Map json_)

Properties

autoExpansionMode ↔ String?
Indicates whether the entity type can be automatically expanded.
getter/setter pair
displayName ↔ String?
The name of the entity type.
getter/setter pair
enableFuzzyExtraction ↔ bool?
Enables fuzzy entity extraction during classification.
getter/setter pair
entities ↔ List<GoogleCloudDialogflowV2EntityTypeEntity>?
The collection of entity entries associated with the entity type.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
kind ↔ String?
Indicates the kind of entity type.
getter/setter pair
name ↔ String?
The unique identifier of the entity type.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited