GoogleCloudDialogflowV2FewShotExample class

Providing examples in the generator (i.e. building a few-shot generator) helps convey the desired format of the LLM response.

Properties

conversationContext ↔ GoogleCloudDialogflowV2ConversationContext?
Conversation transcripts.
getter/setter pair
extraInfo ↔ Map<String, String>?
Key is the placeholder field name in input, value is the value of the placeholder.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
output ↔ GoogleCloudDialogflowV2GeneratorSuggestion?
Example output of the model.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summarizationSectionList ↔ GoogleCloudDialogflowV2SummarizationSectionList?
Summarization sections.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited