GoogleCloudDialogflowV2Generator class

Constructors

GoogleCloudDialogflowV2Generator({GoogleCloudDialogflowV2AgentCoachingContext? agentCoachingContext, String? createTime, String? description, GoogleCloudDialogflowV2FreeFormContext? freeFormContext, GoogleCloudDialogflowV2InferenceParameter? inferenceParameter, String? name, String? publishedModel, GoogleCloudDialogflowV2SuggestionDedupingConfig? suggestionDedupingConfig, GoogleCloudDialogflowV2SummarizationContext? summarizationContext, List<String>? tools, String? triggerEvent, String? updateTime})
GoogleCloudDialogflowV2Generator.fromJson(Map json_)

Properties

agentCoachingContext ↔ GoogleCloudDialogflowV2AgentCoachingContext?
getter/setter pair
createTime ↔ String?
getter/setter pair
description ↔ String?
getter/setter pair
freeFormContext ↔ GoogleCloudDialogflowV2FreeFormContext?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inferenceParameter ↔ GoogleCloudDialogflowV2InferenceParameter?
getter/setter pair
name ↔ String?
getter/setter pair
publishedModel ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestionDedupingConfig ↔ GoogleCloudDialogflowV2SuggestionDedupingConfig?
getter/setter pair
summarizationContext ↔ GoogleCloudDialogflowV2SummarizationContext?
getter/setter pair
tools ↔ List<String>?
getter/setter pair
triggerEvent ↔ String?
Possible string values are:
getter/setter pair
updateTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited