GoogleCloudDialogflowV2SearchKnowledgeAnswerAnswerSource class

The sources of the answers.

Properties

hashCode → int
The hash code for this object.
no setterinherited
metadata ↔ Map<String, Object?>?
Metadata associated with the article.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snippet ↔ String?
The relevant snippet of the article.
getter/setter pair
title ↔ String?
The title of the article.
getter/setter pair
uri ↔ String?
The URI of the article.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited