GoogleCloudDialogflowCxV3DataStoreConnectionSignalsSafetySignals class

Safety check results.

Properties

bannedPhraseMatch ↔ String?
Specifies banned phrase match subject. Possible string values are:
getter/setter pair
decision ↔ String?
Safety decision. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
matchedBannedPhrase ↔ String?
The matched banned phrase if there was a match.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited