GoogleCloudDialogflowCxV3Match class
Constructors
-
GoogleCloudDialogflowCxV3Match({double? confidence, String? event, GoogleCloudDialogflowCxV3Intent? intent, String? matchType, Map<
String, Object?> ? parameters, String? resolvedInput}) - GoogleCloudDialogflowCxV3Match.fromJson(Map json_)
Properties
- confidence ↔ double?
-
getter/setter pair
- event ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- intent ↔ GoogleCloudDialogflowCxV3Intent?
-
getter/setter pair
- matchType ↔ String?
-
Possible string values are:
getter/setter pair
-
parameters
↔ Map<
String, Object?> ? -
The values for Object must be JSON objects. It can consist of
num,String,boolandnullas well asMapandListvalues.getter/setter pair - resolvedInput ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited