GoogleCloudDialogflowCxV3WebhookGenericWebService class

Represents configuration for a generic web service.

Constructors

GoogleCloudDialogflowCxV3WebhookGenericWebService({List<String>? allowedCaCerts, String? httpMethod, GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig? oauthConfig, Map<String, String>? parameterMapping, String? password, String? requestBody, Map<String, String>? requestHeaders, String? secretVersionForUsernamePassword, Map<String, GoogleCloudDialogflowCxV3WebhookGenericWebServiceSecretVersionHeaderValue>? secretVersionsForRequestHeaders, String? serviceAgentAuth, String? uri, String? username, String? webhookType})
GoogleCloudDialogflowCxV3WebhookGenericWebService.fromJson(Map json_)

Properties

allowedCaCerts ↔ List<String>?
Specifies a list of allowed custom CA certificates (in DER format) for HTTPS verification.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
httpMethod ↔ String?
HTTP method for the flexible webhook calls.
getter/setter pair
oauthConfig ↔ GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig?
The OAuth configuration of the webhook.
getter/setter pair
parameterMapping ↔ Map<String, String>?
Maps the values extracted from specific fields of the flexible webhook response into session parameters.
getter/setter pair
password ↔ String?
The password for HTTP Basic authentication.
getter/setter pair
requestBody ↔ String?
Defines a custom JSON object as request body to send to flexible webhook.
getter/setter pair
requestHeaders ↔ Map<String, String>?
The HTTP request headers to send together with webhook requests.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secretVersionForUsernamePassword ↔ String?
The SecretManager secret version resource storing the username:password pair for HTTP Basic authentication.
getter/setter pair
secretVersionsForRequestHeaders ↔ Map<String, GoogleCloudDialogflowCxV3WebhookGenericWebServiceSecretVersionHeaderValue>?
The HTTP request headers to send together with webhook requests.
getter/setter pair
serviceAgentAuth ↔ String?
Indicate the auth token type generated from the Diglogflow service agent.
getter/setter pair
uri ↔ String?
The webhook URI for receiving POST requests.
getter/setter pair
username ↔ String?
The user name for HTTP Basic authentication.
getter/setter pair
webhookType ↔ String?
Type of the webhook.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited