GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig class

Represents configuration of OAuth client credential flow for 3rd party API authentication.

Constructors

GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig({String? clientId, String? clientSecret, List<String>? scopes, String? secretVersionForClientSecret, String? tokenEndpoint})
GoogleCloudDialogflowCxV3WebhookGenericWebServiceOAuthConfig.fromJson(Map json_)

Properties

clientId ↔ String?
The client ID provided by the 3rd party platform.
getter/setter pair
clientSecret ↔ String?
The client secret provided by the 3rd party platform.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes ↔ List<String>?
The OAuth scopes to grant.
getter/setter pair
secretVersionForClientSecret ↔ String?
The name of the SecretManager secret version resource storing the client secret.
getter/setter pair
tokenEndpoint ↔ String?
The token endpoint provided by the 3rd party platform to exchange an access token.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited