DemandGenSettings class
Settings for Demand Gen line items.
Constructors
- DemandGenSettings({bool? geoLanguageTargetingEnabled, String? linkedMerchantId, ThirdPartyMeasurementConfigs? thirdPartyMeasurementConfigs})
- DemandGenSettings.fromJson(Map json_)
Properties
- geoLanguageTargetingEnabled ↔ bool?
-
Whether location and language targeting can be set at the line item level.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- linkedMerchantId ↔ String?
-
The ID of the Merchant Center account used to provide a product feed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thirdPartyMeasurementConfigs ↔ ThirdPartyMeasurementConfigs?
-
The third party measurement settings for the Demand Gen line item.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited