linkedMerchantId property
The ID of the Merchant Center account used to provide a product feed.
This Merchant Center account must already be linked to the advertiser.
Optional.
Implementation
core.String? linkedMerchantId;
The ID of the Merchant Center account used to provide a product feed.
This Merchant Center account must already be linked to the advertiser.
Optional.
core.String? linkedMerchantId;