finalMobileUrl property
The URL address of the webpage that people reach after they click the ad on a mobile device.
Optional.
Implementation
core.String? finalMobileUrl;
The URL address of the webpage that people reach after they click the ad on a mobile device.
Optional.
core.String? finalMobileUrl;