minEffectiveFrequency property
The minimum effective frequency for the reported reach metrics.
This is the smallest number of times a customer must be exposed to the ad for it to be considered effective. This setting only impacts reporting. Must be between 1 and 10, inclusive. If not specified, a default of 1 is applied.
Optional.
Implementation
core.int? minEffectiveFrequency;