PlannableProductCoreAttributes class
Core attributes for a plannable product.
Constructors
- PlannableProductCoreAttributes({String? buyingMethod, String? costModel, String? productCategory})
- PlannableProductCoreAttributes.fromJson(Map json_)
Properties
- buyingMethod ↔ String?
-
The buying method.
getter/setter pair
- costModel ↔ String?
-
The cost model.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- productCategory ↔ String?
-
The product category.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited