PlannableTargeting class
Targeting capabilities for a given product.
Constructors
-
PlannableTargeting({List<
String> ? ageRanges, YouTubeSelectLineUp? defaultYoutubeSelectLineup, List<String> ? devices, List<String> ? genders, List<String> ? networks, SurfaceTargetingCombinations? surfaceTargetingCombinations, List<YouTubeSelectLineUp> ? youtubeSelectLineups}) - PlannableTargeting.fromJson(Map json_)
Properties
-
ageRanges
↔ List<
String> ? -
Allowed plannable age ranges for the product.
getter/setter pair
- defaultYoutubeSelectLineup ↔ YouTubeSelectLineUp?
-
The default YouTube Select Lineup for this product, if applicable.
getter/setter pair
-
devices
↔ List<
String> ? -
Targetable devices for the ad product.
getter/setter pair
-
genders
↔ List<
String> ? -
Targetable genders for the ad product.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
networks
↔ List<
String> ? -
Targetable networks for the ad product.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surfaceTargetingCombinations ↔ SurfaceTargetingCombinations?
-
Targetable surface combinations for the ad product.
getter/setter pair
-
youtubeSelectLineups
↔ List<
YouTubeSelectLineUp> ? -
Targetable YouTube Select Lineups for the ad product.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited