PlannableUserList class
A plannable user list used for reach forecasting.
Constructors
- PlannableUserList({String? displayName, String? name, String? plannableStatus, String? userListType})
- PlannableUserList.fromJson(Map json_)
Properties
- displayName ↔ String?
-
The display name of the user list.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
The resource name identifying the user list.
getter/setter pair
- plannableStatus ↔ String?
-
The plannability status of the user list.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userListType ↔ String?
-
The type of the user list.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited