ReachForecast class
A single point in the reach curve.
Constructors
-
ReachForecast({String? costMicros, PlannedProductForecast? forecast, List<
PlannedProductReachForecast> ? plannedProductReachForecasts}) - ReachForecast.fromJson(Map json_)
Properties
- costMicros ↔ String?
-
Total cost for this point in micros.
getter/setter pair
- forecast ↔ PlannedProductForecast?
-
Aggregate forecast for the entire plan.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
plannedProductReachForecasts
↔ List<
PlannedProductReachForecast> ? -
Breakdown for individual products at this cost point.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited