Targeting class
Targeting settings for a planned campaign.
Constructors
Properties
- ageRange ↔ String?
-
The age range to target.
getter/setter pair
-
devices
↔ List<
String> ? -
The devices to target.
getter/setter pair
-
genders
↔ List<
String> ? -
The gender options to target.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
plannableLocationIds
↔ List<
String> ? -
IDs of plannable locations to target.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited