YoutubeAssetAssociationLinkedYouTubeAsset class
A YouTube asset linked to a resource in a YoutubeAssetAssociation.
Constructors
- YoutubeAssetAssociationLinkedYouTubeAsset({YoutubeAssetAssociationAffiliateLocationAssetFilter? affiliateLocationAssetFilter, YoutubeAssetAssociationLocationAssetFilter? locationAssetFilter, YoutubeAssetAssociationSitelinkAsset? sitelinkAsset})
- YoutubeAssetAssociationLinkedYouTubeAsset.fromJson(Map json_)
Properties
- affiliateLocationAssetFilter ↔ YoutubeAssetAssociationAffiliateLocationAssetFilter?
-
An affiliate location asset filter.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- locationAssetFilter ↔ YoutubeAssetAssociationLocationAssetFilter?
-
A location asset filter.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sitelinkAsset ↔ YoutubeAssetAssociationSitelinkAsset?
-
A sitelink asset.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited