GooglePrivacyDlpV2CreateContentPolicyRequest class

Request message for CreateContentPolicy.

Properties

contentPolicy GooglePrivacyDlpV2ContentPolicy?
The content_policy resource.
getter/setter pair
contentPolicyId String?
The content policy ID can contain uppercase and lowercase letters, numbers, and hyphens; that is, it must match the regular expression: [a-zA-Z\d-_]+.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited