detectionRules property
Set of detection rules to apply to all findings of this CustomInfoType.
Rules are applied in the order that they are specified. Only supported for
the dictionary, regex, and stored_type CustomInfoTypes.
Implementation
core.List<GooglePrivacyDlpV2DetectionRule>? detectionRules;