GooglePrivacyDlpV2GoogleDriveLabelMetadata class

Google Drive labels published by Google.

Properties

hashCode int
The hash code for this object.
no setterinherited
labelFields List<GooglePrivacyDlpV2LabelFieldMetadata>?
The field values of the Google Drive label
getter/setter pair
labelId String?
The label ID of the Google Drive label.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited