GooglePrivacyDlpV2InfoTypeCondition class
A info type based condition.
Constructors
- GooglePrivacyDlpV2InfoTypeCondition({GoogleProtobufEmpty? anyInfoType, GooglePrivacyDlpV2InfoTypes? infoTypes, String? minCount})
- GooglePrivacyDlpV2InfoTypeCondition.fromJson(Map json_)
Properties
- anyInfoType ↔ GooglePrivacyDlpV2JobNotificationEmails?
-
match any info types.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- infoTypes ↔ GooglePrivacyDlpV2InfoTypes?
-
match any of these info types.
getter/setter pair
- minCount ↔ String?
-
The minimum total number of findings of all matching info types required
for this condition to evaluate to true.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited