inspectTemplate property
The full resource name of the inspection template to use.
Settings in the main inspect_config field override the corresponding
settings in this inspection template. The merge behavior is as follows: -
Singular field: The main field's value replaces the value of the
corresponding field in the template. - Repeated fields: The field values
are appended to the list defined in the template. - Sub-messages and
groups: The fields are recursively merged.
Implementation
core.String? inspectTemplate;