list method
Enumerates ResourceRecordSets that you have created but not yet deleted.
Request parameters:
project - Identifies the project addressed by this request.
managedZone - Identifies the managed zone addressed by this request. Can
be the managed zone name or ID.
maxResults - Optional. Maximum number of results to be returned. If
unspecified, the server decides how many results to return.
name - Specify a fully qualified domain name to view only those records.
The name parameter is not supported and must be omitted when you use
filter.
pageToken - Optional. A tag returned by a previous list request that was
truncated. Use this parameter to continue a previous list request.
type - Specify a record type to view only those records. You must also
specify the name parameter. The type parameter is not supported and must
be omitted when you use filter.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ResourceRecordSetsListResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ResourceRecordSetsListResponse> list(
core.String project,
core.String managedZone, {
core.int? maxResults,
core.String? name,
core.String? pageToken,
core.String? type,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'maxResults': ?maxResults == null ? null : ['${maxResults}'],
'name': ?name == null ? null : [name],
'pageToken': ?pageToken == null ? null : [pageToken],
'type': ?type == null ? null : [type],
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'dns/v1/projects/' +
commons.escapeVariable('$project') +
'/managedZones/' +
commons.escapeVariable('$managedZone') +
'/rrsets';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return ResourceRecordSetsListResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}