InsertRichLinkRequest class
Inserts a RichLink at the specified location.
Constructors
- InsertRichLinkRequest({EndOfSegmentLocation? endOfSegmentLocation, Location? location, RichLinkProperties? richLinkProperties})
- InsertRichLinkRequest.fromJson(Map json_)
Properties
- endOfSegmentLocation ↔ EndOfSegmentLocation?
-
Inserts the rich link at the end of a header, footer, footnote or the
document body.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- location ↔ Location?
-
Inserts the rich link at a specific index in the document.
getter/setter pair
- richLinkProperties ↔ RichLinkProperties?
-
The properties of the rich link to insert.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited