GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkField class
The chunk field in the chunk.
A chunk field could be one of the various types (for example, image, table) supported.
Constructors
- GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkField({GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkImageChunkField? imageChunkField, GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkTableChunkField? tableChunkField})
- GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkChunkField.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageChunkField ↔ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkImageChunkField?
-
The image chunk field in the chunk.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableChunkField ↔ GoogleCloudDocumentaiV1DocumentChunkedDocumentChunkTableChunkField?
-
The table chunk field in the chunk.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited