GoogleCloudDocumentaiV1DocumentDocumentLayoutDocumentLayoutBlockLayoutImageBlock class

Represents an image type block.

Properties

annotations GoogleCloudDocumentaiV1DocumentAnnotations?
Annotation of the image block.
getter/setter pair
blobAssetId String?
Asset ID of the inline image.
getter/setter pair
dataUri String?
Data URI of the image.
getter/setter pair
gcsUri String?
Google Cloud Storage URI of the image.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageText String?
Text extracted from the image using OCR or alt text describing the image.
getter/setter pair
mimeType String?
Mime type of the image.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited