validationDetails property
The detailed information of the running the validation process using the entity from the document based on the validation rule.
Implementation
core.String? validationDetails;
The detailed information of the running the validation process using the entity from the document based on the validation rule.
core.String? validationDetails;