ClientEncryptionDetails class
Details about the client-side encryption applied to the file.
Constructors
- ClientEncryptionDetails({DecryptionMetadata? decryptionMetadata, String? encryptionState})
- ClientEncryptionDetails.fromJson(Map json_)
Properties
- decryptionMetadata ↔ DecryptionMetadata?
-
The metadata used for client-side operations.
getter/setter pair
- encryptionState ↔ String?
-
The encryption state of the file.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited