fileContentChangeBehavior property
The behavior of the approval when the file content changes.
Optional. Possible string values are:
- "FILE_CONTENT_CHANGE_BEHAVIOR_UNSPECIFIED" : The behavior is unspecified.
- "RESET_APPROVAL" : Any ReviewerResponse with a Response of APPROVED will be reset to NO_DECISION when the file content changes while the approval has a Status of IN_PROGRESS. When the approval has a Status of APPROVED and RESET_APPROVAL is selected, the file is locked.
- "NO_APPROVAL_ACTION" : No action is taken when the file content changes.
Implementation
core.String? fileContentChangeBehavior;