GoogleFirebaseAppcheckV1Service class
The enforcement configuration for a Firebase service supported by App Check.
Constructors
- GoogleFirebaseAppcheckV1Service({String? enforcementMode, String? etag, String? name, String? replayProtection, String? updateTime})
- GoogleFirebaseAppcheckV1Service.fromJson(Map json_)
Properties
- enforcementMode ↔ String?
-
The baseline protection EnforcementMode for this service.
getter/setter pair
- etag ↔ String?
-
This checksum is computed by the server based on the value of other
fields, and may be sent on update and delete requests to ensure the client
has an up-to-date value before proceeding.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
The relative resource name of the service configuration object, in the
format:
projects/{project_number}/services/{service_id}Note that theservice_idelement must be a supported service ID.getter/setter pair - replayProtection ↔ String?
-
The replay protection EnforcementMode for this service.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updateTime ↔ String?
-
Timestamp when this service configuration object was most recently
updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited