resourcePolicy property
The ResourcePolicy to update.
The ResourcePolicy's name field is used to identify the ResourcePolicy
to be updated, in the format: projects/{project_number}/services/{service_id}/resourcePolicies/{resource_policy_id} Note that the service_id element must be a supported service ID.
Consult the ResourcePolicy.name field for a list of supported service IDs.
Required.
Implementation
GoogleFirebaseAppcheckV1ResourcePolicy? resourcePolicy;