list method
Lists releases.
By default, sorts by createTime in descending order.
Request parameters:
parent - Required. The name of the app resource, which is the parent of
the release resources. Format: projects/{project_number}/apps/{app}
Value must have pattern ^projects/\[^/\]+/apps/\[^/\]+$.
filter - Optional. The expression to filter releases listed in the
response. To learn more about filtering, refer to the [AIP-160
standard](http://aip.dev/160). Supported fields: - Time fields supporting
`<`, `<=`, `>` and `>=`; expecting an RFC-3339 formatted
string: - `create_time` (or `createTime`) - `update_time` (or
`updateTime`) - `expire_time` (or `expireTime`) - Text fields
supporting `=`. The compared text can contain a wildcard character
(`*`) at the beginning and/or end of the string which also enables
case-insensitive matching: - `release_notes.text` (or
`releaseNotes.text`) - `display_version` (or `displayVersion`) -
`build_version` (or `buildVersion`). Examples: - `createTime <=
"2021-09-08T00:00:00+04:00"` - `expire_time >
"2021-09-08T00:00:00+04:00"` - `releaseNotes.text="fixes" AND createTime
>= "2021-09-08T00:00:00.0Z"` - `releaseNotes.text="v1.0.0-rc"` -
`(display_version = "v1.0.0-rc2" AND `build_version = "123") OR
release_notes = "v1.0.0-rc2 (123)"`
orderBy - Optional. The fields used to order releases. Supported fields:
create_time(orcreateTime) -update_time(orupdateTime) -expire_time(orexpireTime) To specify descending order for a field, append a "desc" suffix, for example,createTime desc. If this parameter is not set, releases are ordered bycreateTimein descending order.
pageSize - Optional. The maximum number of releases to return. The
service may return fewer than this value. The valid range is [1-100]; If
unspecified (0), at most 25 releases are returned. Values above 100 are
coerced to 100.
pageToken - Optional. A page token, received from a previous
ListReleases call. Provide this to retrieve the subsequent page. When
paginating, all other parameters provided to ListReleases must match the
call that provided the page token.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleFirebaseAppdistroV1ListReleasesResponse.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleFirebaseAppdistroV1ListReleasesResponse> list(
core.String parent, {
core.String? filter,
core.String? orderBy,
core.int? pageSize,
core.String? pageToken,
core.String? $fields,
}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'filter': ?filter == null ? null : [filter],
'orderBy': ?orderBy == null ? null : [orderBy],
'pageSize': ?pageSize == null ? null : ['${pageSize}'],
'pageToken': ?pageToken == null ? null : [pageToken],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v1/' + core.Uri.encodeFull('$parent') + '/releases';
final response_ = await _requester.request(
url_,
'GET',
queryParams: queryParams_,
);
return GoogleFirebaseAppdistroV1ListReleasesResponse.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}