rootDirectory property
The directory relative to the root of the archive to use as the root for the deployed web app.
Defaults to use the root of the repository if not provided. If deploying a
monorepo, this
should be the directory that contains the package.json or
apphosting.yaml file.
Optional.
Implementation
core.String? rootDirectory;