entityIdIncluded property
A field that, if true, means that responses served by this connector will include entityIds in GraphQL response extensions.
This helps the client SDK cache responses in an improved way, known as "normalized caching", if caching is enabled on the client. Each entityId is a stable key based on primary key values. Therefore, this field should only be set to true if the primary keys of accessed tables do not contain sensitive information.
Optional.
Implementation
core.bool? entityIdIncluded;