CodeChunk class

A chunk of code.

Constructors

CodeChunk({String? code, String? languageCode})
CodeChunk.fromJson(Map json_)

Properties

code String?
The code content string.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
languageCode String?
Specifies the language if we expand support beyond GraphQL (e.g., SQL or JSON) The standard is BCP-47 language code.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited