DataConnectProperties class
SQL Connect specific properties for a path under response.data.
Constructors
-
DataConnectProperties({String? entityId, List<
String> ? entityIds, String? maxAge, List<Object?> ? path}) - DataConnectProperties.fromJson(Map json_)
Properties
- entityId ↔ String?
-
A single Entity ID.
getter/setter pair
-
entityIds
↔ List<
String> ? -
A list of Entity IDs.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxAge ↔ String?
-
The server-suggested duration before data under path is considered stale.
getter/setter pair
-
path
↔ List<
Object?> ? -
The path under response.data where the rest of the fields apply.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited