Part class

Represents a chunk of content.

Constructors

Part({CodeChunk? codeChunk, TextChunk? textChunk})
Part.fromJson(Map json_)

Properties

codeChunk CodeChunk?
A chunk of code.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textChunk TextChunk?
A chunk of text.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited