GoogleFirestoreAdminV1ChangeStream class
A Change Stream is a resource that allows users to receive change notifications from a Firestore database.
Constructors
- GoogleFirestoreAdminV1ChangeStream({GoogleFirestoreAdminV1CollectionGroupScope? collectionGroupScope, String? createTime, GoogleFirestoreAdminV1DatabaseScope? databaseScope, String? etag, String? name, String? retentionPeriod, String? startTime, String? updateTime})
- GoogleFirestoreAdminV1ChangeStream.fromJson(Map json_)
Properties
- collectionGroupScope ↔ GoogleFirestoreAdminV1CollectionGroupScope?
-
If set, the change stream is scoped to a collection group.
getter/setter pair
- createTime ↔ String?
-
The time the Change Stream was created.
getter/setter pair
- databaseScope ↔ GoogleFirestoreAdminV1DailyRecurrence?
-
If set, the change stream is scoped to the entire database.
getter/setter pair
- etag ↔ String?
-
An etag used to determine which version of the configuration is being
edited.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- retentionPeriod ↔ String?
-
The retention period of the change stream.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime ↔ String?
-
The time the Change Stream started recording events.
getter/setter pair
- updateTime ↔ String?
-
The time the Change Stream was last updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited