GoogleFirestoreAdminV1CollectionGroupScope class

The change stream is scoped to a collection group.

Only events associated with the given collection group are visible to the Change Stream. Only a single change stream can be enabled per collection group.

Properties

collectionGroupId String?
The collection group name.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited