ProjectsDatabasesChangeStreamsResource class
Constructors
- ProjectsDatabasesChangeStreamsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
GoogleFirestoreAdminV1ChangeStream request, String parent, {String? changeStreamId, String? $fields}) → Future< GoogleFirestoreAdminV1ChangeStream> - Creates a new change stream for the database.
-
delete(
String name, {String? etag, String? $fields}) → Future< Empty> - Deletes a change stream.
-
get(
String name, {String? $fields}) → Future< GoogleFirestoreAdminV1ChangeStream> - Gets information about a change stream.
-
list(
String parent, {String? $fields}) → Future< GoogleFirestoreAdminV1ListChangeStreamsResponse> - Lists all change streams in a database.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited