consumerRejectList property
A list of projects that are denied connection.
Format: "projects/sample_project_id" or "projects/1234567890" Projects in
this list will be denied access, even if they are included in the
allow_list. If this list is empty, no projects are explicitly rejected.
Optional.
Implementation
core.List<DeniedConsumer>? consumerRejectList;