ProjectsLocationsServersResource class
Methods
-
create(Server request, String parent, {String? requestId, String? serverId, String? $fields})
→ Future<Operation>
-
Creates a new Server in a given project and location.
-
delete(String name, {String? $fields})
→ Future<Operation>
-
Deletes a single Server.
-
get(String name, {String? view, String? $fields})
→ Future<Server>
-
Gets details of a single Server.
-
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? view, String? $fields})
→ Future<ListServersResponse>
-
Lists Servers in a given project and location.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(Server request, String name, {String? requestId, String? updateMask, String? $fields})
→ Future<Operation>
-
Updates the parameters of a single Server.
-
start(StartServerRequest request, String name, {String? $fields})
→ Future<Operation>
-
Starts a stopping/stopped Server.
-
stop(StopServerRequest request, String name, {String? $fields})
→ Future<Operation>
-
Stops an active Server.
-
toString()
→ String
-
A string representation of this object.
inherited