fingerprint property
The fingerprint is a hash of the public key, and is displayed when clients access the server for the first time to verify the server's identity.
Output only.
Implementation
core.String? fingerprint;
The fingerprint is a hash of the public key, and is displayed when clients access the server for the first time to verify the server's identity.
Output only.
core.String? fingerprint;