User class
Message describing User object
Constructors
Properties
- createTime ↔ String?
-
Create time stamp
getter/setter pair
- customerServiceAccount ↔ String?
-
Service account in customer project attached to this SFTP User.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
Labels as key value pairs
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
Tracks user creation.
getter/setter pair
-
storageDirectoryMappings
↔ List<
StorageDirectoryMapping> ? -
Mapping of Cloud Storage buckets to directories where the user will land
in the SFTP server.
getter/setter pair
- updateTime ↔ String?
-
Update time stamp
getter/setter pair
-
userCredentials
↔ List<
UserCredential> ? -
User credential for the user.
getter/setter pair
- username ↔ String?
-
The username of the user.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited