BatchRecordEventsRequest class

Request message for PlayerGameEvents.BatchRecordEvents Next ID: 7

Constructors

BatchRecordEventsRequest({String? droidGuardBlob, List<PlayerGameEvent>? events, String? packageName, String? requestTime, String? salt})
BatchRecordEventsRequest.fromJson(Map json_)

Properties

droidGuardBlob String?
The DroidGuard blob generated by the client.
getter/setter pair
events List<PlayerGameEvent>?
A list of player game events to be recorded.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
packageName String?
Application package name (e.g., "com.example.game").
getter/setter pair
requestTime String?
The time from the client when this specific batch of events was submitted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
salt String?
The salt used to generate content binding for the DroidGuard blob.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited