protectedNamespaceCount property
The number of user managed namespaces backed up in the last successful Backup created via this BackupPlan.
Output only.
Implementation
core.int? protectedNamespaceCount;
The number of user managed namespaces backed up in the last successful Backup created via this BackupPlan.
Output only.
core.int? protectedNamespaceCount;