AutoUpgradeConfig class

Configuration for automatic upgrades.

Constructors

AutoUpgradeConfig({Map<String, String>? enforcedRollouts, RolloutCreationScope? rolloutCreationScope})
AutoUpgradeConfig.fromJson(Map json_)

Properties

enforcedRollouts Map<String, String>?
Mandatory Safety Policies (Always active) which cannot be disabled.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
rolloutCreationScope RolloutCreationScope?
Specifies the scope of automation for the creation of rollouts.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited