OperationalState class
Operational state of the Rollout Sequence.
Constructors
-
OperationalState({List<
String> ? reasons, String? state, String? stateChangeTime}) - OperationalState.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
reasons
↔ List<
String> ? -
Reasons for the Rollout Sequence state.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
State of the Rollout Sequence.
getter/setter pair
- stateChangeTime ↔ String?
-
The timestamp at which the operational state was last changed.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited