stateChangeTime property
The timestamp at which the operational state was last changed.
Used to track how long it has been in the current state.
Output only.
Implementation
core.String? stateChangeTime;
The timestamp at which the operational state was last changed.
Used to track how long it has been in the current state.
Output only.
core.String? stateChangeTime;