RolloutStage class
Stage represents a single stage in the Rollout.
Constructors
-
RolloutStage({ClusterSelector? clusterSelector, String? endTime, List<
String> ? fleetProjects, String? soakDuration, int? stageNumber, String? startTime, String? state}) - RolloutStage.fromJson(Map json_)
Properties
- clusterSelector ↔ ClusterSelector?
-
The selector from the sequence that was used to create this stage.
getter/setter pair
- endTime ↔ String?
-
The time at which the stage ended.
getter/setter pair
-
fleetProjects
↔ List<
String> ? -
The fleet projects from the sequence that was used to create this stage.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- soakDuration ↔ String?
-
Duration to soak after this stage before starting the next stage.
getter/setter pair
- stageNumber ↔ int?
-
The stage number to which this status applies.
getter/setter pair
- startTime ↔ String?
-
The time at which the stage started.
getter/setter pair
- state ↔ String?
-
The state of the stage.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited