state property
The state of the stage.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : Default value.
- "PENDING" : The stage is waiting for previous stages to complete.
- "RUNNING" : The stage targets are being upgraded.
- "SOAKING" : The stage is waiting for a predetermined time before next stage.
- "COMPLETED" : The stage is completed.
- "PAUSED" : The stage is paused.
Implementation
core.String? state;