RolloutTarget class
Metadata about the status of targets (clusters or node pools) involved in the Rollout.
Constructors
- RolloutTarget({String? cluster, String? nodePool, String? operation, String? reason, String? state})
- RolloutTarget.fromJson(Map json_)
Properties
- cluster ↔ String?
-
The resource link of the Cluster resource upgraded in this Rollout.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nodePool ↔ String?
-
The resource link of the NodePool resource upgraded in this Rollout.
getter/setter pair
- operation ↔ String?
-
The operation resource name performing the mutation.
getter/setter pair
- reason ↔ String?
-
A human-readable description of the current status.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
The high-level, machine-readable status of this Rollout for the target.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited