ServiceMeshFeatureSpec class

Service Mesh: Spec for the fleet for the servicemesh feature

Constructors

ServiceMeshFeatureSpec({String? modernizationCompatibility, String? modernizationStrategy})
ServiceMeshFeatureSpec.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
modernizationCompatibility String?
Specifies modernization compatibility for the fleet.
getter/setter pair
modernizationStrategy String?
Declares your intended modernization strategy for the fleet.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited