modernizationStrategy property
Declares your intended modernization strategy for the fleet.
Optional. Possible string values are:
- "MODERNIZATION_STRATEGY_UNSPECIFIED" : Default unspecified.
- "AUTOMATIC" : The infrastructure is automatically modernized. Setting this strategy initiates the modernization process. The system schedules the modernization subject to configured maintenance windows and maintenance exclusions.
- "DEFERRED" : The infrastructure is pinned to the legacy implementation. This fleet will not be selected for Google-driven modernization. If the resource is actively modernizing, or if the modernization has completed but is not yet finalized (e.g., during the soak time), setting this strategy triggers a rollback to the legacy state. If the modernization process has already been marked as finalized, setting this strategy has no effect.
Implementation
core.String? modernizationStrategy;