UpgradeRolloutSequenceRequest class
Request message for upgrading a rollout sequence.
Constructors
- UpgradeRolloutSequenceRequest({bool? force, bool? ignoreClusterDisruptionBudgets, bool? ignoreMaintenancePolicies, bool? patchOnly, String? soakDurationOverrideAllStages, PerStageSoakDurationOverrides? soakDurationOverridePerStage, String? upgradeType, String? version})
- UpgradeRolloutSequenceRequest.fromJson(Map json_)
Properties
- force ↔ bool?
-
If set to true, any rollout already running on the first stage of the
sequence will be cancelled to allow for the creation of the new rollout.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ignoreClusterDisruptionBudgets ↔ bool?
-
If set to true, the rollout will ignore the disruption budgets of the
clusters.
getter/setter pair
- ignoreMaintenancePolicies ↔ bool?
-
If set to true, the rollout will ignore any maintenance policies
(Maintenance Windows and Maintenance Exclusions) set on the clusters.
getter/setter pair
- patchOnly ↔ bool?
-
If set to true, the rollout will only upgrade clusters that match the
minor version of the
versionfield, but are on an earlier patch version.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- soakDurationOverrideAllStages ↔ String?
-
Overrides the soak duration for all stages of the rollout.
getter/setter pair
- soakDurationOverridePerStage ↔ PerStageSoakDurationOverrides?
-
Overrides the soak durations for specific stages of the rollout.
getter/setter pair
- upgradeType ↔ String?
-
The type of upgrade.
getter/setter pair
- version ↔ String?
-
GKE version to upgrade to.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited