force property
If set to true, any rollout already running on the first stage of the sequence will be cancelled to allow for the creation of the new rollout.
Optional.
Implementation
core.bool? force;
If set to true, any rollout already running on the first stage of the sequence will be cancelled to allow for the creation of the new rollout.
Optional.
core.bool? force;