forward property
Email address that the message should be forwarded to.
This effectively redirects the message to the address specified in this field, maintaining the original sender in the "From" field.
Implementation
core.String? forward;
Email address that the message should be forwarded to.
This effectively redirects the message to the address specified in this field, maintaining the original sender in the "From" field.
core.String? forward;