create method
Creates a forwarding address.
If ownership verification is required, a message will be sent to the
recipient and the resource's verification status will be set to pending;
otherwise, the resource will be created with verification status set to
accepted. For more information, see
Manage email forwarding.
This method is only available to service account clients that have been
delegated domain-wide authority.
request - The metadata request object.
Request parameters:
userId - User's email address. The special value "me" can be used to
indicate the authenticated user.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a ForwardingAddress.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<ForwardingAddress> create(
ForwardingAddress request,
core.String userId, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'gmail/v1/users/' +
commons.escapeVariable('$userId') +
'/settings/forwardingAddresses';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return ForwardingAddress.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}