standardMetric property
A predefined standard metric. Possible string values are:
- "STANDARD_METRIC_UNSPECIFIED" : Unspecified standard metric. This value should not be used directly.
- "FEEDBACK_LOOP_ID" : Predefined metric for Feedback Loop (FBL) id. The
filterfield supports selecting the aggregation key type. Supported format:aggregation_key_type= "". Supported values: *FROM_HEADER: (Default) The metric includes messages with From: header domain matching the requested domain. *ALL_DKIM: The metric includes messages with one of the signed DKIM domains matching the requested domain. - "FEEDBACK_LOOP_SPAM_RATE" : Predefined metric for Feedback Loop (FBL)
spam rate. The
filterfield requires afeedback_loop_idand optionally accepts anaggregation_key_type. Supported formats are: *feedback_loop_id= "" *feedback_loop_id= "" ANDaggregation_key_type= "" Ifaggregation_key_typeis omitted, it defaults toFROM_HEADER. Supported values: *FROM_HEADER: (Default) The metric includes messages with From: header domain matching the requested domain. *ALL_DKIM: The metric includes messages with one of the signed DKIM domains matching the requested domain. - "SPAM_RATE" : Predefined metric for spam rate.
- "AUTH_SUCCESS_RATE" : The success rate of authentication mechanisms (DKIM, SPF, DMARC). Filter must be of type auth_type = "" where is one of: [spf, dkim, dmarc]
- "TLS_ENCRYPTION_MESSAGE_COUNT" : The rate of messages that were TLS encrypted in transit Filter must be of type traffic_direction = "" where is one of: [inbound, outbound]
- "TLS_ENCRYPTION_RATE" : The rate of messages that were TLS encrypted in transit Filter must be of type traffic_direction = "" where is one of: [inbound, outbound]
- "DELIVERY_ERROR_COUNT" : The total count of delivery errors encountered
(temporary or permanent rejects). The
filterfield supports a limited syntax. Supported formats are: * Empty: No filter is applied. *error_type= "" *error_type= "" ANDerror_reason= "" If an empty filter is provided, the metric will be aggregated across all error types and reasons. If onlyerror_typeis specified, the metric will be aggregated across all reasons for that type. Supported values: * reject * temp_fail Supported values depend on the : * For 'reject': [bad_attachment, bad_or_missing_ptr_record, ip_in_rbls, low_domain_reputation, low_ip_reputation, spammy_content, stamp_policy_error, other] * For 'temp_fail': [anomalous_traffic_pattern, other] - "DELIVERY_ERROR_RATE" : Delivery error rate for the specified delivery
error type. The
filterfield supports a limited syntax. Supported formats are: * Empty: No filter is applied. *error_type= "" *error_type= "" ANDerror_reason= "" If an empty filter is provided, the metric will be aggregated across all error types and reasons. If onlyerror_typeis specified, the metric will be aggregated across all reasons for that type. Supported values: * reject * temp_fail Supported values depend on the : * For 'reject': [bad_attachment, bad_or_missing_ptr_record, ip_in_rbls, low_domain_reputation, low_ip_reputation, spammy_content, stamp_policy_error, other] * For 'temp_fail': [anomalous_traffic_pattern, other]
Implementation
core.String? standardMetric;