results property
A list of responses, one for each query in the BatchQueryDomainStatsRequest.
The order of responses will correspond to the order of requests.
Implementation
core.List<BatchQueryDomainStatsResult>? results;
A list of responses, one for each query in the BatchQueryDomainStatsRequest.
The order of responses will correspond to the order of requests.
core.List<BatchQueryDomainStatsResult>? results;