BatchQueryDomainStatsResult class
Represents the result of a single QueryDomainStatsRequest within a batch.
Constructors
- BatchQueryDomainStatsResult({Status? error, QueryDomainStatsResponse? response})
- BatchQueryDomainStatsResult.fromJson(Map json_)
Properties
- error ↔ Status?
-
The error status if the individual query failed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- response ↔ QueryDomainStatsResponse?
-
The successful response for the individual query.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited