ComplianceRowData class
Data for a single row of the compliance status table.
Constructors
- ComplianceRowData({String? requirement, ComplianceStatus? status})
- ComplianceRowData.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- requirement ↔ String?
-
The compliance requirement.
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ ComplianceStatus?
-
The compliance status for the requirement.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited