status property
The compliance status.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : Unspecified.
- "COMPLIANT" : The compliance requirement is met, and the sender is deemed compliant.
- "NEEDS_WORK" : The compliance requirement is unmet, and the sender needs to do work to achieve compliance.
Implementation
core.String? status;