permission property
Specifies the permission level to give the user for the specified domain.
If not specified, the default value for this field is READER.
Optional. Possible string values are:
- "PERMISSION_UNSPECIFIED" : Unspecified permission.
- "READER" : User has read access to the domain.
- "ADMIN" : User has admin access to the domain.
- "OWNER" : User has owner access to the domain.
- "NONE" : User has no access to the domain.
Implementation
core.String? permission;