DomainComplianceData class
Compliance data for a given domain.
Constructors
-
DomainComplianceData({DeliverabilityStatusVerdict? deliverabilityStatusVerdict, String? domainId, HonorUnsubscribeVerdict? honorUnsubscribeVerdict, OneClickUnsubscribeVerdict? oneClickUnsubscribeVerdict, List<
ComplianceRowData> ? rowData}) - DomainComplianceData.fromJson(Map json_)
Properties
- deliverabilityStatusVerdict ↔ DeliverabilityStatusVerdict?
-
Deliverability status verdict.
getter/setter pair
- domainId ↔ String?
-
Domain that this data is for.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- honorUnsubscribeVerdict ↔ HonorUnsubscribeVerdict?
-
Unsubscribe honoring compliance verdict.
getter/setter pair
- oneClickUnsubscribeVerdict ↔ OneClickUnsubscribeVerdict?
-
One-click unsubscribe compliance verdict.
getter/setter pair
-
rowData
↔ List<
ComplianceRowData> ? -
Data for each of the rows of the table.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited