DomainComplianceStatus class
Compliance status for a domain.
Constructors
- DomainComplianceStatus({DomainComplianceData? complianceData, String? name, DomainComplianceData? subdomainComplianceData})
- DomainComplianceStatus.fromJson(Map json_)
Properties
- complianceData ↔ DomainComplianceData?
-
Compliance data for the registrable domain part of the domain in
name.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subdomainComplianceData ↔ DomainComplianceData?
-
Compliance data calculated specifically for the subdomain in
name.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited