DomainsResource class
Methods
-
create(CreateDomainRequest request, {String? $fields})
→ Future<Domain>
-
Developer Preview: Adds
a domain to the user's account.
-
delete(String name, {String? $fields})
→ Future<Empty>
-
Developer Preview:
Deletes a domain from the user's account.
-
get(String name, {String? $fields})
→ Future<Domain>
-
Retrieves detailed information about a domain registered by you.
-
getComplianceStatus(String name, {String? $fields})
→ Future<DomainComplianceStatus>
-
Retrieves the compliance status for a given domain.
-
getVerificationToken(String name, {String? verificationMethod, String? $fields})
→ Future<DomainVerificationToken>
-
Developer Preview: Gets
a verification token used for verifying a user's ownership over a domain.
-
list({int? pageSize, String? pageToken, String? $fields})
→ Future<ListDomainsResponse>
-
Retrieves a list of all domains registered by you, along with their
corresponding metadata.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
verify(VerifyDomainRequest request, String name, {String? $fields})
→ Future<Empty>
-
Developer Preview:
Verifies a user's ownership of a domain at the DNS level.