reason property
The specific reason for the compliance verdict.
Must be empty if the status is compliant. Possible string values are:
- "REASON_UNSPECIFIED" : Unspecified.
- "NOT_HONORING" : The sender does not honor unsubscribe requests.
- "NOT_HONORING_TOO_FEW_CAMPAIGNS" : The sender does not honor unsubscribe requests and consider to increase the number of relevant campaigns.
- "NOT_HONORING_TOO_MANY_CAMPAIGNS" : The sender does not honor unsubscribe requests and consider to reduce the number of relevant campaigns.
Implementation
core.String? reason;