reason property
The specific reason for the compliance verdict.
Must be empty if the status is compliant. Possible string values are:
- "REASON_UNSPECIFIED" : Unspecified.
- "NO_UNSUB_GENERAL" : Sender does not support one-click unsubscribe for the majority of their messages.
- "NO_UNSUB_SPAM_REPORTS" : Sender does not support one-click unsubscribe for most messages that are manually reported as spam.
- "NO_UNSUB_PROMO_SPAM_REPORTS" : Sender does not support one-click
unsubscribe for most promotional messages that are manually reported as
spam. This classification of messages is a subset of those encompassed by
NO_UNSUB_SPAM_REPORTS.
Implementation
core.String? reason;