QueryDomainStatsRequest class
Request message for QueryDomainStats.
Constructors
-
QueryDomainStatsRequest({String? aggregationGranularity, List<
MetricDefinition> ? metricDefinitions, int? pageSize, String? pageToken, String? parent, TimeQuery? timeQuery}) - QueryDomainStatsRequest.fromJson(Map json_)
Properties
- aggregationGranularity ↔ String?
-
The granularity at which to aggregate the statistics.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metricDefinitions
↔ List<
MetricDefinition> ? -
The specific metrics to query.
getter/setter pair
- pageSize ↔ int?
-
The maximum number of DomainStats resources to return in the response.
getter/setter pair
- pageToken ↔ String?
-
The next_page_token value returned from a previous List request, if any.
getter/setter pair
- parent ↔ String?
-
The parent resource name where the stats are queried.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeQuery ↔ TimeQuery?
-
The time range or specific dates for which to retrieve the metrics.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited