pageToken property
The next_page_token value returned from a previous List request, if any.
If the aggregation granularity is DAILY, the page token will be the encoded date + "/" + metric name. If the aggregation granularity is OVERALL, the page token will be the encoded metric name.
Optional.
Implementation
core.String? pageToken;