StatisticValue class
The actual value of a statistic.
Constructors
- StatisticValue({double? doubleValue, double? floatValue, String? intValue, StringList? stringList, String? stringValue})
- StatisticValue.fromJson(Map json_)
Properties
- doubleValue ↔ double?
-
Double value.
getter/setter pair
- floatValue ↔ double?
-
Float value.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- intValue ↔ String?
-
Integer value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringList ↔ StringList?
-
List of string values.
getter/setter pair
- stringValue ↔ String?
-
String value.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited