health/v4 library
Google Health API - v4
The Google Health API lets you view and manage health and fitness metrics and measurement data.
For more information, see developers.google.com/health
Create an instance of GoogleHealthApi to access these resources:
Classes
- ActiveEnergyBurned
- Energy burned as part of an activity, excluding the basal energy burn.
- ActiveEnergyBurnedRollupValue
- Represents the result of the rollup of active energy burned.
- ActiveMinutes
- Record of active minutes in a given time interval.
- ActiveMinutesByActivityLevel
- Active minutes at a given activity level.
- ActiveMinutesRollupByActivityLevel
- Active minutes by activity level.
- ActiveMinutesRollupValue
- Represents the result of the rollup of the active minutes data type.
- ActiveZoneMinutes
- Record of active zone minutes in a given time interval.
- ActiveZoneMinutesRollupValue
- Represents the result of the rollup of the active zone minutes data type.
- ActivityLevel
- Internal type to capture activity level during a certain time interval.
- ActivityLevelRollupByActivityLevelType
- Represents the total duration in a specific activity level type.
- ActivityLevelRollupValue
- Represents the result of the rollup of the activity level data type.
- AlertWindow
- An analysis window evaluated for AFib.
- Altitude
- Captures the altitude gain (i.e. deltas), and not level above sea, for a user in millimeters.
- AltitudeRollupValue
- Represents the result of the rollup of the user's altitude.
- Application
- Optional metadata for the application that provided this data.
- BasalEnergyBurned
- Number of calories burned due to basal metabolic rate (BMR) over a period of time.
- BatchDeleteDataPointsRequest
- Request to delete a batch of identifiable data points.
- BloodGlucose
- Represents a blood glucose level measurement.
- BloodGlucoseRollupValue
- Represents the result of the rollup of the blood glucose data type.
- BodyFat
- Body fat measurement.
- BodyFatRollupValue
- Represents the result of the rollup of the body fat data type.
- ByteRange
- Specifies a range of media.
- CaloriesInHeartRateZoneRollupValue
- Represents the result of the rollup of the calories in heart rate zone data type.
- CaloriesInHeartRateZoneValue
- Represents the amount of kilocalories burned in a specific heart rate zone.
- CivilDateTime
- Civil time representation similar to google.type.DateTime, but ensures that neither the timezone nor the UTC offset can be set to avoid confusion between civil and physical time queries.
- CivilTimeInterval
- Counterpart of google.type.Interval, but using CivilDateTime.
- CoreBodyTemperature
- Core body temperature measurement, distinct from peripheral body temperature, reflects the temperature of the body's internal organs.
- CoreBodyTemperatureRollupValue
- Represents the result of the rollup of the core body temperature data type.
- CreateSubscriberPayload
- Payload for creating a subscriber.
- CreateSubscriptionPayload
- Payload for creating a subscription.
- DailyHeartRateVariability
- Represents the daily heart rate variability data type.
- DailyHeartRateZones
- User's heart rate zone thresholds based on the Karvonen algorithm for a specific day.
- DailyOxygenSaturation
- A daily oxygen saturation (SpO2) record.
- DailyRespiratoryRate
- A daily average respiratory rate (breaths per minute) for a day of the year.
- DailyRestingHeartRate
- Measures the daily resting heart rate for a user, calculated using the all day heart rate measurements.
- DailyRestingHeartRateMetadata
- Metadata for the daily resting heart rate.
- DailyRollupDataPoint
- Value of a daily rollup for a single civil time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.
- DailyRollUpDataPointsRequest
- Request to roll up data points by civil time intervals.
- DailyRollUpDataPointsResponse
- Response containing the list of rolled up data points.
- DailySleepTemperatureDerivations
- Provides derived sleep temperature values, calculated from skin or internal device temperature readings during sleep.
- DailyVO2Max
- Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise.
- DataPoint
- A computed or recorded metric.
- DataSource
- Data Source definition to track the origin of data.
- Device
- Captures metadata about the device that recorded the measurement.
- Distance
- Distance traveled over an interval of time.
- DistanceRollupValue
- Result of the rollup of the user's distance.
- DownloadOptions
- Represents options for downloading media.
- Electrocardiogram
- Represents an Electrocardiogram (ECG) measurement session.
- EndpointAuthorization
- Authorization mechanism for a subscriber endpoint.
- EnergyQuantity
- Represents the energy quantity.
- EnergyQuantityRollup
- Rollup for the energy quantity.
- Exercise
- An exercise that stores information about a physical activity.
- ExerciseEvent
- Represents instantaneous events that happen during an exercise, such as start, stop, pause, split.
- ExerciseMetadata
- Additional exercise metadata.
- ExportExerciseTcxResponse
- Represents a Response for exporting exercise data in TCX format.
- Floors
- Gained elevation measured in floors over the time interval
- FloorsRollupValue
- Represents the result of the rollup of the user's floors.
- Food
- Represents a food item.
- FoodMeasurementUnit
- Represents a food measurement unit.
- FoodServing
- Represents different properties and information about the serving of a specific food.
- GoogleHealthApi
- The Google Health API lets you view and manage health and fitness metrics and measurement data.
- HeartBeat
- A single heart beat measurement.
- HeartRate
- A heart rate measurement.
- HeartRateMetadata
- Heart rate metadata.
- HeartRateRollupValue
- Represents the result of the rollup of the heart rate data type.
- HeartRateVariability
- Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN).
- HeartRateVariabilityPersonalRangeRollupValue
- Represents the result of the rollup of the user's daily heart rate variability personal range.
- HeartRateZone
- The heart rate zone.
- Height
- Body height measurement.
- HydrationLog
- Holds information about a user logged hydration.
- HydrationLogRollupValue
- Represents the result of the rollup of the hydration log data type.
- Identity
- Represents details about the Google user's identity.
- IrnProfile
- Irregular Rhythm Notifications (IRN) Profile details.
- IrregularRhythmNotification
- Represents an Irregular Rhythm Notification alert, indicating a potential sign of atrial fibrillation (AFib).
- ListDataPointsResponse
- Response containing raw data points matching the query
- ListPairedDevicesResponse
- Response message for ListPairedDevices.
- ListSubscribersResponse
- Response message for ListSubscribers.
- ListSubscriptionsResponse
- Response message for ListSubscriptions.
- ManifestParams
- Represents the POST body contained in a GetShlManifestRequest This message is nested to represent that See https://build.fhir.org/ig/HL7/smart-health-cards-and-links/links-specification.html#smart-health-link-manifest-request
- Media
- Represents a media consisting of a stream of bytes, a content type and a length.
- MedicalDeviceInfo
- Software as Medical Device (SaMD) metadata.
- MenstrualPeriod
- Menstrual period record.
- MetricsSummary
- Summary metrics for an exercise.
- MobilityMetrics
- Mobility workouts specific metrics
- Moods
- Moods record.
- NutrientQuantity
- Represents the quantity of a nutrient.
- NutrientQuantityRollup
- Nutrient quantity rollup.
- NutritionLog
- Holds information about food logged by a user.
- NutritionLogRollupValue
- Represents the result of the rollup of the nutrition log data type.
- ObservationSampleTime
- Represents a sample time of an observed data point.
- ObservationTimeInterval
- Represents a time interval of an observed data point.
- Operation
- This resource represents a long-running operation that is the result of a network API call.
- OutOfBedSegment
- A time interval to represent an out-of-bed segment.
- OvulationTest
- Ovulation test record.
- OxygenSaturation
- Captures the user's instantaneous oxygen saturation percentage (SpO2).
- PairedDevice
- User's Paired 1P Device The PairedDevice details include information about the device type, battery status, battery level, last sync time, device version, mac address, and features.
- PartialDownloadOptions
- Options for downloading a Media.
- Profile
- Profile details.
- ProjectsResource
- ProjectsSubscribersResource
- ProjectsSubscribersSubscriptionsResource
- ReconcileDataPointsResponse
- Response containing the list of reconciled DataPoints.
- ReconciledDataPoint
- A reconciled computed or recorded metric.
- RespiratoryRateSleepSummary
- Records respiratory rate details during sleep.
- RespiratoryRateSleepSummaryStatistics
- Respiratory rate statistics for a given sleep stage.
- RestingHeartRatePersonalRangeRollupValue
- Represents the rollup value for the daily resting heart rate data type.
- ResumableUploadOptions
- Specifies options for resumable uploads.
- RollupDataPoint
- Value of a rollup for a single physical time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.
- RollUpDataPointsRequest
- Request to roll up data points by physical time intervals.
- RollUpDataPointsResponse
- Response containing the list of rolled up data points.
- RunVO2Max
- VO2 max value calculated based on the user's running activity.
- RunVO2MaxRollupValue
- Represents the result of the rollup of the user's daily heart rate variability personal range.
- SedentaryPeriod
- SedentaryPeriod SedentaryPeriod data represents the periods of time that the user was sedentary (i.e. not moving while wearing the device).
- SedentaryPeriodRollupValue
- Represents the result of the rollup of the user's sedentary periods.
- Serving
- Represents different properties and information about the serving of a specific food.
- SessionTimeInterval
- Represents a time interval of session data point, which bundles multiple observed metrics together.
- Settings
- Settings details.
- ShlMResource
- ShlResource
- ShlRResource
- Sleep
- A sleep session possibly including stages.
- SleepMetadata
- Additional information about how the sleep was processed.
- SleepStage
- Sleep stage segment.
- SleepSummary
- Sleep summary: metrics and stages summary.
- SplitSummary
- Represents splits or laps recorded within an exercise.
- StageSummary
- Total duration and segment count for a stage.
- Steps
- Step count over the time interval.
- StepsRollupValue
- Represents the result of the rollup of the steps data type.
- Subscriber
- -- Resource Messages -- A subscriber receives notifications from Google Health API.
- SubscriberConfig
- Configuration for a subscriber.
- Subscription
- A subscription to a data collection for a specific user, to be delivered to a subscriber.
- SwimLengthsData
- Swim lengths data over the time interval.
- SwimLengthsDataRollupValue
- Represents the result of the rollup of the swim lengths data type.
- Symptoms
- Symptoms logged by the user.
- TimeInHeartRateZone
- Time in heart rate zone record.
- TimeInHeartRateZoneRollupValue
- Represents the result of the rollup of the time in heart rate zone data type.
- TimeInHeartRateZones
- Time spent in each heart rate zone.
- TimeInHeartRateZoneValue
- Represents the total time spent in a specific heart rate zone.
- TotalCaloriesRollupValue
- Represents the result of the rollup of the user's total calories.
- UploadOptions
- Represents options for uploading a Media.
- UsersDataTypesDataPointsResource
- UsersDataTypesResource
- UsersPairedDevicesResource
- UsersResource
- VO2Max
- VO2 max measurement.
- VolumeQuantity
- Represents the volume quantity.
- VolumeQuantityRollup
- Rollup for volume quantity.
- Weight
- Body weight measurement.
- WeightQuantity
- Represents the weight quantity.
- WeightQuantityRollup
- Rollup for the weight.
- WeightRollupValue
- Represents the result of the rollup of the weight data type.
Typedefs
- Date = $Date
- Represents a whole or partial calendar date, such as a birthday.
- Empty = $Empty
- A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs.
- HttpBody = $HttpBody
- Message that represents an arbitrary HTTP body.
- Interval = $Interval
- Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
- Status = $Status00
-
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. - TimeOfDay = $TimeOfDay
- Represents a time of day.
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.