AlertWindow class

An analysis window evaluated for AFib.

Note: The current version of the algorithm will only produce alerts if all windows are positive. So anything returned from the API will always have the positive bit set to true. Internally, windows can be negative, however. We never save "inconclusive" windows (they aren't produced by the algorithm).

Constructors

AlertWindow({CivilDateTime? civilEndTime, CivilDateTime? civilStartTime, String? endTime, String? endUtcOffset, List<HeartBeat>? heartBeats, bool? positive, String? startTime, String? startUtcOffset})
AlertWindow.fromJson(Map json_)

Properties

civilEndTime CivilDateTime?
Observed interval end time in civil time in the timezone the subject is in at the end of the observed interval
getter/setter pair
civilStartTime CivilDateTime?
Observed interval start time in civil time in the timezone the subject is in at the start of the observed interval
getter/setter pair
endTime String?
The end time of the analysis window.
getter/setter pair
endUtcOffset String?
The UTC offset of the user's timezone when the analysis window ended.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
heartBeats List<HeartBeat>?
All heart beats in the interval contained in this analysis window.
getter/setter pair
positive bool?
Flag indicating whether the window was positive for AFib or not.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String?
Observed interval.
getter/setter pair
startUtcOffset String?
The UTC offset of the user's timezone when the analysis window started.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited