Altitude class

Captures the altitude gain (i.e. deltas), and not level above sea, for a user in millimeters.

Constructors

Altitude({String? gainMillimeters, ObservationTimeInterval? interval})
Altitude.fromJson(Map json_)

Properties

gainMillimeters String?
Altitude gain in millimeters over the observed interval.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
interval ObservationTimeInterval?
Observed interval.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited