googleWebClientId property
The Google OAuth 2.0 client ID of the web application or service that recorded the data.
This is the client ID used during the Google OAuth flow to obtain user credentials. This field is system-populated when the data is uploaded from Google Web API.
Output only.
Implementation
core.String? googleWebClientId;