CoreBodyTemperatureRollupValue class
Represents the result of the rollup of the core body temperature data type.
Constructors
- CoreBodyTemperatureRollupValue({double? temperatureCelsiusAvg, double? temperatureCelsiusMax, double? temperatureCelsiusMin})
- CoreBodyTemperatureRollupValue.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temperatureCelsiusAvg ↔ double?
-
Average core body temperature in Celsius.
getter/setter pair
- temperatureCelsiusMax ↔ double?
-
Maximum core body temperature in Celsius.
getter/setter pair
- temperatureCelsiusMin ↔ double?
-
Minimum core body temperature in Celsius.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited