DailyHeartRateVariability class
Represents the daily heart rate variability data type.
At least one of the following fields must be set: -
average_heart_rate_variability_milliseconds -
non_rem_heart_rate_beats_per_minute - entropy -
deep_sleep_root_mean_square_of_successive_differences_milliseconds
Constructors
- DailyHeartRateVariability({double? averageHeartRateVariabilityMilliseconds, Date? date, double? deepSleepRootMeanSquareOfSuccessiveDifferencesMilliseconds, double? entropy, String? nonRemHeartRateBeatsPerMinute})
- DailyHeartRateVariability.fromJson(Map json_)
Properties
- averageHeartRateVariabilityMilliseconds ↔ double?
-
A user's average heart rate variability calculated using the root mean
square of successive differences (RMSSD) in times between heartbeats.
getter/setter pair
- date ↔ Date?
-
Date (in the user's timezone) of heart rate variability measurement.
getter/setter pair
- deepSleepRootMeanSquareOfSuccessiveDifferencesMilliseconds ↔ double?
-
The root mean square of successive differences (RMSSD) value during deep
sleep.
getter/setter pair
- entropy ↔ double?
-
The Shanon entropy of heartbeat intervals.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonRemHeartRateBeatsPerMinute ↔ String?
-
Non-REM heart rate
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited