DailyRollupDataPoint class
Value of a daily rollup for a single civil time interval (aggregation window) of reconciled data points from all data sources, excluding those data points that are identified as recorded by wearables in intervals when they were not actually worn.
Constructors
- DailyRollupDataPoint({ActiveEnergyBurnedRollupValue? activeEnergyBurned, ActiveMinutesRollupValue? activeMinutes, ActiveZoneMinutesRollupValue? activeZoneMinutes, ActivityLevelRollupValue? activityLevel, AltitudeRollupValue? altitude, BloodGlucoseRollupValue? bloodGlucose, BodyFatRollupValue? bodyFat, CaloriesInHeartRateZoneRollupValue? caloriesInHeartRateZone, CivilDateTime? civilEndTime, CivilDateTime? civilStartTime, CoreBodyTemperatureRollupValue? coreBodyTemperature, DistanceRollupValue? distance, FloorsRollupValue? floors, HeartRateRollupValue? heartRate, HeartRateVariabilityPersonalRangeRollupValue? heartRateVariabilityPersonalRange, HydrationLogRollupValue? hydrationLog, NutritionLogRollupValue? nutritionLog, RestingHeartRatePersonalRangeRollupValue? restingHeartRatePersonalRange, RunVO2MaxRollupValue? runVo2Max, SedentaryPeriodRollupValue? sedentaryPeriod, StepsRollupValue? steps, SwimLengthsDataRollupValue? swimLengthsData, TimeInHeartRateZoneRollupValue? timeInHeartRateZone, TotalCaloriesRollupValue? totalCalories, WeightRollupValue? weight})
- DailyRollupDataPoint.fromJson(Map json_)
Properties
- activeEnergyBurned ↔ ActiveEnergyBurnedRollupValue?
-
Returned by default when rolling up data points from the
active-energy-burneddata type.getter/setter pair - activeMinutes ↔ ActiveMinutesRollupValue?
-
Returned by default when rolling up data points from the
active-minutesdata type, or when requested explicitly using theactive-minutesrollup type identifier.getter/setter pair - activeZoneMinutes ↔ ActiveZoneMinutesRollupValue?
-
Returned by default when rolling up data points from the
active-zone-minutesdata type, or when requested explicitly using theactive-zone-minutesrollup type identifier.getter/setter pair - activityLevel ↔ ActivityLevelRollupValue?
-
Returned by default when rolling up data points from the
activity-leveldata type, or when requested explicitly using theactivity-levelrollup type identifier.getter/setter pair - altitude ↔ AltitudeRollupValue?
-
Returned by default when rolling up data points from the
altitudedata type, or when requested explicitly using thealtituderollup type identifier.getter/setter pair - bloodGlucose ↔ BloodGlucoseRollupValue?
-
Returned by default when rolling up data points from the
blood-glucosedata type.getter/setter pair - bodyFat ↔ BodyFatRollupValue?
-
Returned by default when rolling up data points from the
body-fatdata type, or when requested explicitly using thebody-fatrollup type identifier.getter/setter pair - caloriesInHeartRateZone ↔ CaloriesInHeartRateZoneRollupValue?
-
Returned by default when rolling up data points from the
calories-in-heart-rate-zonedata type, or when requested explicitly using thecalories-in-heart-rate-zonerollup type identifier.getter/setter pair - civilEndTime ↔ CivilDateTime?
-
End time of the window this value aggregates over
getter/setter pair
- civilStartTime ↔ CivilDateTime?
-
Start time of the window this value aggregates over
getter/setter pair
- coreBodyTemperature ↔ CoreBodyTemperatureRollupValue?
-
Returned by default when rolling up data points from the
core-body-temperaturedata type, or when requested explicitly using thecore-body-temperaturerollup type identifier.getter/setter pair - distance ↔ DistanceRollupValue?
-
Returned by default when rolling up data points from the
distancedata type, or when requested explicitly using thedistancerollup type identifier.getter/setter pair - floors ↔ FloorsRollupValue?
-
Returned by default when rolling up data points from the
floorsdata type, or when requested explicitly using thefloorsrollup type identifier.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- heartRate ↔ HeartRateRollupValue?
-
Returned by default when rolling up data points from the
heart-ratedata type, or when requested explicitly using theheart-raterollup type identifier.getter/setter pair - heartRateVariabilityPersonalRange ↔ HeartRateVariabilityPersonalRangeRollupValue?
-
Returned by default when rolling up data points from the
daily-heart-rate-variabilitydata type, or when requested explicitly using theheart-rate-variability-personal-rangerollup type identifier.getter/setter pair - hydrationLog ↔ HydrationLogRollupValue?
-
Returned by default when rolling up data points from the
hydration-logdata type, or when requested explicitly using thehydration-logrollup type identifier.getter/setter pair - nutritionLog ↔ NutritionLogRollupValue?
-
Returned by default when rolling up data points from the
nutrition-logdata type, or when requested explicitly using thenutrition-logrollup type identifier.getter/setter pair - restingHeartRatePersonalRange ↔ RestingHeartRatePersonalRangeRollupValue?
-
Returned by default when rolling up data points from the
daily-resting-heart-ratedata type, or when requested explicitly using theresting-heart-rate-personal-rangerollup type identifier.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runVo2Max ↔ RunVO2MaxRollupValue?
-
Returned by default when rolling up data points from the
run-vo2-maxdata type, or when requested explicitly using therun-vo2-maxrollup type identifier.getter/setter pair - sedentaryPeriod ↔ SedentaryPeriodRollupValue?
-
Returned by default when rolling up data points from the
sedentary-perioddata type, or when requested explicitly using thesedentary-periodrollup type identifier.getter/setter pair - steps ↔ StepsRollupValue?
-
Returned by default when rolling up data points from the
stepsdata type, or when requested explicitly using thestepsrollup type identifier.getter/setter pair - swimLengthsData ↔ SwimLengthsDataRollupValue?
-
Returned by default when rolling up data points from the
swim-lengths-datadata type, or when requested explicitly using theswim-lengths-datarollup type identifier.getter/setter pair - timeInHeartRateZone ↔ TimeInHeartRateZoneRollupValue?
-
Returned by default when rolling up data points from the
time-in-heart-rate-zonedata type, or when requested explicitly using thetime-in-heart-rate-zonerollup type identifier.getter/setter pair - totalCalories ↔ TotalCaloriesRollupValue?
-
Returned by default when rolling up data points from the
total-caloriesdata type, or when requested explicitly using thetotal-caloriesrollup type identifier.getter/setter pair - weight ↔ WeightRollupValue?
-
Returned by default when rolling up data points from the
weightdata type, or when requested explicitly using theweightrollup type identifier.getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited