DailyVO2Max class
Contains a daily summary of the user's VO2 max (cardio fitness score), which is the maximum rate of oxygen the body can use during exercise.
Constructors
- DailyVO2Max({String? cardioFitnessLevel, Date? date, bool? estimated, double? vo2Max, double? vo2MaxCovariance})
- DailyVO2Max.fromJson(Map json_)
Properties
- cardioFitnessLevel ↔ String?
-
Represents the user's cardio fitness level based on their VO2 max.
getter/setter pair
- date ↔ Date?
-
The date for which the Daily VO2 max was measured.
getter/setter pair
- estimated ↔ bool?
-
An estimated field is added to indicate when the confidence has decreased
sufficiently to consider the value an estimation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- vo2Max ↔ double?
-
Daily VO2 max value measured as in ml consumed oxygen / kg of body weight
/ min.
getter/setter pair
- vo2MaxCovariance ↔ double?
-
The covariance of the VO2 max value.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited