DataPoint class

A computed or recorded metric.

Constructors

DataPoint({ActiveEnergyBurned? activeEnergyBurned, ActiveMinutes? activeMinutes, ActiveZoneMinutes? activeZoneMinutes, ActivityLevel? activityLevel, Altitude? altitude, BasalEnergyBurned? basalEnergyBurned, BloodGlucose? bloodGlucose, BodyFat? bodyFat, CoreBodyTemperature? coreBodyTemperature, DailyHeartRateVariability? dailyHeartRateVariability, DailyHeartRateZones? dailyHeartRateZones, DailyOxygenSaturation? dailyOxygenSaturation, DailyRespiratoryRate? dailyRespiratoryRate, DailyRestingHeartRate? dailyRestingHeartRate, DailySleepTemperatureDerivations? dailySleepTemperatureDerivations, DailyVO2Max? dailyVo2Max, DataSource? dataSource, Distance? distance, Electrocardiogram? electrocardiogram, Exercise? exercise, Floors? floors, Food? food, FoodMeasurementUnit? foodMeasurementUnit, HeartRate? heartRate, HeartRateVariability? heartRateVariability, Height? height, HydrationLog? hydrationLog, IrregularRhythmNotification? irregularRhythmNotification, MenstrualPeriod? menstrualPeriod, Moods? moods, String? name, NutritionLog? nutritionLog, OvulationTest? ovulationTest, OxygenSaturation? oxygenSaturation, RespiratoryRateSleepSummary? respiratoryRateSleepSummary, RunVO2Max? runVo2Max, SedentaryPeriod? sedentaryPeriod, Sleep? sleep, Steps? steps, SwimLengthsData? swimLengthsData, Symptoms? symptoms, TimeInHeartRateZone? timeInHeartRateZone, VO2Max? vo2Max, Weight? weight})
DataPoint.fromJson(Map json_)

Properties

activeEnergyBurned ActiveEnergyBurned?
Data for points in the active-energy-burned interval data type collection.
getter/setter pair
activeMinutes ActiveMinutes?
Data for points in the active-minutes interval data type collection.
getter/setter pair
activeZoneMinutes ActiveZoneMinutes?
Data for points in the active-zone-minutes interval data type collection, measured in minutes.
getter/setter pair
activityLevel ActivityLevel?
Data for points in the activity-level daily data type collection.
getter/setter pair
altitude Altitude?
Data for points in the altitude interval data type collection.
getter/setter pair
basalEnergyBurned BasalEnergyBurned?
Data for points in the basal-energy-burned interval data type collection.
getter/setter pair
bloodGlucose BloodGlucose?
Data for points in the blood-glucose sample data type collection.
getter/setter pair
bodyFat BodyFat?
Data for points in the body-fat sample data type collection.
getter/setter pair
coreBodyTemperature CoreBodyTemperature?
Data for points in the core-body-temperature sample data type collection.
getter/setter pair
dailyHeartRateVariability DailyHeartRateVariability?
Data for points in the daily-heart-rate-variability daily data type collection.
getter/setter pair
dailyHeartRateZones DailyHeartRateZones?
Data for points in the daily-heart-rate-zones daily data type collection.
getter/setter pair
dailyOxygenSaturation DailyOxygenSaturation?
Data for points in the daily-oxygen-saturation daily data type collection.
getter/setter pair
dailyRespiratoryRate DailyRespiratoryRate?
Data for points in the daily-respiratory-rate daily data type collection.
getter/setter pair
dailyRestingHeartRate DailyRestingHeartRate?
Data for points in the daily-resting-heart-rate daily data type collection.
getter/setter pair
dailySleepTemperatureDerivations DailySleepTemperatureDerivations?
Data for points in the daily-sleep-temperature-derivations daily data type collection.
getter/setter pair
dailyVo2Max DailyVO2Max?
Data for points in the daily-vo2-max daily data type collection.
getter/setter pair
dataSource DataSource?
Data source information for the metric
getter/setter pair
distance Distance?
Data for points in the distance interval data type collection.
getter/setter pair
electrocardiogram Electrocardiogram?
Data for points in the electrocardiogram session data type collection.
getter/setter pair
exercise Exercise?
Data for points in the exercise session data type collection.
getter/setter pair
floors Floors?
Data for points in the floors interval data type collection.
getter/setter pair
food Food?
The food details.
getter/setter pair
foodMeasurementUnit FoodMeasurementUnit?
The food measurement unit details.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
heartRate HeartRate?
Data for points in the heart-rate sample data type collection.
getter/setter pair
heartRateVariability HeartRateVariability?
Data for points in the heart-rate-variability sample data type collection.
getter/setter pair
height Height?
Data for points in the height sample data type collection.
getter/setter pair
hydrationLog HydrationLog?
Data for points in the hydration-log session data type collection.
getter/setter pair
irregularRhythmNotification IrregularRhythmNotification?
Data for points in the irregular-rhythm-notification session data type collection.
getter/setter pair
menstrualPeriod MenstrualPeriod?
Data for points in the menstrual-period interval data type collection.
getter/setter pair
moods Moods?
Data for points in the moods sample data type collection.
getter/setter pair
name String?
Identifier.
getter/setter pair
nutritionLog NutritionLog?
Data for points in the nutrition-log session data type collection.
getter/setter pair
ovulationTest OvulationTest?
Data for points in the ovulation-test sample data type collection.
getter/setter pair
oxygenSaturation OxygenSaturation?
Data for points in the oxygen-saturation sample data type collection.
getter/setter pair
respiratoryRateSleepSummary RespiratoryRateSleepSummary?
Data for points in the respiratory-rate-sleep-summary sample data type collection.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
runVo2Max RunVO2Max?
Data for points in the run-vo2-max sample data type collection.
getter/setter pair
sedentaryPeriod SedentaryPeriod?
Data for points in the sedentary-period interval data type collection.
getter/setter pair
sleep Sleep?
Data for points in the sleep session data type collection.
getter/setter pair
steps Steps?
Data for points in the steps interval data type collection.
getter/setter pair
swimLengthsData SwimLengthsData?
Data for points in the swim-lengths-data interval data type collection.
getter/setter pair
symptoms Symptoms?
Data for points in the symptoms sample data type collection.
getter/setter pair
timeInHeartRateZone TimeInHeartRateZone?
Data for points in the time-in-heart-rate-zone interval data type collection.
getter/setter pair
vo2Max VO2Max?
Data for points in the vo2-max sample data type collection.
getter/setter pair
weight Weight?
Data for points in the weight sample data type collection.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited