name property
Identifier.
Data point name, only supported for the subset of identifiable data types.
For the majority of the data types, individual data points do not need to
be identified and this field would be empty. Format:
users/{user}/dataTypes/{data_type}/dataPoints/{data_point} Example:
users/abcd1234/dataTypes/sleep/dataPoints/a1b2c3d4-e5f6-7890-1234-567890abcdef
The {user} ID is a system-generated identifier, as described in
Identity.health_user_id. The {data_type} ID corresponds to the
kebab-case version of the field names in the DataPoint data union field,
e.g. heart-rate for the heart_rate field. The {data_point} ID can be
client-provided or system-generated. If client-provided, it must be a
string of 4-63 characters, containing only lowercase letters, numbers, and
hyphens.
Implementation
core.String? name;