recordingMethod property
Captures how the data was recorded.
Optional. Possible string values are:
- "RECORDING_METHOD_UNSPECIFIED" : The recording method is unspecified.
- "MANUAL" : The data was manually entered by the user.
- "PASSIVELY_MEASURED" : The data was passively measured by a device.
- "DERIVED" : The data was derived from other data, e.g., by an algorithm in the backend.
- "ACTIVELY_MEASURED" : The data was actively measured by a device.
- "UNKNOWN" : The recording method is unknown. This is set when the data is uploaded from a third party app that does not provide this information.
Implementation
core.String? recordingMethod;