HeartRateVariability class
Captures user's heart rate variability (HRV) as measured by the root mean square of successive differences (RMSSD) between normal heartbeats or by standard deviation of the inter-beat intervals (SDNN).
Constructors
- HeartRateVariability({double? rootMeanSquareOfSuccessiveDifferencesMilliseconds, ObservationSampleTime? sampleTime, double? standardDeviationMilliseconds})
- HeartRateVariability.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rootMeanSquareOfSuccessiveDifferencesMilliseconds ↔ double?
-
The root mean square of successive differences between normal heartbeats.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleTime ↔ ObservationSampleTime?
-
The time of the heart rate variability measurement.
getter/setter pair
- standardDeviationMilliseconds ↔ double?
-
The standard deviation of the heart rate variability measurement.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited