HydrationLog class
Holds information about a user logged hydration.
Constructors
- HydrationLog({VolumeQuantity? amountConsumed, SessionTimeInterval? interval})
- HydrationLog.fromJson(Map json_)
Properties
- amountConsumed ↔ VolumeQuantity?
-
Amount of liquid (ex.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval ↔ SessionTimeInterval?
-
Observed interval.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited