Profile class
Profile details.
Constructors
Properties
- age ↔ int?
-
The age in years based on the user's birth date.
getter/setter pair
- autoRunningStrideLengthMm ↔ int?
-
The automatically calculated running stride length, in millimeters.
getter/setter pair
- autoWalkingStrideLengthMm ↔ int?
-
The automatically calculated walking stride length, in millimeters.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- membershipStartDate ↔ Date?
-
The date the user created their account.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userConfiguredRunningStrideLengthMm ↔ int?
-
The user's user configured running stride length, in millimeters.
getter/setter pair
- userConfiguredWalkingStrideLengthMm ↔ int?
-
The user's user configured walking stride length, in millimeters.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited