patch method
Updates the configuration of an existing subscriber, such as the endpoint URI or the data types it's interested in.
Endpoint Verification: If the endpoint_uri or
endpoint_authorization field is included in the update_mask, the
backend will re-verify the endpoint. The verification process is the same
as described in CreateSubscriber: 1. Verification with
Authorization: POST to the new or existing endpoint_uri with the new
or existing Authorization secret. Expects HTTP 201 Created. 2.
Verification without Authorization: POST to the endpoint_uri without
the Authorization header. Expects HTTP 401 Unauthorized or 403 Forbidden. Both tests must pass using the potentially updated values for
the subscriber update to succeed. If verification fails, the update will
not be applied, and an error will be returned.
request - The metadata request object.
Request parameters:
name - Identifier. The resource name of the Subscriber. Format:
projects/{project}/subscribers/{subscriber} The {project} ID is a Google
Cloud Project ID or Project Number. The {subscriber} ID is user-settable
(4-36 characters, matching /[a-z]([a-z0-9-]{2,34}[a-z0-9])/) if
provided during creation, or system-generated otherwise (e.g., a UUID).
Example (User-settable subscriber ID):
projects/my-project/subscribers/my-sub-123 Example (System-generated
subscriber ID):
projects/my-project/subscribers/a1b2c3d4-e5f6-7890-1234-567890abcdef
Value must have pattern ^projects/\[^/\]+/subscribers/\[^/\]+$.
updateMask - Optional. A field mask that specifies which fields of the
Subscriber message are to be updated. This allows for partial updates.
Supported fields: - endpoint_uri - subscriber_configs -
endpoint_authorization
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Operation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Operation> patch(
Subscriber request,
core.String name, {
core.String? updateMask,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'updateMask': ?updateMask == null ? null : [updateMask],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v4/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'PATCH',
body: body_,
queryParams: queryParams_,
);
return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}