delete method
Deletes a specific user subscription, stopping notifications for this user to this subscriber.
Request parameters:
name - Required. The resource name of the subscription to delete.
Format:
projects/{project}/subscribers/{subscriber}/subscriptions/{subscription}
Example:
projects/my-project/subscribers/my-subscriber-123/subscriptions/my-subscription-456
The {subscriber} ID is user-settable (4-36 characters, matching
/[a-z]([a-z0-9-]{2,34}[a-z0-9])/) if provided during creation, or
system-generated otherwise. The {subscription} ID is user-settable (4-36
characters, matching /[a-z]([a-z0-9-]{2,34}[a-z0-9])/) or
system-generated if not provided during creation.
Value must have pattern
^projects/\[^/\]+/subscribers/\[^/\]+/subscriptions/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Empty.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Empty> delete(core.String name, {core.String? $fields}) async {
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v4/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'DELETE',
queryParams: queryParams_,
);
return Empty.fromJson(response_ as core.Map<core.String, core.dynamic>);
}