patch method
- Subscription request,
- String name, {
- String? updateMask,
- String? $fields,
Updates the data types for an existing user subscription.
request - The metadata request object.
Request parameters:
name - Identifier. The resource name of the Subscription. Format:
projects/{project}/subscribers/{subscriber}/subscriptions/{subscription}
Example:
projects/my-project/subscribers/my-subscriber-123/subscriptions/my-subscription-456
The {project} ID is mandatory (6-30 characters, matching /a-z{6,30}/) The
{subscriber} ID is user-settable (4-36 characters, matching
/[a-z]([a-z0-9-]{2,34}[a-z0-9])/) if provided during creation, or
system-generated otherwise. The {subscription} ID is user-settable (4-36
chars, matching /[a-z]([a-z0-9-]{2,34}[a-z0-9])/) or
system-generated otherwise.
Value must have pattern
^projects/\[^/\]+/subscribers/\[^/\]+/subscriptions/\[^/\]+$.
updateMask - Optional. The list of fields to update.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Subscription.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Subscription> patch(
Subscription request,
core.String name, {
core.String? updateMask,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'updateMask': ?updateMask == null ? null : [updateMask],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v4/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'PATCH',
body: body_,
queryParams: queryParams_,
);
return Subscription.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}