dataSourceFamily property
The data source family name to roll up.
If empty, data points from all available data sources will be rolled up.
Format: users/me/dataSourceFamilies/{data_source_family} The supported
values are: - users/me/dataSourceFamilies/all-sources - Default value.
Includes data from all available data sources. -
users/me/dataSourceFamilies/google-wearables - Includes data from Google
and Fitbit tracker devices (such as Fitbit trackers and Pixel Watch).
Excludes manually logged data. -
users/me/dataSourceFamilies/google-sources - Includes first-party Google
data, such as data from tracker devices, manually logged data, and Health
Connect.
Optional.
Implementation
core.String? dataSourceFamily;