RunVO2Max class
VO2 max value calculated based on the user's running activity.
Value stored in ml/kg/min.
Constructors
- RunVO2Max({double? runVo2Max, ObservationSampleTime? sampleTime})
- RunVO2Max.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runVo2Max ↔ double?
-
Run VO2 max value in ml/kg/min.
getter/setter pair
- sampleTime ↔ ObservationSampleTime?
-
The time at which the metric was measured.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited