RunVO2MaxRollupValue class
Represents the result of the rollup of the user's daily heart rate variability personal range.
Constructors
- RunVO2MaxRollupValue({double? rateAvg, double? rateMax, double? rateMin})
- RunVO2MaxRollupValue.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- rateAvg ↔ double?
-
Average value of run VO2 max in the interval.
getter/setter pair
- rateMax ↔ double?
-
Maximum value of run VO2 max in the interval.
getter/setter pair
- rateMin ↔ double?
-
Minimum value of run VO2 max in the interval..
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited