SessionTimeInterval class

Represents a time interval of session data point, which bundles multiple observed metrics together.

Constructors

SessionTimeInterval({CivilDateTime? civilEndTime, CivilDateTime? civilStartTime, String? endTime, String? endUtcOffset, String? startTime, String? startUtcOffset})
SessionTimeInterval.fromJson(Map json_)

Properties

civilEndTime CivilDateTime?
Session end time in civil time in the timezone the subject is in at the end of the session.
getter/setter pair
civilStartTime CivilDateTime?
Session start time in civil time in the timezone the subject is in at the start of the session.
getter/setter pair
endTime String?
The end time of the observed session.
getter/setter pair
endUtcOffset String?
The offset of the user's local time at the end of the session relative to the Coordinated Universal Time (UTC).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime String?
The start time of the observed session.
getter/setter pair
startUtcOffset String?
The offset of the user's local time at the start of the session relative to the Coordinated Universal Time (UTC).
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited