type property
SleepType: classic or stages.
Optional. Possible string values are:
- "SLEEP_TYPE_UNSPECIFIED" : Sleep type is unspecified.
- "CLASSIC" : Classic sleep is a sleep with 3 stages types: AWAKE, RESTLESS and ASLEEP.
- "STAGES" : On top of "classic" sleep stages an additional processing pass can calculate stages more precisely, overwriting the prior stages with AWAKE, LIGHT, REM and DEEP.
Implementation
core.String? type;