SleepMetadata class
Additional information about how the sleep was processed.
Constructors
- SleepMetadata({String? externalId, bool? mainSleep, bool? manuallyEdited, bool? nap, bool? processed, String? stagesStatus})
- SleepMetadata.fromJson(Map json_)
Properties
- externalId ↔ String?
-
Sleep identifier relevant in the context of the data source.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- mainSleep ↔ bool?
-
main_sleep: the longest sleep session with stages within one day.getter/setter pair - manuallyEdited ↔ bool?
-
Some sleeps autodetected by algorithms can be manually edited by users.
getter/setter pair
- nap ↔ bool?
-
Naps are sleeps without stages and relatively short durations.
getter/setter pair
- processed ↔ bool?
-
Sleep and sleep stages algorithms finished processing.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stagesStatus ↔ String?
-
Sleep stages algorithm processing status.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited