processed property
Sleep and sleep stages algorithms finished processing.
A true value indicates whether all data processing for the session is
complete. A false value means sleep period is detected but sleep stages
is still processing.
Output only.
Implementation
core.bool? processed;