SplitSummary class

Represents splits or laps recorded within an exercise.

Lap events partition a workout into segments based on criteria like distance, time, or calories.

Constructors

SplitSummary({String? activeDuration, String? endTime, String? endUtcOffset, MetricsSummary? metricsSummary, String? splitType, String? startTime, String? startUtcOffset})
SplitSummary.fromJson(Map json_)

Properties

activeDuration String?
Lap time excluding the pauses.
getter/setter pair
endTime String?
Lap end time
getter/setter pair
endUtcOffset String?
Lap end time offset from UTC
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metricsSummary MetricsSummary?
Summary metrics for this split.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splitType String?
Method used to split the exercise laps.
getter/setter pair
startTime String?
Lap start time
getter/setter pair
startUtcOffset String?
Lap start time offset from UTC
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited