dataTypes property
Data types subscribed to.
A subscriber will only receive notifications for data types that are
declared here. A subscription can only subscribe to the data types of the
subscriber. The values should be in the format
"users/{health_user_id}/dataTypes/{data_type}" where {data_type} is one
of "altitude", "distance", "floors", "sleep", "steps", "weight".
Optional.
Implementation
core.List<core.String>? dataTypes;