SwimLengthsData class
Swim lengths data over the time interval.
Constructors
- SwimLengthsData({ObservationTimeInterval? interval, String? strokeCount, String? swimStrokeType})
- SwimLengthsData.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- interval ↔ ObservationTimeInterval?
-
Observed interval.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeCount ↔ String?
-
Number of strokes in the lap.
getter/setter pair
- swimStrokeType ↔ String?
-
Swim stroke type.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited