TimeInHeartRateZone class
Time in heart rate zone record.
It's an interval spent in specific heart rate zone.
Constructors
- TimeInHeartRateZone({String? heartRateZoneType, ObservationTimeInterval? interval})
- TimeInHeartRateZone.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- heartRateZoneType ↔ String?
-
Heart rate zone type.
getter/setter pair
- interval ↔ ObservationTimeInterval?
-
Observed interval.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited