patch method
Updates a single identifiable data point.
If a data point with the specified name is not found, the request will
fail.
request - The metadata request object.
Request parameters:
name - Identifier. Data point name, only supported for the subset of
identifiable data types. For the majority of the data types, individual
data points do not need to be identified and this field would be empty.
Format: users/{user}/dataTypes/{data_type}/dataPoints/{data_point}
Example:
users/abcd1234/dataTypes/sleep/dataPoints/a1b2c3d4-e5f6-7890-1234-567890abcdef
The {user} ID is a system-generated identifier, as described in
Identity.health_user_id. The {data_type} ID corresponds to the
kebab-case version of the field names in the DataPoint data union field,
e.g. heart-rate for the heart_rate field. The {data_point} ID can be
client-provided or system-generated. If client-provided, it must be a
string of 4-63 characters, containing only lowercase letters, numbers, and
hyphens.
Value must have pattern
^users/\[^/\]+/dataTypes/\[^/\]+/dataPoints/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Operation.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Operation> patch(
DataPoint request,
core.String name, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v4/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'PATCH',
body: body_,
queryParams: queryParams_,
);
return Operation.fromJson(response_ as core.Map<core.String, core.dynamic>);
}