VO2Max class
VO2 max measurement.
Constructors
- VO2Max({String? measurementMethod, ObservationSampleTime? sampleTime, double? vo2Max})
- VO2Max.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- measurementMethod ↔ String?
-
The method used to measure the VO2 max value.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleTime ↔ ObservationSampleTime?
-
The time at which VO2 max was measured.
getter/setter pair
- vo2Max ↔ double?
-
VO2 max value measured as in ml consumed oxygen / kg of body weight / min.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited