Weight class
Body weight measurement.
Constructors
- Weight({String? notes, ObservationSampleTime? sampleTime, double? weightGrams})
- Weight.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- notes ↔ String?
-
Standard free-form notes captured at manual logging.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleTime ↔ ObservationSampleTime?
-
The time at which the weight was measured
getter/setter pair
- weightGrams ↔ double?
-
Weight of a user in grams.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited