ReportStateAndNotificationDevice class
The states and notifications specific to a device.
Constructors
-
ReportStateAndNotificationDevice({List<
HomeEvents> ? homeEvents, List<HomeTraitUpdates> ? homeTraits, Map<String, Object?> ? notifications, Map<String, Object?> ? states}) - ReportStateAndNotificationDevice.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
homeEvents
↔ List<
HomeEvents> ? -
UDDM/WHDM trait events
getter/setter pair
-
homeTraits
↔ List<
HomeTraitUpdates> ? -
UDDM/WHDM trait updates.
getter/setter pair
-
notifications
↔ Map<
String, Object?> ? -
Notifications metadata for devices.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
states
↔ Map<
String, Object?> ? -
States of devices to update.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited