ReportStateAndNotificationResponse class
Response type for the
[ReportStateAndNotification](#google.home.graph.v1.HomeGraphApiService.ReportStateAndNotification)
call.
Constructors
-
ReportStateAndNotificationResponse({Map<
String, Result> ? deviceResults, String? requestId}) - ReportStateAndNotificationResponse.fromJson(Map json_)
Properties
-
deviceResults
↔ Map<
String, Result> ? -
Map from agent device ID to the result of reporting state and
notifications.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId ↔ String?
-
Request ID copied from ReportStateAndNotificationRequest.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited