TraitData class
Contains the trait payload for a single trait.
Constructors
Properties
- commitTime ↔ String?
-
Other metadata for the trait.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- providerVersionTime ↔ String?
-
Optional in write requests (e.g. ReportStateAndNotification).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
trait
↔ Map<
String, Object?> ? -
The Provider Home API trait payload.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited