trustDefaultSharedCa property
If set to True, the trust bundle will include the private ca managed identity regional root public certificates.
Important: trust_default_shared_ca is only supported for managed
identity trust domain resource.
Optional.
Implementation
core.bool? trustDefaultSharedCa;