WorkforcePoolProviderScimTenant class

Represents a scim tenant.

Used for provisioning and managing identity data (such as Users and Groups) in cross-domain environments.

Constructors

WorkforcePoolProviderScimTenant({String? baseUri, Map<String, String>? claimMapping, String? description, String? displayName, String? name, String? purgeTime, String? state})
WorkforcePoolProviderScimTenant.fromJson(Map json_)

Properties

baseUri ↔ String?
Represents the base URI as defined in RFC 7644, Section 1.3.
getter/setter pair
claimMapping ↔ Map<String, String>?
Maps BYOID claims to SCIM claims.
getter/setter pair
description ↔ String?
The description of the scim tenant.
getter/setter pair
displayName ↔ String?
The display name of the scim tenant.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Identifier.
getter/setter pair
purgeTime ↔ String?
The timestamp when the scim tenant is going to be purged.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state ↔ String?
The state of the tenant.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited