FieldSource class
A source that can be used to represent a "field of data" within various parts of a structured query, such as in SELECT, WHERE, or ORDER BY clauses.
The term "field of data" is used here because it is not limited to literal fields in the underlying data schema.
Constructors
- FieldSource({String? aliasRef, String? columnType, String? field, bool? isJson, String? parentPath, ProjectedField? projectedField})
- FieldSource.fromJson(Map json_)
Properties
- aliasRef ↔ String?
-
The alias name for a field that has already been aliased within a
different ProjectedField type elsewhere in the query model.
getter/setter pair
- columnType ↔ String?
-
The type of the selected field.
getter/setter pair
- field ↔ String?
-
The fully qualified, dot-delimited path to the selected atomic field (the
leaf value).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- isJson ↔ bool?
-
Whether the field is a JSON field, or has a parent that is a JSON field.
getter/setter pair
- parentPath ↔ String?
-
The dot-delimited path of the parent container that holds the target
field.This path defines the structural hierarchy and is essential for
correctly generating SQL when field keys contain special characters (e.g.,
dots or brackets).Example: json_payload.labels (This points to the
'labels' object).
getter/setter pair
- projectedField ↔ ProjectedField?
-
A projected field option for when a user wants to use a field with some
additional transformations such as casting or extractions.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited