comparator property
The comparison type to use for the filter. Possible string values are:
- "COMPARATOR_UNSPECIFIED" : Invalid value, do not use.
- "EQUALS" : The value is equal to the inputted value.
- "MATCHES_REGEXP" : The value is equal to the inputted regex value.
- "GREATER_THAN" : The value is greater than the inputted value.
- "LESS_THAN" : The value is less than the inputted value.
- "GREATER_THAN_EQUALS" : The value is greater than or equal to the inputted value.
- "LESS_THAN_EQUALS" : The value is less than or equal to the inputted value.
- "IS_NULL" : Requires the filter_value to be a Value type with null_value set to true.
- "IN" : The value is in the inputted array value.
- "LIKE" : The value is like the inputted value.
Implementation
core.String? comparator;