literalValue property
The Value will be used to hold user defined constants set as the Right Hand Side of the filter.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Object? literalValue;