FilterPredicate class
A filter for a query.
This equates to the WHERE clause in SQL.
Constructors
-
FilterPredicate({List<
FilterPredicate> ? childPredicates, FilterExpression? leafPredicate, String? operatorType}) - FilterPredicate.fromJson(Map json_)
Properties
-
childPredicates
↔ List<
FilterPredicate> ? -
The children of the filter predicate.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- leafPredicate ↔ FilterExpression?
-
The leaves of the filter predicate.
getter/setter pair
- operatorType ↔ String?
-
The operator type for the filter.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited