parameters property
Parameters to be applied to the aggregation.
Aggregations that support or require parameters are listed above.
Optional.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.List<core.Object?>? parameters;