filter property
An advanced logs filter (https://docs.cloud.google.com/logging/docs/view/building-queries#queries-by-expression).
The only exported log entries are those that are in the resource owning the sink and that match the filter.For example:logName="projects/[PROJECT_ID]/logs/[LOG_ID]" AND severity>=ERROR
Optional.
Implementation
core.String? filter;