field property
The field name.
This will be the field that is selected using the dot notation to display the drill down value.
Optional.
Implementation
core.String? field;
The field name.
This will be the field that is selected using the dot notation to display the drill down value.
Optional.
core.String? field;