VirtualField class
A virtual field is a field that is not physically present in the underlying data schema, but is created through specific operations within the query builder model based on other fields in the schema.
Constructors
-
VirtualField({List<
FieldSource> ? underlyingFieldSources, String? virtualFieldType}) - VirtualField.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
underlyingFieldSources
↔ List<
FieldSource> ? -
The field sources that will be used to create the virtual field, based on
the semantics of the virtual field type.The field sources must follow
these rules, based on the virtual field type: - For
VIRTUAL_FIELD_TYPE_UNSPECIFIED, this field must be empty.
getter/setter pair
- virtualFieldType ↔ String?
-
The type of the virtual field.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited