virtualFieldType property
The type of the virtual field.
Required. Possible string values are:
- "VIRTUAL_FIELD_TYPE_UNSPECIFIED" : Invalid value, do not use.
- "COALESCE" : Creates a virtual field by selecting the first non-null value from the list of fields specified in underlying_field_sources, similar to a COALESCE function in SQL.
Implementation
core.String? virtualFieldType;