PhoneAccess class
Phone access contains information required to dial into a conference using a regional phone number and a PIN that is specific to that phone number.
Constructors
- PhoneAccess({String? languageCode, String? phoneNumber, String? pin, String? regionCode})
- PhoneAccess.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode ↔ String?
-
The BCP 47/LDML language code for the language associated with this phone
access.
getter/setter pair
- phoneNumber ↔ String?
-
The phone number to dial for this meeting space in E.164 format.
getter/setter pair
- pin ↔ String?
-
The PIN that users must enter after dialing the given number.
getter/setter pair
- regionCode ↔ String?
-
The CLDR/ISO 3166 region code for the country associated with this phone
access.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited