SmartNote class
Metadata for a smart note generated from a conference.
It refers to the notes generated from Take Notes with Gemini during the conference.
Constructors
- SmartNote({DocsDestination? docsDestination, String? endTime, String? name, String? startTime, String? state})
- SmartNote.fromJson(Map json_)
Properties
- docsDestination ↔ DocsDestination?
-
The Google Doc destination where the smart notes are saved.
getter/setter pair
- endTime ↔ String?
-
Timestamp when the smart notes stopped.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startTime ↔ String?
-
Timestamp when the smart notes started.
getter/setter pair
- state ↔ String?
-
Current state.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited