maintenanceVersion property
Last self service update maintenance version triggered by the customer.
If it is empty, it means that the maintenance version is not set by the user.
Optional.
Implementation
core.String? maintenanceVersion;
Last self service update maintenance version triggered by the customer.
If it is empty, it means that the maintenance version is not set by the user.
Optional.
core.String? maintenanceVersion;