defaultRule property
Default rule management of the data source.
If set, the linked data sources will be replaced. Warning: The update
(patch) and create call replaces the entire default rule setup. It doesn't
work as an addition or append. If self is missing from the list of
take_from_data_sources, the API will ignore attributes from the primary
data source itself.
Optional.
Implementation
DefaultRule? defaultRule;