Co2Emissions class
The co2 emission of the vehicle.
Constructors
- Co2Emissions({String? unit, String? value})
- Co2Emissions.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- unit ↔ String?
-
The unit of the co2 emission.
Possible string values are:
getter/setter pair
- value ↔ String?
-
The co2 emission value.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited