HandlingCutoffTime class
Configuration for offer or offer-country level shipping handling cutoff time.
Constructors
- HandlingCutoffTime({String? country, String? cutoffTime, String? cutoffTimezone, bool? disableDeliveryAfterCutoff})
- HandlingCutoffTime.fromJson(Map json_)
Properties
- country ↔ String?
-
The
CLDR territory code
of the country to which the handling cutoff time applies.
getter/setter pair
- cutoffTime ↔ String?
-
The handling cutoff time until which an order has to be placed to be
processed in the same day.
getter/setter pair
- cutoffTimezone ↔ String?
-
Timezone identifier
For example 'Europe/Zurich'.
getter/setter pair
- disableDeliveryAfterCutoff ↔ bool?
-
This field only applies to same-day delivery.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited