ProductMinimumOrderValue class

The minimum order value in the cart before the checkout is permitted.

Constructors

ProductMinimumOrderValue({String? country, Price? price, String? service, String? surface})
ProductMinimumOrderValue.fromJson(Map json_)

Properties

country String?
The CLDR territory code of the country to which an item will ship.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
price Price?
The minimum cart or basket value before the checkout is permitted.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
service String?
A free-form description of the service class or delivery speed.
getter/setter pair
surface String?
The surface to which the minimum order value applies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited