loyaltyProgramLabel property
The label of the loyalty program.
Must match one of the program labels set in loyalty_programs. When set (in combination with loyalty_tier_label), this shipping option is only applicable to loyalty program members of the specified tier.
Optional.
Implementation
core.String? loyaltyProgramLabel;