StatusPerReportingContext class
Status of the product for a specific reporting context.
Equivalent to DestinationStatus in Products API.
Constructors
-
StatusPerReportingContext({List<
String> ? approvedCountries, List<String> ? disapprovedCountries, List<String> ? pendingCountries, String? reportingContext}) - StatusPerReportingContext.fromJson(Map json_)
Properties
-
approvedCountries
↔ List<
String> ? -
List of approved countries in the reporting context, represented in
ISO 3166 format, for
example,
US.getter/setter pair -
disapprovedCountries
↔ List<
String> ? -
List of disapproved countries in the reporting context, represented in
ISO 3166 format, for
example,
US.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
-
pendingCountries
↔ List<
String> ? -
List of pending countries in the reporting context, represented in
ISO 3166 format, for
example,
US.getter/setter pair - reportingContext ↔ String?
-
Reporting context the status applies to.
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited