OntapSource class
Represents ONTAP source details.
Constructors
- OntapSource({String? snapshotUuid, String? storagePool, String? volumeUuid})
- OntapSource.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotUuid ↔ String?
-
The UUID of the ONTAP source snapshot.
getter/setter pair
- storagePool ↔ String?
-
Name of the storage pool.
getter/setter pair
- volumeUuid ↔ String?
-
The UUID of the ONTAP source volume.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited