OntapVolumeTarget class

Represents the ONTAP volume target of the restore operation.

Constructors

OntapVolumeTarget({String? restoreDestinationPath, String? volumeUuid})
OntapVolumeTarget.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
restoreDestinationPath String?
Absolute directory path in the destination volume.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
volumeUuid String?
The UUID of the ONTAP volume to restore to.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited