ProjectsLocationsStoragePoolsOntapResource class
Constructors
- ProjectsLocationsStoragePoolsOntapResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executeOntapDelete(
String ontapPath, {String? $fields}) → Future< ExecuteOntapDeleteResponse> -
ExecuteOntapDeletesends the ONTAPDELETErequest to theStoragePoolcluster. -
executeOntapGet(
String ontapPath, {String? $fields}) → Future< ExecuteOntapDeleteResponse> -
ExecuteOntapGetsends the ONTAPGETrequest to theStoragePoolcluster. -
executeOntapPatch(
ExecuteOntapPatchRequest request, String ontapPath, {String? $fields}) → Future< ExecuteOntapDeleteResponse> -
ExecuteOntapPatchsends the ONTAPPATCHrequest to theStoragePoolcluster. -
executeOntapPost(
ExecuteOntapPostRequest request, String ontapPath, {String? $fields}) → Future< ExecuteOntapDeleteResponse> -
ExecuteOntapPostsends the ONTAPPOSTrequest to theStoragePoolcluster. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited