SplitStatus class
Message for SplitStatus.
Constructors
- SplitStatus({int? progressPercent, String? splitState, String? stateDetails})
- SplitStatus.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- progressPercent ↔ int?
-
The estimated progress percentage of the split operation (0-100).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- splitState ↔ String?
-
The current state of the clone split operation.
getter/setter pair
- stateDetails ↔ String?
-
Human-readable details about the current state.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited