splitState property
The current state of the clone split operation.
Output only. Possible string values are:
- "SPLIT_STATE_UNSPECIFIED" : State is not specified.
- "SPLIT_STATE_NOT_SPLITTING" : The volume is a thin clone, sharing blocks with its source.
- "SPLIT_STATE_IN_PROGRESS" : A split operation is currently active and in progress.
- "SPLIT_STATE_FAILED" : The attempt to split the volume failed.
Implementation
core.String? splitState;