Gateway class
A gateway that can apply specialized traffic processing.
Constructors
-
Gateway({String? capacity, List<
String> ? cloudRouters, List<IpRangeReservation> ? ipRangeReservations, String? sacAttachment}) - Gateway.fromJson(Map json_)
Properties
- capacity ↔ String?
-
The aggregate processing capacity of this gateway.
getter/setter pair
-
cloudRouters
↔ List<
String> ? -
The list of Cloud Routers that are connected to this gateway.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ipRangeReservations
↔ List<
IpRangeReservation> ? -
A list of IP ranges that are reserved for this gateway's internal
intfrastructure.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sacAttachment ↔ String?
-
The URI of the connected SACAttachment.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited