GatewayAdvertisedRoute class
A gateway advertised route is a route that a gateway spoke advertises somewhere.
Constructors
Properties
- createTime ↔ String?
-
The time the gateway advertised route was created.
getter/setter pair
- description ↔ String?
-
An optional description of the gateway advertised route.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipRange ↔ String?
-
This route's advertised IP address range.
getter/setter pair
-
labels
↔ Map<
String, String> ? -
Optional labels in key-value pair format.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- priority ↔ int?
-
The priority of this advertised route.
getter/setter pair
- recipient ↔ String?
-
The recipient of this advertised route.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
The current lifecycle state of this gateway advertised route.
getter/setter pair
- uniqueId ↔ String?
-
The Google-generated UUID for the gateway advertised route.
getter/setter pair
- updateTime ↔ String?
-
The time the gateway advertised route was last updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited