ipRange property
A block of IP addresses used to allocate supporting infrastructure for this gateway.
This block must not overlap with subnets in any spokes or peer VPC networks that the gateway can communicate with. Example: "10.1.2.0/24"
Required.
Implementation
core.String? ipRange;