PscAuthorizationPolicy class
Represents a PSC Authorization Policy.
Constructors
Properties
-
The authorization mode.
getter/setter pair
-
List of authorized consumer resources allowed to connect.
getter/setter pair
- createTime ↔ String?
-
The time when the PscAuthorizationPolicy was created.
getter/setter pair
- description ↔ String?
-
A description of this resource.
getter/setter pair
- etag ↔ String?
-
The etag of the PscAuthorizationPolicy.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
User-defined labels.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetResourceUri ↔ String?
-
The full absolute URI of the targeted resource governed by this policy.
getter/setter pair
- uid ↔ String?
-
The unique identifier of the PscAuthorizationPolicy.
getter/setter pair
- updateTime ↔ String?
-
The time when the PscAuthorizationPolicy was updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited