Transport class
Message describing Transport object.
Constructors
-
Transport({List<
String> ? advertisedRoutes, String? bandwidth, String? createTime, String? description, String? generatedActivationKey, Map<String, String> ? labels, int? mtuLimit, String? name, String? network, String? peeringNetwork, String? providedActivationKey, String? remoteAccountId, String? remoteProfile, String? stackType, String? state, String? updateTime}) - Transport.fromJson(Map json_)
Properties
-
advertisedRoutes
↔ List<
String> ? -
List of IP Prefixes that will be advertised to the remote provider.
getter/setter pair
- bandwidth ↔ String?
-
Bandwidth of the Transport.
getter/setter pair
- createTime ↔ String?
-
Create time stamp.
getter/setter pair
- description ↔ String?
-
Description of the Transport.
getter/setter pair
- generatedActivationKey ↔ String?
-
Google-generated activation key.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
Labels as key value pairs.
getter/setter pair
- mtuLimit ↔ int?
-
The maximum transmission unit (MTU) of a packet that can be sent over this
transport.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- network ↔ String?
-
Resource URI of the Network that will be peered with this Transport.
getter/setter pair
- peeringNetwork ↔ String?
-
VPC Network URI that was created for the VPC Peering connection to the
provided
network.getter/setter pair - providedActivationKey ↔ String?
-
Key used for establishing a connection with the remote transport.
getter/setter pair
- remoteAccountId ↔ String?
-
The user supplied account id for the CSP associated with the remote
profile.
getter/setter pair
- remoteProfile ↔ String?
-
Name of the remoteTransportProfile that this Transport is connecting to.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackType ↔ String?
-
IP version stack for the established connectivity.
getter/setter pair
- state ↔ String?
-
State of the underlying connectivity.
getter/setter pair
- updateTime ↔ String?
-
Update time stamp.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited