network property
Resource URI of the Network that will be peered with this Transport.
This field must be provided during resource creation and cannot be changed.
Optional. Immutable.
Implementation
core.String? network;
Resource URI of the Network that will be peered with this Transport.
This field must be provided during resource creation and cannot be changed.
Optional. Immutable.
core.String? network;