config property
The Monitoring Point configuration of the provider in JSON format.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Object?>? config;