IpMasqueradingSkippedInfo class
For display only.
Contains information about why IP masquerading was skipped for the packet.
Constructors
- IpMasqueradingSkippedInfo({String? nonMasqueradeRange, String? reason})
- IpMasqueradingSkippedInfo.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nonMasqueradeRange ↔ String?
-
The matched non-masquerade IP range.
getter/setter pair
- reason ↔ String?
-
Reason why IP masquerading was not applied.
Possible string values are:
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited