LoadBalancerBackendInfo class
For display only.
Metadata associated with the load balancer backend.
Constructors
- LoadBalancerBackendInfo({String? backendBucketUri, String? backendServiceUri, String? healthCheckFirewallsConfigState, String? healthCheckUri, String? instanceGroupUri, String? instanceUri, String? name, String? networkEndpointGroupUri, String? pscGoogleApiTarget, String? pscServiceAttachmentUri})
- LoadBalancerBackendInfo.fromJson(Map json_)
Properties
- backendBucketUri ↔ String?
-
URI of the backend bucket this backend targets (if applicable) in format
"projects/{project}/global/backendBuckets/{backend_bucket}".
getter/setter pair
- backendServiceUri ↔ String?
-
URI of the backend service this backend belongs to (if applicable) in
format
"projects/{project}/regions/{region}/backendServices/{backend_service}"
(regional) or
"projects/{project}/global/backendServices/{backend_service}" (global).
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- healthCheckFirewallsConfigState ↔ String?
-
Health check firewalls configuration state for the backend.
getter/setter pair
- healthCheckUri ↔ String?
-
URI of the health check attached to this backend (if applicable).
getter/setter pair
- instanceGroupUri ↔ String?
-
URI of the instance group this backend belongs to (if applicable) in
format "projects/{project}/zones/{zone}/instanceGroups/{instance_group}".
getter/setter pair
- instanceUri ↔ String?
-
URI of the backend instance (if applicable) in format
"projects/{project}/zones/{zone}/instances/{instance}".
getter/setter pair
- name ↔ String?
-
Display name of the backend.
getter/setter pair
- networkEndpointGroupUri ↔ String?
-
URI of the network endpoint group this backend belongs to (if applicable)
Format: *
projects/{project_id}/zones/{zone}/networkEndpointGroups/{neg_id}(zonal NEG) *projects/{project_id}/regions/{region}/networkEndpointGroups/{neg_id}(regional NEG) *projects/{project_id}/global/networkEndpointGroups/{neg_id}(global NEG)getter/setter pair - pscGoogleApiTarget ↔ String?
-
PSC Google API target this PSC NEG backend targets (if applicable).
getter/setter pair
- pscServiceAttachmentUri ↔ String?
-
URI of the PSC service attachment this PSC NEG backend targets (if
applicable) in format
"projects/{project}/regions/{region}/serviceAttachments/{service_attachment}".
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited