PrivateConnectionInfo class
For display only.
Metadata associated with a Private Connection.
Constructors
- PrivateConnectionInfo({String? uri})
- PrivateConnectionInfo.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uri ↔ String?
-
URI of the Private Connection in format
"projects/{project_id}/locations/{location}/privateConnections/{private_connection_id}"
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited