AgentGatewaySelfManaged class
Configuration for Self Managed deployment mode.
Attach to existing Application Load Balancers or Secure Web Proxies.
Constructors
-
AgentGatewaySelfManaged({String? resourceUri, List<
String> ? resourceUris}) - AgentGatewaySelfManaged.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceUri ↔ String?
-
A supported Google Cloud networking proxy in the Project and Location
getter/setter pair
-
resourceUris
↔ List<
String> ? -
List of supported Google Cloud networking proxies in the Project and
Location.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited