EgressNetworkConfig class

Constructors

EgressNetworkConfig({DnsPeeringConfig? dnsPeeringConfig, String? networkAttachment, String? trustConfig, String? vpcEgress})
EgressNetworkConfig.fromJson(Map json_)

Properties

dnsPeeringConfig DnsPeeringConfig?
DNS Peering configuration.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
networkAttachment String?
The network attachment resource name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trustConfig String?
Deprecated: Use tls_config instead.
getter/setter pair
vpcEgress String?
The VPC egress setting.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited