failOpen property
Determines the behavior of the extension binding when the call to the extension fails or times out.
Default value is FALSE. When set to TRUE, failures of the extension
are silently ignored.
Optional.
Implementation
core.bool? failOpen;