ExtensionBindingMatchConditionToDestination class
Describes properties of a single destination.
Constructors
-
ExtensionBindingMatchConditionToDestination({ExtensionBindingMatchConditionToDestinationHeaderSet? headerSet, List<
ExtensionBindingMatchConditionStringMatch> ? hosts, List<ExtensionBindingMatchConditionStringMatch> ? paths, List<ExtensionBindingMatchConditionStringMatch> ? resources}) - ExtensionBindingMatchConditionToDestination.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerSet ↔ ExtensionBindingMatchConditionToDestinationHeaderSet?
-
A set of HTTP headers to match against.
getter/setter pair
-
hosts
↔ List<
ExtensionBindingMatchConditionStringMatch> ? -
A list of HTTP Hosts to match against.
getter/setter pair
-
paths
↔ List<
ExtensionBindingMatchConditionStringMatch> ? -
A list of paths to match against.
getter/setter pair
-
resources
↔ List<
ExtensionBindingMatchConditionStringMatch> ? -
A list of non-empty strings whose value is matched against the resource to
which a request is sent (e.g., an Agent in AiApplication).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited