forwardAttributes property
List of the Envoy attributes to forward to the extension server.
The attributes provided here are included as part of the
ProcessingRequest.attributes field (of type map), where the keys are
the attribute names. Refer to the
documentation
for the names of attributes that can be forwarded. If omitted, no
attributes are sent. Each element is a string indicating the attribute
name.
Optional.
Implementation
core.List<core.String>? forwardAttributes;