multicastDomainActivation property
The resource name of the multicast domain activation that is in the same zone as this multicast consumer association.
Use the following format: projects / * /locations / * /multicastDomainActivations / * .
Optional.
Implementation
core.String? multicastDomainActivation;