uniqueId property
The Google-generated UUID for the resource.
This value is unique across all multicast consumer association resources. If a consumer association is deleted and another with the same name is created, the new consumer association is assigned a different unique_id.
Output only.
Implementation
core.String? uniqueId;