MulticastGroupConsumerActivation class
Multicast group consumer activation resource.
Constructors
-
MulticastGroupConsumerActivation({String? createTime, String? description, Map<
String, String> ? labels, MulticastLogConfig? logConfig, String? multicastConsumerAssociation, String? multicastGroup, String? multicastGroupRangeActivation, String? name, String? resourceState, MulticastResourceState? state, String? uniqueId, String? updateTime}) - MulticastGroupConsumerActivation.fromJson(Map json_)
Properties
- createTime ↔ String?
-
The timestamp when the multicast group consumer activation was created.
getter/setter pair
- description ↔ String?
-
An optional text description of the multicast group consumer activation.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
labels
↔ Map<
String, String> ? -
Labels as key-value pairs
getter/setter pair
- logConfig ↔ MulticastLogConfig?
-
Specifies the logging options for the activities performed related to the
multicast group consumer activation.
getter/setter pair
- multicastConsumerAssociation ↔ String?
-
The resource name of the multicast consumer association that is in the
same zone as this multicast group consumer activation.
getter/setter pair
- multicastGroup ↔ String?
-
The resource name of the multicast group created by the admin in the same
zone as this multicast group consumer activation.
getter/setter pair
- multicastGroupRangeActivation ↔ String?
-
The resource name of the multicast group range activation created by the
admin in the same zone as this multicast group consumer activation.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- resourceState ↔ String?
-
The resource state of the multicast group consumer activation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ MulticastResourceState?
-
The state of the resource.
getter/setter pair
- uniqueId ↔ String?
-
The Google-generated UUID for the resource.
getter/setter pair
- updateTime ↔ String?
-
The timestamp when the multicast group consumer activation was most
recently updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited