ProducerExtensionExtensionSettings class
The configuration for the service that this ProducerExtension offers.
Constructors
-
ProducerExtensionExtensionSettings({String? authority, bool? observabilityMode, String? service, List<
String> ? supportedEvents}) - ProducerExtensionExtensionSettings.fromJson(Map json_)
Properties
-
The
:authorityheader in the request sent to the extension service.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- observabilityMode ↔ bool?
-
Whether the extension should function in observability mode.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- service ↔ String?
-
URI of the PSC attachment.
getter/setter pair
-
supportedEvents
↔ List<
String> ? -
The event types supported by the extension.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited