ProjectsLocationsProducerExtensionsResource class
Constructors
- ProjectsLocationsProducerExtensionsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
ProducerExtension request, String parent, {String? producerExtensionId, String? $fields}) → Future< Operation> -
Creates a new
ProducerExtensionresource in a given project and location. -
delete(
String name, {String? etag, String? $fields}) → Future< Operation> -
Deletes the specified
ProducerExtensionresource. -
get(
String name, {String? $fields}) → Future< ProducerExtension> -
Gets details of the specified
ProducerExtensionresource. -
list(
String parent, {int? pageSize, String? pageToken, String? $fields}) → Future< ListProducerExtensionsResponse> -
Lists
ProducerExtensionresources in a given project and location. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited