ImageRelease class

ConfigImage represents an image release available to create a WbI

Constructors

ImageRelease({String? description, String? imageFamily, String? imageName, String? releaseName})
ImageRelease.fromJson(Map json_)

Properties

description String?
The description of the image.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageFamily String?
The image family of the image.
getter/setter pair
imageName String?
The name of the image of the form workbench-instances-vYYYYmmdd--
getter/setter pair
releaseName String?
The release of the image of the form m123
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited