imageFamily property
The Compute Engine image family resource name to upgrade to.
Format: projects/{project_id}/global/images/family/{image_family} If
specified, the instance will be upgraded to the latest image in the
specified image family, allowing upgrades across image families. If not
specified, the instance will be upgraded to the latest image in its
current image family.
Optional.
Implementation
core.String? imageFamily;