Settings class
Describes the settings associated with a project, organization, or folder.
Constructors
Properties
- defaultStorageLocation ↔ String?
-
The location which should be used when any regional resources are
provisioned by Google Cloud.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- kmsKeyName ↔ String?
-
The resource name for the configured Cloud KMS key.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceAccountId ↔ String?
-
The service account for the given resource container, such as project or
folder.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited