AzureDataLakeStorageIcebergStorage class
The Azure Data Lake Storage Iceberg storage.
Constructors
- AzureDataLakeStorageIcebergStorage({String? accountKeySecret, String? azureAccount, String? container, String? endpoint})
- AzureDataLakeStorageIcebergStorage.fromJson(Map json_)
Properties
- accountKeySecret ↔ String?
-
The account key of Azure Data Lake Storage.
getter/setter pair
- azureAccount ↔ String?
-
The account of Azure Data Lake Storage.
getter/setter pair
- container ↔ String?
-
The container of Azure Data Lake Storage.
getter/setter pair
- endpoint ↔ String?
-
The endpoint of Azure Data Lake Storage.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited