pluggableDatabaseId property
The ID of the pluggable database associated with the Database.
The ID must be unique within the project and location.
Optional.
Implementation
core.String? pluggableDatabaseId;
The ID of the pluggable database associated with the Database.
The ID must be unique within the project and location.
Optional.
core.String? pluggableDatabaseId;