DeploymentDiagnosticData class
The deployment diagnostic data.
Constructors
- DeploymentDiagnosticData({String? bucket, String? diagnosticEndTime, String? diagnosticStartTime, String? diagnosticState, String? namespace, String? object})
- DeploymentDiagnosticData.fromJson(Map json_)
Properties
- bucket ↔ String?
-
The bucket name.
getter/setter pair
- diagnosticEndTime ↔ String?
-
The time diagnostic end.
getter/setter pair
- diagnosticStartTime ↔ String?
-
The time diagnostic start.
getter/setter pair
- diagnosticState ↔ String?
-
The diagnostic state.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- namespace ↔ String?
-
The namespace name.
getter/setter pair
- object ↔ String?
-
The object name.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited