ExascaleConfig class
Details of the Exascale configuration for the Exadata Infrastructure.
Constructors
- ExascaleConfig({int? availableStorageSizeGb, int? availableVmStorageSizeGb, int? totalStorageSizeGb, int? totalVmStorageSizeGb})
- ExascaleConfig.fromJson(Map json_)
Properties
- availableStorageSizeGb ↔ int?
-
Available storage size for Exascale in GBs.
getter/setter pair
- availableVmStorageSizeGb ↔ int?
-
Available storage size for VM storage on Exascale in GBs.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalStorageSizeGb ↔ int?
-
Total storage size needed for Exascale in GBs.
getter/setter pair
- totalVmStorageSizeGb ↔ int?
-
Storage size needed for VM storage on Exascale in GBs.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited