GoldengateAmazonS3ConnectionProperties class
The properties of GoldengateAmazonS3Connection.
Constructors
- GoldengateAmazonS3ConnectionProperties({String? accessKeyId, String? endpoint, String? region, String? secretAccessKeySecret, String? technologyType})
- GoldengateAmazonS3ConnectionProperties.fromJson(Map json_)
Properties
- accessKeyId ↔ String?
-
Access key ID to access the Amazon S3 bucket.
getter/setter pair
- endpoint ↔ String?
-
The Amazon Endpoint for S3.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- region ↔ String?
-
The name of the AWS region where the bucket is created.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretAccessKeySecret ↔ String?
-
Secret access key to access the Amazon S3 bucket.
getter/setter pair
- technologyType ↔ String?
-
The technology type of AmazonS3Connection.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited