GoldengateAzureDataLakeStorageConnectionProperties class
The properties of GoldengateAzureDataLakeStorageConnection.
Constructors
- GoldengateAzureDataLakeStorageConnectionProperties({String? account, String? accountKeySecret, String? authenticationType, String? azureAuthorityHost, String? azureTenantId, String? clientId, String? clientSecret, String? endpoint, String? sasTokenSecret, String? technologyType})
- GoldengateAzureDataLakeStorageConnectionProperties.fromJson(Map json_)
Properties
- account ↔ String?
-
Sets the Azure storage account name.
getter/setter pair
- accountKeySecret ↔ String?
-
Azure storage account key.
getter/setter pair
- authenticationType ↔ String?
-
Authentication mechanism to access Azure Data Lake Storage.
getter/setter pair
- azureAuthorityHost ↔ String?
-
The endpoint used for authentication with Microsoft Entra ID (formerly
Azure Active Directory).
getter/setter pair
- azureTenantId ↔ String?
-
Azure tenant ID of the application.
getter/setter pair
- clientId ↔ String?
-
Azure client ID of the application.
getter/setter pair
- clientSecret ↔ String?
-
Azure client secret (aka application password) for authentication.
getter/setter pair
- endpoint ↔ String?
-
Azure Storage service endpoint.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sasTokenSecret ↔ String?
-
Credential that uses a shared access signature (SAS) to authenticate to an
Azure Service.
getter/setter pair
- technologyType ↔ String?
-
The technology type of AzureDataLakeStorageConnection.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited