GoldengateConnectionProperties class
The properties of a GoldengateConnection.
Constructors
-
GoldengateConnectionProperties({GoldengateAmazonKinesisConnectionProperties? amazonKinesisConnectionProperties, GoldengateAmazonRedshiftConnectionProperties? amazonRedshiftConnectionProperties, GoldengateAmazonS3ConnectionProperties? amazonS3ConnectionProperties, GoldengateAzureDataLakeStorageConnectionProperties? azureDataLakeStorageConnectionProperties, GoldengateAzureSynapseAnalyticsConnectionProperties? azureSynapseAnalyticsConnectionProperties, String? connectionType, GoldengateDatabricksConnectionProperties? databricksConnectionProperties, GoldengateDb2ConnectionProperties? db2ConnectionProperties, String? description, String? displayName, GoldengateElasticsearchConnectionProperties? elasticsearchConnectionProperties, GoldengateGenericConnectionProperties? genericConnectionProperties, GoldengateGoldengateConnectionProperties? goldengateConnectionProperties, GoldengateGoogleBigQueryConnectionProperties? googleBigQueryConnectionProperties, GoldengateGoogleCloudStorageConnectionProperties? googleCloudStorageConnectionProperties, GoldengateGooglePubsubConnectionProperties? googlePubsubConnectionProperties, GoldengateHdfsConnectionProperties? hdfsConnectionProperties, GoldengateIcebergConnectionProperties? icebergConnectionProperties, List<
String> ? ingressIpAddresses, GoldengateJavaMessageServiceConnectionProperties? javaMessageServiceConnectionProperties, GoldengateKafkaConnectionProperties? kafkaConnectionProperties, GoldengateKafkaSchemaRegistryConnectionProperties? kafkaSchemaRegistryConnectionProperties, String? lifecycleDetails, String? lifecycleState, GoldengateMicrosoftFabricConnectionProperties? microsoftFabricConnectionProperties, GoldengateMicrosoftSqlserverConnectionProperties? microsoftSqlserverConnectionProperties, GoldengateMongodbConnectionProperties? mongodbConnectionProperties, GoldengateMysqlConnectionProperties? mysqlConnectionProperties, GoldengateOciObjectStorageConnectionProperties? ociObjectStorageConnectionProperties, String? ocid, GoldengateOracleAIDataPlatformConnectionProperties? oracleAiDataPlatformConnectionProperties, GoldengateOracleConnectionProperties? oracleConnectionProperties, GoldengateOracleNosqlConnectionProperties? oracleNosqlConnectionProperties, GoldengatePostgresqlConnectionProperties? postgresqlConnectionProperties, GoldengateRedisConnectionProperties? redisConnectionProperties, String? routingMethod, GoldengateSnowflakeConnectionProperties? snowflakeConnectionProperties, String? updateTime}) - GoldengateConnectionProperties.fromJson(Map json_)
Properties
- amazonKinesisConnectionProperties ↔ GoldengateAmazonKinesisConnectionProperties?
-
Properties for an Amazon Kinesis connection.
getter/setter pair
- amazonRedshiftConnectionProperties ↔ GoldengateAmazonRedshiftConnectionProperties?
-
Properties for an Amazon Redshift connection.
getter/setter pair
- amazonS3ConnectionProperties ↔ GoldengateAmazonS3ConnectionProperties?
-
Properties for an Amazon S3 connection.
getter/setter pair
- azureDataLakeStorageConnectionProperties ↔ GoldengateAzureDataLakeStorageConnectionProperties?
-
Properties for an Azure Data Lake Storage Connection.
getter/setter pair
- azureSynapseAnalyticsConnectionProperties ↔ GoldengateAzureSynapseAnalyticsConnectionProperties?
-
Properties for an Azure Synapse Analytics connection.
getter/setter pair
- connectionType ↔ String?
-
The connection type.
getter/setter pair
- databricksConnectionProperties ↔ GoldengateDatabricksConnectionProperties?
-
Properties for a Databricks connection.
getter/setter pair
- db2ConnectionProperties ↔ GoldengateDb2ConnectionProperties?
-
Properties for a DB2 connection.
getter/setter pair
- description ↔ String?
-
Metadata about this specific object.
getter/setter pair
- displayName ↔ String?
-
An object's Display Name.
getter/setter pair
- elasticsearchConnectionProperties ↔ GoldengateElasticsearchConnectionProperties?
-
Properties for an Elasticsearch connection.
getter/setter pair
- genericConnectionProperties ↔ GoldengateGenericConnectionProperties?
-
Properties for a Generic Connection.
getter/setter pair
- goldengateConnectionProperties ↔ GoldengateGoldengateConnectionProperties?
-
Properties for a Goldengate Connection.
getter/setter pair
- googleBigQueryConnectionProperties ↔ GoldengateGoogleBigQueryConnectionProperties?
-
Properties for a Google BigQuery Connection.
getter/setter pair
- googleCloudStorageConnectionProperties ↔ GoldengateGoogleCloudStorageConnectionProperties?
-
Properties for a Google Cloud Storage Connection.
getter/setter pair
- googlePubsubConnectionProperties ↔ GoldengateGooglePubsubConnectionProperties?
-
Properties for a Google Pub/Sub connection.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hdfsConnectionProperties ↔ GoldengateHdfsConnectionProperties?
-
Properties for an HDFS connection.
getter/setter pair
- icebergConnectionProperties ↔ GoldengateIcebergConnectionProperties?
-
Properties for an Iceberg connection.
getter/setter pair
-
ingressIpAddresses
↔ List<
String> ? -
The Ingress IPs of the GoldengateConnection.
getter/setter pair
- javaMessageServiceConnectionProperties ↔ GoldengateJavaMessageServiceConnectionProperties?
-
Properties for a Java Message Service connection.
getter/setter pair
- kafkaConnectionProperties ↔ GoldengateKafkaConnectionProperties?
-
Properties for a Kafka Connection.
getter/setter pair
- kafkaSchemaRegistryConnectionProperties ↔ GoldengateKafkaSchemaRegistryConnectionProperties?
-
Properties for a Kafka Schema Registry Connection.
getter/setter pair
- lifecycleDetails ↔ String?
-
Describes the object's current state in detail.
getter/setter pair
- lifecycleState ↔ String?
-
The lifecycle state of the connection.
getter/setter pair
- microsoftFabricConnectionProperties ↔ GoldengateMicrosoftFabricConnectionProperties?
-
Properties for a Microsoft Fabric connection.
getter/setter pair
- microsoftSqlserverConnectionProperties ↔ GoldengateMicrosoftSqlserverConnectionProperties?
-
Properties for a Microsoft SQL Server connection.
getter/setter pair
- mongodbConnectionProperties ↔ GoldengateMongodbConnectionProperties?
-
Properties for a MongoDB connection.
getter/setter pair
- mysqlConnectionProperties ↔ GoldengateMysqlConnectionProperties?
-
Properties for a Mysql Connection.
getter/setter pair
- ocid ↔ String?
-
The [OCID] of the connection being referenced.
getter/setter pair
- ociObjectStorageConnectionProperties ↔ GoldengateOciObjectStorageConnectionProperties?
-
Properties for an OCI Object Storage Connection.
getter/setter pair
- oracleAiDataPlatformConnectionProperties ↔ GoldengateOracleAIDataPlatformConnectionProperties?
-
Properties for an Oracle AI Data Platform connection.
getter/setter pair
- oracleConnectionProperties ↔ GoldengateOracleConnectionProperties?
-
Properties for an Oracle Database Connection.
getter/setter pair
- oracleNosqlConnectionProperties ↔ GoldengateOracleNosqlConnectionProperties?
-
Properties for an Oracle NoSQL connection.
getter/setter pair
- postgresqlConnectionProperties ↔ GoldengatePostgresqlConnectionProperties?
-
Properties for a PostgreSQL connection.
getter/setter pair
- redisConnectionProperties ↔ GoldengateRedisConnectionProperties?
-
Properties for a Redis connection.
getter/setter pair
- routingMethod ↔ String?
-
The routing method for the GoldengateConnection.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snowflakeConnectionProperties ↔ GoldengateSnowflakeConnectionProperties?
-
Properties for a Snowflake connection.
getter/setter pair
- updateTime ↔ String?
-
The time the resource was last updated.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited