GoldengateConnectionType class
Details of the Goldengate Connection Type resource.
Constructors
-
GoldengateConnectionType({String? connectionType, String? name, List<
String> ? technologyTypes}) - GoldengateConnectionType.fromJson(Map json_)
Properties
- connectionType ↔ String?
-
The connection type of the Goldengate Connection Type resource.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
technologyTypes
↔ List<
String> ? -
The technology type of the Goldengate Connection Type resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited