GoldengateDatabricksConnectionProperties class
The properties of GoldengateDatabricksConnection.
Constructors
Properties
- authenticationType ↔ String?
-
Authentication type for Databricks.
getter/setter pair
- clientId ↔ String?
-
OAuth client id, only applicable for authentication_type == OAUTH_M2M
getter/setter pair
- clientSecret ↔ String?
-
OAuth client secret, only applicable for authentication_type == OAUTH_M2M
getter/setter pair
- connectionUrl ↔ String?
-
Connection URL.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- password ↔ String?
-
Input only.
getter/setter pair
- passwordSecretVersion ↔ String?
-
Input only.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageCredential ↔ String?
-
External storage credential name to access files on object storage such as
ADLS Gen2, S3 or Cloud Storage.
getter/setter pair
- technologyType ↔ String?
-
The technology type of DatabricksConnection.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited