GoldengateDeploymentEnvironment class
Details of the Goldengate Deployment Environment resource.
Constructors
- GoldengateDeploymentEnvironment({bool? autoScalingEnabled, String? category, int? defaultCpuCoreCount, String? displayName, String? environmentType, int? maxCpuCoreCount, int? memoryGbPerCpuCore, int? minCpuCoreCount, String? name, int? networkBandwidthGbpsPerCpuCore, int? storageUsageLimitGbPerCpuCore})
- GoldengateDeploymentEnvironment.fromJson(Map json_)
Properties
- autoScalingEnabled ↔ bool?
-
Whether auto scaling is enabled by default for the Goldengate Deployment
Environment resource.
getter/setter pair
- category ↔ String?
-
The category of the Goldengate Deployment Environment resource.
getter/setter pair
- defaultCpuCoreCount ↔ int?
-
The default CPU core count of the Goldengate Deployment Environment
resource.
getter/setter pair
- displayName ↔ String?
-
The display name of the Goldengate Deployment Environment resource.
getter/setter pair
- environmentType ↔ String?
-
The environment type of the Goldengate Deployment Environment resource.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxCpuCoreCount ↔ int?
-
The max CPU core count of the Goldengate Deployment Environment resource.
getter/setter pair
- memoryGbPerCpuCore ↔ int?
-
The memory per CPU core in GBs of the Goldengate Deployment Environment
resource.
getter/setter pair
- minCpuCoreCount ↔ int?
-
The min CPU core count of the Goldengate Deployment Environment resource.
getter/setter pair
- name ↔ String?
-
Identifier.
getter/setter pair
- networkBandwidthGbpsPerCpuCore ↔ int?
-
The network bandwidth per CPU core in Gbps of the Goldengate Deployment
Environment resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageUsageLimitGbPerCpuCore ↔ int?
-
The storage usage limit per CPU core in GBs of the Goldengate Deployment
Environment resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited