GoldengateDeploymentType class
Details of the Goldengate Deployment Type resource.
Constructors
-
GoldengateDeploymentType({String? category, List<
String> ? connectionTypes, String? defaultUsername, String? deploymentType, String? displayName, String? name, String? oggVersion, List<String> ? sourceTechnologies, List<String> ? supportedCapabilities, String? supportedTechnologiesUrl, List<String> ? targetTechnologies}) - GoldengateDeploymentType.fromJson(Map json_)
Properties
- category ↔ String?
-
The category of the Goldengate Deployment Type resource.
getter/setter pair
-
connectionTypes
↔ List<
String> ? -
The connection types of the Goldengate Deployment Type resource.
getter/setter pair
- defaultUsername ↔ String?
-
The default username of the Goldengate Deployment Type resource.
getter/setter pair
- deploymentType ↔ String?
-
The deployment type of the Goldengate Deployment Type resource.
getter/setter pair
- displayName ↔ String?
-
The display name of the Goldengate Deployment Type resource.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- name ↔ String?
-
Identifier.
getter/setter pair
- oggVersion ↔ String?
-
The Ogg version of the Goldengate Deployment Type resource.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sourceTechnologies
↔ List<
String> ? -
The source technologies of the Goldengate Deployment Type resource.
getter/setter pair
-
supportedCapabilities
↔ List<
String> ? -
The supported capabilities of the Goldengate Deployment Type resource.
getter/setter pair
- supportedTechnologiesUrl ↔ String?
-
The supported technologies URL of the Goldengate Deployment Type resource.
getter/setter pair
-
targetTechnologies
↔ List<
String> ? -
The target technologies of the Goldengate Deployment Type resource.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited