GoldengateGoogleCloudStorageConnectionProperties class
The properties of GoldengateGoogleCloudStorageConnectionProperties.
Constructors
- GoldengateGoogleCloudStorageConnectionProperties({String? serviceAccountKeyFile, String? technologyType})
- GoldengateGoogleCloudStorageConnectionProperties.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serviceAccountKeyFile ↔ String?
-
The base64 encoded content of the service account key file containing the
credentials required to use Google Cloud Storage.
getter/setter pair
- technologyType ↔ String?
-
The technology type.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited