GoldengateMicrosoftFabricConnectionProperties class
The properties of GoldengateMicrosoftFabricConnection.
Constructors
- GoldengateMicrosoftFabricConnectionProperties({String? clientId, String? clientSecret, String? endpoint, String? technologyType, String? tenantId})
- GoldengateMicrosoftFabricConnectionProperties.fromJson(Map json_)
Properties
- clientId ↔ String?
-
Azure client ID of the application.
getter/setter pair
- clientSecret ↔ String?
-
Client secret associated with the client id.
getter/setter pair
- endpoint ↔ String?
-
Optional Microsoft Fabric service endpoint.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- technologyType ↔ String?
-
The technology type of MicrosoftFabricConnection.
getter/setter pair
- tenantId ↔ String?
-
Azure tenant ID of the application.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited