GoldengateOracleConnectionProperties class
The properties of Goldengate Oracle Database Connection.
Constructors
- GoldengateOracleConnectionProperties({String? authenticationMode, String? connectionString, String? gcpOracleDatabaseId, String? password, String? passwordSecretVersion, String? sessionMode, String? technologyType, String? username, String? walletFile})
- GoldengateOracleConnectionProperties.fromJson(Map json_)
Properties
- authenticationMode ↔ String?
-
Authentication mode.
getter/setter pair
- connectionString ↔ String?
-
Connect descriptor or Easy Connect Naming method used to connect to a
database.
getter/setter pair
- gcpOracleDatabaseId ↔ String?
-
Autonomous AI Database instance id of database in Oracle Database @ Google
Cloud.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- password ↔ String?
-
Input only.
getter/setter pair
- passwordSecretVersion ↔ String?
-
Input only.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionMode ↔ String?
-
The mode of the database connection session to be established by the data
client.
getter/setter pair
- technologyType ↔ String?
-
The technology type.
getter/setter pair
- username ↔ String?
-
The username Oracle Goldengate uses to connect.
getter/setter pair
- walletFile ↔ String?
-
The wallet contents Oracle Goldengate uses to make connections to a
database.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited