GoldengatePostgresqlConnectionProperties class
The properties of GoldengatePostgresqlConnection.
Constructors
-
GoldengatePostgresqlConnectionProperties({List<
NameValuePair> ? additionalAttributes, String? database, String? dbSystemId, String? host, String? password, String? passwordSecretVersion, int? port, String? securityProtocol, String? sslCaFile, String? sslCertFile, String? sslCrlFile, String? sslKeyFile, String? sslMode, String? technologyType, String? username}) - GoldengatePostgresqlConnectionProperties.fromJson(Map json_)
Properties
-
additionalAttributes
↔ List<
NameValuePair> ? -
An array of name-value pair attribute entries.
getter/setter pair
- database ↔ String?
-
The name of the database.
getter/setter pair
- dbSystemId ↔ String?
-
The OCID of the database system being referenced.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String?
-
The name or address of a host.
getter/setter pair
- password ↔ String?
-
Input only.
getter/setter pair
- passwordSecretVersion ↔ String?
-
Input only.
getter/setter pair
- port ↔ int?
-
The port of an endpoint usually specified for a connection.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityProtocol ↔ String?
-
Security protocol for PostgreSQL.
getter/setter pair
- sslCaFile ↔ String?
-
The base64 encoded certificate of the trusted certificate authorities
(Trusted CA) for PostgreSQL.
getter/setter pair
- sslCertFile ↔ String?
-
The base64 encoded certificate of the PostgreSQL server.
getter/setter pair
- sslCrlFile ↔ String?
-
The base64 encoded list of certificates revoked by the trusted certificate
authorities (Trusted CA).
getter/setter pair
- sslKeyFile ↔ String?
-
The base64 encoded private key of the PostgreSQL server.
getter/setter pair
- sslMode ↔ String?
-
SSL modes for PostgreSQL.
getter/setter pair
- technologyType ↔ String?
-
The technology type of PostgresqlConnection.
getter/setter pair
- username ↔ String?
-
The username Oracle Goldengate uses to connect the associated system of
the given technology.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited