GoldengateSnowflakeConnectionProperties class
The properties of GoldengateSnowflakeConnection.
Constructors
- GoldengateSnowflakeConnectionProperties({String? authenticationType, String? connectionUrl, String? password, String? passwordSecretVersion, String? privateKeyFile, String? privateKeyPassphraseSecret, String? technologyType, String? username})
- GoldengateSnowflakeConnectionProperties.fromJson(Map json_)
Properties
- authenticationType ↔ String?
-
Used authentication mechanism to access Snowflake.
getter/setter pair
- connectionUrl ↔ String?
-
JDBC connection URL.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- password ↔ String?
-
Input only.
getter/setter pair
- passwordSecretVersion ↔ String?
-
Input only.
getter/setter pair
- privateKeyFile ↔ String?
-
The content of private key file in PEM format.
getter/setter pair
- privateKeyPassphraseSecret ↔ String?
-
Password if the private key file is encrypted.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- technologyType ↔ String?
-
The technology type of SnowflakeConnection.
getter/setter pair
- username ↔ String?
-
The username Oracle Goldengate uses to connect to Snowflake.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited