IcebergStorage class
The Iceberg storage details.
Constructors
- IcebergStorage({AmazonS3IcebergStorage? amazonS3IcebergStorage, AzureDataLakeStorageIcebergStorage? azureDataLakeStorageIcebergStorage, GoogleCloudStorageIcebergStorage? googleCloudStorageIcebergStorage, String? storageType})
- IcebergStorage.fromJson(Map json_)
Properties
- amazonS3IcebergStorage ↔ AmazonS3IcebergStorage?
-
The Amazon S3 Iceberg storage.
getter/setter pair
- azureDataLakeStorageIcebergStorage ↔ AzureDataLakeStorageIcebergStorage?
-
The Azure Data Lake Storage Iceberg storage.
getter/setter pair
- googleCloudStorageIcebergStorage ↔ GoogleCloudStorageIcebergStorage?
-
The Google Cloud Storage Iceberg storage.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- storageType ↔ String?
-
The type of Iceberg storage.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited