SourceConfig class
The source configuration for the standby Autonomous Database.
Constructors
- SourceConfig({int? autoRefreshFrequencySeconds, int? autoRefreshPointLagSeconds, String? autoRefreshStartTime, bool? automaticBackupsReplicationEnabled, String? autonomousDatabase, String? autonomousDatabaseBackup, String? backupTime, String? cloneType, String? refreshableMode, String? sourceType, bool? useLatestAvailableBackup})
- SourceConfig.fromJson(Map json_)
Properties
- automaticBackupsReplicationEnabled ↔ bool?
-
This field specifies if the replication of automatic backups is enabled
when creating a Data Guard.
getter/setter pair
- autonomousDatabase ↔ String?
-
The name of the primary Autonomous Database that is used to create a Peer
Autonomous Database from a source.
getter/setter pair
- autonomousDatabaseBackup ↔ String?
-
The name of the Autonomous Database Backup resource with the format:
projects/{project}/locations/{region}/autonomousDatabaseBackups/{autonomous_database_backup}
Required when source_type is BACKUP_FROM_ID.
getter/setter pair
- autoRefreshFrequencySeconds ↔ int?
-
The frequency in seconds a refreshable clone is refreshed after
auto-refresh is enabled.
getter/setter pair
- autoRefreshPointLagSeconds ↔ int?
-
The time, in seconds, the data of the automatic refreshable clone lags the
primary database at the point of refresh.
getter/setter pair
- autoRefreshStartTime ↔ String?
-
The date and time that auto-refreshing will begin for an Autonomous
Database refreshable clone.
getter/setter pair
- backupTime ↔ String?
-
The timestamp specified for the point-in-time clone of the source
Autonomous Database.
getter/setter pair
- cloneType ↔ String?
-
The clone type of the Autonomous Database.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- refreshableMode ↔ String?
-
The refresh mode of the clone.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceType ↔ String?
-
The source type of the Autonomous Database.
getter/setter pair
- useLatestAvailableBackup ↔ bool?
-
Clone from latest available backup timestamp.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited