cloneType property
The clone type of the Autonomous Database.
This field is only applicable in case of cloning
Optional. Possible string values are:
- "CLONE_TYPE_UNSPECIFIED" : Default unspecified value.
- "FULL" : Creates a new database with the source database's data and metadata.
- "METADATA" : Creates a new database that includes all the source database schema metadata, but none of the source database data.
Implementation
core.String? cloneType;