TestConnectionAssignmentError class

Error details for TestGoldengateConnectionAssignment.

Constructors

TestConnectionAssignmentError({String? action, String? code, String? issue, String? message})
TestConnectionAssignmentError.fromJson(Map json_)

Properties

action String?
The text describing the action required to fix the issue.
getter/setter pair
code String?
A short error code that defines the error, meant for programmatic parsing.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
issue String?
The text describing the root cause of the reported issue.
getter/setter pair
message String?
A human-readable error message.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited