ProjectsLocationsTemplatesResource class
Methods
-
create(Template request, String parent, {String? requestId, String? templateId, String? $fields})
→ Future<Template>
-
Creates a new Template in a given project and location.
-
delete(String name, {String? requestId, String? $fields})
→ Future<Empty>
-
Deletes a single Template.
-
get(String name, {String? $fields})
→ Future<Template>
-
Gets details of a single Template.
-
list(String parent, {String? filter, String? orderBy, int? pageSize, String? pageToken, String? $fields})
→ Future<ListTemplatesResponse>
-
Lists Templates in a given project and location.
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
patch(Template request, String name, {String? requestId, String? updateMask, String? $fields})
→ Future<Template>
-
Updates a single Template.
-
toString()
→ String
-
A string representation of this object.
inherited