GoogleMapsPlacesV1TransitLine class
Represents a single transit line.
Constructors
- GoogleMapsPlacesV1TransitLine({String? backgroundColor, GoogleTypeLocalizedText? displayName, GoogleMapsPlacesV1TransitIcon? icon, String? id, GoogleTypeLocalizedText? shortDisplayName, String? textColor, String? url, GoogleMapsPlacesV1TransitIcon? vehicleIcon, String? vehicleType})
- GoogleMapsPlacesV1TransitLine.fromJson(Map json_)
Properties
- backgroundColor ↔ String?
-
The background color of the labels for this transit line in #RRGGBB hex
format, e.g. #909CE1.
getter/setter pair
- displayName ↔ GoogleTypeLocalizedText?
-
The long name for this transit line (e.g. "Sunnydale local").
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ GoogleMapsPlacesV1TransitIcon?
-
Icon identifier for this particular line (e.g. subway lines in New York).
getter/setter pair
- id ↔ String?
-
The id of the transit line that can be used to uniquely identify the line
among other transit lines in the same transit station.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortDisplayName ↔ GoogleTypeLocalizedText?
-
The short name for this transit line (e.g. "S2").
getter/setter pair
- textColor ↔ String?
-
The text color of labels for this transit line in #RRGGBB hex format, e.g.
#909CE1.
getter/setter pair
- url ↔ String?
-
The URL of a webpage with details about this line.
getter/setter pair
- vehicleIcon ↔ GoogleMapsPlacesV1TransitIcon?
-
Icon identifier for this particular vehicle type.
getter/setter pair
- vehicleType ↔ String?
-
The type of vehicle using this line.
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited