GoogleMapsPlacesV1TransitStop class
Represents a transit stop within a station.
This is a specific location where passengers board and alight transit
vehicles, such as a platform or bus bay. This is distinct from a
Departure, which is an event of a vehicle leaving a stop at a specific
time.
Constructors
- GoogleMapsPlacesV1TransitStop({GoogleTypeLocalizedText? displayName, String? id, GoogleTypeLatLng? location, GoogleTypeLocalizedText? platformCode, GoogleTypeLocalizedText? signageText, GoogleTypeLocalizedText? stopCode, bool? wheelchairAccessibleEntrance})
- GoogleMapsPlacesV1TransitStop.fromJson(Map json_)
Properties
- displayName ↔ GoogleTypeLocalizedText?
-
The name of the stop.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The id of the transit stop that can be used to uniquely identify the stop
among other transit stops in the same transit station.
getter/setter pair
- location ↔ GoogleTypeLatLng?
-
The stop's location.
getter/setter pair
- platformCode ↔ GoogleTypeLocalizedText?
-
The platform code represented by this stop.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signageText ↔ GoogleTypeLocalizedText?
-
The verbatim text written on the signboard for this platform, e.g.
"Towards Central" or "East side & Brooklyn".
getter/setter pair
- stopCode ↔ GoogleTypeLocalizedText?
-
Human readable identifier of the stop, used by transit agencies to
distinguish stops with the same name.
getter/setter pair
- wheelchairAccessibleEntrance ↔ bool?
-
Wheelchair accessibility of this stop.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited