stopCode property
Human readable identifier of the stop, used by transit agencies to distinguish stops with the same name.
Implementation
GoogleTypeLocalizedText? stopCode;
Human readable identifier of the stop, used by transit agencies to distinguish stops with the same name.
GoogleTypeLocalizedText? stopCode;