allowRequesterSpecifiedNotBeforeTime property
If set to true, allows requesters to specify the requested_not_before_time field when creating a Certificate.
Certificates requested with this option enabled will have a 'not_before_time' equal to the value specified in the request. The 'not_after_time' will be adjusted to preserve the requested lifetime. The maximum time that a certificate can be backdated with these options is 48 hours in the past. This option cannot be set if backdate_duration is set.
Optional.
Implementation
core.bool? allowRequesterSpecifiedNotBeforeTime;