state property
An output-only field that indicates the state of the Event Hubs ingestion source.
Output only. Possible string values are:
- "STATE_UNSPECIFIED" : Default value. This value is unused.
- "ACTIVE" : Ingestion is active.
- "EVENT_HUBS_PERMISSION_DENIED" : Permission denied encountered while
consuming data from Event Hubs. This can happen when
client_id, ortenant_idare invalid. Or the right permissions haven't been granted. - "PUBLISH_PERMISSION_DENIED" : Permission denied encountered while publishing to the topic.
- "NAMESPACE_NOT_FOUND" : The provided Event Hubs namespace couldn't be found.
- "EVENT_HUB_NOT_FOUND" : The provided Event Hub couldn't be found.
- "SUBSCRIPTION_NOT_FOUND" : The provided Event Hubs subscription couldn't be found.
- "RESOURCE_GROUP_NOT_FOUND" : The provided Event Hubs resource group couldn't be found.
- "CONFLICTING_REGION_CONSTRAINTS" : Indicates an error state where the ingestion source cannot be processed because the selected ingestion region is not permitted by the Regional Access Boundary (RAB) restrictions on the project's service account.
Implementation
core.String? state;