dropUnknownFields property
If true and use_topic_schema is true, drops any fields that are part of
the topic schema that are not part of the BigQuery table schema when
writing to BigQuery.
Otherwise, the schemas must be kept in sync and any messages with extra
fields are not written and remain in the subscription's backlog. If true
and use_table_schema is true, drops any fields in the message that are
not part of the BigQuery table schema when writing to BigQuery. Otherwise,
the write to BigQuery will fail.
Optional.
Implementation
core.bool? dropUnknownFields;