create method
Create an Instance.
request - The metadata request object.
Request parameters:
parent - Required. The resource's parent. In Cloud Run, it may be one of
the following: * {project_id_or_number} *
namespaces/{project_id_or_number} *
namespaces/{project_id_or_number}/instances *
projects/{project_id_or_number}/locations/{region} *
projects/{project_id_or_number}/regions/{region} Parent resource
namespace.
Value must have pattern ^namespaces/\[^/\]+$.
dryRun - Optional. Indicates that the server should validate the request
and populate default values without persisting the request. Supported
values: all
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Instance.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Instance> create(
Instance request,
core.String parent, {
core.String? dryRun,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'dryRun': ?dryRun == null ? null : [dryRun],
'fields': ?$fields == null ? null : [$fields],
};
final url_ =
'apis/run.googleapis.com/v1/' +
core.Uri.encodeFull('$parent') +
'/instances';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return Instance.fromJson(response_ as core.Map<core.String, core.dynamic>);
}