replaceInstance method
Replace an Instance.
request - The metadata request object.
Request parameters:
name - Required. The fully qualified name of the Instance being
replaced. It can be any of the following forms: *
namespaces/{project_id_or_number}/instances/{instance_name} (only when
the endpoint is regional) *
projects/{project_id_or_number}/locations/{region}/instances/{instance_name}
*
projects/{project_id_or_number}/regions/{region}/instances/{instance_name}
Parent resource namespace.
Value must have pattern ^namespaces/\[^/\]+/instances/\[^/\]+$.
dryRun - Optional. Indicates that the server should validate the request
and populate default values without persisting the request. Supported
values: all
$fields - Selector specifying which fields to include in a partial
response.
Completes with a Instance.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<Instance> replaceInstance(
Instance request,
core.String name, {
core.String? dryRun,
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'dryRun': ?dryRun == null ? null : [dryRun],
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'apis/run.googleapis.com/v1/' + core.Uri.encodeFull('$name');
final response_ = await _requester.request(
url_,
'PUT',
body: body_,
queryParams: queryParams_,
);
return Instance.fromJson(response_ as core.Map<core.String, core.dynamic>);
}