CustomersCustomColumnsResource class
Constructors
- CustomersCustomColumnsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
String resourceName, {String? $fields}) → Future< GoogleAdsSearchads360V23ResourcesCustomColumn> - Returns the requested custom column in full detail.
-
list(
String customerId, {String? $fields}) → Future< GoogleAdsSearchads360V23ServicesListCustomColumnsResponse> - Returns all the custom columns associated with the customer in full detail.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited