endExperiment method
- GoogleAdsSearchads360V23ServicesEndExperimentRequest request,
- String experiment, {
- String? $fields,
Immediately ends an experiment, changing the experiment's scheduled end date and without waiting for end of day.
End date is updated to be the time of the request. List of thrown errors: [AuthenticationError]() [AuthorizationError]() [ExperimentError]() [HeaderError]() [InternalError]() [QuotaError]() [RequestError]()
request - The metadata request object.
Request parameters:
experiment - Required. The resource name of the campaign experiment to
end.
Value must have pattern ^customers/\[^/\]+/experiments/\[^/\]+$.
$fields - Selector specifying which fields to include in a partial
response.
Completes with a GoogleProtobufEmpty.
Completes with a commons.ApiRequestError if the API endpoint returned an error.
If the used http.Client completes with an error when making a REST call,
this method will complete with the same error.
Implementation
async.Future<GoogleProtobufEmpty> endExperiment(
GoogleAdsSearchads360V23ServicesEndExperimentRequest request,
core.String experiment, {
core.String? $fields,
}) async {
final body_ = convert.json.encode(request);
final queryParams_ = <core.String, core.List<core.String>>{
'fields': ?$fields == null ? null : [$fields],
};
final url_ = 'v23/' + core.Uri.encodeFull('$experiment') + ':endExperiment';
final response_ = await _requester.request(
url_,
'POST',
body: body_,
queryParams: queryParams_,
);
return GoogleProtobufEmpty.fromJson(
response_ as core.Map<core.String, core.dynamic>,
);
}