CustomersOfflineUserDataJobsResource class
Constructors
- CustomersOfflineUserDataJobsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addOperations(
GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsRequest request, String resourceName, {String? $fields}) → Future< GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsResponse> - Adds operations to the offline user data job.
-
create(
GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobRequest request, String customerId, {String? $fields}) → Future< GoogleAdsSearchads360V23ServicesCreateOfflineUserDataJobResponse> - Creates an offline user data job.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
GoogleAdsSearchads360V23ServicesRunOfflineUserDataJobRequest request, String resourceName, {String? $fields}) → Future< GoogleLongrunningOperation> - Runs the offline user data job.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited