CustomersProductLinkInvitationsResource class
Constructors
- CustomersProductLinkInvitationsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
create(
GoogleAdsSearchads360V23ServicesCreateProductLinkInvitationRequest request, String customerId, {String? $fields}) → Future< GoogleAdsSearchads360V23ServicesCreateProductLinkInvitationResponse> - Creates a product link invitation.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
remove(
GoogleAdsSearchads360V23ServicesRemoveProductLinkInvitationRequest request, String customerId, {String? $fields}) → Future< GoogleAdsSearchads360V23ServicesRemoveDataLinkResponse> - Remove a product link invitation.
-
toString(
) → String -
A string representation of this object.
inherited
-
update(
GoogleAdsSearchads360V23ServicesUpdateProductLinkInvitationRequest request, String customerId, {String? $fields}) → Future< GoogleAdsSearchads360V23ServicesUpdateProductLinkInvitationResponse> - Update a product link invitation.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited