CustomersSmartCampaignSettingsResource class
Constructors
- CustomersSmartCampaignSettingsResource(ApiRequester client)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getSmartCampaignStatus(
String resourceName, {String? $fields}) → Future< GoogleAdsSearchads360V23ServicesGetSmartCampaignStatusResponse> - Returns the status of the requested Smart campaign.
-
mutate(
GoogleAdsSearchads360V23ServicesMutateSmartCampaignSettingsRequest request, String customerId, {String? $fields}) → Future< GoogleAdsSearchads360V23ServicesMutateSmartCampaignSettingsResponse> - Updates Smart campaign settings for campaigns.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited