GoogleAdsSearchads360V23ResourcesAndroidPrivacySharedKeyGoogleNetworkType class
An Android privacy shared key view for Google network type key.
Constructors
Properties
- androidPrivacyInteractionDate ↔ String?
-
The interaction date used in the shared key encoding in the format of
"YYYY-MM-DD" in UTC timezone.
getter/setter pair
- androidPrivacyInteractionType ↔ String?
-
The interaction type enum used in the share key encoding.
getter/setter pair
- androidPrivacyNetworkType ↔ String?
-
The network type enum used in the share key encoding.
getter/setter pair
- campaignId ↔ String?
-
The campaign ID used in the share key encoding.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- resourceName ↔ String?
-
The resource name of the Android privacy shared key.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
128 bit hex string of the encoded shared network type key, including a
'0x' prefix.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited