GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsRequest class
Request message for OfflineUserDataJobService.AddOfflineUserDataJobOperations.
Constructors
-
GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsRequest({bool? enablePartialFailure, bool? enableWarnings, List<
GoogleAdsSearchads360V23ServicesOfflineUserDataJobOperation> ? operations, bool? validateOnly}) - GoogleAdsSearchads360V23ServicesAddOfflineUserDataJobOperationsRequest.fromJson(Map json_)
Properties
- enablePartialFailure ↔ bool?
-
True to enable partial failure for the offline user data job.
getter/setter pair
- enableWarnings ↔ bool?
-
True to enable warnings for the offline user data job.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
operations
↔ List<
GoogleAdsSearchads360V23ServicesOfflineUserDataJobOperation> ? -
The list of operations to be done.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- validateOnly ↔ bool?
-
If true, the request is validated but not executed.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited