policyMember property
Defines the policy member for the secret.
This will be used to check if the caller has the permission to perform certain operations on the typed secret.
Output only.
Implementation
ResourcePolicyMember? policyMember;
Defines the policy member for the secret.
This will be used to check if the caller has the permission to perform certain operations on the typed secret.
Output only.
ResourcePolicyMember? policyMember;