securitycenter/v1 library
Security Command Center API - v1
Security Command Center API provides access to temporal views of assets and findings within an organization.
For more information, see cloud.google.com/security-command-center
Create an instance of SecurityCommandCenterApi to access these resources:
- FoldersResource
- FoldersSecurityHealthAnalyticsSettingsEffectiveCustomModulesResource
- OrganizationsResource
- OrganizationsEventThreatDetectionSettingsEffectiveCustomModulesResource
OrganizationsSecurityHealthAnalyticsSettingsEffectiveCustomModulesResource
- OrganizationsSimulationsResource
- OrganizationsSimulationsAttackExposureResultsValuedResourcesResource
- ProjectsResource
- ProjectsSecurityHealthAnalyticsSettingsEffectiveCustomModulesResource
Classes
- Access
- AccessReview
- AdaptiveProtection
- AdcApplication
- AffectedResources
- AgentAnomaly
- AgentDataAccessEvent
- AgentSession
- AiModel
- Allowed
- Application
- ArtifactGuardPolicies
- ArtifactGuardPolicy
- Asset
- AssetDiscoveryConfig
- Attack
- AttackExposure
- AttackPath
- AttackPathEdge
- AttackPathNode
- AttackStepNode
- AuditConfig
- AuditLogConfig
- AwsMetadata
- AzureMetadata
- BackupDisasterRecovery
- BatchCreateResourceValueConfigsRequest
- BatchCreateResourceValueConfigsResponse
- Binding
- BulkMuteFindingsRequest
- Chokepoint
- CloudArmor
- CloudControl
- CloudDlpDataProfile
- CloudDlpInspection
- CloudLoggingEntry
- Compliance
- ComplianceDetails
- Connection
- ContactDetails
- Container
- Control
- CreateResourceValueConfigRequest
- CustomModuleValidationError
- CustomModuleValidationErrors
- Cve
- Cvssv3
- Cwe
- DataAccessEvent
- Database
- DataFlowEvent
- DataRetentionDeletionEvent
- Dataset
- Denied
- Detection
- DetectorReference
- DiscoveredWorkload
- DiskPath
- DynamicMuteRecord
- EffectiveEventThreatDetectionCustomModule
- EnvironmentVariable
- EventThreatDetectionCustomModule
- ExfilResource
- Exfiltration
- Expr
- ExternalExposure
- File
- FileOperation
- Finding
- Folder
- FoldersAssetsResource
- FoldersBigQueryExportsResource
- FoldersEventThreatDetectionSettingsCustomModulesResource
- FoldersEventThreatDetectionSettingsEffectiveCustomModulesResource
- FoldersEventThreatDetectionSettingsResource
- FoldersFindingsResource
- FoldersLocationsMuteConfigsResource
- FoldersLocationsResource
- FoldersMuteConfigsResource
- FoldersNotificationConfigsResource
- FoldersResource
- FoldersSecurityHealthAnalyticsSettingsCustomModulesResource
- FoldersSecurityHealthAnalyticsSettingsEffectiveCustomModulesResource
- FoldersSecurityHealthAnalyticsSettingsResource
- FoldersSourcesFindingsExternalSystemsResource
- FoldersSourcesFindingsResource
- FoldersSourcesResource
- Framework
- Geolocation
- GetIamPolicyRequest
- GetPolicyOptions
- GoogleCloudSecuritycenterV1BigQueryExport
- GoogleCloudSecuritycenterV1Binding
- GoogleCloudSecuritycenterV1CustomConfig
- GoogleCloudSecuritycenterV1CustomOutputSpec
- GoogleCloudSecuritycenterV1EffectiveSecurityHealthAnalyticsCustomModule
- GoogleCloudSecuritycenterV1ExternalSystem
- GoogleCloudSecuritycenterV1IamDetails
- GoogleCloudSecuritycenterV1IamRolePermission
- GoogleCloudSecuritycenterV1MuteConfig
- GoogleCloudSecuritycenterV1Property
- GoogleCloudSecuritycenterV1ResourceApplication
- GoogleCloudSecuritycenterV1ResourceApplicationAttributes
- GoogleCloudSecuritycenterV1ResourceApplicationAttributesCriticality
- GoogleCloudSecuritycenterV1ResourceApplicationAttributesEnvironment
- GoogleCloudSecuritycenterV1ResourceSelector
- GoogleCloudSecuritycenterV1ResourceValueConfig
- GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule
- GoogleCloudSecuritycenterV1SensitiveDataProtectionMapping
- GroupAssetsRequest
- GroupAssetsResponse
- GroupFindingsRequest
- GroupFindingsResponse
- GroupMembership
- GroupResult
- HttpResponse
- IamBinding
- IamPolicy
- Indicator
- InfoType
- InvocationReference
- IpRule
- IpRules
- Job
- KernelRootkit
- Kubernetes
- ListAssetsResponse
- ListAssetsResult
- ListAttackPathsResponse
- ListBigQueryExportsResponse
- ListDescendantEventThreatDetectionCustomModulesResponse
- ListDescendantSecurityHealthAnalyticsCustomModulesResponse
- ListEffectiveEventThreatDetectionCustomModulesResponse
- ListEffectiveSecurityHealthAnalyticsCustomModulesResponse
- ListEventThreatDetectionCustomModulesResponse
- ListFindingsResponse
- ListFindingsResult
- ListMuteConfigsResponse
- ListNotificationConfigsResponse
- ListOperationsResponse
- ListResourceValueConfigsResponse
- ListSecurityHealthAnalyticsCustomModulesResponse
- ListSourcesResponse
- ListValuedResourcesResponse
- LogEntry
- MemoryHashSignature
- MitreAttack
- MuteInfo
- NodePool
- Notebook
- NotificationConfig
- Object
- Operation
- OrganizationsAssetsResource
- OrganizationsAttackPathsResource
- OrganizationsBigQueryExportsResource
- OrganizationSettings
- OrganizationsEventThreatDetectionSettingsCustomModulesResource
- OrganizationsEventThreatDetectionSettingsEffectiveCustomModulesResource
- OrganizationsEventThreatDetectionSettingsResource
- OrganizationsFindingsResource
- OrganizationsLocationsMuteConfigsResource
- OrganizationsLocationsResource
- OrganizationsMuteConfigsResource
- OrganizationsNotificationConfigsResource
- OrganizationsOperationsResource
- OrganizationsResource
- OrganizationsResourceValueConfigsResource
- OrganizationsSecurityHealthAnalyticsSettingsCustomModulesResource
- OrganizationsSecurityHealthAnalyticsSettingsEffectiveCustomModulesResource
- OrganizationsSecurityHealthAnalyticsSettingsResource
- OrganizationsSimulationsAttackExposureResultsAttackPathsResource
- OrganizationsSimulationsAttackExposureResultsResource
- OrganizationsSimulationsAttackExposureResultsValuedResourcesResource
- OrganizationsSimulationsAttackPathsResource
- OrganizationsSimulationsResource
- OrganizationsSimulationsValuedResourcesAttackPathsResource
- OrganizationsSimulationsValuedResourcesResource
- OrganizationsSourcesFindingsExternalSystemsResource
- OrganizationsSourcesFindingsResource
- OrganizationsSourcesResource
- OrganizationsValuedResourcesResource
- Package
- PathNodeAssociatedFinding
- Pod
- Policy
- PolicyDriftDetails
- PolicyViolationSummary
- PortRange
- Position
- Process
- ProcessSignature
- ProjectsAssetsResource
- ProjectsBigQueryExportsResource
- ProjectsEventThreatDetectionSettingsCustomModulesResource
- ProjectsEventThreatDetectionSettingsEffectiveCustomModulesResource
- ProjectsEventThreatDetectionSettingsResource
- ProjectsFindingsResource
- ProjectsLocationsMuteConfigsResource
- ProjectsLocationsResource
- ProjectsMuteConfigsResource
- ProjectsNotificationConfigsResource
- ProjectsResource
- ProjectsSecurityHealthAnalyticsSettingsCustomModulesResource
- ProjectsSecurityHealthAnalyticsSettingsEffectiveCustomModulesResource
- ProjectsSecurityHealthAnalyticsSettingsResource
- ProjectsSourcesFindingsExternalSystemsResource
- ProjectsSourcesFindingsResource
- ProjectsSourcesResource
- Reference
- Requests
- Resource
- ResourcePath
- ResourcePathNode
- Role
- Secret
- SecretEnvironmentVariable
- SecretFilePath
- SecretStatus
- SecurityBulletin
- SecurityCenterProperties
- SecurityCommandCenterApi
- Security Command Center API provides access to temporal views of assets and findings within an organization.
- SecurityMarks
- SecurityPolicy
- SecurityPosture
- SensitivityScore
- ServiceAccountDelegationInfo
- SetFindingStateRequest
- SetIamPolicyRequest
- SetMuteRequest
- SimulatedResource
- SimulatedResult
- SimulateSecurityHealthAnalyticsCustomModuleRequest
- SimulateSecurityHealthAnalyticsCustomModuleResponse
- Simulation
- Source
- StaticMute
- StreamingConfig
- Subject
- TicketInfo
- ToxicCombination
- ValidateEventThreatDetectionCustomModuleRequest
- ValidateEventThreatDetectionCustomModuleResponse
- ValuedResource
- VertexAi
- Vulnerability
- YaraRuleSignature
Typedefs
- AdcApplicationTemplateRevision = $Shared00
- Agent = $Shared08
- AwsAccount = $Shared05
- AwsOrganization = $Shared02
- AwsOrganizationalUnit = $Shared05
- AzureManagementGroup = $Shared08
- AzureResourceGroup = $Shared05
- AzureSubscription = $Shared08
- AzureTenant = $Shared08
- Contact = $Shared30
- Disk = $Shared00
- Empty = $Empty
- GoogleCloudSecuritycenterV1ResourceApplicationAttributesContactInfo = $Shared30
- Label = $Shared09
- LoadBalancer = $Shared00
- Network = $Shared00
- Node = $Shared00
- OrgPolicy = $Shared00
- Pipeline = $Shared23
- ResourceValueConfigMetadata = $Shared00
- RunAssetDiscoveryRequest = $Empty
- Status = $Status01
- TestIamPermissionsRequest = $Shared31
- TestIamPermissionsResponse = $Shared31
Exceptions / Errors
- ApiRequestError
- Represents a general error reported by the API endpoint.
- DetailedApiRequestError
- Represents a specific error reported by the API endpoint.