Access class

Constructors

Access({String? callerIp, Geolocation? callerIpGeo, String? methodName, String? principalEmail, String? principalSubject, List<ServiceAccountDelegationInfo>? serviceAccountDelegationInfo, String? serviceAccountKeyName, String? serviceName, String? userAgent, String? userAgentFamily, String? userName})
Access.fromJson(Map json_)

Properties

callerIp String?
getter/setter pair
callerIpGeo Geolocation?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
methodName String?
getter/setter pair
principalEmail String?
getter/setter pair
principalSubject String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceAccountDelegationInfo List<ServiceAccountDelegationInfo>?
getter/setter pair
serviceAccountKeyName String?
getter/setter pair
serviceName String?
getter/setter pair
userAgent String?
getter/setter pair
userAgentFamily String?
getter/setter pair
userName String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited