AccessReview class

Conveys information about a Kubernetes access review (such as one returned by a [kubectl auth can-i](https://kubernetes.io/docs/reference/access-authn-authz/authorization/#checking-api-access) command) that was involved in a finding.

Constructors

AccessReview({String? group, String? name, String? ns, String? resource, String? subresource, String? verb, String? version})
AccessReview.fromJson(Map json_)

Properties

group ↔ String?
The API group of the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
The name of the resource being requested.
getter/setter pair
ns ↔ String?
Namespace of the action being requested.
getter/setter pair
resource ↔ String?
The optional resource type requested.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subresource ↔ String?
The optional subresource type.
getter/setter pair
verb ↔ String?
A Kubernetes resource API verb, like get, list, watch, create, update, delete, proxy.
getter/setter pair
version ↔ String?
The API version of the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited