Asset class
Constructors
-
Asset({String? canonicalName, String? createTime, IamPolicy? iamPolicy, String? name, Map<
String, Object?> ? resourceProperties, SecurityCenterProperties? securityCenterProperties, SecurityMarks? securityMarks, String? updateTime}) - Asset.fromJson(Map json_)
Properties
- canonicalName ↔ String?
-
getter/setter pair
- createTime ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- iamPolicy ↔ IamPolicy?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
-
resourceProperties
↔ Map<
String, Object?> ? -
The values for Object must be JSON objects. It can consist of
num,String,boolandnullas well asMapandListvalues.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- securityCenterProperties ↔ SecurityCenterProperties?
-
getter/setter pair
- securityMarks ↔ SecurityMarks?
-
getter/setter pair
- updateTime ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited