Asset class

Security Command Center representation of a Google Cloud resource.

The Asset is a Security Command Center resource that captures information about a single Google Cloud resource. All modifications to an Asset are only within the context of Security Command Center and don't affect the referenced Google Cloud resource.

Constructors

Asset({String? canonicalName, String? createTime, IamPolicy? iamPolicy, String? name, Map<String, Object?>? resourceProperties, SecurityCenterProperties? securityCenterProperties, SecurityMarks? securityMarks, String? updateTime})
Asset.fromJson(Map json_)

Properties

canonicalName ↔ String?
The canonical name of the resource.
getter/setter pair
createTime ↔ String?
The time at which the asset was created in Security Command Center.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iamPolicy ↔ IamPolicy?
Cloud IAM Policy information associated with the Google Cloud resource described by the Security Command Center asset.
getter/setter pair
name ↔ String?
The relative resource name of this asset.
getter/setter pair
resourceProperties ↔ Map<String, Object?>?
Resource managed properties.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
securityCenterProperties ↔ SecurityCenterProperties?
Security Command Center managed properties.
getter/setter pair
securityMarks ↔ SecurityMarks?
User specified security marks.
getter/setter pair
updateTime ↔ String?
The time at which the asset was last updated or added in Cloud SCC.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited