Attack class

Information about DDoS attack volume and classification.

Constructors

Attack({String? classification, int? volumeBps, String? volumeBpsLong, int? volumePps, String? volumePpsLong})
Attack.fromJson(Map json_)

Properties

classification ↔ String?
Type of attack, for example, 'SYN-flood', 'NTP-udp', or 'CHARGEN-udp'.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
volumeBps ↔ int?
Total BPS (bytes per second) volume of attack.
getter/setter pair
volumeBpsLong ↔ String?
Total BPS (bytes per second) volume of attack.
getter/setter pair
volumePps ↔ int?
Total PPS (packets per second) volume of attack.
getter/setter pair
volumePpsLong ↔ String?
Total PPS (packets per second) volume of attack.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited