AttackExposure class

An attack exposure contains the results of an attack path simulation run.

Constructors

AttackExposure({String? attackExposureResult, int? exposedHighValueResourcesCount, int? exposedLowValueResourcesCount, int? exposedMediumValueResourcesCount, String? latestCalculationTime, double? score, String? state})
AttackExposure.fromJson(Map json_)

Properties

attackExposureResult ↔ String?
The resource name of the attack path simulation result that contains the details regarding this attack exposure score.
getter/setter pair
exposedHighValueResourcesCount ↔ int?
The number of high value resources that are exposed as a result of this finding.
getter/setter pair
exposedLowValueResourcesCount ↔ int?
The number of high value resources that are exposed as a result of this finding.
getter/setter pair
exposedMediumValueResourcesCount ↔ int?
The number of medium value resources that are exposed as a result of this finding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
latestCalculationTime ↔ String?
The most recent time the attack exposure was updated on this finding.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
score ↔ double?
A number between 0 (inclusive) and infinity that represents how important this finding is to remediate.
getter/setter pair
state ↔ String?
What state this AttackExposure is in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited