AttackPathNode class

Constructors

AttackPathNode({List<PathNodeAssociatedFinding>? associatedFindings, List<AttackStepNode>? attackSteps, String? displayName, String? resource, String? resourceType, String? uuid})
AttackPathNode.fromJson(Map json_)

Properties

associatedFindings ↔ List<PathNodeAssociatedFinding>?
getter/setter pair
attackSteps ↔ List<AttackStepNode>?
getter/setter pair
displayName ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resource ↔ String?
getter/setter pair
resourceType ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uuid ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited