AwsMetadata class

Constructors

AwsMetadata({AwsAccount? account, AwsOrganization? organization, List<AwsOrganizationalUnit>? organizationalUnits})
AwsMetadata.fromJson(Map json_)

Properties

account ↔ AwsAccount?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
organization ↔ AwsOrganization?
getter/setter pair
organizationalUnits ↔ List<AwsOrganizationalUnit>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited