AwsMetadata class

AWS metadata associated with the resource, only applicable if the finding's cloud provider is Amazon Web Services.

Constructors

AwsMetadata({AwsAccount? account, AwsOrganization? organization, List<AwsOrganizationalUnit>? organizationalUnits})
AwsMetadata.fromJson(Map json_)

Properties

account ↔ AwsAccount?
The AWS account associated with the resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
organization ↔ AwsOrganization?
The AWS organization associated with the resource.
getter/setter pair
organizationalUnits ↔ List<AwsOrganizationalUnit>?
A list of AWS organizational units associated with the resource, ordered from lowest level (closest to the account) to highest level.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited