AzureMetadata class

Azure metadata associated with the resource, only applicable if the finding's cloud provider is Microsoft Azure.

Constructors

AzureMetadata({List<AzureManagementGroup>? managementGroups, AzureResourceGroup? resourceGroup, AzureSubscription? subscription, AzureTenant? tenant})
AzureMetadata.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
managementGroups ↔ List<AzureManagementGroup>?
A list of Azure management groups associated with the resource, ordered from lowest level (closest to the subscription) to highest level.
getter/setter pair
resourceGroup ↔ AzureResourceGroup?
The Azure resource group associated with the resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscription ↔ AzureSubscription?
The Azure subscription associated with the resource.
getter/setter pair
tenant ↔ AzureTenant?
The Azure Entra tenant associated with the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited