BackupDisasterRecovery class

Information related to Google Cloud Backup and DR Service findings.

Constructors

BackupDisasterRecovery({String? appliance, List<String>? applications, String? backupCreateTime, String? backupTemplate, String? backupType, String? host, List<String>? policies, List<String>? policyOptions, String? profile, String? storagePool})
BackupDisasterRecovery.fromJson(Map json_)

Properties

appliance ↔ String?
The name of the Backup and DR appliance that captures, moves, and manages the lifecycle of backup data.
getter/setter pair
applications ↔ List<String>?
The names of Backup and DR applications.
getter/setter pair
backupCreateTime ↔ String?
The timestamp at which the Backup and DR backup was created.
getter/setter pair
backupTemplate ↔ String?
The name of a Backup and DR template which comprises one or more backup policies.
getter/setter pair
backupType ↔ String?
The backup type of the Backup and DR image.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
host ↔ String?
The name of a Backup and DR host, which is managed by the backup and recovery appliance and known to the management console.
getter/setter pair
policies ↔ List<String>?
The names of Backup and DR policies that are associated with a template and that define when to run a backup, how frequently to run a backup, and how long to retain the backup image.
getter/setter pair
policyOptions ↔ List<String>?
The names of Backup and DR advanced policy options of a policy applying to an application.
getter/setter pair
profile ↔ String?
The name of the Backup and DR resource profile that specifies the storage media for backups of application and VM data.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storagePool ↔ String?
The name of the Backup and DR storage pool that the backup and recovery appliance is storing data in.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited