CloudControl class

CloudControl associated with the finding.

Constructors

CloudControl({String? cloudControlName, String? policyType, String? type, int? version})
CloudControl.fromJson(Map json_)

Properties

cloudControlName ↔ String?
Name of the CloudControl associated with the finding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
policyType ↔ String?
Policy type of the CloudControl
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type of cloud control. Possible string values are:
getter/setter pair
version ↔ int?
Version of the Cloud Control
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited