Connection class

Contains information about the IP connection associated with the finding.

Constructors

Connection({String? destinationIp, int? destinationPort, String? protocol, String? sourceIp, int? sourcePort})
Connection.fromJson(Map json_)

Properties

destinationIp ↔ String?
Destination IP address.
getter/setter pair
destinationPort ↔ int?
Destination port.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
protocol ↔ String?
IANA Internet Protocol Number such as TCP(6) and UDP(17). Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceIp ↔ String?
Source IP address.
getter/setter pair
sourcePort ↔ int?
Source port.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited