Container class

Constructors

Container({String? createTime, String? imageId, List<Label>? labels, String? name, String? uri})
Container.fromJson(Map json_)

Properties

createTime String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageId String?
getter/setter pair
labels List<Label>?
getter/setter pair
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited