DiscoveredWorkload class
Constructors
- DiscoveredWorkload({String? confidence, bool? detectedRelevantHardware, bool? detectedRelevantKeywords, bool? detectedRelevantPackages, String? workloadType})
- DiscoveredWorkload.fromJson(Map json_)
Properties
- confidence ↔ String?
-
Possible string values are:
getter/setter pair
- detectedRelevantHardware ↔ bool?
-
getter/setter pair
- detectedRelevantKeywords ↔ bool?
-
getter/setter pair
- detectedRelevantPackages ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- workloadType ↔ String?
-
Possible string values are:
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited