EventThreatDetectionCustomModule class

Represents an instance of an Event Threat Detection custom module, including its full module name, display name, enablement state, and last updated time.

You can create a custom module at the organization, folder, or project level. Custom modules that you create at the organization or folder level are inherited by child folders and projects.

Constructors

EventThreatDetectionCustomModule({String? ancestorModule, String? cloudProvider, Map<String, Object?>? config, String? description, String? displayName, String? enablementState, String? lastEditor, String? name, String? type, String? updateTime})
EventThreatDetectionCustomModule.fromJson(Map json_)

Properties

ancestorModule ↔ String?
The closest ancestor module that this module inherits the enablement state from.
getter/setter pair
cloudProvider ↔ String?
The cloud provider of the custom module. Possible string values are:
getter/setter pair
config ↔ Map<String, Object?>?
Config for the module.
getter/setter pair
description ↔ String?
The description for the module.
getter/setter pair
displayName ↔ String?
The human readable name to be displayed for the module.
getter/setter pair
enablementState ↔ String?
The state of enablement for the module at the given level of the hierarchy. Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastEditor ↔ String?
The editor the module was last updated by.
getter/setter pair
name ↔ String?
The resource name of the Event Threat Detection custom module.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
Type for the module.
getter/setter pair
updateTime ↔ String?
The time the module was last updated.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited