Exfiltration class
Constructors
-
Exfiltration({List<
ExfilResource> ? sources, List<ExfilResource> ? targets, String? totalExfiltratedBytes}) - Exfiltration.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sources
↔ List<
ExfilResource> ? -
getter/setter pair
-
targets
↔ List<
ExfilResource> ? -
getter/setter pair
- totalExfiltratedBytes ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited