ExternalExposure class

Constructors

ExternalExposure({String? backendBucket, String? backendService, String? exposedApplication, String? exposedEndpoint, String? exposedService, String? forwardingRule, String? hostnameUri, List<HttpResponse>? httpResponse, String? instanceGroup, String? internalBackendService, String? loadBalancerFirewallPolicy, String? networkEndpointGroup, String? networkIngressFirewallPolicy, String? networkPathInsightsGenerationTime, String? privateIpAddress, String? privatePort, String? pscNetworkAttachment, String? pscServiceAttachment, String? publicIpAddress, String? publicPort, String? serviceFirewallPolicy})
ExternalExposure.fromJson(Map json_)

Properties

backendBucket String?
getter/setter pair
backendService String?
getter/setter pair
exposedApplication String?
getter/setter pair
exposedEndpoint String?
getter/setter pair
exposedService String?
getter/setter pair
forwardingRule String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hostnameUri String?
getter/setter pair
httpResponse List<HttpResponse>?
getter/setter pair
instanceGroup String?
getter/setter pair
internalBackendService String?
getter/setter pair
loadBalancerFirewallPolicy String?
getter/setter pair
networkEndpointGroup String?
getter/setter pair
networkIngressFirewallPolicy String?
getter/setter pair
networkPathInsightsGenerationTime String?
getter/setter pair
privateIpAddress String?
getter/setter pair
privatePort String?
getter/setter pair
pscNetworkAttachment String?
getter/setter pair
pscServiceAttachment String?
getter/setter pair
publicIpAddress String?
getter/setter pair
publicPort String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceFirewallPolicy String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited