fileLoadState property
The load state of the file. Possible string values are:
- "FILE_LOAD_STATE_UNSPECIFIED" : The file state is unspecified.
- "LOADED_BY_PROCESS" : The file is being used by an active process at the time of scanning.
- "NOT_LOADED_BY_PROCESS" : The file is not being used by any active process at the time of scanning.
Implementation
core.String? fileLoadState;