Finding class

Security Command Center finding.

A finding is a record of assessment data like security, risk, health, or privacy, that is ingested into Security Command Center for presentation, notification, analysis, policy testing, and enforcement. For example, a cross-site scripting (XSS) vulnerability in an App Engine application is a finding.

Constructors

Finding({Access? access, AffectedResources? affectedResources, AiModel? aiModel, Application? application, ArtifactGuardPolicies? artifactGuardPolicies, AttackExposure? attackExposure, BackupDisasterRecovery? backupDisasterRecovery, String? canonicalName, String? category, Chokepoint? chokepoint, CloudArmor? cloudArmor, CloudDlpDataProfile? cloudDlpDataProfile, CloudDlpInspection? cloudDlpInspection, ComplianceDetails? complianceDetails, List<Compliance>? compliances, List<Connection>? connections, Map<String, ContactDetails>? contacts, List<Container>? containers, String? createTime, List<DataAccessEvent>? dataAccessEvents, List<DataFlowEvent>? dataFlowEvents, List<DataRetentionDeletionEvent>? dataRetentionDeletionEvents, Database? database, String? description, Disk? disk, String? eventTime, Exfiltration? exfiltration, Map<String, GoogleCloudSecuritycenterV1ExternalSystem>? externalSystems, String? externalUri, List<File>? files, String? findingClass, List<GroupMembership>? groupMemberships, List<IamBinding>? iamBindings, Indicator? indicator, IpRules? ipRules, Job? job, KernelRootkit? kernelRootkit, Kubernetes? kubernetes, List<LoadBalancer>? loadBalancers, List<LogEntry>? logEntries, MitreAttack? mitreAttack, String? moduleName, String? mute, MuteInfo? muteInfo, String? muteInitiator, String? muteUpdateTime, String? name, List<Network>? networks, String? nextSteps, Notebook? notebook, List<OrgPolicy>? orgPolicies, String? parent, String? parentDisplayName, List<Process>? processes, String? resourceName, Secret? secret, SecurityMarks? securityMarks, SecurityPosture? securityPosture, String? severity, Map<String, Object?>? sourceProperties, String? state, ToxicCombination? toxicCombination, VertexAi? vertexAi, Vulnerability? vulnerability})
Finding.fromJson(Map json_)

Properties

access ↔ Access?
Access details associated with the finding, such as more information on the caller, which method was accessed, and from where.
getter/setter pair
affectedResources ↔ AffectedResources?
AffectedResources associated with the finding.
getter/setter pair
aiModel ↔ AiModel?
The AI model associated with the finding.
getter/setter pair
application ↔ Application?
Represents an application associated with the finding.
getter/setter pair
artifactGuardPolicies ↔ ArtifactGuardPolicies?
ArtifactGuardPolicies associated with the finding.
getter/setter pair
attackExposure ↔ AttackExposure?
The results of an attack path simulation relevant to this finding.
getter/setter pair
backupDisasterRecovery ↔ BackupDisasterRecovery?
Fields related to Backup and DR findings.
getter/setter pair
canonicalName ↔ String?
The canonical name of the finding.
getter/setter pair
category ↔ String?
The additional taxonomy group within findings from a given source.
getter/setter pair
chokepoint ↔ Chokepoint?
Contains details about a chokepoint, which is a resource or resource group where high-risk attack paths converge, based on attack path simulations.
getter/setter pair
cloudArmor ↔ CloudArmor?
Fields related to Cloud Armor findings.
getter/setter pair
cloudDlpDataProfile ↔ CloudDlpDataProfile?
Cloud DLP data profile that is associated with the finding.
getter/setter pair
cloudDlpInspection ↔ CloudDlpInspection?
Cloud Data Loss Prevention (Cloud DLP) inspection results that are associated with the finding.
getter/setter pair
complianceDetails ↔ ComplianceDetails?
Details about the compliance implications of the finding.
getter/setter pair
compliances ↔ List<Compliance>?
Contains compliance information for security standards associated to the finding.
getter/setter pair
connections ↔ List<Connection>?
Contains information about the IP connection associated with the finding.
getter/setter pair
contacts ↔ Map<String, ContactDetails>?
Map containing the points of contact for the given finding.
getter/setter pair
containers ↔ List<Container>?
Containers associated with the finding.
getter/setter pair
createTime ↔ String?
The time at which the finding was created in Security Command Center.
getter/setter pair
dataAccessEvents ↔ List<DataAccessEvent>?
Data access events associated with the finding.
getter/setter pair
database ↔ Database?
Database associated with the finding.
getter/setter pair
dataFlowEvents ↔ List<DataFlowEvent>?
Data flow events associated with the finding.
getter/setter pair
dataRetentionDeletionEvents ↔ List<DataRetentionDeletionEvent>?
Data retention deletion events associated with the finding.
getter/setter pair
description ↔ String?
Contains more details about the finding.
getter/setter pair
disk ↔ Disk?
Disk associated with the finding.
getter/setter pair
eventTime ↔ String?
The time the finding was first detected.
getter/setter pair
exfiltration ↔ Exfiltration?
Represents exfiltrations associated with the finding.
getter/setter pair
externalSystems ↔ Map<String, GoogleCloudSecuritycenterV1ExternalSystem>?
Third party SIEM/SOAR fields within SCC, contains external system information and external system finding fields.
getter/setter pair
externalUri ↔ String?
The URI that, if available, points to a web page outside of Security Command Center where additional information about the finding can be found.
getter/setter pair
files ↔ List<File>?
File associated with the finding.
getter/setter pair
findingClass ↔ String?
The class of the finding. Possible string values are:
getter/setter pair
groupMemberships ↔ List<GroupMembership>?
Contains details about groups of which this finding is a member.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iamBindings ↔ List<IamBinding>?
Represents IAM bindings associated with the finding.
getter/setter pair
indicator ↔ Indicator?
Represents what's commonly known as an indicator of compromise (IoC) in computer forensics.
getter/setter pair
ipRules ↔ IpRules?
IP rules associated with the finding.
getter/setter pair
job ↔ Job?
Job associated with the finding.
getter/setter pair
kernelRootkit ↔ KernelRootkit?
Signature of the kernel rootkit.
getter/setter pair
kubernetes ↔ Kubernetes?
Kubernetes resources associated with the finding.
getter/setter pair
loadBalancers ↔ List<LoadBalancer>?
The load balancers associated with the finding.
getter/setter pair
logEntries ↔ List<LogEntry>?
Log entries that are relevant to the finding.
getter/setter pair
mitreAttack ↔ MitreAttack?
MITRE ATT&CK tactics and techniques related to this finding.
getter/setter pair
moduleName ↔ String?
Unique identifier of the module which generated the finding.
getter/setter pair
mute ↔ String?
Indicates the mute state of a finding (either muted, unmuted or undefined).
getter/setter pair
muteInfo ↔ MuteInfo?
The mute information regarding this finding.
getter/setter pair
muteInitiator ↔ String?
Records additional information about the mute operation, for example, the [mute configuration](/security-command-center/docs/how-to-mute-findings) that muted the finding and the user who muted the finding.
getter/setter pair
muteUpdateTime ↔ String?
The most recent time this finding was muted or unmuted.
getter/setter pair
name ↔ String?
The relative resource name of the finding.
getter/setter pair
networks ↔ List<Network>?
Represents the VPC networks that the resource is attached to.
getter/setter pair
nextSteps ↔ String?
Steps to address the finding.
getter/setter pair
notebook ↔ Notebook?
Notebook associated with the finding.
getter/setter pair
orgPolicies ↔ List<OrgPolicy>?
Contains information about the org policies associated with the finding.
getter/setter pair
parent ↔ String?
The relative resource name of the source the finding belongs to.
getter/setter pair
parentDisplayName ↔ String?
The human readable display name of the finding source such as "Event Threat Detection" or "Security Health Analytics".
getter/setter pair
processes ↔ List<Process>?
Represents operating system processes associated with the Finding.
getter/setter pair
resourceName ↔ String?
For findings on Google Cloud resources, the full resource name of the Google Cloud resource this finding is for.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secret ↔ Secret?
Secret associated with the finding.
getter/setter pair
securityMarks ↔ SecurityMarks?
User specified security marks.
getter/setter pair
securityPosture ↔ SecurityPosture?
The security posture associated with the finding.
getter/setter pair
severity ↔ String?
The severity of the finding.
getter/setter pair
sourceProperties ↔ Map<String, Object?>?
Source specific properties.
getter/setter pair
state ↔ String?
The state of the finding. Possible string values are:
getter/setter pair
toxicCombination ↔ ToxicCombination?
Contains details about a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently.
getter/setter pair
vertexAi ↔ VertexAi?
VertexAi associated with the finding.
getter/setter pair
vulnerability ↔ Vulnerability?
Represents vulnerability-specific fields like CVE and CVSS scores.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited