GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule class

Constructors

GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule({String? ancestorModule, String? cloudProvider, GoogleCloudSecuritycenterV1CustomConfig? customConfig, String? displayName, String? enablementState, String? lastEditor, String? name, String? updateTime})
GoogleCloudSecuritycenterV1SecurityHealthAnalyticsCustomModule.fromJson(Map json_)

Properties

ancestorModule ↔ String?
getter/setter pair
cloudProvider ↔ String?
Possible string values are:
getter/setter pair
customConfig ↔ GoogleCloudSecuritycenterV1CustomConfig?
getter/setter pair
displayName ↔ String?
getter/setter pair
enablementState ↔ String?
Possible string values are:
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastEditor ↔ String?
getter/setter pair
name ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updateTime ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited