GroupAssetsRequest class

Request message for grouping by assets.

Constructors

GroupAssetsRequest({String? compareDuration, String? filter, String? groupBy, int? pageSize, String? pageToken, String? readTime})
GroupAssetsRequest.fromJson(Map json_)

Properties

compareDuration ↔ String?
When compare_duration is set, the GroupResult's "state_change" property is updated to indicate whether the asset was added, removed, or remained present during the compare_duration period of time that precedes the read_time.
getter/setter pair
filter ↔ String?
Expression that defines the filter to apply across assets.
getter/setter pair
groupBy ↔ String?
Expression that defines what assets fields to use for grouping.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
pageSize ↔ int?
The maximum number of results to return in a single response.
getter/setter pair
pageToken ↔ String?
The value returned by the last GroupAssetsResponse; indicates that this is a continuation of a prior GroupAssets call, and that the system should return the next page of data.
getter/setter pair
readTime ↔ String?
Time used as a reference point when filtering assets.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited