Indicator class

Represents what's commonly known as an indicator of compromise (IoC) in computer forensics.

This is an artifact observed on a network or in an operating system that, with high confidence, indicates a computer intrusion. For more information, see Indicator of compromise.

Constructors

Indicator({List<String>? domains, List<String>? ipAddresses, List<ProcessSignature>? signatures, List<String>? uris})
Indicator.fromJson(Map json_)

Properties

domains ↔ List<String>?
List of domains associated to the Finding.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
ipAddresses ↔ List<String>?
The list of IP addresses that are associated with the finding.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signatures ↔ List<ProcessSignature>?
The list of matched signatures indicating that the given process is present in the environment.
getter/setter pair
uris ↔ List<String>?
The list of URIs associated to the Findings.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited