KernelRootkit class

Constructors

KernelRootkit({String? name, bool? unexpectedCodeModification, bool? unexpectedFtraceHandler, bool? unexpectedInterruptHandler, bool? unexpectedKernelCodePages, bool? unexpectedKprobeHandler, bool? unexpectedProcessesInRunqueue, bool? unexpectedReadOnlyDataModification, bool? unexpectedSystemCallHandler})
KernelRootkit.fromJson(Map json_)

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unexpectedCodeModification bool?
getter/setter pair
unexpectedFtraceHandler bool?
getter/setter pair
unexpectedInterruptHandler bool?
getter/setter pair
unexpectedKernelCodePages bool?
getter/setter pair
unexpectedKprobeHandler bool?
getter/setter pair
unexpectedProcessesInRunqueue bool?
getter/setter pair
unexpectedReadOnlyDataModification bool?
getter/setter pair
unexpectedSystemCallHandler bool?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited