Policy class
Constructors
-
Policy({List<
AuditConfig> ? auditConfigs, List<Binding> ? bindings, String? etag, int? version}) - Policy.fromJson(Map json_)
Properties
-
auditConfigs
↔ List<
AuditConfig> ? -
getter/setter pair
-
bindings
↔ List<
Binding> ? -
getter/setter pair
- etag ↔ String?
-
getter/setter pair
-
etagAsBytes
↔ List<
int> -
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version ↔ int?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited