PolicyViolationSummary class
Constructors
- PolicyViolationSummary({String? conformantResourcesCount, String? evaluationErrorsCount, String? outOfScopeResourcesCount, String? policyViolationsCount})
- PolicyViolationSummary.fromJson(Map json_)
Properties
- conformantResourcesCount ↔ String?
-
getter/setter pair
- evaluationErrorsCount ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- outOfScopeResourcesCount ↔ String?
-
getter/setter pair
- policyViolationsCount ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited