Process class

Constructors

Process({List<String>? args, bool? argumentsTruncated, File? binary, List<EnvironmentVariable>? envVariables, bool? envVariablesTruncated, List<File>? libraries, String? name, String? parentPid, String? pid, File? script, String? userId})
Process.fromJson(Map json_)

Properties

args List<String>?
getter/setter pair
argumentsTruncated bool?
getter/setter pair
binary File?
getter/setter pair
envVariables List<EnvironmentVariable>?
getter/setter pair
envVariablesTruncated bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
libraries List<File>?
getter/setter pair
name String?
getter/setter pair
parentPid String?
getter/setter pair
pid String?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
script File?
getter/setter pair
userId String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited