Resource class

Information related to the Google Cloud resource that is associated with this finding.

Constructors

Resource({AdcApplication? adcApplication, AdcApplicationTemplateRevision? adcApplicationTemplate, AdcSharedTemplateRevision? adcSharedTemplate, GoogleCloudSecuritycenterV1ResourceApplication? application, AwsMetadata? awsMetadata, AzureMetadata? azureMetadata, String? cloudProvider, String? displayName, List<Folder>? folders, String? location, String? name, String? organization, String? parentDisplayName, String? parentName, String? projectDisplayName, String? projectName, ResourcePath? resourcePath, String? resourcePathString, String? service, String? type})
Resource.fromJson(Map json_)

Properties

adcApplication ↔ AdcApplication?
The ADC application associated with the finding.
getter/setter pair
adcApplicationTemplate ↔ AdcApplicationTemplateRevision?
The ADC template associated with the finding.
getter/setter pair
adcSharedTemplate ↔ AdcSharedTemplateRevision?
The ADC shared template associated with the finding.
getter/setter pair
application ↔ GoogleCloudSecuritycenterV1ResourceApplication?
The App Hub application this resource belongs to.
getter/setter pair
awsMetadata ↔ AwsMetadata?
The AWS metadata associated with the finding.
getter/setter pair
azureMetadata ↔ AzureMetadata?
The Azure metadata associated with the finding.
getter/setter pair
cloudProvider ↔ String?
Indicates which cloud provider the finding is from. Possible string values are:
getter/setter pair
displayName ↔ String?
The human readable name of the resource.
getter/setter pair
folders ↔ List<Folder>?
Contains a Folder message for each folder in the assets ancestry.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
location ↔ String?
The region or location of the service (if applicable).
getter/setter pair
name ↔ String?
The full resource name of the resource.
getter/setter pair
organization ↔ String?
Indicates which organization / tenant the finding is for.
getter/setter pair
parentDisplayName ↔ String?
The human readable name of resource's parent.
getter/setter pair
parentName ↔ String?
The full resource name of resource's parent.
getter/setter pair
projectDisplayName ↔ String?
The project ID that the resource belongs to.
getter/setter pair
projectName ↔ String?
The full resource name of project that the resource belongs to.
getter/setter pair
resourcePath ↔ ResourcePath?
Provides the path to the resource within the resource hierarchy.
getter/setter pair
resourcePathString ↔ String?
A string representation of the resource path.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
service ↔ String?
The service or resource provider associated with the resource.
getter/setter pair
type ↔ String?
The full resource type of the resource.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited