SecurityCenterProperties class

Constructors

SecurityCenterProperties({List<Folder>? folders, String? resourceDisplayName, String? resourceName, List<String>? resourceOwners, String? resourceParent, String? resourceParentDisplayName, String? resourceProject, String? resourceProjectDisplayName, String? resourceType})
SecurityCenterProperties.fromJson(Map json_)

Properties

folders ↔ List<Folder>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
resourceDisplayName ↔ String?
getter/setter pair
resourceName ↔ String?
getter/setter pair
resourceOwners ↔ List<String>?
getter/setter pair
resourceParent ↔ String?
getter/setter pair
resourceParentDisplayName ↔ String?
getter/setter pair
resourceProject ↔ String?
getter/setter pair
resourceProjectDisplayName ↔ String?
getter/setter pair
resourceType ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited