securitycenterScope constant
String
const securitycenterScope
See, edit, configure, and delete your Google Cloud Security Command Center data and see the email address for your Google Account
Implementation
static const securitycenterScope =
'https://www.googleapis.com/auth/securitycenter';