ValuedResource class

A resource that is determined to have value to a user's system

Constructors

ValuedResource({String? displayName, double? exposedScore, String? name, String? resource, String? resourceType, String? resourceValue, List<ResourceValueConfigMetadata>? resourceValueConfigsUsed})
ValuedResource.fromJson(Map json_)

Properties

displayName ↔ String?
Human-readable name of the valued resource.
getter/setter pair
exposedScore ↔ double?
Exposed score for this valued resource.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
Valued resource name, for example, e.g.: organizations/123/simulations/456/valuedResources/789
getter/setter pair
resource ↔ String?
The full resource name of the valued resource.
getter/setter pair
resourceType ↔ String?
The resource type of the valued resource.
getter/setter pair
resourceValue ↔ String?
How valuable this resource is. Possible string values are:
getter/setter pair
resourceValueConfigsUsed ↔ List<ResourceValueConfigMetadata>?
List of resource value configurations' metadata used to determine the value of this resource.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited