AspectRule class

Rule-based configuration for an aspect.

Constructors

AspectRule({Map<String, Object?>? config, String? selector})
AspectRule.fromJson(Map json_)

Properties

config Map<String, Object?>?
Rules of the configuration.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selector String?
Selects the RPC methods to which this rule applies.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited