message property
A message to accompany the reviewer response on the approval.
This message is included in notifications for the action and in the approval activity log.
Optional.
Implementation
core.String? message;
A message to accompany the reviewer response on the approval.
This message is included in notifications for the action and in the approval activity log.
Optional.
core.String? message;