$CVSS class

Used by:

  • containeranalysis:v1 : CVSS
  • ondemandscanning:v1 : CVSS

Constructors

$CVSS({String? attackComplexity, String? attackVector, String? authentication, String? availabilityImpact, double? baseScore, String? confidentialityImpact, double? exploitabilityScore, double? impactScore, String? integrityImpact, String? privilegesRequired, String? scope, String? userInteraction})
$CVSS.fromJson(Map json_)

Properties

attackComplexity ↔ String?
Possible string values are:
getter/setter pair
attackVector ↔ String?
Base Metrics Represents the intrinsic characteristics of a vulnerability that are constant over time and across user environments. Possible string values are:
getter/setter pair
authentication ↔ String?
Possible string values are:
getter/setter pair
availabilityImpact ↔ String?
Possible string values are:
getter/setter pair
baseScore ↔ double?
The base score is a function of the base metric scores.
getter/setter pair
confidentialityImpact ↔ String?
Possible string values are:
getter/setter pair
exploitabilityScore ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
impactScore ↔ double?
getter/setter pair
integrityImpact ↔ String?
Possible string values are:
getter/setter pair
privilegesRequired ↔ String?
Possible string values are:
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
Possible string values are:
getter/setter pair
userInteraction ↔ String?
Possible string values are:
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited