$DecryptionMetadata class
Used by:
- drive:v2 : DecryptionMetadata
- drive:v3 : DecryptionMetadata
Constructors
- $DecryptionMetadata({String? aes256GcmChunkSize, String? encryptionResourceKeyHash, String? jwt, String? kaclsId, String? kaclsName, String? keyFormat, String? wrappedKey})
- $DecryptionMetadata.fromJson(Map json_)
Properties
- aes256GcmChunkSize ↔ String?
-
Chunk size used if content was encrypted with the AES 256 GCM Cipher.
getter/setter pair
- encryptionResourceKeyHash ↔ String?
-
The URL-safe Base64 encoded HMAC-SHA256 digest of the resource metadata
with its DEK (Data Encryption Key); see
https://developers.google.com/workspace/cse/reference
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- jwt ↔ String?
-
The signed JSON Web Token (JWT) which can be used to authorize the
requesting user with the Key ACL Service (KACLS).
getter/setter pair
- kaclsId ↔ String?
-
The ID of the KACLS (Key ACL Service) used to encrypt the file.
getter/setter pair
- kaclsName ↔ String?
-
The name of the KACLS (Key ACL Service) used to encrypt the file.
getter/setter pair
- keyFormat ↔ String?
-
Key format for the unwrapped key.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wrappedKey ↔ String?
-
The URL-safe Base64 encoded wrapped key used to encrypt the contents of
the file.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited