jwt property
The signed JSON Web Token (JWT) which can be used to authorize the requesting user with the Key ACL Service (KACLS).
The JWT asserts that the requesting user has at least read permissions on the file.
Implementation
core.String? jwt;
The signed JSON Web Token (JWT) which can be used to authorize the requesting user with the Key ACL Service (KACLS).
The JWT asserts that the requesting user has at least read permissions on the file.
core.String? jwt;