$DemandGenBiddingStrategy class
Used by:
- displayvideo:v2 : DemandGenBiddingStrategy
- displayvideo:v3 : DemandGenBiddingStrategy
- displayvideo:v4 : DemandGenBiddingStrategy
Constructors
- $DemandGenBiddingStrategy({String? effectiveBiddingValue, String? effectiveBiddingValueSource, String? type, String? value})
- $DemandGenBiddingStrategy.fromJson(Map json_)
Properties
- effectiveBiddingValue ↔ String?
-
The value effectively used by the bidding strategy.
getter/setter pair
- effectiveBiddingValueSource ↔ String?
-
Source of the effective bidding value.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
The type of the bidding strategy.
getter/setter pair
- value ↔ String?
-
The value used by the bidding strategy.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited