metadata property
Provides additional information about the end session signal, such as the reason for ending the session.
Optional.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Object?>? metadata;