force property
If false (default): The operation will fail if any Repository within the
folder hierarchy has associated Release Configs or Workflow Configs.
If true: The operation will attempt to delete everything, including any
Release Configs and Workflow Configs linked to Repositories within the
folder hierarchy. This permanently removes schedules and resources.
Optional.
Implementation
core.bool? force;