allowedAccessReasons property
The list of allowed reasons for access to a CryptoKey.
Note that empty allowed_access_reasons has a different meaning depending on where this message appears. If this is under KeyAccessJustificationsPolicyConfig, it means allow-all. If this is under CryptoKey, it means deny-all.
Implementation
core.List<core.String>? allowedAccessReasons;