$KeywordAssignedTargetingOptionDetails class
Used by:
- displayvideo:v2 : KeywordAssignedTargetingOptionDetails
- displayvideo:v3 : KeywordAssignedTargetingOptionDetails
- displayvideo:v4 : KeywordAssignedTargetingOptionDetails
Constructors
-
$KeywordAssignedTargetingOptionDetails({List<
String> ? exemptedPolicyNames, String? keyword, bool? negative}) - $KeywordAssignedTargetingOptionDetails.fromJson(Map json_)
Properties
-
exemptedPolicyNames
↔ List<
String> ? -
The policy names to exempt the keyword from.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- keyword ↔ String?
-
The keyword, for example
car insurance.getter/setter pair - negative ↔ bool?
-
Indicates if this option is being negatively targeted.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited