body property
The raw JSON body of the request.
The body should be in the format of the ONTAP resource. For example: { "body": { "field1": "value1", "field2": "value2", } }
Required.
The values for Object must be JSON objects. It can consist of num,
String, bool and null as well as Map and List values.
Implementation
core.Map<core.String, core.Object?>? body;