$SelectedInventories class

Used by:

  • displayvideo:v3 : SelectedInventories
  • displayvideo:v4 : SelectedInventories

Constructors

$SelectedInventories({bool? allowDiscover, bool? allowGmail, bool? allowGoogleDisplayNetwork, bool? allowYoutubeFeed, bool? allowYoutubeShorts, bool? allowYoutubeStream})
$SelectedInventories.fromJson(Map json_)

Properties

allowDiscover bool?
Whether the ad group is opted-in to Discover inventory.
getter/setter pair
allowGmail bool?
Whether the ad group is opted-in to Gmail inventory.
getter/setter pair
allowGoogleDisplayNetwork bool?
Whether the ad group is opted-in to Google Display Network inventory.
getter/setter pair
allowYoutubeFeed bool?
Whether the ad group is opted-in to YouTube in-feed inventory.
getter/setter pair
allowYoutubeShorts bool?
Whether the ad group is opted-in to YouTube shorts inventory.
getter/setter pair
allowYoutubeStream bool?
Whether the ad group is opted-in to YouTube in-stream inventory.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited