$Shared08 class

Used by:

  • cloudsearch:v1 : IntegerValues
  • integrations:v1 : EnterpriseCrmEventbusProtoIntArray

Constructors

$Shared08({List<String>? values})
$Shared08.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
values ↔ List<String>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited