enableOptimizedTargeting property
Whether to enable Optimized Targeting for the line item.
Optimized targeting is not compatible with all bid strategies. Attempting
to set this field to true for a line item using the BiddingStrategy
field fixed_bid or one of the following combinations of BiddingStrategy
fields and BiddingStrategyPerformanceGoalType will result in an error:
maximize_auto_spend_bid: * BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_CIVA *
BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_IVO_TEN *
BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_AV_VIEWED
performance_goal_auto_bid: *
BIDDING_STRATEGY_PERFORMANCE_GOAL_TYPE_VIEWABLE_CPM This also applies if
the line item inherits one of the above bid strategies from the parent
insertion order. Bid strategies set at the insertion order-level will be
inherited by their line items if the InsertionOrder budget field
automationType is set to INSERTION_ORDER_AUTOMATION_TYPE_BUDGET or
INSERTION_ORDER_AUTOMATION_TYPE_BID_BUDGET.
Required.
Implementation
core.bool? enableOptimizedTargeting;