$ToolsetTool class
Used by:
- ces:v1 : ToolsetTool
- contactcenterinsights:v1 : GoogleCloudCesV1mainToolsetTool
Constructors
- $ToolsetTool({String? toolId, String? toolset})
- $ToolsetTool.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toolId ↔ String?
-
The tool ID to filter the tools to retrieve the schema for.
getter/setter pair
- toolset ↔ String?
-
The resource name of the Toolset from which this tool is derived.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited