CommitResponse class

The response for Commit.

Constructors

CommitResponse({CommitStats? commitStats, String? commitTimestamp, MultiplexedSessionPrecommitToken? precommitToken})
CommitResponse.fromJson(Map json_)

Properties

commitStats ↔ CommitStats?
The statistics about this Commit.
getter/setter pair
commitTimestamp ↔ String?
The Cloud Spanner timestamp at which the transaction committed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
precommitToken ↔ MultiplexedSessionPrecommitToken?
If specified, transaction has not committed yet.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited