Mutation class

A modification to one or more Cloud Spanner rows.

Mutations can be applied to a Cloud Spanner database by sending them in a Commit call.

Constructors

Mutation({Delete? delete, Write? insert, Write? insertOrUpdate, Write? replace, Write? update})
Mutation.fromJson(Map json_)

Properties

delete ↔ Delete?
Delete rows from a table.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
insert ↔ Write?
Insert new rows in a table.
getter/setter pair
insertOrUpdate ↔ Write?
Like insert, except that if the row already exists, then its column values are overwritten with the ones provided.
getter/setter pair
replace ↔ Write?
Like insert, except that if the row already exists, it is deleted, and the column values provided are inserted instead.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
update ↔ Write?
Update existing rows in a table.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited