Counters class
Describes details about the progress of the job.
Constructors
Properties
- failedObjectCount ↔ String?
-
The number of objects that failed due to user errors or service errors.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- objectCustomContextsCreated ↔ String?
-
Number of object custom contexts created.
getter/setter pair
- objectCustomContextsDeleted ↔ String?
-
Number of object custom contexts deleted.
getter/setter pair
- objectCustomContextsUpdated ↔ String?
-
Number of object custom contexts updated.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- succeededObjectCount ↔ String?
-
Number of objects completed.
getter/setter pair
- totalBytesFound ↔ String?
-
Number of bytes found from source.
getter/setter pair
- totalBytesTransformed ↔ String?
-
The total number of bytes affected by the transformation.
getter/setter pair
- totalObjectCount ↔ String?
-
Number of objects listed.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited