Counters class

Describes details about the progress of the job.

Constructors

Counters({String? failedObjectCount, String? succeededObjectCount, String? totalBytesFound, String? totalObjectCount})
Counters.fromJson(Map json_)

Properties

failedObjectCount ↔ String?
Number of objects failed.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
succeededObjectCount ↔ String?
Number of objects completed.
getter/setter pair
totalBytesFound ↔ String?
Number of bytes found from source.
getter/setter pair
totalObjectCount ↔ String?
Number of objects listed.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited