CustomContextUpdates class
Describes a collection of updates to apply to custom contexts identified by key.
Constructors
-
CustomContextUpdates({List<
String> ? keysToClear, Map<String, ObjectCustomContextPayload> ? updates}) - CustomContextUpdates.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
keysToClear
↔ List<
String> ? -
Custom contexts to clear by key.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
updates
↔ Map<
String, ObjectCustomContextPayload> ? -
Insert or update the existing custom contexts.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited