ObjectAccessControl class
Represents an access control entry on an object.
Constructors
- ObjectAccessControl({String? entity, String? role})
- ObjectAccessControl.fromJson(Map json_)
Properties
- entity ↔ String?
-
The entity holding the permission, in one of the following forms: *
allUsers*allAuthenticatedUsersgetter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- role ↔ String?
-
The role to grant.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited