dryRunJobId property
The unique identifier of a dry run job to use as the baseline for the current job.
Specifying this ID ensures the job is executed against the same set of
objects validated during the dry run. The value corresponds to the
{job_id} segment of the resource name:
projects/{project_id}/locations/{location}/jobs/{job_id}.
Optional.
Implementation
core.String? dryRunJobId;