snapshotTime property
The snapshot time used by the job to read the Storage Insights dataset for bucket and object discovery.
This field is populated by the service and reflects the exact timestamp of the dataset snapshot used.
Output only.
Implementation
core.String? snapshotTime;