targetLocations property
Specifies the Cloud Storage locations to include in the job.
If provided, only buckets and objects within these locations will be
discovered from the Storage Insights dataset as configured in the
insights_dataset_config. If omitted, the job will discover buckets and
objects from all locations configured in the insights_dataset_config.
Optional.
Implementation
TargetLocations? targetLocations;