customMetadata property
Updates the object's custom metadata.
This operation adds or sets individual custom metadata key-value pairs. Keys specified with empty values have their values cleared. Existing custom metadata keys not included in the request remain unchanged. For details, see Custom metadata.
Optional.
Implementation
core.Map<core.String, core.String>? customMetadata;