kmsKey property
Resource name of the Cloud KMS key that is used to encrypt the object.
The Cloud KMS key must be located in same location as the object. For
details, see
https://cloud.google.com/storage/docs/encryption/using-customer-managed-keys#add-object-key
Format:
projects/{project_id}/locations/{location}/keyRings/{keyring}/cryptoKeys/{key}
For example:
projects/123456/locations/us-central1/keyRings/my-keyring/cryptoKeys/my-key.
The object will be rewritten and set with the specified KMS key.
Optional.
Implementation
core.String? kmsKey;