TargetLocations class
Describes the Cloud Storage locations to include in a ProjectSource job.
Constructors
-
TargetLocations({List<
String> ? locations, String? snapshotTime}) - TargetLocations.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
locations
↔ List<
String> ? -
A list of Cloud Storage locations (e.g.,
us-central1) to include in the job.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snapshotTime ↔ String?
-
The exact Storage Insights snapshot timestamp to use for the job
compatible with the RFC 3339 format (e.g.,
2024-01-02T03:04:05Z).getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited