snapshotTime property
The exact Storage Insights snapshot timestamp to use for the job
compatible with the RFC 3339 format (e.g., 2024-01-02T03:04:05Z).
If specified, this exact snapshot must exist in BOTH the
object_attributes_view and bucket_attributes_view for every location
listed in locations. If the snapshot is missing from either view in any
of the locations, the job fails.
Optional.
Implementation
core.String? snapshotTime;