UpdateObjectCustomContext class
Describes options to update object custom contexts.
Constructors
- UpdateObjectCustomContext({bool? clearAll, CustomContextUpdates? customContextUpdates})
- UpdateObjectCustomContext.fromJson(Map json_)
Properties
- clearAll ↔ bool?
-
If set, must be set to true and all existing object custom contexts are
deleted.
getter/setter pair
- customContextUpdates ↔ CustomContextUpdates?
-
A collection of updates to apply to specific custom contexts.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited