customContextUpdates property
A collection of updates to apply to specific custom contexts.
Use this to add, update or delete individual contexts by key.
Implementation
CustomContextUpdates? customContextUpdates;
A collection of updates to apply to specific custom contexts.
Use this to add, update or delete individual contexts by key.
CustomContextUpdates? customContextUpdates;