convertToNumber property
The option to convert a variable value to a number. Possible string values are:
- "decimalSeparatorTypeUnspecified"
- "period" : The option to convert a variable value to a number with a period as the decimal separator.
- "comma" : The option to convert a variable value to a number with a comma as the decimal separator.
- "automatic" : The option to convert a variable value to a number with automatic decimal separator detection.
Implementation
core.String? convertToNumber;