category property
The harm category to apply the safety setting to. Possible string values are:
- "HARM_CATEGORY_UNSPECIFIED" : Default value. This value is unused.
- "HARM_CATEGORY_HATE_SPEECH" : Content that promotes violence or incites hatred against individuals or groups based on certain attributes.
- "HARM_CATEGORY_DANGEROUS_CONTENT" : Content that promotes, facilitates, or enables dangerous activities.
- "HARM_CATEGORY_HARASSMENT" : Abusive, threatening, or content intended to bully, torment, or ridicule.
- "HARM_CATEGORY_SEXUALLY_EXPLICIT" : Content that contains sexually explicit material.
Implementation
core.String? category;