DatastoreMountConfig class

The Datastore Mount configuration

Constructors

DatastoreMountConfig({String? accessMode, String? datastore, DatastoreNetwork? datastoreNetwork, String? fileShare, String? nfsVersion, List<String>? servers})
DatastoreMountConfig.fromJson(Map json_)

Properties

accessMode String?
The access mode of the NFS volume.
getter/setter pair
datastore String?
The resource name of the datastore to mount.
getter/setter pair
datastoreNetwork DatastoreNetwork?
The network configuration for the datastore.
getter/setter pair
fileShare String?
File share name.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
nfsVersion String?
The NFS protocol supported by the NFS volume.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
servers List<String>?
Server IP addresses of the NFS volume.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited