EncryptionConfig class

Encryption configuration for a private cloud.

Constructors

EncryptionConfig({String? cryptoKeyName, String? type})
EncryptionConfig.fromJson(Map json_)

Properties

cryptoKeyName String?
The resource name of the Cloud KMS key to be used for CMEK encryption.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String?
The encryption type of the private cloud.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited