MigrateManagementVmsRequest class
Request message for VmwareEngine.MigrateManagementVms
Constructors
- MigrateManagementVmsRequest({String? clusterId, String? etag, String? requestId})
- MigrateManagementVmsRequest.fromJson(Map json_)
Properties
- clusterId ↔ String?
-
The user-provided identifier of the workload cluster to which the
management VMs are to be migrated.
getter/setter pair
- etag ↔ String?
-
Checksum used to ensure that the user-provided value is up to date before
the server processes the request.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- requestId ↔ String?
-
A request ID to identify requests.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited