json property
A JSON string representing the unencoded JWT payload for a pass of the format described at https://developers.google.com/wallet/reference/rest/v1/Jwt.
This can be set to either the entire JSON representation described at this link or just the contents of the payload field holding the relevant classes and objects.
Required.
Implementation
core.String? json;