ContentPolicyStatus class
The content policy status of the publication, indicating any violations.
Constructors
- ContentPolicyStatus({String? policyInfoUrl, String? state})
- ContentPolicyStatus.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- policyInfoUrl ↔ String?
-
URL pointing to more details about the policy violation or status.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state ↔ String?
-
The current policy state.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited