DomainProperty class
Represents a domain property associated with a publication, typically used to verify ownership and scope access.
Constructors
- DomainProperty({bool? ownershipVerified, String? url})
- DomainProperty.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- ownershipVerified ↔ bool?
-
Whether the domain ownership has been verified (e.g., via Google Search
Console).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url ↔ String?
-
The URL of the domain property (e.g., "https://example.com").
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited