RrmProduct class
Configuration and status of the Reader Revenue Manager (RRM) product for a publication.
Constructors
- RrmProduct({bool? enabled, String? productTosUrl, TosAcceptance? tosAcceptance})
- RrmProduct.fromJson(Map json_)
Properties
- enabled ↔ bool?
-
Whether the RRM product is enabled for the publication.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- productTosUrl ↔ String?
-
The URL to the product-specific Terms of Service.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tosAcceptance ↔ TosAcceptance?
-
The details of the TOS acceptance.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited