BigQueryDestination class
BigQuery destination for evaluation results.
Constructors
- BigQueryDestination({bool? createNewResultsTable, String? destinationDataset})
- BigQueryDestination.fromJson(Map json_)
Properties
- createNewResultsTable ↔ bool?
-
Determines if a new results table will be created when an Execution is
created.
getter/setter pair
- destinationDataset ↔ String?
-
Destination dataset to save evaluation results.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited