Database class
Database details.
Constructors
- Database({String? diskType, String? floatingIpAddress, String? machineType, String? secondarySoleTenantNode, String? secondarySoleTenantNodeType, String? secretManagerSecret, bool? smt, String? soleTenantNode, String? soleTenantNodeType, bool? tempdbOnSsd, String? tenancyModel})
- Database.fromJson(Map json_)
Properties
- diskType ↔ String?
-
Disk type.
getter/setter pair
- floatingIpAddress ↔ String?
-
Only useful for Linux High Availability setup.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- machineType ↔ String?
-
Machine type.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondarySoleTenantNode ↔ String?
-
The name of a secondary-sole-tenant node/node group.
getter/setter pair
- secondarySoleTenantNodeType ↔ String?
-
The type of a secondary-sole-tenant node/node group.
getter/setter pair
- secretManagerSecret ↔ String?
-
Secret Manager secret.
getter/setter pair
- smt ↔ bool?
-
Whether simultaneous multithreading is enabled or not.
getter/setter pair
- soleTenantNode ↔ String?
-
The name of a primary sole-tenant node/node group.
getter/setter pair
- soleTenantNodeType ↔ String?
-
The type of a primary sole-tenant node/node group.
getter/setter pair
- tempdbOnSsd ↔ bool?
-
Whether to have TempDB on local SSD.
getter/setter pair
- tenancyModel ↔ String?
-
SHARED or SOLE_TENANT.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited