DatabaseDetails class

Message for SAP instance details.

Constructors

DatabaseDetails({String? databaseServiceAccount, String? diskType, String? image, String? instanceId, String? machineType, String? primaryDbVm, String? secondaryDbVm, String? secretManagerSecret, String? sid})
DatabaseDetails.fromJson(Map json_)

Properties

databaseServiceAccount String?
Database service account.
getter/setter pair
diskType String?
Disk type.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
image String?
Image for the database server.
getter/setter pair
instanceId String?
Instance ID.
getter/setter pair
machineType String?
Machine type.
getter/setter pair
primaryDbVm String?
Primary DB VM name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryDbVm String?
Secondary DB VM name.
getter/setter pair
secretManagerSecret String?
Secret Manager secret.
getter/setter pair
sid String?
The SID is a three-digit server-specific unique identification code.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited