terraformVariables property
terraform_variables represents all the Terraform variables for the deployment workload.
The key is the name of the Terraform variable, and the value is the TerraformVariable. For example: { "project_id": { "input_value": { "string_value": "my-project-id" } }, "zone": { "input_value": { "string_value": "us-central1-a" } } }
Optional.
Implementation
core.Map<core.String, TerraformVariable>? terraformVariables;