Evaluation class

Represents a Workload Manager Evaluation configuration.

An Evaluation defines a set of rules to be validated against a scope of Cloud resources.

Constructors

Evaluation({BigQueryDestination? bigQueryDestination, String? createTime, String? customRulesBucket, String? description, String? evaluationType, String? kmsKey, Map<String, String>? labels, String? name, ResourceFilter? resourceFilter, ResourceStatus? resourceStatus, List<String>? ruleNames, String? schedule, String? updateTime})
Evaluation.fromJson(Map json_)

Properties

bigQueryDestination BigQueryDestination?
The BigQuery destination for detailed evaluation results.
getter/setter pair
createTime String?
Create time stamp.
getter/setter pair
customRulesBucket String?
The Cloud Storage bucket name for custom rules.
getter/setter pair
description String?
Description of the Evaluation.
getter/setter pair
evaluationType String?
Evaluation type. Possible string values are:
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
kmsKey String?
Customer-managed encryption key name, in the format projects / * /locations / * /keyRings / * /cryptoKeys / * .
getter/setter pair
labels Map<String, String>?
Labels as key value pairs.
getter/setter pair
name String?
Name of resource that has the form projects/{project_id}/locations/{location_id}/evaluations/{evaluation_id}.
getter/setter pair
resourceFilter ResourceFilter?
Resource filter for an evaluation defining the scope of resources to be evaluated.
getter/setter pair
resourceStatus ResourceStatus?
The current lifecycle state of the evaluation resource.
getter/setter pair
ruleNames List<String>?
The names of the rules used for this evaluation.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schedule String?
Crontab format schedule for scheduled evaluation, currently only supports the following fixed schedules: * 0 * / 1 * * * # Hourly * 0 * / 6 * * * # Every 6 hours * 0 * / 12 * * * # Every 12 hours * 0 0 * / 1 * * # Daily * 0 0 * / 7 * * # Weekly * 0 0 * / 14 * * # Every 14 days * 0 0 1 * / 1 * # Monthly
getter/setter pair
updateTime String?
Update time stamp.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited