Execution class

Message describing Execution object

Constructors

Execution({String? endTime, String? engine, String? evaluationId, List<ExternalDataSources>? externalDataSources, String? inventoryTime, Map<String, String>? labels, String? name, List<Notice>? notices, Summary? resultSummary, List<RuleExecutionResult>? ruleResults, String? runType, String? startTime, String? state})
Execution.fromJson(Map json_)

Properties

endTime ↔ String?
End time stamp
getter/setter pair
engine ↔ String?
Engine
getter/setter pair
evaluationId ↔ String?
Evaluation ID
getter/setter pair
externalDataSources ↔ List<ExternalDataSources>?
External data sources
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inventoryTime ↔ String?
Inventory time stamp
getter/setter pair
labels ↔ Map<String, String>?
Labels as key value pairs
getter/setter pair
name ↔ String?
The name of execution resource.
getter/setter pair
notices ↔ List<Notice>?
Additional information generated by the execution
getter/setter pair
resultSummary ↔ Summary?
Result summary for the execution
getter/setter pair
ruleResults ↔ List<RuleExecutionResult>?
execution result summary per rule
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
runType ↔ String?
type represent whether the execution executed directly by user or scheduled according evaluation.schedule field. Possible string values are:
getter/setter pair
startTime ↔ String?
Start time stamp
getter/setter pair
state ↔ String?
State
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited