ListRulesResponse class

Mesesage of response of list rules

Constructors

ListRulesResponse({InvalidRulesWrapper? invalidRulesWrapper, List<Rule>? rules})
ListRulesResponse.fromJson(Map json_)

Properties

hashCode → int
The hash code for this object.
no setterinherited
invalidRulesWrapper ↔ InvalidRulesWrapper?
A wrapper of the invalid rules that failed to be validated.
getter/setter pair
rules ↔ List<Rule>?
all rules in response
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited