LocationDetails class

Message for SAP instance details.

Constructors

LocationDetails({bool? createCommsFirewall, List<String>? customTags, bool? deploymentDnsEnabled, String? dnsZone, String? dnsZoneNameSuffix, String? internetAccess, String? networkProject, String? regionName, String? subnetName, String? vpcName, String? zone1Name, String? zone2Name})
LocationDetails.fromJson(Map json_)

Properties

createCommsFirewall bool?
Create firewall.
getter/setter pair
customTags List<String>?
Network tags.
getter/setter pair
deploymentDnsEnabled bool?
When the user skips DNS configuration in the UI, deployment_dns_enabled is false; otherwise deployment_dns_enabled is true.
getter/setter pair
dnsZone String?
DNS zone name.
getter/setter pair
dnsZoneNameSuffix String?
DNS zone name suffix.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
internetAccess String?
Possible string values are:
getter/setter pair
networkProject String?
Network project.
getter/setter pair
regionName String?
Region name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subnetName String?
Subnet name.
getter/setter pair
vpcName String?
VPC name.
getter/setter pair
zone1Name String?
Zone 1 name.
getter/setter pair
zone2Name String?
Zone 2 name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited