RuleExecutionResult class
Execution result summary per rule.
Constructors
- RuleExecutionResult({String? message, String? resultCount, String? rule, String? scannedResourceCount, String? state})
- RuleExecutionResult.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message ↔ String?
-
Execution message, if any.
getter/setter pair
- resultCount ↔ String?
-
Number of violations.
getter/setter pair
- rule ↔ String?
-
Rule name as plain text like
sap-hana-configured.getter/setter pair - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scannedResourceCount ↔ String?
-
Number of total scanned resources.
getter/setter pair
- state ↔ String?
-
The execution status.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited