SapSystemS4Config class

Message for SAP system workload.

Constructors

SapSystemS4Config({bool? allowStoppingForUpdate, String? ansibleRunnerServiceAccount, AppDetails? app, DatabaseDetails? database, String? deploymentModel, String? environmentType, String? gcpProjectId, LocationDetails? location, String? mediaBucketName, String? sapBootDiskImage, String? scalingMethod, String? version, String? vmPrefix})
SapSystemS4Config.fromJson(Map json_)

Properties

allowStoppingForUpdate bool?
getter/setter pair
ansibleRunnerServiceAccount String?
Ansible runner service account.
getter/setter pair
app AppDetails?
Instance details.
getter/setter pair
database DatabaseDetails?
Database details.
getter/setter pair
deploymentModel String?
Supports non-HA and HA models.
getter/setter pair
environmentType String?
Deployment environment.
getter/setter pair
gcpProjectId String?
The project that infrastructure is deployed in.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
location LocationDetails?
Database details.
getter/setter pair
mediaBucketName String?
Media bucket name.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sapBootDiskImage String?
SAP boot disk image.
getter/setter pair
scalingMethod String?
Supports scale up and scale out.
getter/setter pair
version String?
SAP HANA version.
getter/setter pair
vmPrefix String?
VM prefix.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited