SqlServerWorkload class
Message for MS SQL workload.
Constructors
- SqlServerWorkload({ActiveDirectory? activeDirectory, String? computeEngineServiceAccount, Database? database, String? deploymentModel, String? environmentType, String? fciType, String? haType, bool? isSqlPayg, SqlLocationDetails? location, String? mediaBucket, String? operatingSystemType, String? osImage, String? osImageType, Pacemaker? pacemaker, String? sqlServerEdition, String? sqlServerVersion, String? vmPrefix})
- SqlServerWorkload.fromJson(Map json_)
Properties
- activeDirectory ↔ ActiveDirectory?
-
Active Directory details.
getter/setter pair
- computeEngineServiceAccount ↔ String?
-
Compute Engine service account.
getter/setter pair
- database ↔ Database?
-
Database details.
getter/setter pair
- deploymentModel ↔ String?
-
HIGH_AVAILABILITY or SINGLE_INSTANCE.
getter/setter pair
- environmentType ↔ String?
-
Deployment environment.
getter/setter pair
- fciType ↔ String?
-
SHARED_DISK or S2D.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- haType ↔ String?
-
AOAG or FCI.
getter/setter pair
- isSqlPayg ↔ bool?
-
SQL licensing type.
getter/setter pair
- location ↔ SqlLocationDetails?
-
Location details.
getter/setter pair
- mediaBucket ↔ String?
-
Name of the media storing SQL server installation files.
getter/setter pair
- operatingSystemType ↔ String?
-
The type of the operating system the SQL server is going to run on top of.
getter/setter pair
- osImage ↔ String?
-
The image of the operating system.
getter/setter pair
- osImageType ↔ String?
-
OS image type.
getter/setter pair
- pacemaker ↔ Pacemaker?
-
Pacemaker configuration, only applicable for Linux HA deployments.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sqlServerEdition ↔ String?
-
SQL Server Edition type, only applicable when the operating system is
Linux.
getter/setter pair
- sqlServerVersion ↔ String?
-
2017, 2019, or 2022.
getter/setter pair
- vmPrefix ↔ String?
-
Should be unique in the project.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited