TerraformVariable typedef
TerraformVariable = $TerraformVariable
In order to align with the Infra Manager dependency, we create the same TerraformVariable message to represent a Terraform input variable, by following Infra Manager's API documentation: https://cloud.google.com/infrastructure-manager/docs/reference/rest.
A Terraform input variable.
Implementation
typedef TerraformVariable = $TerraformVariable;