Artifact class
Artifacts are the container for task completed results.
These are similar to Messages but are intended to be the product of a task, as opposed to point-to-point communication.
Constructors
Properties
- artifactId ↔ String?
-
Unique identifier (e.g. UUID) for the artifact.
getter/setter pair
- description ↔ String?
-
A human readable description of the artifact, optional.
getter/setter pair
-
extensions
↔ List<
String> ? -
The URIs of extensions that are present or contributed to this Artifact.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
↔ Map<
String, Object?> ? -
Optional metadata included with the artifact.
getter/setter pair
- name ↔ String?
-
A human readable name for the artifact.
getter/setter pair
-
parts
↔ List<
Part> ? -
The content of the artifact.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited