DriveOptions class
Additional supported options for serving Drive events.
Constructors
- DriveOptions({bool? includeDescendants})
- DriveOptions.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeDescendants ↔ bool?
-
For subscriptions to Google Drive events, whether to receive events about
Drive files that are children of the target folder or shared drive.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited