chatAppAllUsersReadstateReadonlyScope constant
String
const chatAppAllUsersReadstateReadonlyScope
On their own behalf, apps in Google Chat can see the last read time for all users in all spaces and conversations throughout your Workspace organization, even when the Chat app isn't a member.
Implementation
static const chatAppAllUsersReadstateReadonlyScope =
'https://www.googleapis.com/auth/chat.app.all.users.readstate.readonly';