maxSizeGb property
Maximum size in GB to which this persistent directory can be resized.
Defaults to 0, which indicates no maximum limit is enforced by this
configuration. Resizing is still subject to the quotas and limits of the
underlying disk type.
Optional.
Implementation
core.int? maxSizeGb;