workstationLaunchUrl property
Specifies the launch URL for workstations in this cluster.
Requests sent to unstarted workstations will be redirected to this URL.
Requests redirected to the launch endpoint will be sent with a
workstation and project query parameter containing the full
workstation resource name and project ID, respectively. The launch
endpoint is responsible for starting the workstation, polling it until it
reaches STATE_RUNNING, and then issuing a redirect to the workstation's
host URL.
Optional.
Implementation
core.String? workstationLaunchUrl;