WorkstationPersistentDirectory class

A directory to persist across workstation sessions.

Updates to this field will only take effect on this workstation after it is restarted.

Properties

hashCode int
The hash code for this object.
no setterinherited
mountPath String?
The mount path of the persistent directory.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeGb int?
Size of the persistent directory in GB.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited