VideoStat class
A VideoStat resource represents a YouTube video's stats.
Constructors
- VideoStat({VideoStatsContentDetails? contentDetails, String? etag, String? id, String? kind, VideoStatsSnippet? snippet, VideoStatsStatistics? statistics})
- VideoStat.fromJson(Map json_)
Properties
- contentDetails ↔ VideoStatsContentDetails?
-
The VideoStatsContentDetails object contains information about the video
content, including the length of the video.
getter/setter pair
- etag ↔ String?
-
Etag of this resource.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
The ID that YouTube uses to uniquely identify the video.
getter/setter pair
- kind ↔ String?
-
Identifies what kind of resource this is.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- snippet ↔ VideoStatsSnippet?
-
The VideoStatsSnippet object contains basic details about the video, such
publish time.
getter/setter pair
- statistics ↔ VideoStatsStatistics?
-
The VideoStatsStatistics object contains statistics about the video.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited