VideoStatsSnippet class
Basic details about a video.
This is a subset of the information in VideoSnippet specifically for the Videos.stats API.
Constructors
- VideoStatsSnippet({String? publishTime})
- VideoStatsSnippet.fromJson(Map json_)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- publishTime ↔ String?
-
The date and time that the video was uploaded.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited